Class: Aws::SecurityHub::Types::AccountFreeTrialStatus

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

The free trial status of each Security Hub feature for an account.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#account_idString

The Amazon Web Services account identifier that the free trial statuses apply to.

Returns:

  • (String)


218
219
220
221
222
223
224
# File 'lib/aws-sdk-securityhub/types.rb', line 218

class AccountFreeTrialStatus < Struct.new(
  :account_id,
  :evaluated_at,
  :free_trial_statuses)
  SENSITIVE = []
  include Aws::Structure
end

#evaluated_atTime

The date and time at which Security Hub evaluated the free trial statuses for this account. Every status in FreeTrialStatuses reflects this point in time.

Returns:

  • (Time)


218
219
220
221
222
223
224
# File 'lib/aws-sdk-securityhub/types.rb', line 218

class AccountFreeTrialStatus < Struct.new(
  :account_id,
  :evaluated_at,
  :free_trial_statuses)
  SENSITIVE = []
  include Aws::Structure
end

#free_trial_statusesArray<Types::FreeTrialStatus>

An array of free trial statuses, one for each feature that has a free trial period for the account. The array is empty if the account has no free trial to report.

Returns:



218
219
220
221
222
223
224
# File 'lib/aws-sdk-securityhub/types.rb', line 218

class AccountFreeTrialStatus < Struct.new(
  :account_id,
  :evaluated_at,
  :free_trial_statuses)
  SENSITIVE = []
  include Aws::Structure
end