Class: Aws::SecurityHub::Types::Actor

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

Information about the threat actor identified in an Amazon GuardDuty Extended Threat Detection attack sequence. GuardDuty generates an attack sequence finding when multiple events align to a potentially suspicious activity. To receive GuardDuty attack sequence findings in Security Hub CSPM, you must have GuardDuty enabled. For more information, see GuardDuty Extended Threat Detection in the Amazon GuardDuty User Guide.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#idString

The ID of the threat actor.

Returns:

  • (String)


401
402
403
404
405
406
407
# File 'lib/aws-sdk-securityhub/types.rb', line 401

class Actor < Struct.new(
  :id,
  :user,
  :session)
  SENSITIVE = []
  include Aws::Structure
end

#sessionTypes::ActorSession

Contains information about the user session where the activity initiated.

Returns:



401
402
403
404
405
406
407
# File 'lib/aws-sdk-securityhub/types.rb', line 401

class Actor < Struct.new(
  :id,
  :user,
  :session)
  SENSITIVE = []
  include Aws::Structure
end

#userTypes::ActorUser

Contains information about the user credentials used by the threat actor.

Returns:



401
402
403
404
405
406
407
# File 'lib/aws-sdk-securityhub/types.rb', line 401

class Actor < Struct.new(
  :id,
  :user,
  :session)
  SENSITIVE = []
  include Aws::Structure
end