Class: Aws::SecurityHub::Types::ActorSession

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

Contains information about the authenticated session used by the threat actor identified in an Amazon GuardDuty Extended Threat Detection attack sequence. GuardDuty generates an attack sequence finding when multiple events align to a potentially suspicious activity. To receive GuardDuty attack sequence findings in Security Hub CSPM, you must have GuardDuty enabled. For more information, see GuardDuty Extended Threat Detection in the Amazon GuardDuty User Guide.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#created_timeInteger

The timestamp for when the session was created.

In CloudTrail, you can find this value as userIdentity.sessionContext.attributes.creationDate.

Returns:

  • (Integer)


450
451
452
453
454
455
456
457
# File 'lib/aws-sdk-securityhub/types.rb', line 450

class ActorSession < Struct.new(
  :uid,
  :mfa_status,
  :created_time,
  :issuer)
  SENSITIVE = []
  include Aws::Structure
end

#issuerString

The issuer of the session.

In CloudTrail, you can find this value as userIdentity.sessionContext.sessionIssuer.arn.

Returns:

  • (String)


450
451
452
453
454
455
456
457
# File 'lib/aws-sdk-securityhub/types.rb', line 450

class ActorSession < Struct.new(
  :uid,
  :mfa_status,
  :created_time,
  :issuer)
  SENSITIVE = []
  include Aws::Structure
end

#mfa_statusString

Indicates whether multi-factor authentication (MFA) was used for authentication during the session.

In CloudTrail, you can find this value as userIdentity.sessionContext.attributes.mfaAuthenticated.

Returns:

  • (String)


450
451
452
453
454
455
456
457
# File 'lib/aws-sdk-securityhub/types.rb', line 450

class ActorSession < Struct.new(
  :uid,
  :mfa_status,
  :created_time,
  :issuer)
  SENSITIVE = []
  include Aws::Structure
end

#uidString

Unique identifier of the session.

Returns:

  • (String)


450
451
452
453
454
455
456
457
# File 'lib/aws-sdk-securityhub/types.rb', line 450

class ActorSession < Struct.new(
  :uid,
  :mfa_status,
  :created_time,
  :issuer)
  SENSITIVE = []
  include Aws::Structure
end