Class: Aws::SecurityHub::Types::ActorUser

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

Contains information about the credentials used by the threat actor identified in an Amazon GuardDuty Extended Threat Detection attack sequence. GuardDuty generates an attack sequence finding when multiple events align to a potentially suspicious activity. To receive GuardDuty attack sequence findings in Security Hub CSPM, you must have GuardDuty enabled. For more information, see GuardDuty Extended Threat Detection in the Amazon GuardDuty User Guide.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#accountTypes::UserAccount

The account of the threat actor.

Returns:



522
523
524
525
526
527
528
529
530
# File 'lib/aws-sdk-securityhub/types.rb', line 522

class ActorUser < Struct.new(
  :name,
  :uid,
  :type,
  :credential_uid,
  :account)
  SENSITIVE = []
  include Aws::Structure
end

#credential_uidString

Unique identifier of the threat actor’s user credentials.

Returns:

  • (String)


522
523
524
525
526
527
528
529
530
# File 'lib/aws-sdk-securityhub/types.rb', line 522

class ActorUser < Struct.new(
  :name,
  :uid,
  :type,
  :credential_uid,
  :account)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the threat actor.

Returns:

  • (String)


522
523
524
525
526
527
528
529
530
# File 'lib/aws-sdk-securityhub/types.rb', line 522

class ActorUser < Struct.new(
  :name,
  :uid,
  :type,
  :credential_uid,
  :account)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The type of user.

Returns:

  • (String)


522
523
524
525
526
527
528
529
530
# File 'lib/aws-sdk-securityhub/types.rb', line 522

class ActorUser < Struct.new(
  :name,
  :uid,
  :type,
  :credential_uid,
  :account)
  SENSITIVE = []
  include Aws::Structure
end

#uidString

The unique identifier of the threat actor.

Returns:

  • (String)


522
523
524
525
526
527
528
529
530
# File 'lib/aws-sdk-securityhub/types.rb', line 522

class ActorUser < Struct.new(
  :name,
  :uid,
  :type,
  :credential_uid,
  :account)
  SENSITIVE = []
  include Aws::Structure
end