Class: Aws::SecurityHub::Types::AdminAccount

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

Represents a Security Hub CSPM administrator account designated by an organization management account.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#account_idString

The Amazon Web Services account identifier of the Security Hub CSPM administrator account.

Returns:

  • (String)


538
539
540
541
542
543
# File 'lib/aws-sdk-securityhub/types.rb', line 538

class AdminAccount < Struct.new(
  :account_id,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The current status of the Security Hub CSPM administrator account. Indicates whether the account is currently enabled as a Security Hub CSPM administrator.

Returns:

  • (String)


538
539
540
541
542
543
# File 'lib/aws-sdk-securityhub/types.rb', line 538

class AdminAccount < Struct.new(
  :account_id,
  :status)
  SENSITIVE = []
  include Aws::Structure
end