Method: Aws::SecurityHub::Types::AutomationRulesConfig#actions
- Defined in:
- lib/aws-sdk-securityhub/types.rb
#actions ⇒ Array<Types::AutomationRulesAction>
One or more actions to update finding fields if a finding matches the defined criteria of the rule.
716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 |
# File 'lib/aws-sdk-securityhub/types.rb', line 716 class AutomationRulesConfig < Struct.new( :rule_arn, :rule_status, :rule_order, :rule_name, :description, :is_terminal, :criteria, :actions, :created_at, :updated_at, :created_by) SENSITIVE = [] include Aws::Structure end |