Class: Aws::SecurityHub::Types::AutomationRulesMetadata

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

Metadata for automation rules in the calling account. The response includes rules with a RuleStatus of ENABLED and DISABLED.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#created_atTime

A timestamp that indicates when the rule was created.

For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.

Returns:

  • (Time)


1410
1411
1412
1413
1414
1415
1416
1417
1418
1419
1420
1421
1422
# File 'lib/aws-sdk-securityhub/types.rb', line 1410

class AutomationRulesMetadata < Struct.new(
  :rule_arn,
  :rule_status,
  :rule_order,
  :rule_name,
  :description,
  :is_terminal,
  :created_at,
  :updated_at,
  :created_by)
  SENSITIVE = []
  include Aws::Structure
end

#created_byString

The principal that created a rule.

Returns:

  • (String)


1410
1411
1412
1413
1414
1415
1416
1417
1418
1419
1420
1421
1422
# File 'lib/aws-sdk-securityhub/types.rb', line 1410

class AutomationRulesMetadata < Struct.new(
  :rule_arn,
  :rule_status,
  :rule_order,
  :rule_name,
  :description,
  :is_terminal,
  :created_at,
  :updated_at,
  :created_by)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A description of the rule.

Returns:

  • (String)


1410
1411
1412
1413
1414
1415
1416
1417
1418
1419
1420
1421
1422
# File 'lib/aws-sdk-securityhub/types.rb', line 1410

class AutomationRulesMetadata < Struct.new(
  :rule_arn,
  :rule_status,
  :rule_order,
  :rule_name,
  :description,
  :is_terminal,
  :created_at,
  :updated_at,
  :created_by)
  SENSITIVE = []
  include Aws::Structure
end

#is_terminalBoolean

Specifies whether a rule is the last to be applied with respect to a finding that matches the rule criteria. This is useful when a finding matches the criteria for multiple rules, and each rule has different actions. If a rule is terminal, Security Hub CSPM applies the rule action to a finding that matches the rule criteria and doesn't evaluate other rules for the finding. By default, a rule isn't terminal.

Returns:

  • (Boolean)


1410
1411
1412
1413
1414
1415
1416
1417
1418
1419
1420
1421
1422
# File 'lib/aws-sdk-securityhub/types.rb', line 1410

class AutomationRulesMetadata < Struct.new(
  :rule_arn,
  :rule_status,
  :rule_order,
  :rule_name,
  :description,
  :is_terminal,
  :created_at,
  :updated_at,
  :created_by)
  SENSITIVE = []
  include Aws::Structure
end

#rule_arnString

The Amazon Resource Name (ARN) for the rule.

Returns:

  • (String)


1410
1411
1412
1413
1414
1415
1416
1417
1418
1419
1420
1421
1422
# File 'lib/aws-sdk-securityhub/types.rb', line 1410

class AutomationRulesMetadata < Struct.new(
  :rule_arn,
  :rule_status,
  :rule_order,
  :rule_name,
  :description,
  :is_terminal,
  :created_at,
  :updated_at,
  :created_by)
  SENSITIVE = []
  include Aws::Structure
end

#rule_nameString

The name of the rule.

Returns:

  • (String)


1410
1411
1412
1413
1414
1415
1416
1417
1418
1419
1420
1421
1422
# File 'lib/aws-sdk-securityhub/types.rb', line 1410

class AutomationRulesMetadata < Struct.new(
  :rule_arn,
  :rule_status,
  :rule_order,
  :rule_name,
  :description,
  :is_terminal,
  :created_at,
  :updated_at,
  :created_by)
  SENSITIVE = []
  include Aws::Structure
end

#rule_orderInteger

An integer ranging from 1 to 1000 that represents the order in which the rule action is applied to findings. Security Hub CSPM applies rules with lower values for this parameter first.

Returns:

  • (Integer)


1410
1411
1412
1413
1414
1415
1416
1417
1418
1419
1420
1421
1422
# File 'lib/aws-sdk-securityhub/types.rb', line 1410

class AutomationRulesMetadata < Struct.new(
  :rule_arn,
  :rule_status,
  :rule_order,
  :rule_name,
  :description,
  :is_terminal,
  :created_at,
  :updated_at,
  :created_by)
  SENSITIVE = []
  include Aws::Structure
end

#rule_statusString

Whether the rule is active after it is created. If this parameter is equal to ENABLED, Security Hub CSPM starts applying the rule to findings and finding updates after the rule is created. To change the value of this parameter after creating a rule, use BatchUpdateAutomationRules .

Returns:

  • (String)


1410
1411
1412
1413
1414
1415
1416
1417
1418
1419
1420
1421
1422
# File 'lib/aws-sdk-securityhub/types.rb', line 1410

class AutomationRulesMetadata < Struct.new(
  :rule_arn,
  :rule_status,
  :rule_order,
  :rule_name,
  :description,
  :is_terminal,
  :created_at,
  :updated_at,
  :created_by)
  SENSITIVE = []
  include Aws::Structure
end

#updated_atTime

A timestamp that indicates when the rule was most recently updated.

For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.

Returns:

  • (Time)


1410
1411
1412
1413
1414
1415
1416
1417
1418
1419
1420
1421
1422
# File 'lib/aws-sdk-securityhub/types.rb', line 1410

class AutomationRulesMetadata < Struct.new(
  :rule_arn,
  :rule_status,
  :rule_order,
  :rule_name,
  :description,
  :is_terminal,
  :created_at,
  :updated_at,
  :created_by)
  SENSITIVE = []
  include Aws::Structure
end