Class: Aws::SecurityHub::Types::AwsAmazonMqBrokerDetails

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

Provides details about an Amazon MQ message broker. A message broker allows software applications and components to communicate using various programming languages, operating systems, and formal messaging protocols.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#authentication_strategyString

The authentication strategy used to secure the broker. The default is SIMPLE.

Returns:

  • (String)


1461
1462
1463
1464
1465
1466
1467
1468
1469
1470
1471
1472
1473
1474
1475
1476
1477
1478
1479
1480
1481
1482
# File 'lib/aws-sdk-securityhub/types.rb', line 1461

class AwsAmazonMqBrokerDetails < Struct.new(
  :authentication_strategy,
  :auto_minor_version_upgrade,
  :broker_arn,
  :broker_name,
  :deployment_mode,
  :encryption_options,
  :engine_type,
  :engine_version,
  :host_instance_type,
  :broker_id,
  :ldap_server_metadata,
  :logs,
  :maintenance_window_start_time,
  :publicly_accessible,
  :security_groups,
  :storage_type,
  :subnet_ids,
  :users)
  SENSITIVE = []
  include Aws::Structure
end

#auto_minor_version_upgradeBoolean

Whether automatically upgrade new minor versions for brokers, as new versions are released and supported by Amazon MQ. Automatic upgrades occur during the scheduled maintenance window of the broker or after a manual broker reboot.

Returns:

  • (Boolean)


1461
1462
1463
1464
1465
1466
1467
1468
1469
1470
1471
1472
1473
1474
1475
1476
1477
1478
1479
1480
1481
1482
# File 'lib/aws-sdk-securityhub/types.rb', line 1461

class AwsAmazonMqBrokerDetails < Struct.new(
  :authentication_strategy,
  :auto_minor_version_upgrade,
  :broker_arn,
  :broker_name,
  :deployment_mode,
  :encryption_options,
  :engine_type,
  :engine_version,
  :host_instance_type,
  :broker_id,
  :ldap_server_metadata,
  :logs,
  :maintenance_window_start_time,
  :publicly_accessible,
  :security_groups,
  :storage_type,
  :subnet_ids,
  :users)
  SENSITIVE = []
  include Aws::Structure
end

#broker_arnString

The Amazon Resource Name (ARN) of the broker.

Returns:

  • (String)


1461
1462
1463
1464
1465
1466
1467
1468
1469
1470
1471
1472
1473
1474
1475
1476
1477
1478
1479
1480
1481
1482
# File 'lib/aws-sdk-securityhub/types.rb', line 1461

class AwsAmazonMqBrokerDetails < Struct.new(
  :authentication_strategy,
  :auto_minor_version_upgrade,
  :broker_arn,
  :broker_name,
  :deployment_mode,
  :encryption_options,
  :engine_type,
  :engine_version,
  :host_instance_type,
  :broker_id,
  :ldap_server_metadata,
  :logs,
  :maintenance_window_start_time,
  :publicly_accessible,
  :security_groups,
  :storage_type,
  :subnet_ids,
  :users)
  SENSITIVE = []
  include Aws::Structure
end

#broker_idString

The unique ID that Amazon MQ generates for the broker.

Returns:

  • (String)


1461
1462
1463
1464
1465
1466
1467
1468
1469
1470
1471
1472
1473
1474
1475
1476
1477
1478
1479
1480
1481
1482
# File 'lib/aws-sdk-securityhub/types.rb', line 1461

class AwsAmazonMqBrokerDetails < Struct.new(
  :authentication_strategy,
  :auto_minor_version_upgrade,
  :broker_arn,
  :broker_name,
  :deployment_mode,
  :encryption_options,
  :engine_type,
  :engine_version,
  :host_instance_type,
  :broker_id,
  :ldap_server_metadata,
  :logs,
  :maintenance_window_start_time,
  :publicly_accessible,
  :security_groups,
  :storage_type,
  :subnet_ids,
  :users)
  SENSITIVE = []
  include Aws::Structure
end

#broker_nameString

The broker's name.

Returns:

  • (String)


1461
1462
1463
1464
1465
1466
1467
1468
1469
1470
1471
1472
1473
1474
1475
1476
1477
1478
1479
1480
1481
1482
# File 'lib/aws-sdk-securityhub/types.rb', line 1461

class AwsAmazonMqBrokerDetails < Struct.new(
  :authentication_strategy,
  :auto_minor_version_upgrade,
  :broker_arn,
  :broker_name,
  :deployment_mode,
  :encryption_options,
  :engine_type,
  :engine_version,
  :host_instance_type,
  :broker_id,
  :ldap_server_metadata,
  :logs,
  :maintenance_window_start_time,
  :publicly_accessible,
  :security_groups,
  :storage_type,
  :subnet_ids,
  :users)
  SENSITIVE = []
  include Aws::Structure
end

#deployment_modeString

The broker's deployment mode.

Returns:

  • (String)


1461
1462
1463
1464
1465
1466
1467
1468
1469
1470
1471
1472
1473
1474
1475
1476
1477
1478
1479
1480
1481
1482
# File 'lib/aws-sdk-securityhub/types.rb', line 1461

class AwsAmazonMqBrokerDetails < Struct.new(
  :authentication_strategy,
  :auto_minor_version_upgrade,
  :broker_arn,
  :broker_name,
  :deployment_mode,
  :encryption_options,
  :engine_type,
  :engine_version,
  :host_instance_type,
  :broker_id,
  :ldap_server_metadata,
  :logs,
  :maintenance_window_start_time,
  :publicly_accessible,
  :security_groups,
  :storage_type,
  :subnet_ids,
  :users)
  SENSITIVE = []
  include Aws::Structure
end

#encryption_optionsTypes::AwsAmazonMqBrokerEncryptionOptionsDetails

Encryption options for the broker. Doesn’t apply to RabbitMQ brokers.



1461
1462
1463
1464
1465
1466
1467
1468
1469
1470
1471
1472
1473
1474
1475
1476
1477
1478
1479
1480
1481
1482
# File 'lib/aws-sdk-securityhub/types.rb', line 1461

class AwsAmazonMqBrokerDetails < Struct.new(
  :authentication_strategy,
  :auto_minor_version_upgrade,
  :broker_arn,
  :broker_name,
  :deployment_mode,
  :encryption_options,
  :engine_type,
  :engine_version,
  :host_instance_type,
  :broker_id,
  :ldap_server_metadata,
  :logs,
  :maintenance_window_start_time,
  :publicly_accessible,
  :security_groups,
  :storage_type,
  :subnet_ids,
  :users)
  SENSITIVE = []
  include Aws::Structure
end

#engine_typeString

The type of broker engine.

Returns:

  • (String)


1461
1462
1463
1464
1465
1466
1467
1468
1469
1470
1471
1472
1473
1474
1475
1476
1477
1478
1479
1480
1481
1482
# File 'lib/aws-sdk-securityhub/types.rb', line 1461

class AwsAmazonMqBrokerDetails < Struct.new(
  :authentication_strategy,
  :auto_minor_version_upgrade,
  :broker_arn,
  :broker_name,
  :deployment_mode,
  :encryption_options,
  :engine_type,
  :engine_version,
  :host_instance_type,
  :broker_id,
  :ldap_server_metadata,
  :logs,
  :maintenance_window_start_time,
  :publicly_accessible,
  :security_groups,
  :storage_type,
  :subnet_ids,
  :users)
  SENSITIVE = []
  include Aws::Structure
end

#engine_versionString

The version of the broker engine.

Returns:

  • (String)


1461
1462
1463
1464
1465
1466
1467
1468
1469
1470
1471
1472
1473
1474
1475
1476
1477
1478
1479
1480
1481
1482
# File 'lib/aws-sdk-securityhub/types.rb', line 1461

class AwsAmazonMqBrokerDetails < Struct.new(
  :authentication_strategy,
  :auto_minor_version_upgrade,
  :broker_arn,
  :broker_name,
  :deployment_mode,
  :encryption_options,
  :engine_type,
  :engine_version,
  :host_instance_type,
  :broker_id,
  :ldap_server_metadata,
  :logs,
  :maintenance_window_start_time,
  :publicly_accessible,
  :security_groups,
  :storage_type,
  :subnet_ids,
  :users)
  SENSITIVE = []
  include Aws::Structure
end

#host_instance_typeString

The broker's instance type.

Returns:

  • (String)


1461
1462
1463
1464
1465
1466
1467
1468
1469
1470
1471
1472
1473
1474
1475
1476
1477
1478
1479
1480
1481
1482
# File 'lib/aws-sdk-securityhub/types.rb', line 1461

class AwsAmazonMqBrokerDetails < Struct.new(
  :authentication_strategy,
  :auto_minor_version_upgrade,
  :broker_arn,
  :broker_name,
  :deployment_mode,
  :encryption_options,
  :engine_type,
  :engine_version,
  :host_instance_type,
  :broker_id,
  :ldap_server_metadata,
  :logs,
  :maintenance_window_start_time,
  :publicly_accessible,
  :security_groups,
  :storage_type,
  :subnet_ids,
  :users)
  SENSITIVE = []
  include Aws::Structure
end

#ldap_server_metadataTypes::AwsAmazonMqBrokerLdapServerMetadataDetails

The metadata of the Lightweight Directory Access Protocol (LDAP) server used to authenticate and authorize connections to the broker. This is an optional failover server.



1461
1462
1463
1464
1465
1466
1467
1468
1469
1470
1471
1472
1473
1474
1475
1476
1477
1478
1479
1480
1481
1482
# File 'lib/aws-sdk-securityhub/types.rb', line 1461

class AwsAmazonMqBrokerDetails < Struct.new(
  :authentication_strategy,
  :auto_minor_version_upgrade,
  :broker_arn,
  :broker_name,
  :deployment_mode,
  :encryption_options,
  :engine_type,
  :engine_version,
  :host_instance_type,
  :broker_id,
  :ldap_server_metadata,
  :logs,
  :maintenance_window_start_time,
  :publicly_accessible,
  :security_groups,
  :storage_type,
  :subnet_ids,
  :users)
  SENSITIVE = []
  include Aws::Structure
end

#logsTypes::AwsAmazonMqBrokerLogsDetails

Turns on Amazon CloudWatch logging for brokers.



1461
1462
1463
1464
1465
1466
1467
1468
1469
1470
1471
1472
1473
1474
1475
1476
1477
1478
1479
1480
1481
1482
# File 'lib/aws-sdk-securityhub/types.rb', line 1461

class AwsAmazonMqBrokerDetails < Struct.new(
  :authentication_strategy,
  :auto_minor_version_upgrade,
  :broker_arn,
  :broker_name,
  :deployment_mode,
  :encryption_options,
  :engine_type,
  :engine_version,
  :host_instance_type,
  :broker_id,
  :ldap_server_metadata,
  :logs,
  :maintenance_window_start_time,
  :publicly_accessible,
  :security_groups,
  :storage_type,
  :subnet_ids,
  :users)
  SENSITIVE = []
  include Aws::Structure
end

#maintenance_window_start_timeTypes::AwsAmazonMqBrokerMaintenanceWindowStartTimeDetails

The scheduled time period (UTC) during which Amazon MQ begins to apply pending updates or patches to the broker.



1461
1462
1463
1464
1465
1466
1467
1468
1469
1470
1471
1472
1473
1474
1475
1476
1477
1478
1479
1480
1481
1482
# File 'lib/aws-sdk-securityhub/types.rb', line 1461

class AwsAmazonMqBrokerDetails < Struct.new(
  :authentication_strategy,
  :auto_minor_version_upgrade,
  :broker_arn,
  :broker_name,
  :deployment_mode,
  :encryption_options,
  :engine_type,
  :engine_version,
  :host_instance_type,
  :broker_id,
  :ldap_server_metadata,
  :logs,
  :maintenance_window_start_time,
  :publicly_accessible,
  :security_groups,
  :storage_type,
  :subnet_ids,
  :users)
  SENSITIVE = []
  include Aws::Structure
end

#publicly_accessibleBoolean

Permits connections from applications outside of the VPC that hosts the broker's subnets.

Returns:

  • (Boolean)


1461
1462
1463
1464
1465
1466
1467
1468
1469
1470
1471
1472
1473
1474
1475
1476
1477
1478
1479
1480
1481
1482
# File 'lib/aws-sdk-securityhub/types.rb', line 1461

class AwsAmazonMqBrokerDetails < Struct.new(
  :authentication_strategy,
  :auto_minor_version_upgrade,
  :broker_arn,
  :broker_name,
  :deployment_mode,
  :encryption_options,
  :engine_type,
  :engine_version,
  :host_instance_type,
  :broker_id,
  :ldap_server_metadata,
  :logs,
  :maintenance_window_start_time,
  :publicly_accessible,
  :security_groups,
  :storage_type,
  :subnet_ids,
  :users)
  SENSITIVE = []
  include Aws::Structure
end

#security_groupsArray<String>

The list of rules (one minimum, 125 maximum) that authorize connections to brokers.

Returns:

  • (Array<String>)


1461
1462
1463
1464
1465
1466
1467
1468
1469
1470
1471
1472
1473
1474
1475
1476
1477
1478
1479
1480
1481
1482
# File 'lib/aws-sdk-securityhub/types.rb', line 1461

class AwsAmazonMqBrokerDetails < Struct.new(
  :authentication_strategy,
  :auto_minor_version_upgrade,
  :broker_arn,
  :broker_name,
  :deployment_mode,
  :encryption_options,
  :engine_type,
  :engine_version,
  :host_instance_type,
  :broker_id,
  :ldap_server_metadata,
  :logs,
  :maintenance_window_start_time,
  :publicly_accessible,
  :security_groups,
  :storage_type,
  :subnet_ids,
  :users)
  SENSITIVE = []
  include Aws::Structure
end

#storage_typeString

The broker's storage type.

Returns:

  • (String)


1461
1462
1463
1464
1465
1466
1467
1468
1469
1470
1471
1472
1473
1474
1475
1476
1477
1478
1479
1480
1481
1482
# File 'lib/aws-sdk-securityhub/types.rb', line 1461

class AwsAmazonMqBrokerDetails < Struct.new(
  :authentication_strategy,
  :auto_minor_version_upgrade,
  :broker_arn,
  :broker_name,
  :deployment_mode,
  :encryption_options,
  :engine_type,
  :engine_version,
  :host_instance_type,
  :broker_id,
  :ldap_server_metadata,
  :logs,
  :maintenance_window_start_time,
  :publicly_accessible,
  :security_groups,
  :storage_type,
  :subnet_ids,
  :users)
  SENSITIVE = []
  include Aws::Structure
end

#subnet_idsArray<String>

The list of groups that define which subnets and IP ranges the broker can use from different Availability Zones.

Returns:

  • (Array<String>)


1461
1462
1463
1464
1465
1466
1467
1468
1469
1470
1471
1472
1473
1474
1475
1476
1477
1478
1479
1480
1481
1482
# File 'lib/aws-sdk-securityhub/types.rb', line 1461

class AwsAmazonMqBrokerDetails < Struct.new(
  :authentication_strategy,
  :auto_minor_version_upgrade,
  :broker_arn,
  :broker_name,
  :deployment_mode,
  :encryption_options,
  :engine_type,
  :engine_version,
  :host_instance_type,
  :broker_id,
  :ldap_server_metadata,
  :logs,
  :maintenance_window_start_time,
  :publicly_accessible,
  :security_groups,
  :storage_type,
  :subnet_ids,
  :users)
  SENSITIVE = []
  include Aws::Structure
end

#usersArray<Types::AwsAmazonMqBrokerUsersDetails>

The list of all broker usernames for the specified broker. Doesn't apply to RabbitMQ brokers.



1461
1462
1463
1464
1465
1466
1467
1468
1469
1470
1471
1472
1473
1474
1475
1476
1477
1478
1479
1480
1481
1482
# File 'lib/aws-sdk-securityhub/types.rb', line 1461

class AwsAmazonMqBrokerDetails < Struct.new(
  :authentication_strategy,
  :auto_minor_version_upgrade,
  :broker_arn,
  :broker_name,
  :deployment_mode,
  :encryption_options,
  :engine_type,
  :engine_version,
  :host_instance_type,
  :broker_id,
  :ldap_server_metadata,
  :logs,
  :maintenance_window_start_time,
  :publicly_accessible,
  :security_groups,
  :storage_type,
  :subnet_ids,
  :users)
  SENSITIVE = []
  include Aws::Structure
end