Class: Aws::SecurityHub::Types::AwsApiCallAction

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

Provided if ActionType is AWS_API_CALL. It provides details about the API call that was detected.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#affected_resourcesHash<String,String>

Identifies the resources that were affected by the API call.

Returns:



1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
1883
1884
# File 'lib/aws-sdk-securityhub/types.rb', line 1873

class AwsApiCallAction < Struct.new(
  :api,
  :service_name,
  :caller_type,
  :remote_ip_details,
  :domain_details,
  :affected_resources,
  :first_seen,
  :last_seen)
  SENSITIVE = []
  include Aws::Structure
end

#apiString

The name of the API method that was issued.

Length Constraints: 128.

Returns:



1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
1883
1884
# File 'lib/aws-sdk-securityhub/types.rb', line 1873

class AwsApiCallAction < Struct.new(
  :api,
  :service_name,
  :caller_type,
  :remote_ip_details,
  :domain_details,
  :affected_resources,
  :first_seen,
  :last_seen)
  SENSITIVE = []
  include Aws::Structure
end

#caller_typeString

Indicates whether the API call originated from a remote IP address (remoteip) or from a DNS domain (domain).

Returns:



1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
1883
1884
# File 'lib/aws-sdk-securityhub/types.rb', line 1873

class AwsApiCallAction < Struct.new(
  :api,
  :service_name,
  :caller_type,
  :remote_ip_details,
  :domain_details,
  :affected_resources,
  :first_seen,
  :last_seen)
  SENSITIVE = []
  include Aws::Structure
end

#domain_detailsTypes::AwsApiCallActionDomainDetails

Provided if CallerType is domain. Provides information about the DNS domain that the API call originated from.

Returns:



1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
1883
1884
# File 'lib/aws-sdk-securityhub/types.rb', line 1873

class AwsApiCallAction < Struct.new(
  :api,
  :service_name,
  :caller_type,
  :remote_ip_details,
  :domain_details,
  :affected_resources,
  :first_seen,
  :last_seen)
  SENSITIVE = []
  include Aws::Structure
end

#first_seenString

A timestamp that indicates when the API call was first observed.

For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.

Returns:



1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
1883
1884
# File 'lib/aws-sdk-securityhub/types.rb', line 1873

class AwsApiCallAction < Struct.new(
  :api,
  :service_name,
  :caller_type,
  :remote_ip_details,
  :domain_details,
  :affected_resources,
  :first_seen,
  :last_seen)
  SENSITIVE = []
  include Aws::Structure
end

#last_seenString

A timestamp that indicates when the API call was most recently observed.

For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.

Returns:



1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
1883
1884
# File 'lib/aws-sdk-securityhub/types.rb', line 1873

class AwsApiCallAction < Struct.new(
  :api,
  :service_name,
  :caller_type,
  :remote_ip_details,
  :domain_details,
  :affected_resources,
  :first_seen,
  :last_seen)
  SENSITIVE = []
  include Aws::Structure
end

#remote_ip_detailsTypes::ActionRemoteIpDetails

Provided if CallerType is remoteip. Provides information about the remote IP address that the API call originated from.

Returns:



1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
1883
1884
# File 'lib/aws-sdk-securityhub/types.rb', line 1873

class AwsApiCallAction < Struct.new(
  :api,
  :service_name,
  :caller_type,
  :remote_ip_details,
  :domain_details,
  :affected_resources,
  :first_seen,
  :last_seen)
  SENSITIVE = []
  include Aws::Structure
end

#service_nameString

The name of the Amazon Web Services service that the API method belongs to.

Length Constraints: 128.

Returns:



1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
1883
1884
# File 'lib/aws-sdk-securityhub/types.rb', line 1873

class AwsApiCallAction < Struct.new(
  :api,
  :service_name,
  :caller_type,
  :remote_ip_details,
  :domain_details,
  :affected_resources,
  :first_seen,
  :last_seen)
  SENSITIVE = []
  include Aws::Structure
end