Class: Aws::SecurityHub::Types::AwsApiGatewayAccessLogSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::AwsApiGatewayAccessLogSettings
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Contains information about settings for logging access for the stage.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#destination_arn ⇒ String
The ARN of the CloudWatch Logs log group that receives the access logs.
-
#format ⇒ String
A single-line format of the access logs of data, as specified by selected
$contextvariables.
Instance Attribute Details
#destination_arn ⇒ String
The ARN of the CloudWatch Logs log group that receives the access logs.
1788 1789 1790 1791 1792 1793 |
# File 'lib/aws-sdk-securityhub/types.rb', line 1788 class AwsApiGatewayAccessLogSettings < Struct.new( :format, :destination_arn) SENSITIVE = [] include Aws::Structure end |
#format ⇒ String
A single-line format of the access logs of data, as specified by
selected $context variables. The format must include at least
$context.requestId.
1788 1789 1790 1791 1792 1793 |
# File 'lib/aws-sdk-securityhub/types.rb', line 1788 class AwsApiGatewayAccessLogSettings < Struct.new( :format, :destination_arn) SENSITIVE = [] include Aws::Structure end |