Class: Aws::SecurityHub::Types::AwsApiGatewayMethodSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::AwsApiGatewayMethodSettings
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Defines settings for a method for the stage.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cache_data_encrypted ⇒ Boolean
Indicates whether the cached responses are encrypted.
-
#cache_ttl_in_seconds ⇒ Integer
Specifies the time to live (TTL), in seconds, for cached responses.
-
#caching_enabled ⇒ Boolean
Indicates whether responses are cached and returned for requests.
-
#data_trace_enabled ⇒ Boolean
Indicates whether data trace logging is enabled for the method.
-
#http_method ⇒ String
The HTTP method.
-
#logging_level ⇒ String
The logging level for this method.
-
#metrics_enabled ⇒ Boolean
Indicates whether CloudWatch metrics are enabled for the method.
-
#require_authorization_for_cache_control ⇒ Boolean
Indicates whether authorization is required for a cache invalidation request.
-
#resource_path ⇒ String
The resource path for this method.
-
#throttling_burst_limit ⇒ Integer
The throttling burst limit for the method.
-
#throttling_rate_limit ⇒ Float
The throttling rate limit for the method.
-
#unauthorized_cache_control_header_strategy ⇒ String
Indicates how to handle unauthorized requests for cache invalidation.
Instance Attribute Details
#cache_data_encrypted ⇒ Boolean
Indicates whether the cached responses are encrypted.
2029 2030 2031 2032 2033 2034 2035 2036 2037 2038 2039 2040 2041 2042 2043 2044 |
# File 'lib/aws-sdk-securityhub/types.rb', line 2029 class AwsApiGatewayMethodSettings < Struct.new( :metrics_enabled, :logging_level, :data_trace_enabled, :throttling_burst_limit, :throttling_rate_limit, :caching_enabled, :cache_ttl_in_seconds, :cache_data_encrypted, :require_authorization_for_cache_control, :unauthorized_cache_control_header_strategy, :http_method, :resource_path) SENSITIVE = [] include Aws::Structure end |
#cache_ttl_in_seconds ⇒ Integer
Specifies the time to live (TTL), in seconds, for cached responses. The higher the TTL, the longer the response is cached.
2029 2030 2031 2032 2033 2034 2035 2036 2037 2038 2039 2040 2041 2042 2043 2044 |
# File 'lib/aws-sdk-securityhub/types.rb', line 2029 class AwsApiGatewayMethodSettings < Struct.new( :metrics_enabled, :logging_level, :data_trace_enabled, :throttling_burst_limit, :throttling_rate_limit, :caching_enabled, :cache_ttl_in_seconds, :cache_data_encrypted, :require_authorization_for_cache_control, :unauthorized_cache_control_header_strategy, :http_method, :resource_path) SENSITIVE = [] include Aws::Structure end |
#caching_enabled ⇒ Boolean
Indicates whether responses are cached and returned for requests. For responses to be cached, a cache cluster must be enabled on the stage.
2029 2030 2031 2032 2033 2034 2035 2036 2037 2038 2039 2040 2041 2042 2043 2044 |
# File 'lib/aws-sdk-securityhub/types.rb', line 2029 class AwsApiGatewayMethodSettings < Struct.new( :metrics_enabled, :logging_level, :data_trace_enabled, :throttling_burst_limit, :throttling_rate_limit, :caching_enabled, :cache_ttl_in_seconds, :cache_data_encrypted, :require_authorization_for_cache_control, :unauthorized_cache_control_header_strategy, :http_method, :resource_path) SENSITIVE = [] include Aws::Structure end |
#data_trace_enabled ⇒ Boolean
Indicates whether data trace logging is enabled for the method. Data trace logging affects the log entries that are pushed to CloudWatch Logs.
2029 2030 2031 2032 2033 2034 2035 2036 2037 2038 2039 2040 2041 2042 2043 2044 |
# File 'lib/aws-sdk-securityhub/types.rb', line 2029 class AwsApiGatewayMethodSettings < Struct.new( :metrics_enabled, :logging_level, :data_trace_enabled, :throttling_burst_limit, :throttling_rate_limit, :caching_enabled, :cache_ttl_in_seconds, :cache_data_encrypted, :require_authorization_for_cache_control, :unauthorized_cache_control_header_strategy, :http_method, :resource_path) SENSITIVE = [] include Aws::Structure end |
#http_method ⇒ String
The HTTP method. You can use an asterisk (*) as a wildcard to apply method settings to multiple methods.
2029 2030 2031 2032 2033 2034 2035 2036 2037 2038 2039 2040 2041 2042 2043 2044 |
# File 'lib/aws-sdk-securityhub/types.rb', line 2029 class AwsApiGatewayMethodSettings < Struct.new( :metrics_enabled, :logging_level, :data_trace_enabled, :throttling_burst_limit, :throttling_rate_limit, :caching_enabled, :cache_ttl_in_seconds, :cache_data_encrypted, :require_authorization_for_cache_control, :unauthorized_cache_control_header_strategy, :http_method, :resource_path) SENSITIVE = [] include Aws::Structure end |
#logging_level ⇒ String
The logging level for this method. The logging level affects the log entries that are pushed to CloudWatch Logs.
If the logging level is ERROR, then the logs only include
error-level entries.
If the logging level is INFO, then the logs include both ERROR
events and extra informational events.
Valid values: OFF | ERROR | INFO
2029 2030 2031 2032 2033 2034 2035 2036 2037 2038 2039 2040 2041 2042 2043 2044 |
# File 'lib/aws-sdk-securityhub/types.rb', line 2029 class AwsApiGatewayMethodSettings < Struct.new( :metrics_enabled, :logging_level, :data_trace_enabled, :throttling_burst_limit, :throttling_rate_limit, :caching_enabled, :cache_ttl_in_seconds, :cache_data_encrypted, :require_authorization_for_cache_control, :unauthorized_cache_control_header_strategy, :http_method, :resource_path) SENSITIVE = [] include Aws::Structure end |
#metrics_enabled ⇒ Boolean
Indicates whether CloudWatch metrics are enabled for the method.
2029 2030 2031 2032 2033 2034 2035 2036 2037 2038 2039 2040 2041 2042 2043 2044 |
# File 'lib/aws-sdk-securityhub/types.rb', line 2029 class AwsApiGatewayMethodSettings < Struct.new( :metrics_enabled, :logging_level, :data_trace_enabled, :throttling_burst_limit, :throttling_rate_limit, :caching_enabled, :cache_ttl_in_seconds, :cache_data_encrypted, :require_authorization_for_cache_control, :unauthorized_cache_control_header_strategy, :http_method, :resource_path) SENSITIVE = [] include Aws::Structure end |
#require_authorization_for_cache_control ⇒ Boolean
Indicates whether authorization is required for a cache invalidation request.
2029 2030 2031 2032 2033 2034 2035 2036 2037 2038 2039 2040 2041 2042 2043 2044 |
# File 'lib/aws-sdk-securityhub/types.rb', line 2029 class AwsApiGatewayMethodSettings < Struct.new( :metrics_enabled, :logging_level, :data_trace_enabled, :throttling_burst_limit, :throttling_rate_limit, :caching_enabled, :cache_ttl_in_seconds, :cache_data_encrypted, :require_authorization_for_cache_control, :unauthorized_cache_control_header_strategy, :http_method, :resource_path) SENSITIVE = [] include Aws::Structure end |
#resource_path ⇒ String
The resource path for this method. Forward slashes (/) are encoded as ~1 . The initial slash must include a forward slash.
For example, the path value /resource/subresource must be encoded
as /~1resource~1subresource.
To specify the root path, use only a slash (/). You can use an asterisk (*) as a wildcard to apply method settings to multiple methods.
2029 2030 2031 2032 2033 2034 2035 2036 2037 2038 2039 2040 2041 2042 2043 2044 |
# File 'lib/aws-sdk-securityhub/types.rb', line 2029 class AwsApiGatewayMethodSettings < Struct.new( :metrics_enabled, :logging_level, :data_trace_enabled, :throttling_burst_limit, :throttling_rate_limit, :caching_enabled, :cache_ttl_in_seconds, :cache_data_encrypted, :require_authorization_for_cache_control, :unauthorized_cache_control_header_strategy, :http_method, :resource_path) SENSITIVE = [] include Aws::Structure end |
#throttling_burst_limit ⇒ Integer
The throttling burst limit for the method.
2029 2030 2031 2032 2033 2034 2035 2036 2037 2038 2039 2040 2041 2042 2043 2044 |
# File 'lib/aws-sdk-securityhub/types.rb', line 2029 class AwsApiGatewayMethodSettings < Struct.new( :metrics_enabled, :logging_level, :data_trace_enabled, :throttling_burst_limit, :throttling_rate_limit, :caching_enabled, :cache_ttl_in_seconds, :cache_data_encrypted, :require_authorization_for_cache_control, :unauthorized_cache_control_header_strategy, :http_method, :resource_path) SENSITIVE = [] include Aws::Structure end |
#throttling_rate_limit ⇒ Float
The throttling rate limit for the method.
2029 2030 2031 2032 2033 2034 2035 2036 2037 2038 2039 2040 2041 2042 2043 2044 |
# File 'lib/aws-sdk-securityhub/types.rb', line 2029 class AwsApiGatewayMethodSettings < Struct.new( :metrics_enabled, :logging_level, :data_trace_enabled, :throttling_burst_limit, :throttling_rate_limit, :caching_enabled, :cache_ttl_in_seconds, :cache_data_encrypted, :require_authorization_for_cache_control, :unauthorized_cache_control_header_strategy, :http_method, :resource_path) SENSITIVE = [] include Aws::Structure end |
#unauthorized_cache_control_header_strategy ⇒ String
Indicates how to handle unauthorized requests for cache invalidation.
Valid values: FAIL_WITH_403 | SUCCEED_WITH_RESPONSE_HEADER |
SUCCEED_WITHOUT_RESPONSE_HEADER
2029 2030 2031 2032 2033 2034 2035 2036 2037 2038 2039 2040 2041 2042 2043 2044 |
# File 'lib/aws-sdk-securityhub/types.rb', line 2029 class AwsApiGatewayMethodSettings < Struct.new( :metrics_enabled, :logging_level, :data_trace_enabled, :throttling_burst_limit, :throttling_rate_limit, :caching_enabled, :cache_ttl_in_seconds, :cache_data_encrypted, :require_authorization_for_cache_control, :unauthorized_cache_control_header_strategy, :http_method, :resource_path) SENSITIVE = [] include Aws::Structure end |