Class: Aws::SecurityHub::Types::AwsApiGatewayRestApiDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::AwsApiGatewayRestApiDetails
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Contains information about a REST API in version 1 of Amazon API Gateway.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#api_key_source ⇒ String
The source of the API key for metering requests according to a usage plan.
-
#binary_media_types ⇒ Array<String>
The list of binary media types supported by the REST API.
-
#created_date ⇒ String
Indicates when the API was created.
-
#description ⇒ String
A description of the REST API.
-
#endpoint_configuration ⇒ Types::AwsApiGatewayEndpointConfiguration
The endpoint configuration of the REST API.
-
#id ⇒ String
The identifier of the REST API.
-
#minimum_compression_size ⇒ Integer
The minimum size in bytes of a payload before compression is enabled.
-
#name ⇒ String
The name of the REST API.
-
#version ⇒ String
The version identifier for the REST API.
Instance Attribute Details
#api_key_source ⇒ String
The source of the API key for metering requests according to a usage plan.
HEADER indicates whether to read the API key from the X-API-Key
header of a request.
AUTHORIZER indicates whether to read the API key from the
UsageIdentifierKey from a custom authorizer.
2135 2136 2137 2138 2139 2140 2141 2142 2143 2144 2145 2146 2147 |
# File 'lib/aws-sdk-securityhub/types.rb', line 2135 class AwsApiGatewayRestApiDetails < Struct.new( :id, :name, :description, :created_date, :version, :binary_media_types, :minimum_compression_size, :api_key_source, :endpoint_configuration) SENSITIVE = [] include Aws::Structure end |
#binary_media_types ⇒ Array<String>
The list of binary media types supported by the REST API.
2135 2136 2137 2138 2139 2140 2141 2142 2143 2144 2145 2146 2147 |
# File 'lib/aws-sdk-securityhub/types.rb', line 2135 class AwsApiGatewayRestApiDetails < Struct.new( :id, :name, :description, :created_date, :version, :binary_media_types, :minimum_compression_size, :api_key_source, :endpoint_configuration) SENSITIVE = [] include Aws::Structure end |
#created_date ⇒ String
Indicates when the API was created.
For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.
2135 2136 2137 2138 2139 2140 2141 2142 2143 2144 2145 2146 2147 |
# File 'lib/aws-sdk-securityhub/types.rb', line 2135 class AwsApiGatewayRestApiDetails < Struct.new( :id, :name, :description, :created_date, :version, :binary_media_types, :minimum_compression_size, :api_key_source, :endpoint_configuration) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the REST API.
2135 2136 2137 2138 2139 2140 2141 2142 2143 2144 2145 2146 2147 |
# File 'lib/aws-sdk-securityhub/types.rb', line 2135 class AwsApiGatewayRestApiDetails < Struct.new( :id, :name, :description, :created_date, :version, :binary_media_types, :minimum_compression_size, :api_key_source, :endpoint_configuration) SENSITIVE = [] include Aws::Structure end |
#endpoint_configuration ⇒ Types::AwsApiGatewayEndpointConfiguration
The endpoint configuration of the REST API.
2135 2136 2137 2138 2139 2140 2141 2142 2143 2144 2145 2146 2147 |
# File 'lib/aws-sdk-securityhub/types.rb', line 2135 class AwsApiGatewayRestApiDetails < Struct.new( :id, :name, :description, :created_date, :version, :binary_media_types, :minimum_compression_size, :api_key_source, :endpoint_configuration) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The identifier of the REST API.
2135 2136 2137 2138 2139 2140 2141 2142 2143 2144 2145 2146 2147 |
# File 'lib/aws-sdk-securityhub/types.rb', line 2135 class AwsApiGatewayRestApiDetails < Struct.new( :id, :name, :description, :created_date, :version, :binary_media_types, :minimum_compression_size, :api_key_source, :endpoint_configuration) SENSITIVE = [] include Aws::Structure end |
#minimum_compression_size ⇒ Integer
The minimum size in bytes of a payload before compression is enabled.
If null, then compression is disabled.
If 0, then all payloads are compressed.
2135 2136 2137 2138 2139 2140 2141 2142 2143 2144 2145 2146 2147 |
# File 'lib/aws-sdk-securityhub/types.rb', line 2135 class AwsApiGatewayRestApiDetails < Struct.new( :id, :name, :description, :created_date, :version, :binary_media_types, :minimum_compression_size, :api_key_source, :endpoint_configuration) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the REST API.
2135 2136 2137 2138 2139 2140 2141 2142 2143 2144 2145 2146 2147 |
# File 'lib/aws-sdk-securityhub/types.rb', line 2135 class AwsApiGatewayRestApiDetails < Struct.new( :id, :name, :description, :created_date, :version, :binary_media_types, :minimum_compression_size, :api_key_source, :endpoint_configuration) SENSITIVE = [] include Aws::Structure end |
#version ⇒ String
The version identifier for the REST API.
2135 2136 2137 2138 2139 2140 2141 2142 2143 2144 2145 2146 2147 |
# File 'lib/aws-sdk-securityhub/types.rb', line 2135 class AwsApiGatewayRestApiDetails < Struct.new( :id, :name, :description, :created_date, :version, :binary_media_types, :minimum_compression_size, :api_key_source, :endpoint_configuration) SENSITIVE = [] include Aws::Structure end |