Class: Aws::SecurityHub::Types::AwsApiGatewayV2ApiDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::AwsApiGatewayV2ApiDetails
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Contains information about a version 2 API in Amazon API Gateway.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#api_endpoint ⇒ String
The URI of the API.
-
#api_id ⇒ String
The identifier of the API.
-
#api_key_selection_expression ⇒ String
An API key selection expression.
-
#cors_configuration ⇒ Types::AwsCorsConfiguration
A cross-origin resource sharing (CORS) configuration.
-
#created_date ⇒ String
Indicates when the API was created.
-
#description ⇒ String
A description of the API.
-
#name ⇒ String
The name of the API.
-
#protocol_type ⇒ String
The API protocol for the API.
-
#route_selection_expression ⇒ String
The route selection expression for the API.
-
#version ⇒ String
The version identifier for the API.
Instance Attribute Details
#api_endpoint ⇒ String
The URI of the API.
Uses the format <api-id>.execute-api.<region>.amazonaws.com
The stage name is typically appended to the URI to form a complete path to a deployed API stage.
2299 2300 2301 2302 2303 2304 2305 2306 2307 2308 2309 2310 2311 2312 |
# File 'lib/aws-sdk-securityhub/types.rb', line 2299 class AwsApiGatewayV2ApiDetails < Struct.new( :api_endpoint, :api_id, :api_key_selection_expression, :created_date, :description, :version, :name, :protocol_type, :route_selection_expression, :cors_configuration) SENSITIVE = [] include Aws::Structure end |
#api_id ⇒ String
The identifier of the API.
2299 2300 2301 2302 2303 2304 2305 2306 2307 2308 2309 2310 2311 2312 |
# File 'lib/aws-sdk-securityhub/types.rb', line 2299 class AwsApiGatewayV2ApiDetails < Struct.new( :api_endpoint, :api_id, :api_key_selection_expression, :created_date, :description, :version, :name, :protocol_type, :route_selection_expression, :cors_configuration) SENSITIVE = [] include Aws::Structure end |
#api_key_selection_expression ⇒ String
An API key selection expression. Supported only for WebSocket APIs.
2299 2300 2301 2302 2303 2304 2305 2306 2307 2308 2309 2310 2311 2312 |
# File 'lib/aws-sdk-securityhub/types.rb', line 2299 class AwsApiGatewayV2ApiDetails < Struct.new( :api_endpoint, :api_id, :api_key_selection_expression, :created_date, :description, :version, :name, :protocol_type, :route_selection_expression, :cors_configuration) SENSITIVE = [] include Aws::Structure end |
#cors_configuration ⇒ Types::AwsCorsConfiguration
A cross-origin resource sharing (CORS) configuration. Supported only for HTTP APIs.
2299 2300 2301 2302 2303 2304 2305 2306 2307 2308 2309 2310 2311 2312 |
# File 'lib/aws-sdk-securityhub/types.rb', line 2299 class AwsApiGatewayV2ApiDetails < Struct.new( :api_endpoint, :api_id, :api_key_selection_expression, :created_date, :description, :version, :name, :protocol_type, :route_selection_expression, :cors_configuration) SENSITIVE = [] include Aws::Structure end |
#created_date ⇒ String
Indicates when the API was created.
For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.
2299 2300 2301 2302 2303 2304 2305 2306 2307 2308 2309 2310 2311 2312 |
# File 'lib/aws-sdk-securityhub/types.rb', line 2299 class AwsApiGatewayV2ApiDetails < Struct.new( :api_endpoint, :api_id, :api_key_selection_expression, :created_date, :description, :version, :name, :protocol_type, :route_selection_expression, :cors_configuration) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the API.
2299 2300 2301 2302 2303 2304 2305 2306 2307 2308 2309 2310 2311 2312 |
# File 'lib/aws-sdk-securityhub/types.rb', line 2299 class AwsApiGatewayV2ApiDetails < Struct.new( :api_endpoint, :api_id, :api_key_selection_expression, :created_date, :description, :version, :name, :protocol_type, :route_selection_expression, :cors_configuration) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the API.
2299 2300 2301 2302 2303 2304 2305 2306 2307 2308 2309 2310 2311 2312 |
# File 'lib/aws-sdk-securityhub/types.rb', line 2299 class AwsApiGatewayV2ApiDetails < Struct.new( :api_endpoint, :api_id, :api_key_selection_expression, :created_date, :description, :version, :name, :protocol_type, :route_selection_expression, :cors_configuration) SENSITIVE = [] include Aws::Structure end |
#protocol_type ⇒ String
The API protocol for the API.
Valid values: WEBSOCKET | HTTP
2299 2300 2301 2302 2303 2304 2305 2306 2307 2308 2309 2310 2311 2312 |
# File 'lib/aws-sdk-securityhub/types.rb', line 2299 class AwsApiGatewayV2ApiDetails < Struct.new( :api_endpoint, :api_id, :api_key_selection_expression, :created_date, :description, :version, :name, :protocol_type, :route_selection_expression, :cors_configuration) SENSITIVE = [] include Aws::Structure end |
#route_selection_expression ⇒ String
The route selection expression for the API.
For HTTP APIs, must be ${request.method} ${request.path}. This is
the default value for HTTP APIs.
For WebSocket APIs, there is no default value.
2299 2300 2301 2302 2303 2304 2305 2306 2307 2308 2309 2310 2311 2312 |
# File 'lib/aws-sdk-securityhub/types.rb', line 2299 class AwsApiGatewayV2ApiDetails < Struct.new( :api_endpoint, :api_id, :api_key_selection_expression, :created_date, :description, :version, :name, :protocol_type, :route_selection_expression, :cors_configuration) SENSITIVE = [] include Aws::Structure end |
#version ⇒ String
The version identifier for the API.
2299 2300 2301 2302 2303 2304 2305 2306 2307 2308 2309 2310 2311 2312 |
# File 'lib/aws-sdk-securityhub/types.rb', line 2299 class AwsApiGatewayV2ApiDetails < Struct.new( :api_endpoint, :api_id, :api_key_selection_expression, :created_date, :description, :version, :name, :protocol_type, :route_selection_expression, :cors_configuration) SENSITIVE = [] include Aws::Structure end |