Class: Aws::SecurityHub::Types::AwsAppSyncGraphQlApiDetails

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

Provides details about an AppSync Graph QL API, which lets you query multiple databases, microservices, and APIs from a single GraphQL endpoint.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#additional_authentication_providersArray<Types::AwsAppSyncGraphQlApiAdditionalAuthenticationProvidersDetails>

A list of additional authentication providers for the GraphQL API.

Returns:



2429
2430
2431
2432
2433
2434
2435
2436
2437
2438
2439
2440
2441
2442
2443
2444
# File 'lib/aws-sdk-securityhub/types.rb', line 2429

class AwsAppSyncGraphQlApiDetails < Struct.new(
  :api_id,
  :id,
  :open_id_connect_config,
  :name,
  :lambda_authorizer_config,
  :xray_enabled,
  :arn,
  :user_pool_config,
  :authentication_type,
  :log_config,
  :additional_authentication_providers,
  :waf_web_acl_arn)
  SENSITIVE = []
  include Aws::Structure
end

#api_idString

The unique identifier for the API.

Returns:



2429
2430
2431
2432
2433
2434
2435
2436
2437
2438
2439
2440
2441
2442
2443
2444
# File 'lib/aws-sdk-securityhub/types.rb', line 2429

class AwsAppSyncGraphQlApiDetails < Struct.new(
  :api_id,
  :id,
  :open_id_connect_config,
  :name,
  :lambda_authorizer_config,
  :xray_enabled,
  :arn,
  :user_pool_config,
  :authentication_type,
  :log_config,
  :additional_authentication_providers,
  :waf_web_acl_arn)
  SENSITIVE = []
  include Aws::Structure
end

#arnString

The Amazon Resource Name (ARN) of the API.

Returns:



2429
2430
2431
2432
2433
2434
2435
2436
2437
2438
2439
2440
2441
2442
2443
2444
# File 'lib/aws-sdk-securityhub/types.rb', line 2429

class AwsAppSyncGraphQlApiDetails < Struct.new(
  :api_id,
  :id,
  :open_id_connect_config,
  :name,
  :lambda_authorizer_config,
  :xray_enabled,
  :arn,
  :user_pool_config,
  :authentication_type,
  :log_config,
  :additional_authentication_providers,
  :waf_web_acl_arn)
  SENSITIVE = []
  include Aws::Structure
end

#authentication_typeString

The type of security configuration for your GraphQL API: API key, Identity and Access Management (IAM), OpenID Connect (OIDC), Amazon Cognito user pools, or Lambda.

Returns:



2429
2430
2431
2432
2433
2434
2435
2436
2437
2438
2439
2440
2441
2442
2443
2444
# File 'lib/aws-sdk-securityhub/types.rb', line 2429

class AwsAppSyncGraphQlApiDetails < Struct.new(
  :api_id,
  :id,
  :open_id_connect_config,
  :name,
  :lambda_authorizer_config,
  :xray_enabled,
  :arn,
  :user_pool_config,
  :authentication_type,
  :log_config,
  :additional_authentication_providers,
  :waf_web_acl_arn)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The unique identifier for the API.

Returns:



2429
2430
2431
2432
2433
2434
2435
2436
2437
2438
2439
2440
2441
2442
2443
2444
# File 'lib/aws-sdk-securityhub/types.rb', line 2429

class AwsAppSyncGraphQlApiDetails < Struct.new(
  :api_id,
  :id,
  :open_id_connect_config,
  :name,
  :lambda_authorizer_config,
  :xray_enabled,
  :arn,
  :user_pool_config,
  :authentication_type,
  :log_config,
  :additional_authentication_providers,
  :waf_web_acl_arn)
  SENSITIVE = []
  include Aws::Structure
end

#lambda_authorizer_configTypes::AwsAppSyncGraphQlApiLambdaAuthorizerConfigDetails

Specifies the configuration for Lambda function authorization.

Returns:



2429
2430
2431
2432
2433
2434
2435
2436
2437
2438
2439
2440
2441
2442
2443
2444
# File 'lib/aws-sdk-securityhub/types.rb', line 2429

class AwsAppSyncGraphQlApiDetails < Struct.new(
  :api_id,
  :id,
  :open_id_connect_config,
  :name,
  :lambda_authorizer_config,
  :xray_enabled,
  :arn,
  :user_pool_config,
  :authentication_type,
  :log_config,
  :additional_authentication_providers,
  :waf_web_acl_arn)
  SENSITIVE = []
  include Aws::Structure
end

#log_configTypes::AwsAppSyncGraphQlApiLogConfigDetails

The Amazon CloudWatch Logs configuration.

Returns:



2429
2430
2431
2432
2433
2434
2435
2436
2437
2438
2439
2440
2441
2442
2443
2444
# File 'lib/aws-sdk-securityhub/types.rb', line 2429

class AwsAppSyncGraphQlApiDetails < Struct.new(
  :api_id,
  :id,
  :open_id_connect_config,
  :name,
  :lambda_authorizer_config,
  :xray_enabled,
  :arn,
  :user_pool_config,
  :authentication_type,
  :log_config,
  :additional_authentication_providers,
  :waf_web_acl_arn)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The API name.

Returns:



2429
2430
2431
2432
2433
2434
2435
2436
2437
2438
2439
2440
2441
2442
2443
2444
# File 'lib/aws-sdk-securityhub/types.rb', line 2429

class AwsAppSyncGraphQlApiDetails < Struct.new(
  :api_id,
  :id,
  :open_id_connect_config,
  :name,
  :lambda_authorizer_config,
  :xray_enabled,
  :arn,
  :user_pool_config,
  :authentication_type,
  :log_config,
  :additional_authentication_providers,
  :waf_web_acl_arn)
  SENSITIVE = []
  include Aws::Structure
end

#open_id_connect_configTypes::AwsAppSyncGraphQlApiOpenIdConnectConfigDetails

Specifies the authorization configuration for using an OpenID Connect compliant service with an AppSync GraphQL API endpoint.

Returns:



2429
2430
2431
2432
2433
2434
2435
2436
2437
2438
2439
2440
2441
2442
2443
2444
# File 'lib/aws-sdk-securityhub/types.rb', line 2429

class AwsAppSyncGraphQlApiDetails < Struct.new(
  :api_id,
  :id,
  :open_id_connect_config,
  :name,
  :lambda_authorizer_config,
  :xray_enabled,
  :arn,
  :user_pool_config,
  :authentication_type,
  :log_config,
  :additional_authentication_providers,
  :waf_web_acl_arn)
  SENSITIVE = []
  include Aws::Structure
end

#user_pool_configTypes::AwsAppSyncGraphQlApiUserPoolConfigDetails

The Amazon Cognito user pools configuration.

Returns:



2429
2430
2431
2432
2433
2434
2435
2436
2437
2438
2439
2440
2441
2442
2443
2444
# File 'lib/aws-sdk-securityhub/types.rb', line 2429

class AwsAppSyncGraphQlApiDetails < Struct.new(
  :api_id,
  :id,
  :open_id_connect_config,
  :name,
  :lambda_authorizer_config,
  :xray_enabled,
  :arn,
  :user_pool_config,
  :authentication_type,
  :log_config,
  :additional_authentication_providers,
  :waf_web_acl_arn)
  SENSITIVE = []
  include Aws::Structure
end

#waf_web_acl_arnString

The Amazon Resource Name (ARN) of the WAF web access control list (web ACL) associated with this GraphQL API, if one exists.

Returns:



2429
2430
2431
2432
2433
2434
2435
2436
2437
2438
2439
2440
2441
2442
2443
2444
# File 'lib/aws-sdk-securityhub/types.rb', line 2429

class AwsAppSyncGraphQlApiDetails < Struct.new(
  :api_id,
  :id,
  :open_id_connect_config,
  :name,
  :lambda_authorizer_config,
  :xray_enabled,
  :arn,
  :user_pool_config,
  :authentication_type,
  :log_config,
  :additional_authentication_providers,
  :waf_web_acl_arn)
  SENSITIVE = []
  include Aws::Structure
end

#xray_enabledBoolean

Indicates whether to use X-Ray tracing for the GraphQL API.

Returns:



2429
2430
2431
2432
2433
2434
2435
2436
2437
2438
2439
2440
2441
2442
2443
2444
# File 'lib/aws-sdk-securityhub/types.rb', line 2429

class AwsAppSyncGraphQlApiDetails < Struct.new(
  :api_id,
  :id,
  :open_id_connect_config,
  :name,
  :lambda_authorizer_config,
  :xray_enabled,
  :arn,
  :user_pool_config,
  :authentication_type,
  :log_config,
  :additional_authentication_providers,
  :waf_web_acl_arn)
  SENSITIVE = []
  include Aws::Structure
end