Class: Aws::SecurityHub::Types::AwsAppSyncGraphQlApiOpenIdConnectConfigDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::AwsAppSyncGraphQlApiOpenIdConnectConfigDetails
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Specifies the authorization configuration for using an OpenID Connect compliant service with your AppSync GraphQL API endpoint.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#auth_tt_l ⇒ Integer
The number of milliseconds that a token is valid after being authenticated.
-
#client_id ⇒ String
The client identifier of the relying party at the OpenID identity provider.
-
#iat_tt_l ⇒ Integer
The number of milliseconds that a token is valid after it's issued to a user.
-
#issuer ⇒ String
The issuer for the OIDC configuration.
Instance Attribute Details
#auth_tt_l ⇒ Integer
The number of milliseconds that a token is valid after being authenticated.
2680 2681 2682 2683 2684 2685 2686 2687 |
# File 'lib/aws-sdk-securityhub/types.rb', line 2680 class AwsAppSyncGraphQlApiOpenIdConnectConfigDetails < Struct.new( :auth_tt_l, :client_id, :iat_tt_l, :issuer) SENSITIVE = [] include Aws::Structure end |
#client_id ⇒ String
The client identifier of the relying party at the OpenID identity provider. This identifier is typically obtained when the relying party is registered with the OpenID identity provider. You can specify a regular expression so that AppSync can validate against multiple client identifiers at a time.
2680 2681 2682 2683 2684 2685 2686 2687 |
# File 'lib/aws-sdk-securityhub/types.rb', line 2680 class AwsAppSyncGraphQlApiOpenIdConnectConfigDetails < Struct.new( :auth_tt_l, :client_id, :iat_tt_l, :issuer) SENSITIVE = [] include Aws::Structure end |
#iat_tt_l ⇒ Integer
The number of milliseconds that a token is valid after it's issued to a user.
2680 2681 2682 2683 2684 2685 2686 2687 |
# File 'lib/aws-sdk-securityhub/types.rb', line 2680 class AwsAppSyncGraphQlApiOpenIdConnectConfigDetails < Struct.new( :auth_tt_l, :client_id, :iat_tt_l, :issuer) SENSITIVE = [] include Aws::Structure end |
#issuer ⇒ String
The issuer for the OIDC configuration. The issuer returned by
discovery must exactly match the value of iss in the ID token.
2680 2681 2682 2683 2684 2685 2686 2687 |
# File 'lib/aws-sdk-securityhub/types.rb', line 2680 class AwsAppSyncGraphQlApiOpenIdConnectConfigDetails < Struct.new( :auth_tt_l, :client_id, :iat_tt_l, :issuer) SENSITIVE = [] include Aws::Structure end |