Class: Aws::SecurityHub::Types::AwsAthenaWorkGroupDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::AwsAthenaWorkGroupDetails
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Provides information about an Amazon Athena workgroup.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#configuration ⇒ Types::AwsAthenaWorkGroupConfigurationDetails
The configuration of the workgroup, which includes the location in Amazon Simple Storage Service (Amazon S3) where query results are stored, the encryption option, if any, used for query results, whether Amazon CloudWatch metrics are enabled for the workgroup, and the limit for the amount of bytes scanned (cutoff) per query, if it is specified.
-
#description ⇒ String
The workgroup description.
-
#name ⇒ String
The workgroup name.
-
#state ⇒ String
Whether the workgroup is enabled or disabled.
Instance Attribute Details
#configuration ⇒ Types::AwsAthenaWorkGroupConfigurationDetails
The configuration of the workgroup, which includes the location in Amazon Simple Storage Service (Amazon S3) where query results are stored, the encryption option, if any, used for query results, whether Amazon CloudWatch metrics are enabled for the workgroup, and the limit for the amount of bytes scanned (cutoff) per query, if it is specified.
2814 2815 2816 2817 2818 2819 2820 2821 |
# File 'lib/aws-sdk-securityhub/types.rb', line 2814 class AwsAthenaWorkGroupDetails < Struct.new( :name, :description, :state, :configuration) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The workgroup description.
2814 2815 2816 2817 2818 2819 2820 2821 |
# File 'lib/aws-sdk-securityhub/types.rb', line 2814 class AwsAthenaWorkGroupDetails < Struct.new( :name, :description, :state, :configuration) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The workgroup name.
2814 2815 2816 2817 2818 2819 2820 2821 |
# File 'lib/aws-sdk-securityhub/types.rb', line 2814 class AwsAthenaWorkGroupDetails < Struct.new( :name, :description, :state, :configuration) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
Whether the workgroup is enabled or disabled.
2814 2815 2816 2817 2818 2819 2820 2821 |
# File 'lib/aws-sdk-securityhub/types.rb', line 2814 class AwsAthenaWorkGroupDetails < Struct.new( :name, :description, :state, :configuration) SENSITIVE = [] include Aws::Structure end |