Class: Aws::SecurityHub::Types::AwsAutoScalingAutoScalingGroupDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::AwsAutoScalingAutoScalingGroupDetails
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Provides details about an auto scaling group.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#availability_zones ⇒ Array<Types::AwsAutoScalingAutoScalingGroupAvailabilityZonesListDetails>
The list of Availability Zones for the automatic scaling group.
-
#capacity_rebalance ⇒ Boolean
Indicates whether capacity rebalancing is enabled.
-
#created_time ⇒ String
Indicates when the auto scaling group was created.
-
#health_check_grace_period ⇒ Integer
The amount of time, in seconds, that Amazon EC2 Auto Scaling waits before it checks the health status of an EC2 instance that has come into service.
-
#health_check_type ⇒ String
The service to use for the health checks.
-
#launch_configuration_name ⇒ String
The name of the launch configuration.
-
#launch_template ⇒ Types::AwsAutoScalingAutoScalingGroupLaunchTemplateLaunchTemplateSpecification
The launch template to use.
-
#load_balancer_names ⇒ Array<String>
The list of load balancers associated with the group.
-
#mixed_instances_policy ⇒ Types::AwsAutoScalingAutoScalingGroupMixedInstancesPolicyDetails
The mixed instances policy for the automatic scaling group.
Instance Attribute Details
#availability_zones ⇒ Array<Types::AwsAutoScalingAutoScalingGroupAvailabilityZonesListDetails>
The list of Availability Zones for the automatic scaling group.
2858 2859 2860 2861 2862 2863 2864 2865 2866 2867 2868 2869 2870 |
# File 'lib/aws-sdk-securityhub/types.rb', line 2858 class AwsAutoScalingAutoScalingGroupDetails < Struct.new( :launch_configuration_name, :load_balancer_names, :health_check_type, :health_check_grace_period, :created_time, :mixed_instances_policy, :availability_zones, :launch_template, :capacity_rebalance) SENSITIVE = [] include Aws::Structure end |
#capacity_rebalance ⇒ Boolean
Indicates whether capacity rebalancing is enabled.
2858 2859 2860 2861 2862 2863 2864 2865 2866 2867 2868 2869 2870 |
# File 'lib/aws-sdk-securityhub/types.rb', line 2858 class AwsAutoScalingAutoScalingGroupDetails < Struct.new( :launch_configuration_name, :load_balancer_names, :health_check_type, :health_check_grace_period, :created_time, :mixed_instances_policy, :availability_zones, :launch_template, :capacity_rebalance) SENSITIVE = [] include Aws::Structure end |
#created_time ⇒ String
Indicates when the auto scaling group was created.
For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.
2858 2859 2860 2861 2862 2863 2864 2865 2866 2867 2868 2869 2870 |
# File 'lib/aws-sdk-securityhub/types.rb', line 2858 class AwsAutoScalingAutoScalingGroupDetails < Struct.new( :launch_configuration_name, :load_balancer_names, :health_check_type, :health_check_grace_period, :created_time, :mixed_instances_policy, :availability_zones, :launch_template, :capacity_rebalance) SENSITIVE = [] include Aws::Structure end |
#health_check_grace_period ⇒ Integer
The amount of time, in seconds, that Amazon EC2 Auto Scaling waits before it checks the health status of an EC2 instance that has come into service.
2858 2859 2860 2861 2862 2863 2864 2865 2866 2867 2868 2869 2870 |
# File 'lib/aws-sdk-securityhub/types.rb', line 2858 class AwsAutoScalingAutoScalingGroupDetails < Struct.new( :launch_configuration_name, :load_balancer_names, :health_check_type, :health_check_grace_period, :created_time, :mixed_instances_policy, :availability_zones, :launch_template, :capacity_rebalance) SENSITIVE = [] include Aws::Structure end |
#health_check_type ⇒ String
The service to use for the health checks. Valid values are EC2 or
ELB.
2858 2859 2860 2861 2862 2863 2864 2865 2866 2867 2868 2869 2870 |
# File 'lib/aws-sdk-securityhub/types.rb', line 2858 class AwsAutoScalingAutoScalingGroupDetails < Struct.new( :launch_configuration_name, :load_balancer_names, :health_check_type, :health_check_grace_period, :created_time, :mixed_instances_policy, :availability_zones, :launch_template, :capacity_rebalance) SENSITIVE = [] include Aws::Structure end |
#launch_configuration_name ⇒ String
The name of the launch configuration.
2858 2859 2860 2861 2862 2863 2864 2865 2866 2867 2868 2869 2870 |
# File 'lib/aws-sdk-securityhub/types.rb', line 2858 class AwsAutoScalingAutoScalingGroupDetails < Struct.new( :launch_configuration_name, :load_balancer_names, :health_check_type, :health_check_grace_period, :created_time, :mixed_instances_policy, :availability_zones, :launch_template, :capacity_rebalance) SENSITIVE = [] include Aws::Structure end |
#launch_template ⇒ Types::AwsAutoScalingAutoScalingGroupLaunchTemplateLaunchTemplateSpecification
The launch template to use.
2858 2859 2860 2861 2862 2863 2864 2865 2866 2867 2868 2869 2870 |
# File 'lib/aws-sdk-securityhub/types.rb', line 2858 class AwsAutoScalingAutoScalingGroupDetails < Struct.new( :launch_configuration_name, :load_balancer_names, :health_check_type, :health_check_grace_period, :created_time, :mixed_instances_policy, :availability_zones, :launch_template, :capacity_rebalance) SENSITIVE = [] include Aws::Structure end |
#load_balancer_names ⇒ Array<String>
The list of load balancers associated with the group.
2858 2859 2860 2861 2862 2863 2864 2865 2866 2867 2868 2869 2870 |
# File 'lib/aws-sdk-securityhub/types.rb', line 2858 class AwsAutoScalingAutoScalingGroupDetails < Struct.new( :launch_configuration_name, :load_balancer_names, :health_check_type, :health_check_grace_period, :created_time, :mixed_instances_policy, :availability_zones, :launch_template, :capacity_rebalance) SENSITIVE = [] include Aws::Structure end |
#mixed_instances_policy ⇒ Types::AwsAutoScalingAutoScalingGroupMixedInstancesPolicyDetails
The mixed instances policy for the automatic scaling group.
2858 2859 2860 2861 2862 2863 2864 2865 2866 2867 2868 2869 2870 |
# File 'lib/aws-sdk-securityhub/types.rb', line 2858 class AwsAutoScalingAutoScalingGroupDetails < Struct.new( :launch_configuration_name, :load_balancer_names, :health_check_type, :health_check_grace_period, :created_time, :mixed_instances_policy, :availability_zones, :launch_template, :capacity_rebalance) SENSITIVE = [] include Aws::Structure end |