Class: Aws::SecurityHub::Types::AwsAutoScalingAutoScalingGroupMixedInstancesPolicyLaunchTemplateOverridesListDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::AwsAutoScalingAutoScalingGroupMixedInstancesPolicyLaunchTemplateOverridesListDetails
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Property values to use to override the values in the launch template.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_type ⇒ String
The instance type.
-
#weighted_capacity ⇒ String
The number of capacity units provided by the specified instance type in terms of virtual CPUs, memory, storage, throughput, or other relative performance characteristic.
Instance Attribute Details
#instance_type ⇒ String
The instance type. For example, m3.xlarge.
3064 3065 3066 3067 3068 3069 |
# File 'lib/aws-sdk-securityhub/types.rb', line 3064 class AwsAutoScalingAutoScalingGroupMixedInstancesPolicyLaunchTemplateOverridesListDetails < Struct.new( :instance_type, :weighted_capacity) SENSITIVE = [] include Aws::Structure end |
#weighted_capacity ⇒ String
The number of capacity units provided by the specified instance type in terms of virtual CPUs, memory, storage, throughput, or other relative performance characteristic.
3064 3065 3066 3067 3068 3069 |
# File 'lib/aws-sdk-securityhub/types.rb', line 3064 class AwsAutoScalingAutoScalingGroupMixedInstancesPolicyLaunchTemplateOverridesListDetails < Struct.new( :instance_type, :weighted_capacity) SENSITIVE = [] include Aws::Structure end |