Class: Aws::SecurityHub::Types::AwsAutoScalingLaunchConfigurationBlockDeviceMappingsEbsDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::AwsAutoScalingLaunchConfigurationBlockDeviceMappingsEbsDetails
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Parameters that are used to automatically set up EBS volumes when an instance is launched.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#delete_on_termination ⇒ Boolean
Whether to delete the volume when the instance is terminated.
-
#encrypted ⇒ Boolean
Whether to encrypt the volume.
-
#iops ⇒ Integer
The number of input/output (I/O) operations per second (IOPS) to provision for the volume.
-
#snapshot_id ⇒ String
The snapshot ID of the volume to use.
-
#volume_size ⇒ Integer
The volume size, in GiBs.
-
#volume_type ⇒ String
The volume type.
Instance Attribute Details
#delete_on_termination ⇒ Boolean
Whether to delete the volume when the instance is terminated.
3037 3038 3039 3040 3041 3042 3043 3044 3045 3046 |
# File 'lib/aws-sdk-securityhub/types.rb', line 3037 class AwsAutoScalingLaunchConfigurationBlockDeviceMappingsEbsDetails < Struct.new( :delete_on_termination, :encrypted, :iops, :snapshot_id, :volume_size, :volume_type) SENSITIVE = [] include Aws::Structure end |
#encrypted ⇒ Boolean
Whether to encrypt the volume.
3037 3038 3039 3040 3041 3042 3043 3044 3045 3046 |
# File 'lib/aws-sdk-securityhub/types.rb', line 3037 class AwsAutoScalingLaunchConfigurationBlockDeviceMappingsEbsDetails < Struct.new( :delete_on_termination, :encrypted, :iops, :snapshot_id, :volume_size, :volume_type) SENSITIVE = [] include Aws::Structure end |
#iops ⇒ Integer
The number of input/output (I/O) operations per second (IOPS) to provision for the volume.
Only supported for gp3 or io1 volumes. Required for io1
volumes. Not used with standard, gp2, st1, or sc1 volumes.
3037 3038 3039 3040 3041 3042 3043 3044 3045 3046 |
# File 'lib/aws-sdk-securityhub/types.rb', line 3037 class AwsAutoScalingLaunchConfigurationBlockDeviceMappingsEbsDetails < Struct.new( :delete_on_termination, :encrypted, :iops, :snapshot_id, :volume_size, :volume_type) SENSITIVE = [] include Aws::Structure end |
#snapshot_id ⇒ String
The snapshot ID of the volume to use.
You must specify either VolumeSize or SnapshotId.
3037 3038 3039 3040 3041 3042 3043 3044 3045 3046 |
# File 'lib/aws-sdk-securityhub/types.rb', line 3037 class AwsAutoScalingLaunchConfigurationBlockDeviceMappingsEbsDetails < Struct.new( :delete_on_termination, :encrypted, :iops, :snapshot_id, :volume_size, :volume_type) SENSITIVE = [] include Aws::Structure end |
#volume_size ⇒ Integer
The volume size, in GiBs. The following are the supported volumes sizes for each volume type:
-
gp2 and gp3: 1-16,384
-
io1: 4-16,384
-
st1 and sc1: 125-16,384
-
standard: 1-1,024
You must specify either SnapshotId or VolumeSize. If you specify
both SnapshotId and VolumeSize, the volume size must be equal or
greater than the size of the snapshot.
3037 3038 3039 3040 3041 3042 3043 3044 3045 3046 |
# File 'lib/aws-sdk-securityhub/types.rb', line 3037 class AwsAutoScalingLaunchConfigurationBlockDeviceMappingsEbsDetails < Struct.new( :delete_on_termination, :encrypted, :iops, :snapshot_id, :volume_size, :volume_type) SENSITIVE = [] include Aws::Structure end |
#volume_type ⇒ String
The volume type. Valid values are as follows:
-
gp2 -
gp3 -
io1 -
sc1 -
st1 -
standard
3037 3038 3039 3040 3041 3042 3043 3044 3045 3046 |
# File 'lib/aws-sdk-securityhub/types.rb', line 3037 class AwsAutoScalingLaunchConfigurationBlockDeviceMappingsEbsDetails < Struct.new( :delete_on_termination, :encrypted, :iops, :snapshot_id, :volume_size, :volume_type) SENSITIVE = [] include Aws::Structure end |