Class: Aws::SecurityHub::Types::AwsAutoScalingLaunchConfigurationInstanceMonitoringDetails

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

Information about the type of monitoring for instances in the group.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#enabledBoolean

If set to true, then instances in the group launch with detailed monitoring.

If set to false, then instances in the group launch with basic monitoring.



3161
3162
3163
3164
3165
# File 'lib/aws-sdk-securityhub/types.rb', line 3161

class AwsAutoScalingLaunchConfigurationInstanceMonitoringDetails < Struct.new(
  :enabled)
  SENSITIVE = []
  include Aws::Structure
end