Class: Aws::SecurityHub::Types::AwsBackupBackupVaultNotificationsDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::AwsBackupBackupVaultNotificationsDetails
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Provides details about the Amazon SNS event notifications for the specified backup vault.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#backup_vault_events ⇒ Array<String>
An array of events that indicate the status of jobs to back up resources to the backup vault.
-
#sns_topic_arn ⇒ String
The Amazon Resource Name (ARN) that uniquely identifies the Amazon SNS topic for a backup vault's events.
Instance Attribute Details
#backup_vault_events ⇒ Array<String>
An array of events that indicate the status of jobs to back up resources to the backup vault. The following events are supported:
-
BACKUP_JOB_STARTED | BACKUP_JOB_COMPLETED -
COPY_JOB_STARTED | COPY_JOB_SUCCESSFUL | COPY_JOB_FAILED -
RESTORE_JOB_STARTED | RESTORE_JOB_COMPLETED | RECOVERY_POINT_MODIFIED -
S3_BACKUP_OBJECT_FAILED | S3_RESTORE_OBJECT_FAILED
3497 3498 3499 3500 3501 3502 |
# File 'lib/aws-sdk-securityhub/types.rb', line 3497 class AwsBackupBackupVaultNotificationsDetails < Struct.new( :backup_vault_events, :sns_topic_arn) SENSITIVE = [] include Aws::Structure end |
#sns_topic_arn ⇒ String
The Amazon Resource Name (ARN) that uniquely identifies the Amazon SNS topic for a backup vault's events.
3497 3498 3499 3500 3501 3502 |
# File 'lib/aws-sdk-securityhub/types.rb', line 3497 class AwsBackupBackupVaultNotificationsDetails < Struct.new( :backup_vault_events, :sns_topic_arn) SENSITIVE = [] include Aws::Structure end |