Class: Aws::SecurityHub::Types::AwsBackupRecoveryPointCalculatedLifecycleDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::AwsBackupRecoveryPointCalculatedLifecycleDetails
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Specifies how long in days before a recovery point transitions to cold storage or is deleted.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#delete_at ⇒ String
Specifies the number of days after creation that a recovery point is deleted.
-
#move_to_cold_storage_at ⇒ String
Specifies the number of days after creation that a recovery point is moved to cold storage.
Instance Attribute Details
#delete_at ⇒ String
Specifies the number of days after creation that a recovery point is
deleted. Must be greater than 90 days plus
MoveToColdStorageAfterDays.
3520 3521 3522 3523 3524 3525 |
# File 'lib/aws-sdk-securityhub/types.rb', line 3520 class AwsBackupRecoveryPointCalculatedLifecycleDetails < Struct.new( :delete_at, :move_to_cold_storage_at) SENSITIVE = [] include Aws::Structure end |
#move_to_cold_storage_at ⇒ String
Specifies the number of days after creation that a recovery point is moved to cold storage.
3520 3521 3522 3523 3524 3525 |
# File 'lib/aws-sdk-securityhub/types.rb', line 3520 class AwsBackupRecoveryPointCalculatedLifecycleDetails < Struct.new( :delete_at, :move_to_cold_storage_at) SENSITIVE = [] include Aws::Structure end |