Class: Aws::SecurityHub::Types::AwsCertificateManagerCertificateDetails

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

Provides details about an Certificate Manager certificate.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#certificate_authority_arnString

The ARN of the private certificate authority (CA) that will be used to issue the certificate.

Returns:

  • (String)


4007
4008
4009
4010
4011
4012
4013
4014
4015
4016
4017
4018
4019
4020
4021
4022
4023
4024
4025
4026
4027
4028
4029
4030
4031
4032
4033
# File 'lib/aws-sdk-securityhub/types.rb', line 4007

class AwsCertificateManagerCertificateDetails < Struct.new(
  :certificate_authority_arn,
  :created_at,
  :domain_name,
  :domain_validation_options,
  :extended_key_usages,
  :failure_reason,
  :imported_at,
  :in_use_by,
  :issued_at,
  :issuer,
  :key_algorithm,
  :key_usages,
  :not_after,
  :not_before,
  :options,
  :renewal_eligibility,
  :renewal_summary,
  :serial,
  :signature_algorithm,
  :status,
  :subject,
  :subject_alternative_names,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#created_atString

Indicates when the certificate was requested.

For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.

Returns:

  • (String)


4007
4008
4009
4010
4011
4012
4013
4014
4015
4016
4017
4018
4019
4020
4021
4022
4023
4024
4025
4026
4027
4028
4029
4030
4031
4032
4033
# File 'lib/aws-sdk-securityhub/types.rb', line 4007

class AwsCertificateManagerCertificateDetails < Struct.new(
  :certificate_authority_arn,
  :created_at,
  :domain_name,
  :domain_validation_options,
  :extended_key_usages,
  :failure_reason,
  :imported_at,
  :in_use_by,
  :issued_at,
  :issuer,
  :key_algorithm,
  :key_usages,
  :not_after,
  :not_before,
  :options,
  :renewal_eligibility,
  :renewal_summary,
  :serial,
  :signature_algorithm,
  :status,
  :subject,
  :subject_alternative_names,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#domain_nameString

The fully qualified domain name (FQDN), such as www.example.com, that is secured by the certificate.

Returns:

  • (String)


4007
4008
4009
4010
4011
4012
4013
4014
4015
4016
4017
4018
4019
4020
4021
4022
4023
4024
4025
4026
4027
4028
4029
4030
4031
4032
4033
# File 'lib/aws-sdk-securityhub/types.rb', line 4007

class AwsCertificateManagerCertificateDetails < Struct.new(
  :certificate_authority_arn,
  :created_at,
  :domain_name,
  :domain_validation_options,
  :extended_key_usages,
  :failure_reason,
  :imported_at,
  :in_use_by,
  :issued_at,
  :issuer,
  :key_algorithm,
  :key_usages,
  :not_after,
  :not_before,
  :options,
  :renewal_eligibility,
  :renewal_summary,
  :serial,
  :signature_algorithm,
  :status,
  :subject,
  :subject_alternative_names,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#domain_validation_optionsArray<Types::AwsCertificateManagerCertificateDomainValidationOption>

Contains information about the initial validation of each domain name that occurs as a result of the RequestCertificate request.

Only provided if the certificate type is AMAZON_ISSUED.



4007
4008
4009
4010
4011
4012
4013
4014
4015
4016
4017
4018
4019
4020
4021
4022
4023
4024
4025
4026
4027
4028
4029
4030
4031
4032
4033
# File 'lib/aws-sdk-securityhub/types.rb', line 4007

class AwsCertificateManagerCertificateDetails < Struct.new(
  :certificate_authority_arn,
  :created_at,
  :domain_name,
  :domain_validation_options,
  :extended_key_usages,
  :failure_reason,
  :imported_at,
  :in_use_by,
  :issued_at,
  :issuer,
  :key_algorithm,
  :key_usages,
  :not_after,
  :not_before,
  :options,
  :renewal_eligibility,
  :renewal_summary,
  :serial,
  :signature_algorithm,
  :status,
  :subject,
  :subject_alternative_names,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#extended_key_usagesArray<Types::AwsCertificateManagerCertificateExtendedKeyUsage>

Contains a list of Extended Key Usage X.509 v3 extension objects. Each object specifies a purpose for which the certificate public key can be used and consists of a name and an object identifier (OID).



4007
4008
4009
4010
4011
4012
4013
4014
4015
4016
4017
4018
4019
4020
4021
4022
4023
4024
4025
4026
4027
4028
4029
4030
4031
4032
4033
# File 'lib/aws-sdk-securityhub/types.rb', line 4007

class AwsCertificateManagerCertificateDetails < Struct.new(
  :certificate_authority_arn,
  :created_at,
  :domain_name,
  :domain_validation_options,
  :extended_key_usages,
  :failure_reason,
  :imported_at,
  :in_use_by,
  :issued_at,
  :issuer,
  :key_algorithm,
  :key_usages,
  :not_after,
  :not_before,
  :options,
  :renewal_eligibility,
  :renewal_summary,
  :serial,
  :signature_algorithm,
  :status,
  :subject,
  :subject_alternative_names,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#failure_reasonString

For a failed certificate request, the reason for the failure.

Valid values: NO_AVAILABLE_CONTACTS | ADDITIONAL_VERIFICATION_REQUIRED | DOMAIN_NOT_ALLOWED | INVALID_PUBLIC_DOMAIN | DOMAIN_VALIDATION_DENIED | CAA_ERROR | PCA_LIMIT_EXCEEDED | PCA_INVALID_ARN | PCA_INVALID_STATE | PCA_REQUEST_FAILED | PCA_NAME_CONSTRAINTS_VALIDATION | PCA_RESOURCE_NOT_FOUND | PCA_INVALID_ARGS | PCA_INVALID_DURATION | PCA_ACCESS_DENIED | SLR_NOT_FOUND | OTHER

Returns:

  • (String)


4007
4008
4009
4010
4011
4012
4013
4014
4015
4016
4017
4018
4019
4020
4021
4022
4023
4024
4025
4026
4027
4028
4029
4030
4031
4032
4033
# File 'lib/aws-sdk-securityhub/types.rb', line 4007

class AwsCertificateManagerCertificateDetails < Struct.new(
  :certificate_authority_arn,
  :created_at,
  :domain_name,
  :domain_validation_options,
  :extended_key_usages,
  :failure_reason,
  :imported_at,
  :in_use_by,
  :issued_at,
  :issuer,
  :key_algorithm,
  :key_usages,
  :not_after,
  :not_before,
  :options,
  :renewal_eligibility,
  :renewal_summary,
  :serial,
  :signature_algorithm,
  :status,
  :subject,
  :subject_alternative_names,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#imported_atString

Indicates when the certificate was imported. Provided if the certificate type is IMPORTED.

For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.

Returns:

  • (String)


4007
4008
4009
4010
4011
4012
4013
4014
4015
4016
4017
4018
4019
4020
4021
4022
4023
4024
4025
4026
4027
4028
4029
4030
4031
4032
4033
# File 'lib/aws-sdk-securityhub/types.rb', line 4007

class AwsCertificateManagerCertificateDetails < Struct.new(
  :certificate_authority_arn,
  :created_at,
  :domain_name,
  :domain_validation_options,
  :extended_key_usages,
  :failure_reason,
  :imported_at,
  :in_use_by,
  :issued_at,
  :issuer,
  :key_algorithm,
  :key_usages,
  :not_after,
  :not_before,
  :options,
  :renewal_eligibility,
  :renewal_summary,
  :serial,
  :signature_algorithm,
  :status,
  :subject,
  :subject_alternative_names,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#in_use_byArray<String>

The list of ARNs for the Amazon Web Services resources that use the certificate.

Returns:

  • (Array<String>)


4007
4008
4009
4010
4011
4012
4013
4014
4015
4016
4017
4018
4019
4020
4021
4022
4023
4024
4025
4026
4027
4028
4029
4030
4031
4032
4033
# File 'lib/aws-sdk-securityhub/types.rb', line 4007

class AwsCertificateManagerCertificateDetails < Struct.new(
  :certificate_authority_arn,
  :created_at,
  :domain_name,
  :domain_validation_options,
  :extended_key_usages,
  :failure_reason,
  :imported_at,
  :in_use_by,
  :issued_at,
  :issuer,
  :key_algorithm,
  :key_usages,
  :not_after,
  :not_before,
  :options,
  :renewal_eligibility,
  :renewal_summary,
  :serial,
  :signature_algorithm,
  :status,
  :subject,
  :subject_alternative_names,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#issued_atString

Indicates when the certificate was issued. Provided if the certificate type is AMAZON_ISSUED.

For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.

Returns:

  • (String)


4007
4008
4009
4010
4011
4012
4013
4014
4015
4016
4017
4018
4019
4020
4021
4022
4023
4024
4025
4026
4027
4028
4029
4030
4031
4032
4033
# File 'lib/aws-sdk-securityhub/types.rb', line 4007

class AwsCertificateManagerCertificateDetails < Struct.new(
  :certificate_authority_arn,
  :created_at,
  :domain_name,
  :domain_validation_options,
  :extended_key_usages,
  :failure_reason,
  :imported_at,
  :in_use_by,
  :issued_at,
  :issuer,
  :key_algorithm,
  :key_usages,
  :not_after,
  :not_before,
  :options,
  :renewal_eligibility,
  :renewal_summary,
  :serial,
  :signature_algorithm,
  :status,
  :subject,
  :subject_alternative_names,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#issuerString

The name of the certificate authority that issued and signed the certificate.

Returns:

  • (String)


4007
4008
4009
4010
4011
4012
4013
4014
4015
4016
4017
4018
4019
4020
4021
4022
4023
4024
4025
4026
4027
4028
4029
4030
4031
4032
4033
# File 'lib/aws-sdk-securityhub/types.rb', line 4007

class AwsCertificateManagerCertificateDetails < Struct.new(
  :certificate_authority_arn,
  :created_at,
  :domain_name,
  :domain_validation_options,
  :extended_key_usages,
  :failure_reason,
  :imported_at,
  :in_use_by,
  :issued_at,
  :issuer,
  :key_algorithm,
  :key_usages,
  :not_after,
  :not_before,
  :options,
  :renewal_eligibility,
  :renewal_summary,
  :serial,
  :signature_algorithm,
  :status,
  :subject,
  :subject_alternative_names,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#key_algorithmString

The algorithm that was used to generate the public-private key pair.

Valid values: RSA_2048 | RSA_1024 | RSA_4096 | EC_prime256v1 | EC_secp384r1 | EC_secp521r1

Returns:

  • (String)


4007
4008
4009
4010
4011
4012
4013
4014
4015
4016
4017
4018
4019
4020
4021
4022
4023
4024
4025
4026
4027
4028
4029
4030
4031
4032
4033
# File 'lib/aws-sdk-securityhub/types.rb', line 4007

class AwsCertificateManagerCertificateDetails < Struct.new(
  :certificate_authority_arn,
  :created_at,
  :domain_name,
  :domain_validation_options,
  :extended_key_usages,
  :failure_reason,
  :imported_at,
  :in_use_by,
  :issued_at,
  :issuer,
  :key_algorithm,
  :key_usages,
  :not_after,
  :not_before,
  :options,
  :renewal_eligibility,
  :renewal_summary,
  :serial,
  :signature_algorithm,
  :status,
  :subject,
  :subject_alternative_names,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#key_usagesArray<Types::AwsCertificateManagerCertificateKeyUsage>

A list of key usage X.509 v3 extension objects.



4007
4008
4009
4010
4011
4012
4013
4014
4015
4016
4017
4018
4019
4020
4021
4022
4023
4024
4025
4026
4027
4028
4029
4030
4031
4032
4033
# File 'lib/aws-sdk-securityhub/types.rb', line 4007

class AwsCertificateManagerCertificateDetails < Struct.new(
  :certificate_authority_arn,
  :created_at,
  :domain_name,
  :domain_validation_options,
  :extended_key_usages,
  :failure_reason,
  :imported_at,
  :in_use_by,
  :issued_at,
  :issuer,
  :key_algorithm,
  :key_usages,
  :not_after,
  :not_before,
  :options,
  :renewal_eligibility,
  :renewal_summary,
  :serial,
  :signature_algorithm,
  :status,
  :subject,
  :subject_alternative_names,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#not_afterString

The time after which the certificate becomes invalid.

For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.

Returns:

  • (String)


4007
4008
4009
4010
4011
4012
4013
4014
4015
4016
4017
4018
4019
4020
4021
4022
4023
4024
4025
4026
4027
4028
4029
4030
4031
4032
4033
# File 'lib/aws-sdk-securityhub/types.rb', line 4007

class AwsCertificateManagerCertificateDetails < Struct.new(
  :certificate_authority_arn,
  :created_at,
  :domain_name,
  :domain_validation_options,
  :extended_key_usages,
  :failure_reason,
  :imported_at,
  :in_use_by,
  :issued_at,
  :issuer,
  :key_algorithm,
  :key_usages,
  :not_after,
  :not_before,
  :options,
  :renewal_eligibility,
  :renewal_summary,
  :serial,
  :signature_algorithm,
  :status,
  :subject,
  :subject_alternative_names,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#not_beforeString

The time before which the certificate is not valid.

For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.

Returns:

  • (String)


4007
4008
4009
4010
4011
4012
4013
4014
4015
4016
4017
4018
4019
4020
4021
4022
4023
4024
4025
4026
4027
4028
4029
4030
4031
4032
4033
# File 'lib/aws-sdk-securityhub/types.rb', line 4007

class AwsCertificateManagerCertificateDetails < Struct.new(
  :certificate_authority_arn,
  :created_at,
  :domain_name,
  :domain_validation_options,
  :extended_key_usages,
  :failure_reason,
  :imported_at,
  :in_use_by,
  :issued_at,
  :issuer,
  :key_algorithm,
  :key_usages,
  :not_after,
  :not_before,
  :options,
  :renewal_eligibility,
  :renewal_summary,
  :serial,
  :signature_algorithm,
  :status,
  :subject,
  :subject_alternative_names,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#optionsTypes::AwsCertificateManagerCertificateOptions

Provides a value that specifies whether to add the certificate to a transparency log.



4007
4008
4009
4010
4011
4012
4013
4014
4015
4016
4017
4018
4019
4020
4021
4022
4023
4024
4025
4026
4027
4028
4029
4030
4031
4032
4033
# File 'lib/aws-sdk-securityhub/types.rb', line 4007

class AwsCertificateManagerCertificateDetails < Struct.new(
  :certificate_authority_arn,
  :created_at,
  :domain_name,
  :domain_validation_options,
  :extended_key_usages,
  :failure_reason,
  :imported_at,
  :in_use_by,
  :issued_at,
  :issuer,
  :key_algorithm,
  :key_usages,
  :not_after,
  :not_before,
  :options,
  :renewal_eligibility,
  :renewal_summary,
  :serial,
  :signature_algorithm,
  :status,
  :subject,
  :subject_alternative_names,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#renewal_eligibilityString

Whether the certificate is eligible for renewal.

Valid values: ELIGIBLE | INELIGIBLE

Returns:

  • (String)


4007
4008
4009
4010
4011
4012
4013
4014
4015
4016
4017
4018
4019
4020
4021
4022
4023
4024
4025
4026
4027
4028
4029
4030
4031
4032
4033
# File 'lib/aws-sdk-securityhub/types.rb', line 4007

class AwsCertificateManagerCertificateDetails < Struct.new(
  :certificate_authority_arn,
  :created_at,
  :domain_name,
  :domain_validation_options,
  :extended_key_usages,
  :failure_reason,
  :imported_at,
  :in_use_by,
  :issued_at,
  :issuer,
  :key_algorithm,
  :key_usages,
  :not_after,
  :not_before,
  :options,
  :renewal_eligibility,
  :renewal_summary,
  :serial,
  :signature_algorithm,
  :status,
  :subject,
  :subject_alternative_names,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#renewal_summaryTypes::AwsCertificateManagerCertificateRenewalSummary

Information about the status of the Certificate Manager managed renewal for the certificate. Provided only when the certificate type is AMAZON_ISSUED.



4007
4008
4009
4010
4011
4012
4013
4014
4015
4016
4017
4018
4019
4020
4021
4022
4023
4024
4025
4026
4027
4028
4029
4030
4031
4032
4033
# File 'lib/aws-sdk-securityhub/types.rb', line 4007

class AwsCertificateManagerCertificateDetails < Struct.new(
  :certificate_authority_arn,
  :created_at,
  :domain_name,
  :domain_validation_options,
  :extended_key_usages,
  :failure_reason,
  :imported_at,
  :in_use_by,
  :issued_at,
  :issuer,
  :key_algorithm,
  :key_usages,
  :not_after,
  :not_before,
  :options,
  :renewal_eligibility,
  :renewal_summary,
  :serial,
  :signature_algorithm,
  :status,
  :subject,
  :subject_alternative_names,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#serialString

The serial number of the certificate.

Returns:

  • (String)


4007
4008
4009
4010
4011
4012
4013
4014
4015
4016
4017
4018
4019
4020
4021
4022
4023
4024
4025
4026
4027
4028
4029
4030
4031
4032
4033
# File 'lib/aws-sdk-securityhub/types.rb', line 4007

class AwsCertificateManagerCertificateDetails < Struct.new(
  :certificate_authority_arn,
  :created_at,
  :domain_name,
  :domain_validation_options,
  :extended_key_usages,
  :failure_reason,
  :imported_at,
  :in_use_by,
  :issued_at,
  :issuer,
  :key_algorithm,
  :key_usages,
  :not_after,
  :not_before,
  :options,
  :renewal_eligibility,
  :renewal_summary,
  :serial,
  :signature_algorithm,
  :status,
  :subject,
  :subject_alternative_names,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#signature_algorithmString

The algorithm that was used to sign the certificate.

Returns:

  • (String)


4007
4008
4009
4010
4011
4012
4013
4014
4015
4016
4017
4018
4019
4020
4021
4022
4023
4024
4025
4026
4027
4028
4029
4030
4031
4032
4033
# File 'lib/aws-sdk-securityhub/types.rb', line 4007

class AwsCertificateManagerCertificateDetails < Struct.new(
  :certificate_authority_arn,
  :created_at,
  :domain_name,
  :domain_validation_options,
  :extended_key_usages,
  :failure_reason,
  :imported_at,
  :in_use_by,
  :issued_at,
  :issuer,
  :key_algorithm,
  :key_usages,
  :not_after,
  :not_before,
  :options,
  :renewal_eligibility,
  :renewal_summary,
  :serial,
  :signature_algorithm,
  :status,
  :subject,
  :subject_alternative_names,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the certificate.

Valid values: PENDING_VALIDATION | ISSUED | INACTIVE | EXPIRED | VALIDATION_TIMED_OUT | REVOKED | FAILED

Returns:

  • (String)


4007
4008
4009
4010
4011
4012
4013
4014
4015
4016
4017
4018
4019
4020
4021
4022
4023
4024
4025
4026
4027
4028
4029
4030
4031
4032
4033
# File 'lib/aws-sdk-securityhub/types.rb', line 4007

class AwsCertificateManagerCertificateDetails < Struct.new(
  :certificate_authority_arn,
  :created_at,
  :domain_name,
  :domain_validation_options,
  :extended_key_usages,
  :failure_reason,
  :imported_at,
  :in_use_by,
  :issued_at,
  :issuer,
  :key_algorithm,
  :key_usages,
  :not_after,
  :not_before,
  :options,
  :renewal_eligibility,
  :renewal_summary,
  :serial,
  :signature_algorithm,
  :status,
  :subject,
  :subject_alternative_names,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#subjectString

The name of the entity that is associated with the public key contained in the certificate.

Returns:

  • (String)


4007
4008
4009
4010
4011
4012
4013
4014
4015
4016
4017
4018
4019
4020
4021
4022
4023
4024
4025
4026
4027
4028
4029
4030
4031
4032
4033
# File 'lib/aws-sdk-securityhub/types.rb', line 4007

class AwsCertificateManagerCertificateDetails < Struct.new(
  :certificate_authority_arn,
  :created_at,
  :domain_name,
  :domain_validation_options,
  :extended_key_usages,
  :failure_reason,
  :imported_at,
  :in_use_by,
  :issued_at,
  :issuer,
  :key_algorithm,
  :key_usages,
  :not_after,
  :not_before,
  :options,
  :renewal_eligibility,
  :renewal_summary,
  :serial,
  :signature_algorithm,
  :status,
  :subject,
  :subject_alternative_names,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#subject_alternative_namesArray<String>

One or more domain names (subject alternative names) included in the certificate. This list contains the domain names that are bound to the public key that is contained in the certificate.

The subject alternative names include the canonical domain name (CN) of the certificate and additional domain names that can be used to connect to the website.

Returns:

  • (Array<String>)


4007
4008
4009
4010
4011
4012
4013
4014
4015
4016
4017
4018
4019
4020
4021
4022
4023
4024
4025
4026
4027
4028
4029
4030
4031
4032
4033
# File 'lib/aws-sdk-securityhub/types.rb', line 4007

class AwsCertificateManagerCertificateDetails < Struct.new(
  :certificate_authority_arn,
  :created_at,
  :domain_name,
  :domain_validation_options,
  :extended_key_usages,
  :failure_reason,
  :imported_at,
  :in_use_by,
  :issued_at,
  :issuer,
  :key_algorithm,
  :key_usages,
  :not_after,
  :not_before,
  :options,
  :renewal_eligibility,
  :renewal_summary,
  :serial,
  :signature_algorithm,
  :status,
  :subject,
  :subject_alternative_names,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The source of the certificate. For certificates that Certificate Manager provides, Type is AMAZON_ISSUED. For certificates that are imported with ImportCertificate, Type is IMPORTED.

Valid values: IMPORTED | AMAZON_ISSUED | PRIVATE

Returns:

  • (String)


4007
4008
4009
4010
4011
4012
4013
4014
4015
4016
4017
4018
4019
4020
4021
4022
4023
4024
4025
4026
4027
4028
4029
4030
4031
4032
4033
# File 'lib/aws-sdk-securityhub/types.rb', line 4007

class AwsCertificateManagerCertificateDetails < Struct.new(
  :certificate_authority_arn,
  :created_at,
  :domain_name,
  :domain_validation_options,
  :extended_key_usages,
  :failure_reason,
  :imported_at,
  :in_use_by,
  :issued_at,
  :issuer,
  :key_algorithm,
  :key_usages,
  :not_after,
  :not_before,
  :options,
  :renewal_eligibility,
  :renewal_summary,
  :serial,
  :signature_algorithm,
  :status,
  :subject,
  :subject_alternative_names,
  :type)
  SENSITIVE = []
  include Aws::Structure
end