Class: Aws::SecurityHub::Types::AwsCodeBuildProjectEnvironment
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::AwsCodeBuildProjectEnvironment
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Information about the build environment for this build project.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#certificate ⇒ String
The certificate to use with this build project.
-
#environment_variables ⇒ Array<Types::AwsCodeBuildProjectEnvironmentEnvironmentVariablesDetails>
A set of environment variables to make available to builds for the build project.
-
#image_pull_credentials_type ⇒ String
The type of credentials CodeBuild uses to pull images in your build.
-
#privileged_mode ⇒ Boolean
Whether to allow the Docker daemon to run inside a Docker container.
-
#registry_credential ⇒ Types::AwsCodeBuildProjectEnvironmentRegistryCredential
The credentials for access to a private registry.
-
#type ⇒ String
The type of build environment to use for related builds.
Instance Attribute Details
#certificate ⇒ String
The certificate to use with this build project.
5139 5140 5141 5142 5143 5144 5145 5146 5147 5148 |
# File 'lib/aws-sdk-securityhub/types.rb', line 5139 class AwsCodeBuildProjectEnvironment < Struct.new( :certificate, :environment_variables, :privileged_mode, :image_pull_credentials_type, :registry_credential, :type) SENSITIVE = [] include Aws::Structure end |
#environment_variables ⇒ Array<Types::AwsCodeBuildProjectEnvironmentEnvironmentVariablesDetails>
A set of environment variables to make available to builds for the build project.
5139 5140 5141 5142 5143 5144 5145 5146 5147 5148 |
# File 'lib/aws-sdk-securityhub/types.rb', line 5139 class AwsCodeBuildProjectEnvironment < Struct.new( :certificate, :environment_variables, :privileged_mode, :image_pull_credentials_type, :registry_credential, :type) SENSITIVE = [] include Aws::Structure end |
#image_pull_credentials_type ⇒ String
The type of credentials CodeBuild uses to pull images in your build.
Valid values:
-
CODEBUILDspecifies that CodeBuild uses its own credentials. This requires that you modify your ECR repository policy to trust the CodeBuild service principal. -
SERVICE_ROLEspecifies that CodeBuild uses your build project's service role.
When you use a cross-account or private registry image, you must use
SERVICE_ROLE credentials. When you use an CodeBuild curated image,
you must use CODEBUILD credentials.
5139 5140 5141 5142 5143 5144 5145 5146 5147 5148 |
# File 'lib/aws-sdk-securityhub/types.rb', line 5139 class AwsCodeBuildProjectEnvironment < Struct.new( :certificate, :environment_variables, :privileged_mode, :image_pull_credentials_type, :registry_credential, :type) SENSITIVE = [] include Aws::Structure end |
#privileged_mode ⇒ Boolean
Whether to allow the Docker daemon to run inside a Docker container.
Set to true if the build project is used to build Docker images.
5139 5140 5141 5142 5143 5144 5145 5146 5147 5148 |
# File 'lib/aws-sdk-securityhub/types.rb', line 5139 class AwsCodeBuildProjectEnvironment < Struct.new( :certificate, :environment_variables, :privileged_mode, :image_pull_credentials_type, :registry_credential, :type) SENSITIVE = [] include Aws::Structure end |
#registry_credential ⇒ Types::AwsCodeBuildProjectEnvironmentRegistryCredential
The credentials for access to a private registry.
5139 5140 5141 5142 5143 5144 5145 5146 5147 5148 |
# File 'lib/aws-sdk-securityhub/types.rb', line 5139 class AwsCodeBuildProjectEnvironment < Struct.new( :certificate, :environment_variables, :privileged_mode, :image_pull_credentials_type, :registry_credential, :type) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of build environment to use for related builds.
The environment type ARM_CONTAINER is available only in Regions US
East (N. Virginia), US East (Ohio), US West (Oregon), Europe
(Ireland), Asia Pacific (Mumbai), Asia Pacific (Tokyo), Asia Pacific
(Sydney), and Europe (Frankfurt).
The environment type LINUX_CONTAINER with compute type
build.general1.2xlarge is available only in Regions US East (N.
Virginia), US East (N. Virginia), US West (Oregon), Canada
(Central), Europe (Ireland), Europe (London), Europe (Frankfurt),
Asia Pacific (Tokyo), Asia Pacific (Seoul), Asia Pacific
(Singapore), Asia Pacific (Sydney), China (Beijing), and China
(Ningxia).
The environment type LINUX_GPU_CONTAINER is available only in
Regions US East (N. Virginia), US East (N. Virginia), US West
(Oregon), Canada (Central), Europe (Ireland), Europe (London),
Europe (Frankfurt), Asia Pacific (Tokyo), Asia Pacific (Seoul), Asia
Pacific (Singapore), Asia Pacific (Sydney), China (Beijing), and
China (Ningxia).
Valid values: WINDOWS_CONTAINER | LINUX_CONTAINER |
LINUX_GPU_CONTAINER | ARM_CONTAINER
5139 5140 5141 5142 5143 5144 5145 5146 5147 5148 |
# File 'lib/aws-sdk-securityhub/types.rb', line 5139 class AwsCodeBuildProjectEnvironment < Struct.new( :certificate, :environment_variables, :privileged_mode, :image_pull_credentials_type, :registry_credential, :type) SENSITIVE = [] include Aws::Structure end |