Class: Aws::SecurityHub::Types::AwsDmsEndpointDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::AwsDmsEndpointDetails
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Provides details about an Database Migration Service (DMS) endpoint. An endpoint provides connection, data store type, and location information about your data store.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#certificate_arn ⇒ String
The Amazon Resource Name (ARN) for the SSL certificate that encrypts connections between the DMS endpoint and the replication instance.
-
#database_name ⇒ String
The name of the endpoint database.
-
#endpoint_arn ⇒ String
The Amazon Resource Name (ARN) of the endpoint.
-
#endpoint_identifier ⇒ String
The database endpoint identifier.
-
#endpoint_type ⇒ String
The type of endpoint.
-
#engine_name ⇒ String
The type of engine for the endpoint, depending on the
EndpointTypevalue. -
#external_id ⇒ String
A value that can be used for cross-account validation.
-
#extra_connection_attributes ⇒ String
Additional attributes associated with the connection.
-
#kms_key_id ⇒ String
An DMS key identifier that is used to encrypt the connection parameters for the endpoint.
-
#port ⇒ Integer
The port used to access the endpoint.
-
#server_name ⇒ String
The name of the server where the endpoint database resides.
-
#ssl_mode ⇒ String
The SSL mode used to connect to the endpoint.
-
#username ⇒ String
The user name to be used to log in to the endpoint database.
Instance Attribute Details
#certificate_arn ⇒ String
The Amazon Resource Name (ARN) for the SSL certificate that encrypts connections between the DMS endpoint and the replication instance.
5575 5576 5577 5578 5579 5580 5581 5582 5583 5584 5585 5586 5587 5588 5589 5590 5591 |
# File 'lib/aws-sdk-securityhub/types.rb', line 5575 class AwsDmsEndpointDetails < Struct.new( :certificate_arn, :database_name, :endpoint_arn, :endpoint_identifier, :endpoint_type, :engine_name, :external_id, :extra_connection_attributes, :kms_key_id, :port, :server_name, :ssl_mode, :username) SENSITIVE = [] include Aws::Structure end |
#database_name ⇒ String
The name of the endpoint database.
5575 5576 5577 5578 5579 5580 5581 5582 5583 5584 5585 5586 5587 5588 5589 5590 5591 |
# File 'lib/aws-sdk-securityhub/types.rb', line 5575 class AwsDmsEndpointDetails < Struct.new( :certificate_arn, :database_name, :endpoint_arn, :endpoint_identifier, :endpoint_type, :engine_name, :external_id, :extra_connection_attributes, :kms_key_id, :port, :server_name, :ssl_mode, :username) SENSITIVE = [] include Aws::Structure end |
#endpoint_arn ⇒ String
The Amazon Resource Name (ARN) of the endpoint.
5575 5576 5577 5578 5579 5580 5581 5582 5583 5584 5585 5586 5587 5588 5589 5590 5591 |
# File 'lib/aws-sdk-securityhub/types.rb', line 5575 class AwsDmsEndpointDetails < Struct.new( :certificate_arn, :database_name, :endpoint_arn, :endpoint_identifier, :endpoint_type, :engine_name, :external_id, :extra_connection_attributes, :kms_key_id, :port, :server_name, :ssl_mode, :username) SENSITIVE = [] include Aws::Structure end |
#endpoint_identifier ⇒ String
The database endpoint identifier.
5575 5576 5577 5578 5579 5580 5581 5582 5583 5584 5585 5586 5587 5588 5589 5590 5591 |
# File 'lib/aws-sdk-securityhub/types.rb', line 5575 class AwsDmsEndpointDetails < Struct.new( :certificate_arn, :database_name, :endpoint_arn, :endpoint_identifier, :endpoint_type, :engine_name, :external_id, :extra_connection_attributes, :kms_key_id, :port, :server_name, :ssl_mode, :username) SENSITIVE = [] include Aws::Structure end |
#endpoint_type ⇒ String
The type of endpoint. Valid values are source and target.
5575 5576 5577 5578 5579 5580 5581 5582 5583 5584 5585 5586 5587 5588 5589 5590 5591 |
# File 'lib/aws-sdk-securityhub/types.rb', line 5575 class AwsDmsEndpointDetails < Struct.new( :certificate_arn, :database_name, :endpoint_arn, :endpoint_identifier, :endpoint_type, :engine_name, :external_id, :extra_connection_attributes, :kms_key_id, :port, :server_name, :ssl_mode, :username) SENSITIVE = [] include Aws::Structure end |
#engine_name ⇒ String
The type of engine for the endpoint, depending on the EndpointType
value.
5575 5576 5577 5578 5579 5580 5581 5582 5583 5584 5585 5586 5587 5588 5589 5590 5591 |
# File 'lib/aws-sdk-securityhub/types.rb', line 5575 class AwsDmsEndpointDetails < Struct.new( :certificate_arn, :database_name, :endpoint_arn, :endpoint_identifier, :endpoint_type, :engine_name, :external_id, :extra_connection_attributes, :kms_key_id, :port, :server_name, :ssl_mode, :username) SENSITIVE = [] include Aws::Structure end |
#external_id ⇒ String
A value that can be used for cross-account validation.
5575 5576 5577 5578 5579 5580 5581 5582 5583 5584 5585 5586 5587 5588 5589 5590 5591 |
# File 'lib/aws-sdk-securityhub/types.rb', line 5575 class AwsDmsEndpointDetails < Struct.new( :certificate_arn, :database_name, :endpoint_arn, :endpoint_identifier, :endpoint_type, :engine_name, :external_id, :extra_connection_attributes, :kms_key_id, :port, :server_name, :ssl_mode, :username) SENSITIVE = [] include Aws::Structure end |
#extra_connection_attributes ⇒ String
Additional attributes associated with the connection.
5575 5576 5577 5578 5579 5580 5581 5582 5583 5584 5585 5586 5587 5588 5589 5590 5591 |
# File 'lib/aws-sdk-securityhub/types.rb', line 5575 class AwsDmsEndpointDetails < Struct.new( :certificate_arn, :database_name, :endpoint_arn, :endpoint_identifier, :endpoint_type, :engine_name, :external_id, :extra_connection_attributes, :kms_key_id, :port, :server_name, :ssl_mode, :username) SENSITIVE = [] include Aws::Structure end |
#kms_key_id ⇒ String
An DMS key identifier that is used to encrypt the connection
parameters for the endpoint. If you don't specify a value for the
KmsKeyId parameter, then DMS uses your default encryption key. KMS
creates the default encryption key for your Amazon Web Services
account. Your Amazon Web Services account has a different default
encryption key for each Amazon Web Services Region.
5575 5576 5577 5578 5579 5580 5581 5582 5583 5584 5585 5586 5587 5588 5589 5590 5591 |
# File 'lib/aws-sdk-securityhub/types.rb', line 5575 class AwsDmsEndpointDetails < Struct.new( :certificate_arn, :database_name, :endpoint_arn, :endpoint_identifier, :endpoint_type, :engine_name, :external_id, :extra_connection_attributes, :kms_key_id, :port, :server_name, :ssl_mode, :username) SENSITIVE = [] include Aws::Structure end |
#port ⇒ Integer
The port used to access the endpoint.
5575 5576 5577 5578 5579 5580 5581 5582 5583 5584 5585 5586 5587 5588 5589 5590 5591 |
# File 'lib/aws-sdk-securityhub/types.rb', line 5575 class AwsDmsEndpointDetails < Struct.new( :certificate_arn, :database_name, :endpoint_arn, :endpoint_identifier, :endpoint_type, :engine_name, :external_id, :extra_connection_attributes, :kms_key_id, :port, :server_name, :ssl_mode, :username) SENSITIVE = [] include Aws::Structure end |
#server_name ⇒ String
The name of the server where the endpoint database resides.
5575 5576 5577 5578 5579 5580 5581 5582 5583 5584 5585 5586 5587 5588 5589 5590 5591 |
# File 'lib/aws-sdk-securityhub/types.rb', line 5575 class AwsDmsEndpointDetails < Struct.new( :certificate_arn, :database_name, :endpoint_arn, :endpoint_identifier, :endpoint_type, :engine_name, :external_id, :extra_connection_attributes, :kms_key_id, :port, :server_name, :ssl_mode, :username) SENSITIVE = [] include Aws::Structure end |
#ssl_mode ⇒ String
The SSL mode used to connect to the endpoint. The default is none.
5575 5576 5577 5578 5579 5580 5581 5582 5583 5584 5585 5586 5587 5588 5589 5590 5591 |
# File 'lib/aws-sdk-securityhub/types.rb', line 5575 class AwsDmsEndpointDetails < Struct.new( :certificate_arn, :database_name, :endpoint_arn, :endpoint_identifier, :endpoint_type, :engine_name, :external_id, :extra_connection_attributes, :kms_key_id, :port, :server_name, :ssl_mode, :username) SENSITIVE = [] include Aws::Structure end |
#username ⇒ String
The user name to be used to log in to the endpoint database.
5575 5576 5577 5578 5579 5580 5581 5582 5583 5584 5585 5586 5587 5588 5589 5590 5591 |
# File 'lib/aws-sdk-securityhub/types.rb', line 5575 class AwsDmsEndpointDetails < Struct.new( :certificate_arn, :database_name, :endpoint_arn, :endpoint_identifier, :endpoint_type, :engine_name, :external_id, :extra_connection_attributes, :kms_key_id, :port, :server_name, :ssl_mode, :username) SENSITIVE = [] include Aws::Structure end |