Class: Aws::SecurityHub::Types::AwsDynamoDbTableBillingModeSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::AwsDynamoDbTableBillingModeSummary
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Provides information about the billing for read/write capacity on the table.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#billing_mode ⇒ String
The method used to charge for read and write throughput and to manage capacity.
-
#last_update_to_pay_per_request_date_time ⇒ String
If the billing mode is
PAY_PER_REQUEST, indicates when the billing mode was set to that value.
Instance Attribute Details
#billing_mode ⇒ String
The method used to charge for read and write throughput and to manage capacity.
5741 5742 5743 5744 5745 5746 |
# File 'lib/aws-sdk-securityhub/types.rb', line 5741 class AwsDynamoDbTableBillingModeSummary < Struct.new( :billing_mode, :last_update_to_pay_per_request_date_time) SENSITIVE = [] include Aws::Structure end |
#last_update_to_pay_per_request_date_time ⇒ String
If the billing mode is PAY_PER_REQUEST, indicates when the billing
mode was set to that value.
For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.
5741 5742 5743 5744 5745 5746 |
# File 'lib/aws-sdk-securityhub/types.rb', line 5741 class AwsDynamoDbTableBillingModeSummary < Struct.new( :billing_mode, :last_update_to_pay_per_request_date_time) SENSITIVE = [] include Aws::Structure end |