Class: Aws::SecurityHub::Types::AwsDynamoDbTableGlobalSecondaryIndex

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

Information abut a global secondary index for the table.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#backfillingBoolean

Whether the index is currently backfilling.

Returns:

  • (Boolean)


6030
6031
6032
6033
6034
6035
6036
6037
6038
6039
6040
6041
6042
# File 'lib/aws-sdk-securityhub/types.rb', line 6030

class AwsDynamoDbTableGlobalSecondaryIndex < Struct.new(
  :backfilling,
  :index_arn,
  :index_name,
  :index_size_bytes,
  :index_status,
  :item_count,
  :key_schema,
  :projection,
  :provisioned_throughput)
  SENSITIVE = []
  include Aws::Structure
end

#index_arnString

The ARN of the index.

Returns:

  • (String)


6030
6031
6032
6033
6034
6035
6036
6037
6038
6039
6040
6041
6042
# File 'lib/aws-sdk-securityhub/types.rb', line 6030

class AwsDynamoDbTableGlobalSecondaryIndex < Struct.new(
  :backfilling,
  :index_arn,
  :index_name,
  :index_size_bytes,
  :index_status,
  :item_count,
  :key_schema,
  :projection,
  :provisioned_throughput)
  SENSITIVE = []
  include Aws::Structure
end

#index_nameString

The name of the index.

Returns:

  • (String)


6030
6031
6032
6033
6034
6035
6036
6037
6038
6039
6040
6041
6042
# File 'lib/aws-sdk-securityhub/types.rb', line 6030

class AwsDynamoDbTableGlobalSecondaryIndex < Struct.new(
  :backfilling,
  :index_arn,
  :index_name,
  :index_size_bytes,
  :index_status,
  :item_count,
  :key_schema,
  :projection,
  :provisioned_throughput)
  SENSITIVE = []
  include Aws::Structure
end

#index_size_bytesInteger

The total size in bytes of the index.

Returns:

  • (Integer)


6030
6031
6032
6033
6034
6035
6036
6037
6038
6039
6040
6041
6042
# File 'lib/aws-sdk-securityhub/types.rb', line 6030

class AwsDynamoDbTableGlobalSecondaryIndex < Struct.new(
  :backfilling,
  :index_arn,
  :index_name,
  :index_size_bytes,
  :index_status,
  :item_count,
  :key_schema,
  :projection,
  :provisioned_throughput)
  SENSITIVE = []
  include Aws::Structure
end

#index_statusString

The current status of the index.

  • ACTIVE

  • CREATING

  • DELETING

  • UPDATING

Returns:

  • (String)


6030
6031
6032
6033
6034
6035
6036
6037
6038
6039
6040
6041
6042
# File 'lib/aws-sdk-securityhub/types.rb', line 6030

class AwsDynamoDbTableGlobalSecondaryIndex < Struct.new(
  :backfilling,
  :index_arn,
  :index_name,
  :index_size_bytes,
  :index_status,
  :item_count,
  :key_schema,
  :projection,
  :provisioned_throughput)
  SENSITIVE = []
  include Aws::Structure
end

#item_countInteger

The number of items in the index.

Returns:

  • (Integer)


6030
6031
6032
6033
6034
6035
6036
6037
6038
6039
6040
6041
6042
# File 'lib/aws-sdk-securityhub/types.rb', line 6030

class AwsDynamoDbTableGlobalSecondaryIndex < Struct.new(
  :backfilling,
  :index_arn,
  :index_name,
  :index_size_bytes,
  :index_status,
  :item_count,
  :key_schema,
  :projection,
  :provisioned_throughput)
  SENSITIVE = []
  include Aws::Structure
end

#key_schemaArray<Types::AwsDynamoDbTableKeySchema>

The key schema for the index.



6030
6031
6032
6033
6034
6035
6036
6037
6038
6039
6040
6041
6042
# File 'lib/aws-sdk-securityhub/types.rb', line 6030

class AwsDynamoDbTableGlobalSecondaryIndex < Struct.new(
  :backfilling,
  :index_arn,
  :index_name,
  :index_size_bytes,
  :index_status,
  :item_count,
  :key_schema,
  :projection,
  :provisioned_throughput)
  SENSITIVE = []
  include Aws::Structure
end

#projectionTypes::AwsDynamoDbTableProjection

Attributes that are copied from the table into an index.



6030
6031
6032
6033
6034
6035
6036
6037
6038
6039
6040
6041
6042
# File 'lib/aws-sdk-securityhub/types.rb', line 6030

class AwsDynamoDbTableGlobalSecondaryIndex < Struct.new(
  :backfilling,
  :index_arn,
  :index_name,
  :index_size_bytes,
  :index_status,
  :item_count,
  :key_schema,
  :projection,
  :provisioned_throughput)
  SENSITIVE = []
  include Aws::Structure
end

#provisioned_throughputTypes::AwsDynamoDbTableProvisionedThroughput

Information about the provisioned throughput settings for the indexes.



6030
6031
6032
6033
6034
6035
6036
6037
6038
6039
6040
6041
6042
# File 'lib/aws-sdk-securityhub/types.rb', line 6030

class AwsDynamoDbTableGlobalSecondaryIndex < Struct.new(
  :backfilling,
  :index_arn,
  :index_name,
  :index_size_bytes,
  :index_status,
  :item_count,
  :key_schema,
  :projection,
  :provisioned_throughput)
  SENSITIVE = []
  include Aws::Structure
end