Class: Aws::SecurityHub::Types::AwsDynamoDbTableLocalSecondaryIndex

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

Information about a local secondary index for a DynamoDB table.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#index_arnString

The ARN of the index.

Returns:

  • (String)


6116
6117
6118
6119
6120
6121
6122
6123
# File 'lib/aws-sdk-securityhub/types.rb', line 6116

class AwsDynamoDbTableLocalSecondaryIndex < Struct.new(
  :index_arn,
  :index_name,
  :key_schema,
  :projection)
  SENSITIVE = []
  include Aws::Structure
end

#index_nameString

The name of the index.

Returns:

  • (String)


6116
6117
6118
6119
6120
6121
6122
6123
# File 'lib/aws-sdk-securityhub/types.rb', line 6116

class AwsDynamoDbTableLocalSecondaryIndex < Struct.new(
  :index_arn,
  :index_name,
  :key_schema,
  :projection)
  SENSITIVE = []
  include Aws::Structure
end

#key_schemaArray<Types::AwsDynamoDbTableKeySchema>

The complete key schema for the index.



6116
6117
6118
6119
6120
6121
6122
6123
# File 'lib/aws-sdk-securityhub/types.rb', line 6116

class AwsDynamoDbTableLocalSecondaryIndex < Struct.new(
  :index_arn,
  :index_name,
  :key_schema,
  :projection)
  SENSITIVE = []
  include Aws::Structure
end

#projectionTypes::AwsDynamoDbTableProjection

Attributes that are copied from the table into the index. These are in addition to the primary key attributes and index key attributes, which are automatically projected.



6116
6117
6118
6119
6120
6121
6122
6123
# File 'lib/aws-sdk-securityhub/types.rb', line 6116

class AwsDynamoDbTableLocalSecondaryIndex < Struct.new(
  :index_arn,
  :index_name,
  :key_schema,
  :projection)
  SENSITIVE = []
  include Aws::Structure
end