Class: Aws::SecurityHub::Types::AwsDynamoDbTableProvisionedThroughput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::AwsDynamoDbTableProvisionedThroughput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Information about the provisioned throughput for the table or for a global secondary index.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#last_decrease_date_time ⇒ String
Indicates when the provisioned throughput was last decreased.
-
#last_increase_date_time ⇒ String
Indicates when the provisioned throughput was last increased.
-
#number_of_decreases_today ⇒ Integer
The number of times during the current UTC calendar day that the provisioned throughput was decreased.
-
#read_capacity_units ⇒ Integer
The maximum number of strongly consistent reads consumed per second before DynamoDB returns a
ThrottlingException. -
#write_capacity_units ⇒ Integer
The maximum number of writes consumed per second before DynamoDB returns a
ThrottlingException.
Instance Attribute Details
#last_decrease_date_time ⇒ String
Indicates when the provisioned throughput was last decreased.
For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.
6065 6066 6067 6068 6069 6070 6071 6072 6073 |
# File 'lib/aws-sdk-securityhub/types.rb', line 6065 class AwsDynamoDbTableProvisionedThroughput < Struct.new( :last_decrease_date_time, :last_increase_date_time, :number_of_decreases_today, :read_capacity_units, :write_capacity_units) SENSITIVE = [] include Aws::Structure end |
#last_increase_date_time ⇒ String
Indicates when the provisioned throughput was last increased.
For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.
6065 6066 6067 6068 6069 6070 6071 6072 6073 |
# File 'lib/aws-sdk-securityhub/types.rb', line 6065 class AwsDynamoDbTableProvisionedThroughput < Struct.new( :last_decrease_date_time, :last_increase_date_time, :number_of_decreases_today, :read_capacity_units, :write_capacity_units) SENSITIVE = [] include Aws::Structure end |
#number_of_decreases_today ⇒ Integer
The number of times during the current UTC calendar day that the provisioned throughput was decreased.
6065 6066 6067 6068 6069 6070 6071 6072 6073 |
# File 'lib/aws-sdk-securityhub/types.rb', line 6065 class AwsDynamoDbTableProvisionedThroughput < Struct.new( :last_decrease_date_time, :last_increase_date_time, :number_of_decreases_today, :read_capacity_units, :write_capacity_units) SENSITIVE = [] include Aws::Structure end |
#read_capacity_units ⇒ Integer
The maximum number of strongly consistent reads consumed per second
before DynamoDB returns a ThrottlingException.
6065 6066 6067 6068 6069 6070 6071 6072 6073 |
# File 'lib/aws-sdk-securityhub/types.rb', line 6065 class AwsDynamoDbTableProvisionedThroughput < Struct.new( :last_decrease_date_time, :last_increase_date_time, :number_of_decreases_today, :read_capacity_units, :write_capacity_units) SENSITIVE = [] include Aws::Structure end |
#write_capacity_units ⇒ Integer
The maximum number of writes consumed per second before DynamoDB
returns a ThrottlingException.
6065 6066 6067 6068 6069 6070 6071 6072 6073 |
# File 'lib/aws-sdk-securityhub/types.rb', line 6065 class AwsDynamoDbTableProvisionedThroughput < Struct.new( :last_decrease_date_time, :last_increase_date_time, :number_of_decreases_today, :read_capacity_units, :write_capacity_units) SENSITIVE = [] include Aws::Structure end |