Class: Aws::SecurityHub::Types::AwsEc2EipDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::AwsEc2EipDetails
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Information about an Elastic IP address.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#allocation_id ⇒ String
The identifier that Amazon Web Services assigns to represent the allocation of the Elastic IP address for use with Amazon VPC.
-
#association_id ⇒ String
The identifier that represents the association of the Elastic IP address with an EC2 instance.
-
#domain ⇒ String
The domain in which to allocate the address.
-
#instance_id ⇒ String
The identifier of the EC2 instance.
-
#network_border_group ⇒ String
The name of the location from which the Elastic IP address is advertised.
-
#network_interface_id ⇒ String
The identifier of the network interface.
-
#network_interface_owner_id ⇒ String
The Amazon Web Services account ID of the owner of the network interface.
-
#private_ip_address ⇒ String
The private IP address that is associated with the Elastic IP address.
-
#public_ip ⇒ String
A public IP address that is associated with the EC2 instance.
-
#public_ipv_4_pool ⇒ String
The identifier of an IP address pool.
Instance Attribute Details
#allocation_id ⇒ String
The identifier that Amazon Web Services assigns to represent the allocation of the Elastic IP address for use with Amazon VPC.
6681 6682 6683 6684 6685 6686 6687 6688 6689 6690 6691 6692 6693 6694 |
# File 'lib/aws-sdk-securityhub/types.rb', line 6681 class AwsEc2EipDetails < Struct.new( :instance_id, :public_ip, :allocation_id, :association_id, :domain, :public_ipv_4_pool, :network_border_group, :network_interface_id, :network_interface_owner_id, :private_ip_address) SENSITIVE = [] include Aws::Structure end |
#association_id ⇒ String
The identifier that represents the association of the Elastic IP address with an EC2 instance.
6681 6682 6683 6684 6685 6686 6687 6688 6689 6690 6691 6692 6693 6694 |
# File 'lib/aws-sdk-securityhub/types.rb', line 6681 class AwsEc2EipDetails < Struct.new( :instance_id, :public_ip, :allocation_id, :association_id, :domain, :public_ipv_4_pool, :network_border_group, :network_interface_id, :network_interface_owner_id, :private_ip_address) SENSITIVE = [] include Aws::Structure end |
#domain ⇒ String
The domain in which to allocate the address.
If the address is for use with EC2 instances in a VPC, then Domain
is vpc. Otherwise, Domain is standard.
6681 6682 6683 6684 6685 6686 6687 6688 6689 6690 6691 6692 6693 6694 |
# File 'lib/aws-sdk-securityhub/types.rb', line 6681 class AwsEc2EipDetails < Struct.new( :instance_id, :public_ip, :allocation_id, :association_id, :domain, :public_ipv_4_pool, :network_border_group, :network_interface_id, :network_interface_owner_id, :private_ip_address) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the EC2 instance.
6681 6682 6683 6684 6685 6686 6687 6688 6689 6690 6691 6692 6693 6694 |
# File 'lib/aws-sdk-securityhub/types.rb', line 6681 class AwsEc2EipDetails < Struct.new( :instance_id, :public_ip, :allocation_id, :association_id, :domain, :public_ipv_4_pool, :network_border_group, :network_interface_id, :network_interface_owner_id, :private_ip_address) SENSITIVE = [] include Aws::Structure end |
#network_border_group ⇒ String
The name of the location from which the Elastic IP address is advertised.
6681 6682 6683 6684 6685 6686 6687 6688 6689 6690 6691 6692 6693 6694 |
# File 'lib/aws-sdk-securityhub/types.rb', line 6681 class AwsEc2EipDetails < Struct.new( :instance_id, :public_ip, :allocation_id, :association_id, :domain, :public_ipv_4_pool, :network_border_group, :network_interface_id, :network_interface_owner_id, :private_ip_address) SENSITIVE = [] include Aws::Structure end |
#network_interface_id ⇒ String
The identifier of the network interface.
6681 6682 6683 6684 6685 6686 6687 6688 6689 6690 6691 6692 6693 6694 |
# File 'lib/aws-sdk-securityhub/types.rb', line 6681 class AwsEc2EipDetails < Struct.new( :instance_id, :public_ip, :allocation_id, :association_id, :domain, :public_ipv_4_pool, :network_border_group, :network_interface_id, :network_interface_owner_id, :private_ip_address) SENSITIVE = [] include Aws::Structure end |
#network_interface_owner_id ⇒ String
The Amazon Web Services account ID of the owner of the network interface.
6681 6682 6683 6684 6685 6686 6687 6688 6689 6690 6691 6692 6693 6694 |
# File 'lib/aws-sdk-securityhub/types.rb', line 6681 class AwsEc2EipDetails < Struct.new( :instance_id, :public_ip, :allocation_id, :association_id, :domain, :public_ipv_4_pool, :network_border_group, :network_interface_id, :network_interface_owner_id, :private_ip_address) SENSITIVE = [] include Aws::Structure end |
#private_ip_address ⇒ String
The private IP address that is associated with the Elastic IP address.
6681 6682 6683 6684 6685 6686 6687 6688 6689 6690 6691 6692 6693 6694 |
# File 'lib/aws-sdk-securityhub/types.rb', line 6681 class AwsEc2EipDetails < Struct.new( :instance_id, :public_ip, :allocation_id, :association_id, :domain, :public_ipv_4_pool, :network_border_group, :network_interface_id, :network_interface_owner_id, :private_ip_address) SENSITIVE = [] include Aws::Structure end |
#public_ip ⇒ String
A public IP address that is associated with the EC2 instance.
6681 6682 6683 6684 6685 6686 6687 6688 6689 6690 6691 6692 6693 6694 |
# File 'lib/aws-sdk-securityhub/types.rb', line 6681 class AwsEc2EipDetails < Struct.new( :instance_id, :public_ip, :allocation_id, :association_id, :domain, :public_ipv_4_pool, :network_border_group, :network_interface_id, :network_interface_owner_id, :private_ip_address) SENSITIVE = [] include Aws::Structure end |
#public_ipv_4_pool ⇒ String
The identifier of an IP address pool. This parameter allows Amazon EC2 to select an IP address from the address pool.
6681 6682 6683 6684 6685 6686 6687 6688 6689 6690 6691 6692 6693 6694 |
# File 'lib/aws-sdk-securityhub/types.rb', line 6681 class AwsEc2EipDetails < Struct.new( :instance_id, :public_ip, :allocation_id, :association_id, :domain, :public_ipv_4_pool, :network_border_group, :network_interface_id, :network_interface_owner_id, :private_ip_address) SENSITIVE = [] include Aws::Structure end |