Class: Aws::SecurityHub::Types::AwsEc2InstanceDetails

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

The details of an Amazon EC2 instance.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#iam_instance_profile_arnString

The IAM profile ARN of the instance.



6791
6792
6793
6794
6795
6796
6797
6798
6799
6800
6801
6802
6803
6804
6805
6806
6807
# File 'lib/aws-sdk-securityhub/types.rb', line 6791

class AwsEc2InstanceDetails < Struct.new(
  :type,
  :image_id,
  :ip_v4_addresses,
  :ip_v6_addresses,
  :key_name,
  :iam_instance_profile_arn,
  :vpc_id,
  :subnet_id,
  :launched_at,
  :network_interfaces,
  :virtualization_type,
  :metadata_options,
  :monitoring)
  SENSITIVE = []
  include Aws::Structure
end

#image_idString

The Amazon Machine Image (AMI) ID of the instance.



6791
6792
6793
6794
6795
6796
6797
6798
6799
6800
6801
6802
6803
6804
6805
6806
6807
# File 'lib/aws-sdk-securityhub/types.rb', line 6791

class AwsEc2InstanceDetails < Struct.new(
  :type,
  :image_id,
  :ip_v4_addresses,
  :ip_v6_addresses,
  :key_name,
  :iam_instance_profile_arn,
  :vpc_id,
  :subnet_id,
  :launched_at,
  :network_interfaces,
  :virtualization_type,
  :metadata_options,
  :monitoring)
  SENSITIVE = []
  include Aws::Structure
end

#ip_v4_addressesArray<String>

The IPv4 addresses associated with the instance.



6791
6792
6793
6794
6795
6796
6797
6798
6799
6800
6801
6802
6803
6804
6805
6806
6807
# File 'lib/aws-sdk-securityhub/types.rb', line 6791

class AwsEc2InstanceDetails < Struct.new(
  :type,
  :image_id,
  :ip_v4_addresses,
  :ip_v6_addresses,
  :key_name,
  :iam_instance_profile_arn,
  :vpc_id,
  :subnet_id,
  :launched_at,
  :network_interfaces,
  :virtualization_type,
  :metadata_options,
  :monitoring)
  SENSITIVE = []
  include Aws::Structure
end

#ip_v6_addressesArray<String>

The IPv6 addresses associated with the instance.



6791
6792
6793
6794
6795
6796
6797
6798
6799
6800
6801
6802
6803
6804
6805
6806
6807
# File 'lib/aws-sdk-securityhub/types.rb', line 6791

class AwsEc2InstanceDetails < Struct.new(
  :type,
  :image_id,
  :ip_v4_addresses,
  :ip_v6_addresses,
  :key_name,
  :iam_instance_profile_arn,
  :vpc_id,
  :subnet_id,
  :launched_at,
  :network_interfaces,
  :virtualization_type,
  :metadata_options,
  :monitoring)
  SENSITIVE = []
  include Aws::Structure
end

#key_nameString

The key name associated with the instance.



6791
6792
6793
6794
6795
6796
6797
6798
6799
6800
6801
6802
6803
6804
6805
6806
6807
# File 'lib/aws-sdk-securityhub/types.rb', line 6791

class AwsEc2InstanceDetails < Struct.new(
  :type,
  :image_id,
  :ip_v4_addresses,
  :ip_v6_addresses,
  :key_name,
  :iam_instance_profile_arn,
  :vpc_id,
  :subnet_id,
  :launched_at,
  :network_interfaces,
  :virtualization_type,
  :metadata_options,
  :monitoring)
  SENSITIVE = []
  include Aws::Structure
end

#launched_atString

Indicates when the instance was launched.

For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.



6791
6792
6793
6794
6795
6796
6797
6798
6799
6800
6801
6802
6803
6804
6805
6806
6807
# File 'lib/aws-sdk-securityhub/types.rb', line 6791

class AwsEc2InstanceDetails < Struct.new(
  :type,
  :image_id,
  :ip_v4_addresses,
  :ip_v6_addresses,
  :key_name,
  :iam_instance_profile_arn,
  :vpc_id,
  :subnet_id,
  :launched_at,
  :network_interfaces,
  :virtualization_type,
  :metadata_options,
  :monitoring)
  SENSITIVE = []
  include Aws::Structure
end

#metadata_optionsTypes::AwsEc2InstanceMetadataOptions

Details about the metadata options for the Amazon EC2 instance.



6791
6792
6793
6794
6795
6796
6797
6798
6799
6800
6801
6802
6803
6804
6805
6806
6807
# File 'lib/aws-sdk-securityhub/types.rb', line 6791

class AwsEc2InstanceDetails < Struct.new(
  :type,
  :image_id,
  :ip_v4_addresses,
  :ip_v6_addresses,
  :key_name,
  :iam_instance_profile_arn,
  :vpc_id,
  :subnet_id,
  :launched_at,
  :network_interfaces,
  :virtualization_type,
  :metadata_options,
  :monitoring)
  SENSITIVE = []
  include Aws::Structure
end

#monitoringTypes::AwsEc2InstanceMonitoringDetails

Describes the type of monitoring that’s turned on for an instance.



6791
6792
6793
6794
6795
6796
6797
6798
6799
6800
6801
6802
6803
6804
6805
6806
6807
# File 'lib/aws-sdk-securityhub/types.rb', line 6791

class AwsEc2InstanceDetails < Struct.new(
  :type,
  :image_id,
  :ip_v4_addresses,
  :ip_v6_addresses,
  :key_name,
  :iam_instance_profile_arn,
  :vpc_id,
  :subnet_id,
  :launched_at,
  :network_interfaces,
  :virtualization_type,
  :metadata_options,
  :monitoring)
  SENSITIVE = []
  include Aws::Structure
end

#network_interfacesArray<Types::AwsEc2InstanceNetworkInterfacesDetails>

The identifiers of the network interfaces for the EC2 instance. The details for each network interface are in a corresponding AwsEc2NetworkInterfacesDetails object.



6791
6792
6793
6794
6795
6796
6797
6798
6799
6800
6801
6802
6803
6804
6805
6806
6807
# File 'lib/aws-sdk-securityhub/types.rb', line 6791

class AwsEc2InstanceDetails < Struct.new(
  :type,
  :image_id,
  :ip_v4_addresses,
  :ip_v6_addresses,
  :key_name,
  :iam_instance_profile_arn,
  :vpc_id,
  :subnet_id,
  :launched_at,
  :network_interfaces,
  :virtualization_type,
  :metadata_options,
  :monitoring)
  SENSITIVE = []
  include Aws::Structure
end

#subnet_idString

The identifier of the subnet that the instance was launched in.



6791
6792
6793
6794
6795
6796
6797
6798
6799
6800
6801
6802
6803
6804
6805
6806
6807
# File 'lib/aws-sdk-securityhub/types.rb', line 6791

class AwsEc2InstanceDetails < Struct.new(
  :type,
  :image_id,
  :ip_v4_addresses,
  :ip_v6_addresses,
  :key_name,
  :iam_instance_profile_arn,
  :vpc_id,
  :subnet_id,
  :launched_at,
  :network_interfaces,
  :virtualization_type,
  :metadata_options,
  :monitoring)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The instance type of the instance.



6791
6792
6793
6794
6795
6796
6797
6798
6799
6800
6801
6802
6803
6804
6805
6806
6807
# File 'lib/aws-sdk-securityhub/types.rb', line 6791

class AwsEc2InstanceDetails < Struct.new(
  :type,
  :image_id,
  :ip_v4_addresses,
  :ip_v6_addresses,
  :key_name,
  :iam_instance_profile_arn,
  :vpc_id,
  :subnet_id,
  :launched_at,
  :network_interfaces,
  :virtualization_type,
  :metadata_options,
  :monitoring)
  SENSITIVE = []
  include Aws::Structure
end

#virtualization_typeString

The virtualization type of the Amazon Machine Image (AMI) required to launch the instance.



6791
6792
6793
6794
6795
6796
6797
6798
6799
6800
6801
6802
6803
6804
6805
6806
6807
# File 'lib/aws-sdk-securityhub/types.rb', line 6791

class AwsEc2InstanceDetails < Struct.new(
  :type,
  :image_id,
  :ip_v4_addresses,
  :ip_v6_addresses,
  :key_name,
  :iam_instance_profile_arn,
  :vpc_id,
  :subnet_id,
  :launched_at,
  :network_interfaces,
  :virtualization_type,
  :metadata_options,
  :monitoring)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_idString

The identifier of the VPC that the instance was launched in.



6791
6792
6793
6794
6795
6796
6797
6798
6799
6800
6801
6802
6803
6804
6805
6806
6807
# File 'lib/aws-sdk-securityhub/types.rb', line 6791

class AwsEc2InstanceDetails < Struct.new(
  :type,
  :image_id,
  :ip_v4_addresses,
  :ip_v6_addresses,
  :key_name,
  :iam_instance_profile_arn,
  :vpc_id,
  :subnet_id,
  :launched_at,
  :network_interfaces,
  :virtualization_type,
  :metadata_options,
  :monitoring)
  SENSITIVE = []
  include Aws::Structure
end