Class: Aws::SecurityHub::Types::AwsEc2LaunchTemplateDataBlockDeviceMappingSetEbsDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::AwsEc2LaunchTemplateDataBlockDeviceMappingSetEbsDetails
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Parameters for a block device for an Amazon Elastic Block Store (Amazon EBS) volume in an Amazon EC2 launch template.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#delete_on_termination ⇒ Boolean
Indicates whether the EBS volume is deleted on instance termination.
-
#encrypted ⇒ Boolean
Indicates whether the EBS volume is encrypted.
-
#iops ⇒ Integer
The number of I/O operations per second (IOPS).
-
#kms_key_id ⇒ String
The Amazon Resource Name (ARN) of the symmetric Key Management Service (KMS) customer managed key used for encryption.
-
#snapshot_id ⇒ String
The ID of the EBS snapshot.
-
#throughput ⇒ Integer
The throughput to provision for a gp3 volume, with a maximum of 1,000 MiB/s.
-
#volume_size ⇒ Integer
The size of the volume, in GiBs.
-
#volume_type ⇒ String
The volume type.
Instance Attribute Details
#delete_on_termination ⇒ Boolean
Indicates whether the EBS volume is deleted on instance termination.
6827 6828 6829 6830 6831 6832 6833 6834 6835 6836 6837 6838 |
# File 'lib/aws-sdk-securityhub/types.rb', line 6827 class AwsEc2LaunchTemplateDataBlockDeviceMappingSetEbsDetails < Struct.new( :delete_on_termination, :encrypted, :iops, :kms_key_id, :snapshot_id, :throughput, :volume_size, :volume_type) SENSITIVE = [] include Aws::Structure end |
#encrypted ⇒ Boolean
Indicates whether the EBS volume is encrypted. Encrypted volumes can only be attached to instances that support Amazon EBS encryption. If you're creating a volume from a snapshot, you can't specify an encryption value.
6827 6828 6829 6830 6831 6832 6833 6834 6835 6836 6837 6838 |
# File 'lib/aws-sdk-securityhub/types.rb', line 6827 class AwsEc2LaunchTemplateDataBlockDeviceMappingSetEbsDetails < Struct.new( :delete_on_termination, :encrypted, :iops, :kms_key_id, :snapshot_id, :throughput, :volume_size, :volume_type) SENSITIVE = [] include Aws::Structure end |
#iops ⇒ Integer
The number of I/O operations per second (IOPS).
6827 6828 6829 6830 6831 6832 6833 6834 6835 6836 6837 6838 |
# File 'lib/aws-sdk-securityhub/types.rb', line 6827 class AwsEc2LaunchTemplateDataBlockDeviceMappingSetEbsDetails < Struct.new( :delete_on_termination, :encrypted, :iops, :kms_key_id, :snapshot_id, :throughput, :volume_size, :volume_type) SENSITIVE = [] include Aws::Structure end |
#kms_key_id ⇒ String
The Amazon Resource Name (ARN) of the symmetric Key Management Service (KMS) customer managed key used for encryption.
6827 6828 6829 6830 6831 6832 6833 6834 6835 6836 6837 6838 |
# File 'lib/aws-sdk-securityhub/types.rb', line 6827 class AwsEc2LaunchTemplateDataBlockDeviceMappingSetEbsDetails < Struct.new( :delete_on_termination, :encrypted, :iops, :kms_key_id, :snapshot_id, :throughput, :volume_size, :volume_type) SENSITIVE = [] include Aws::Structure end |
#snapshot_id ⇒ String
The ID of the EBS snapshot.
6827 6828 6829 6830 6831 6832 6833 6834 6835 6836 6837 6838 |
# File 'lib/aws-sdk-securityhub/types.rb', line 6827 class AwsEc2LaunchTemplateDataBlockDeviceMappingSetEbsDetails < Struct.new( :delete_on_termination, :encrypted, :iops, :kms_key_id, :snapshot_id, :throughput, :volume_size, :volume_type) SENSITIVE = [] include Aws::Structure end |
#throughput ⇒ Integer
The throughput to provision for a gp3 volume, with a maximum of 1,000 MiB/s.
6827 6828 6829 6830 6831 6832 6833 6834 6835 6836 6837 6838 |
# File 'lib/aws-sdk-securityhub/types.rb', line 6827 class AwsEc2LaunchTemplateDataBlockDeviceMappingSetEbsDetails < Struct.new( :delete_on_termination, :encrypted, :iops, :kms_key_id, :snapshot_id, :throughput, :volume_size, :volume_type) SENSITIVE = [] include Aws::Structure end |
#volume_size ⇒ Integer
The size of the volume, in GiBs. You must specify either a snapshot ID or a volume size.
6827 6828 6829 6830 6831 6832 6833 6834 6835 6836 6837 6838 |
# File 'lib/aws-sdk-securityhub/types.rb', line 6827 class AwsEc2LaunchTemplateDataBlockDeviceMappingSetEbsDetails < Struct.new( :delete_on_termination, :encrypted, :iops, :kms_key_id, :snapshot_id, :throughput, :volume_size, :volume_type) SENSITIVE = [] include Aws::Structure end |
#volume_type ⇒ String
The volume type.
6827 6828 6829 6830 6831 6832 6833 6834 6835 6836 6837 6838 |
# File 'lib/aws-sdk-securityhub/types.rb', line 6827 class AwsEc2LaunchTemplateDataBlockDeviceMappingSetEbsDetails < Struct.new( :delete_on_termination, :encrypted, :iops, :kms_key_id, :snapshot_id, :throughput, :volume_size, :volume_type) SENSITIVE = [] include Aws::Structure end |