Class: Aws::SecurityHub::Types::AwsEc2LaunchTemplateDataInstanceRequirementsDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::AwsEc2LaunchTemplateDataInstanceRequirementsDetails
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
The attributes for the Amazon EC2 instance types.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#accelerator_count ⇒ Types::AwsEc2LaunchTemplateDataInstanceRequirementsAcceleratorCountDetails
The minimum and maximum number of accelerators (GPUs, FPGAs, or Amazon Web Services Inferentia chips) on an instance.
-
#accelerator_manufacturers ⇒ Array<String>
Indicates whether instance types must have accelerators by specific manufacturers.
-
#accelerator_names ⇒ Array<String>
The accelerators that must be on the instance type.
-
#accelerator_total_memory_mi_b ⇒ Types::AwsEc2LaunchTemplateDataInstanceRequirementsAcceleratorTotalMemoryMiBDetails
The minimum and maximum amount of total accelerator memory, in MiB.
-
#accelerator_types ⇒ Array<String>
The accelerator types that must be on the instance type.
-
#bare_metal ⇒ String
Indicates whether bare metal instance types must be included, excluded, or required.
-
#baseline_ebs_bandwidth_mbps ⇒ Types::AwsEc2LaunchTemplateDataInstanceRequirementsBaselineEbsBandwidthMbpsDetails
The minimum and maximum baseline bandwidth to Amazon EBS, in Mbps.
-
#burstable_performance ⇒ String
Indicates whether burstable performance T instance types are included, excluded, or required.
-
#cpu_manufacturers ⇒ Array<String>
The CPU manufacturers to include.
-
#excluded_instance_types ⇒ Array<String>
The instance types to exclude.
-
#instance_generations ⇒ Array<String>
Indicates whether current or previous generation instance types are included.
-
#local_storage ⇒ String
Indicates whether instance types with instance store volumes are included, excluded, or required.
-
#local_storage_types ⇒ Array<String>
The type of local storage that is required.
-
#memory_gi_b_per_v_cpu ⇒ Types::AwsEc2LaunchTemplateDataInstanceRequirementsMemoryGiBPerVCpuDetails
The minimum and maximum amount of memory per vCPU, in GiB.
-
#memory_mi_b ⇒ Types::AwsEc2LaunchTemplateDataInstanceRequirementsMemoryMiBDetails
The minimum and maximum amount of memory, in MiB.
-
#network_interface_count ⇒ Types::AwsEc2LaunchTemplateDataInstanceRequirementsNetworkInterfaceCountDetails
The minimum and maximum number of network interfaces.
-
#on_demand_max_price_percentage_over_lowest_price ⇒ Integer
The price protection threshold for On-Demand Instances.
-
#require_hibernate_support ⇒ Boolean
Indicates whether instance types must support hibernation for On-Demand Instances.
-
#spot_max_price_percentage_over_lowest_price ⇒ Integer
The price protection threshold for Spot Instances.
-
#total_local_storage_gb ⇒ Types::AwsEc2LaunchTemplateDataInstanceRequirementsTotalLocalStorageGBDetails
The minimum and maximum amount of total local storage, in GB.
-
#v_cpu_count ⇒ Types::AwsEc2LaunchTemplateDataInstanceRequirementsVCpuCountDetails
The minimum and maximum number of vCPUs.
Instance Attribute Details
#accelerator_count ⇒ Types::AwsEc2LaunchTemplateDataInstanceRequirementsAcceleratorCountDetails
The minimum and maximum number of accelerators (GPUs, FPGAs, or Amazon Web Services Inferentia chips) on an instance.
7473 7474 7475 7476 7477 7478 7479 7480 7481 7482 7483 7484 7485 7486 7487 7488 7489 7490 7491 7492 7493 7494 7495 7496 7497 |
# File 'lib/aws-sdk-securityhub/types.rb', line 7473 class AwsEc2LaunchTemplateDataInstanceRequirementsDetails < Struct.new( :accelerator_count, :accelerator_manufacturers, :accelerator_names, :accelerator_total_memory_mi_b, :accelerator_types, :bare_metal, :baseline_ebs_bandwidth_mbps, :burstable_performance, :cpu_manufacturers, :excluded_instance_types, :instance_generations, :local_storage, :local_storage_types, :memory_gi_b_per_v_cpu, :memory_mi_b, :network_interface_count, :on_demand_max_price_percentage_over_lowest_price, :require_hibernate_support, :spot_max_price_percentage_over_lowest_price, :total_local_storage_gb, :v_cpu_count) SENSITIVE = [] include Aws::Structure end |
#accelerator_manufacturers ⇒ Array<String>
Indicates whether instance types must have accelerators by specific manufacturers.
7473 7474 7475 7476 7477 7478 7479 7480 7481 7482 7483 7484 7485 7486 7487 7488 7489 7490 7491 7492 7493 7494 7495 7496 7497 |
# File 'lib/aws-sdk-securityhub/types.rb', line 7473 class AwsEc2LaunchTemplateDataInstanceRequirementsDetails < Struct.new( :accelerator_count, :accelerator_manufacturers, :accelerator_names, :accelerator_total_memory_mi_b, :accelerator_types, :bare_metal, :baseline_ebs_bandwidth_mbps, :burstable_performance, :cpu_manufacturers, :excluded_instance_types, :instance_generations, :local_storage, :local_storage_types, :memory_gi_b_per_v_cpu, :memory_mi_b, :network_interface_count, :on_demand_max_price_percentage_over_lowest_price, :require_hibernate_support, :spot_max_price_percentage_over_lowest_price, :total_local_storage_gb, :v_cpu_count) SENSITIVE = [] include Aws::Structure end |
#accelerator_names ⇒ Array<String>
The accelerators that must be on the instance type.
7473 7474 7475 7476 7477 7478 7479 7480 7481 7482 7483 7484 7485 7486 7487 7488 7489 7490 7491 7492 7493 7494 7495 7496 7497 |
# File 'lib/aws-sdk-securityhub/types.rb', line 7473 class AwsEc2LaunchTemplateDataInstanceRequirementsDetails < Struct.new( :accelerator_count, :accelerator_manufacturers, :accelerator_names, :accelerator_total_memory_mi_b, :accelerator_types, :bare_metal, :baseline_ebs_bandwidth_mbps, :burstable_performance, :cpu_manufacturers, :excluded_instance_types, :instance_generations, :local_storage, :local_storage_types, :memory_gi_b_per_v_cpu, :memory_mi_b, :network_interface_count, :on_demand_max_price_percentage_over_lowest_price, :require_hibernate_support, :spot_max_price_percentage_over_lowest_price, :total_local_storage_gb, :v_cpu_count) SENSITIVE = [] include Aws::Structure end |
#accelerator_total_memory_mi_b ⇒ Types::AwsEc2LaunchTemplateDataInstanceRequirementsAcceleratorTotalMemoryMiBDetails
The minimum and maximum amount of total accelerator memory, in MiB.
7473 7474 7475 7476 7477 7478 7479 7480 7481 7482 7483 7484 7485 7486 7487 7488 7489 7490 7491 7492 7493 7494 7495 7496 7497 |
# File 'lib/aws-sdk-securityhub/types.rb', line 7473 class AwsEc2LaunchTemplateDataInstanceRequirementsDetails < Struct.new( :accelerator_count, :accelerator_manufacturers, :accelerator_names, :accelerator_total_memory_mi_b, :accelerator_types, :bare_metal, :baseline_ebs_bandwidth_mbps, :burstable_performance, :cpu_manufacturers, :excluded_instance_types, :instance_generations, :local_storage, :local_storage_types, :memory_gi_b_per_v_cpu, :memory_mi_b, :network_interface_count, :on_demand_max_price_percentage_over_lowest_price, :require_hibernate_support, :spot_max_price_percentage_over_lowest_price, :total_local_storage_gb, :v_cpu_count) SENSITIVE = [] include Aws::Structure end |
#accelerator_types ⇒ Array<String>
The accelerator types that must be on the instance type.
7473 7474 7475 7476 7477 7478 7479 7480 7481 7482 7483 7484 7485 7486 7487 7488 7489 7490 7491 7492 7493 7494 7495 7496 7497 |
# File 'lib/aws-sdk-securityhub/types.rb', line 7473 class AwsEc2LaunchTemplateDataInstanceRequirementsDetails < Struct.new( :accelerator_count, :accelerator_manufacturers, :accelerator_names, :accelerator_total_memory_mi_b, :accelerator_types, :bare_metal, :baseline_ebs_bandwidth_mbps, :burstable_performance, :cpu_manufacturers, :excluded_instance_types, :instance_generations, :local_storage, :local_storage_types, :memory_gi_b_per_v_cpu, :memory_mi_b, :network_interface_count, :on_demand_max_price_percentage_over_lowest_price, :require_hibernate_support, :spot_max_price_percentage_over_lowest_price, :total_local_storage_gb, :v_cpu_count) SENSITIVE = [] include Aws::Structure end |
#bare_metal ⇒ String
Indicates whether bare metal instance types must be included, excluded, or required.
7473 7474 7475 7476 7477 7478 7479 7480 7481 7482 7483 7484 7485 7486 7487 7488 7489 7490 7491 7492 7493 7494 7495 7496 7497 |
# File 'lib/aws-sdk-securityhub/types.rb', line 7473 class AwsEc2LaunchTemplateDataInstanceRequirementsDetails < Struct.new( :accelerator_count, :accelerator_manufacturers, :accelerator_names, :accelerator_total_memory_mi_b, :accelerator_types, :bare_metal, :baseline_ebs_bandwidth_mbps, :burstable_performance, :cpu_manufacturers, :excluded_instance_types, :instance_generations, :local_storage, :local_storage_types, :memory_gi_b_per_v_cpu, :memory_mi_b, :network_interface_count, :on_demand_max_price_percentage_over_lowest_price, :require_hibernate_support, :spot_max_price_percentage_over_lowest_price, :total_local_storage_gb, :v_cpu_count) SENSITIVE = [] include Aws::Structure end |
#baseline_ebs_bandwidth_mbps ⇒ Types::AwsEc2LaunchTemplateDataInstanceRequirementsBaselineEbsBandwidthMbpsDetails
The minimum and maximum baseline bandwidth to Amazon EBS, in Mbps. For more information, see Amazon EBS optimized instances in the Amazon EC2 User Guide.
7473 7474 7475 7476 7477 7478 7479 7480 7481 7482 7483 7484 7485 7486 7487 7488 7489 7490 7491 7492 7493 7494 7495 7496 7497 |
# File 'lib/aws-sdk-securityhub/types.rb', line 7473 class AwsEc2LaunchTemplateDataInstanceRequirementsDetails < Struct.new( :accelerator_count, :accelerator_manufacturers, :accelerator_names, :accelerator_total_memory_mi_b, :accelerator_types, :bare_metal, :baseline_ebs_bandwidth_mbps, :burstable_performance, :cpu_manufacturers, :excluded_instance_types, :instance_generations, :local_storage, :local_storage_types, :memory_gi_b_per_v_cpu, :memory_mi_b, :network_interface_count, :on_demand_max_price_percentage_over_lowest_price, :require_hibernate_support, :spot_max_price_percentage_over_lowest_price, :total_local_storage_gb, :v_cpu_count) SENSITIVE = [] include Aws::Structure end |
#burstable_performance ⇒ String
Indicates whether burstable performance T instance types are included, excluded, or required. For more information, Burstable performance instances in the Amazon EC2 User Guide.
7473 7474 7475 7476 7477 7478 7479 7480 7481 7482 7483 7484 7485 7486 7487 7488 7489 7490 7491 7492 7493 7494 7495 7496 7497 |
# File 'lib/aws-sdk-securityhub/types.rb', line 7473 class AwsEc2LaunchTemplateDataInstanceRequirementsDetails < Struct.new( :accelerator_count, :accelerator_manufacturers, :accelerator_names, :accelerator_total_memory_mi_b, :accelerator_types, :bare_metal, :baseline_ebs_bandwidth_mbps, :burstable_performance, :cpu_manufacturers, :excluded_instance_types, :instance_generations, :local_storage, :local_storage_types, :memory_gi_b_per_v_cpu, :memory_mi_b, :network_interface_count, :on_demand_max_price_percentage_over_lowest_price, :require_hibernate_support, :spot_max_price_percentage_over_lowest_price, :total_local_storage_gb, :v_cpu_count) SENSITIVE = [] include Aws::Structure end |
#cpu_manufacturers ⇒ Array<String>
The CPU manufacturers to include.
7473 7474 7475 7476 7477 7478 7479 7480 7481 7482 7483 7484 7485 7486 7487 7488 7489 7490 7491 7492 7493 7494 7495 7496 7497 |
# File 'lib/aws-sdk-securityhub/types.rb', line 7473 class AwsEc2LaunchTemplateDataInstanceRequirementsDetails < Struct.new( :accelerator_count, :accelerator_manufacturers, :accelerator_names, :accelerator_total_memory_mi_b, :accelerator_types, :bare_metal, :baseline_ebs_bandwidth_mbps, :burstable_performance, :cpu_manufacturers, :excluded_instance_types, :instance_generations, :local_storage, :local_storage_types, :memory_gi_b_per_v_cpu, :memory_mi_b, :network_interface_count, :on_demand_max_price_percentage_over_lowest_price, :require_hibernate_support, :spot_max_price_percentage_over_lowest_price, :total_local_storage_gb, :v_cpu_count) SENSITIVE = [] include Aws::Structure end |
#excluded_instance_types ⇒ Array<String>
The instance types to exclude.
7473 7474 7475 7476 7477 7478 7479 7480 7481 7482 7483 7484 7485 7486 7487 7488 7489 7490 7491 7492 7493 7494 7495 7496 7497 |
# File 'lib/aws-sdk-securityhub/types.rb', line 7473 class AwsEc2LaunchTemplateDataInstanceRequirementsDetails < Struct.new( :accelerator_count, :accelerator_manufacturers, :accelerator_names, :accelerator_total_memory_mi_b, :accelerator_types, :bare_metal, :baseline_ebs_bandwidth_mbps, :burstable_performance, :cpu_manufacturers, :excluded_instance_types, :instance_generations, :local_storage, :local_storage_types, :memory_gi_b_per_v_cpu, :memory_mi_b, :network_interface_count, :on_demand_max_price_percentage_over_lowest_price, :require_hibernate_support, :spot_max_price_percentage_over_lowest_price, :total_local_storage_gb, :v_cpu_count) SENSITIVE = [] include Aws::Structure end |
#instance_generations ⇒ Array<String>
Indicates whether current or previous generation instance types are included.
7473 7474 7475 7476 7477 7478 7479 7480 7481 7482 7483 7484 7485 7486 7487 7488 7489 7490 7491 7492 7493 7494 7495 7496 7497 |
# File 'lib/aws-sdk-securityhub/types.rb', line 7473 class AwsEc2LaunchTemplateDataInstanceRequirementsDetails < Struct.new( :accelerator_count, :accelerator_manufacturers, :accelerator_names, :accelerator_total_memory_mi_b, :accelerator_types, :bare_metal, :baseline_ebs_bandwidth_mbps, :burstable_performance, :cpu_manufacturers, :excluded_instance_types, :instance_generations, :local_storage, :local_storage_types, :memory_gi_b_per_v_cpu, :memory_mi_b, :network_interface_count, :on_demand_max_price_percentage_over_lowest_price, :require_hibernate_support, :spot_max_price_percentage_over_lowest_price, :total_local_storage_gb, :v_cpu_count) SENSITIVE = [] include Aws::Structure end |
#local_storage ⇒ String
Indicates whether instance types with instance store volumes are included, excluded, or required. For more information, see Amazon EC2 instance store in the Amazon EC2 User Guide.
7473 7474 7475 7476 7477 7478 7479 7480 7481 7482 7483 7484 7485 7486 7487 7488 7489 7490 7491 7492 7493 7494 7495 7496 7497 |
# File 'lib/aws-sdk-securityhub/types.rb', line 7473 class AwsEc2LaunchTemplateDataInstanceRequirementsDetails < Struct.new( :accelerator_count, :accelerator_manufacturers, :accelerator_names, :accelerator_total_memory_mi_b, :accelerator_types, :bare_metal, :baseline_ebs_bandwidth_mbps, :burstable_performance, :cpu_manufacturers, :excluded_instance_types, :instance_generations, :local_storage, :local_storage_types, :memory_gi_b_per_v_cpu, :memory_mi_b, :network_interface_count, :on_demand_max_price_percentage_over_lowest_price, :require_hibernate_support, :spot_max_price_percentage_over_lowest_price, :total_local_storage_gb, :v_cpu_count) SENSITIVE = [] include Aws::Structure end |
#local_storage_types ⇒ Array<String>
The type of local storage that is required.
7473 7474 7475 7476 7477 7478 7479 7480 7481 7482 7483 7484 7485 7486 7487 7488 7489 7490 7491 7492 7493 7494 7495 7496 7497 |
# File 'lib/aws-sdk-securityhub/types.rb', line 7473 class AwsEc2LaunchTemplateDataInstanceRequirementsDetails < Struct.new( :accelerator_count, :accelerator_manufacturers, :accelerator_names, :accelerator_total_memory_mi_b, :accelerator_types, :bare_metal, :baseline_ebs_bandwidth_mbps, :burstable_performance, :cpu_manufacturers, :excluded_instance_types, :instance_generations, :local_storage, :local_storage_types, :memory_gi_b_per_v_cpu, :memory_mi_b, :network_interface_count, :on_demand_max_price_percentage_over_lowest_price, :require_hibernate_support, :spot_max_price_percentage_over_lowest_price, :total_local_storage_gb, :v_cpu_count) SENSITIVE = [] include Aws::Structure end |
#memory_gi_b_per_v_cpu ⇒ Types::AwsEc2LaunchTemplateDataInstanceRequirementsMemoryGiBPerVCpuDetails
The minimum and maximum amount of memory per vCPU, in GiB.
7473 7474 7475 7476 7477 7478 7479 7480 7481 7482 7483 7484 7485 7486 7487 7488 7489 7490 7491 7492 7493 7494 7495 7496 7497 |
# File 'lib/aws-sdk-securityhub/types.rb', line 7473 class AwsEc2LaunchTemplateDataInstanceRequirementsDetails < Struct.new( :accelerator_count, :accelerator_manufacturers, :accelerator_names, :accelerator_total_memory_mi_b, :accelerator_types, :bare_metal, :baseline_ebs_bandwidth_mbps, :burstable_performance, :cpu_manufacturers, :excluded_instance_types, :instance_generations, :local_storage, :local_storage_types, :memory_gi_b_per_v_cpu, :memory_mi_b, :network_interface_count, :on_demand_max_price_percentage_over_lowest_price, :require_hibernate_support, :spot_max_price_percentage_over_lowest_price, :total_local_storage_gb, :v_cpu_count) SENSITIVE = [] include Aws::Structure end |
#memory_mi_b ⇒ Types::AwsEc2LaunchTemplateDataInstanceRequirementsMemoryMiBDetails
The minimum and maximum amount of memory, in MiB.
7473 7474 7475 7476 7477 7478 7479 7480 7481 7482 7483 7484 7485 7486 7487 7488 7489 7490 7491 7492 7493 7494 7495 7496 7497 |
# File 'lib/aws-sdk-securityhub/types.rb', line 7473 class AwsEc2LaunchTemplateDataInstanceRequirementsDetails < Struct.new( :accelerator_count, :accelerator_manufacturers, :accelerator_names, :accelerator_total_memory_mi_b, :accelerator_types, :bare_metal, :baseline_ebs_bandwidth_mbps, :burstable_performance, :cpu_manufacturers, :excluded_instance_types, :instance_generations, :local_storage, :local_storage_types, :memory_gi_b_per_v_cpu, :memory_mi_b, :network_interface_count, :on_demand_max_price_percentage_over_lowest_price, :require_hibernate_support, :spot_max_price_percentage_over_lowest_price, :total_local_storage_gb, :v_cpu_count) SENSITIVE = [] include Aws::Structure end |
#network_interface_count ⇒ Types::AwsEc2LaunchTemplateDataInstanceRequirementsNetworkInterfaceCountDetails
The minimum and maximum number of network interfaces.
7473 7474 7475 7476 7477 7478 7479 7480 7481 7482 7483 7484 7485 7486 7487 7488 7489 7490 7491 7492 7493 7494 7495 7496 7497 |
# File 'lib/aws-sdk-securityhub/types.rb', line 7473 class AwsEc2LaunchTemplateDataInstanceRequirementsDetails < Struct.new( :accelerator_count, :accelerator_manufacturers, :accelerator_names, :accelerator_total_memory_mi_b, :accelerator_types, :bare_metal, :baseline_ebs_bandwidth_mbps, :burstable_performance, :cpu_manufacturers, :excluded_instance_types, :instance_generations, :local_storage, :local_storage_types, :memory_gi_b_per_v_cpu, :memory_mi_b, :network_interface_count, :on_demand_max_price_percentage_over_lowest_price, :require_hibernate_support, :spot_max_price_percentage_over_lowest_price, :total_local_storage_gb, :v_cpu_count) SENSITIVE = [] include Aws::Structure end |
#on_demand_max_price_percentage_over_lowest_price ⇒ Integer
The price protection threshold for On-Demand Instances. This is the maximum you'll pay for an On-Demand Instance, expressed as a percentage above the least expensive current generation M, C, or R instance type with your specified attributes. When Amazon EC2 selects instance types with your attributes, it excludes instance types priced above your threshold.
The parameter accepts an integer, which Amazon EC2 interprets as a percentage.
A high value, such as 999999, turns off price protection.
7473 7474 7475 7476 7477 7478 7479 7480 7481 7482 7483 7484 7485 7486 7487 7488 7489 7490 7491 7492 7493 7494 7495 7496 7497 |
# File 'lib/aws-sdk-securityhub/types.rb', line 7473 class AwsEc2LaunchTemplateDataInstanceRequirementsDetails < Struct.new( :accelerator_count, :accelerator_manufacturers, :accelerator_names, :accelerator_total_memory_mi_b, :accelerator_types, :bare_metal, :baseline_ebs_bandwidth_mbps, :burstable_performance, :cpu_manufacturers, :excluded_instance_types, :instance_generations, :local_storage, :local_storage_types, :memory_gi_b_per_v_cpu, :memory_mi_b, :network_interface_count, :on_demand_max_price_percentage_over_lowest_price, :require_hibernate_support, :spot_max_price_percentage_over_lowest_price, :total_local_storage_gb, :v_cpu_count) SENSITIVE = [] include Aws::Structure end |
#require_hibernate_support ⇒ Boolean
Indicates whether instance types must support hibernation for On-Demand Instances.
7473 7474 7475 7476 7477 7478 7479 7480 7481 7482 7483 7484 7485 7486 7487 7488 7489 7490 7491 7492 7493 7494 7495 7496 7497 |
# File 'lib/aws-sdk-securityhub/types.rb', line 7473 class AwsEc2LaunchTemplateDataInstanceRequirementsDetails < Struct.new( :accelerator_count, :accelerator_manufacturers, :accelerator_names, :accelerator_total_memory_mi_b, :accelerator_types, :bare_metal, :baseline_ebs_bandwidth_mbps, :burstable_performance, :cpu_manufacturers, :excluded_instance_types, :instance_generations, :local_storage, :local_storage_types, :memory_gi_b_per_v_cpu, :memory_mi_b, :network_interface_count, :on_demand_max_price_percentage_over_lowest_price, :require_hibernate_support, :spot_max_price_percentage_over_lowest_price, :total_local_storage_gb, :v_cpu_count) SENSITIVE = [] include Aws::Structure end |
#spot_max_price_percentage_over_lowest_price ⇒ Integer
The price protection threshold for Spot Instances. This is the maximum you'll pay for a Spot Instance, expressed as a percentage above the least expensive current generation M, C, or R instance type with your specified attributes. When Amazon EC2 selects instance types with your attributes, it excludes instance types priced above your threshold.
The parameter accepts an integer, which Amazon EC2 interprets as a percentage.
A high value, such as 999999, turns off price protection.
7473 7474 7475 7476 7477 7478 7479 7480 7481 7482 7483 7484 7485 7486 7487 7488 7489 7490 7491 7492 7493 7494 7495 7496 7497 |
# File 'lib/aws-sdk-securityhub/types.rb', line 7473 class AwsEc2LaunchTemplateDataInstanceRequirementsDetails < Struct.new( :accelerator_count, :accelerator_manufacturers, :accelerator_names, :accelerator_total_memory_mi_b, :accelerator_types, :bare_metal, :baseline_ebs_bandwidth_mbps, :burstable_performance, :cpu_manufacturers, :excluded_instance_types, :instance_generations, :local_storage, :local_storage_types, :memory_gi_b_per_v_cpu, :memory_mi_b, :network_interface_count, :on_demand_max_price_percentage_over_lowest_price, :require_hibernate_support, :spot_max_price_percentage_over_lowest_price, :total_local_storage_gb, :v_cpu_count) SENSITIVE = [] include Aws::Structure end |
#total_local_storage_gb ⇒ Types::AwsEc2LaunchTemplateDataInstanceRequirementsTotalLocalStorageGBDetails
The minimum and maximum amount of total local storage, in GB.
7473 7474 7475 7476 7477 7478 7479 7480 7481 7482 7483 7484 7485 7486 7487 7488 7489 7490 7491 7492 7493 7494 7495 7496 7497 |
# File 'lib/aws-sdk-securityhub/types.rb', line 7473 class AwsEc2LaunchTemplateDataInstanceRequirementsDetails < Struct.new( :accelerator_count, :accelerator_manufacturers, :accelerator_names, :accelerator_total_memory_mi_b, :accelerator_types, :bare_metal, :baseline_ebs_bandwidth_mbps, :burstable_performance, :cpu_manufacturers, :excluded_instance_types, :instance_generations, :local_storage, :local_storage_types, :memory_gi_b_per_v_cpu, :memory_mi_b, :network_interface_count, :on_demand_max_price_percentage_over_lowest_price, :require_hibernate_support, :spot_max_price_percentage_over_lowest_price, :total_local_storage_gb, :v_cpu_count) SENSITIVE = [] include Aws::Structure end |
#v_cpu_count ⇒ Types::AwsEc2LaunchTemplateDataInstanceRequirementsVCpuCountDetails
The minimum and maximum number of vCPUs.
7473 7474 7475 7476 7477 7478 7479 7480 7481 7482 7483 7484 7485 7486 7487 7488 7489 7490 7491 7492 7493 7494 7495 7496 7497 |
# File 'lib/aws-sdk-securityhub/types.rb', line 7473 class AwsEc2LaunchTemplateDataInstanceRequirementsDetails < Struct.new( :accelerator_count, :accelerator_manufacturers, :accelerator_names, :accelerator_total_memory_mi_b, :accelerator_types, :bare_metal, :baseline_ebs_bandwidth_mbps, :burstable_performance, :cpu_manufacturers, :excluded_instance_types, :instance_generations, :local_storage, :local_storage_types, :memory_gi_b_per_v_cpu, :memory_mi_b, :network_interface_count, :on_demand_max_price_percentage_over_lowest_price, :require_hibernate_support, :spot_max_price_percentage_over_lowest_price, :total_local_storage_gb, :v_cpu_count) SENSITIVE = [] include Aws::Structure end |