Class: Aws::SecurityHub::Types::AwsEc2LaunchTemplateDataMetadataOptionsDetails

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

Specifies the metadata options for an Amazon EC2 instance.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#http_endpointString

Enables or disables the HTTP metadata endpoint on your instances. If the parameter is not specified, the default state is enabled, and you won't be able to access your instance metadata.

Returns:

  • (String)


7767
7768
7769
7770
7771
7772
7773
7774
7775
# File 'lib/aws-sdk-securityhub/types.rb', line 7767

class AwsEc2LaunchTemplateDataMetadataOptionsDetails < Struct.new(
  :http_endpoint,
  :http_protocol_ipv_6,
  :http_tokens,
  :http_put_response_hop_limit,
  :instance_metadata_tags)
  SENSITIVE = []
  include Aws::Structure
end

#http_protocol_ipv_6String

Enables or disables the IPv6 endpoint for the instance metadata service.

Returns:

  • (String)


7767
7768
7769
7770
7771
7772
7773
7774
7775
# File 'lib/aws-sdk-securityhub/types.rb', line 7767

class AwsEc2LaunchTemplateDataMetadataOptionsDetails < Struct.new(
  :http_endpoint,
  :http_protocol_ipv_6,
  :http_tokens,
  :http_put_response_hop_limit,
  :instance_metadata_tags)
  SENSITIVE = []
  include Aws::Structure
end

#http_put_response_hop_limitInteger

The desired HTTP PUT response hop limit for instance metadata requests. The larger the number, the further instance metadata requests can travel.

Returns:

  • (Integer)


7767
7768
7769
7770
7771
7772
7773
7774
7775
# File 'lib/aws-sdk-securityhub/types.rb', line 7767

class AwsEc2LaunchTemplateDataMetadataOptionsDetails < Struct.new(
  :http_endpoint,
  :http_protocol_ipv_6,
  :http_tokens,
  :http_put_response_hop_limit,
  :instance_metadata_tags)
  SENSITIVE = []
  include Aws::Structure
end

#http_tokensString

The state of token usage for your instance metadata requests.

Returns:

  • (String)


7767
7768
7769
7770
7771
7772
7773
7774
7775
# File 'lib/aws-sdk-securityhub/types.rb', line 7767

class AwsEc2LaunchTemplateDataMetadataOptionsDetails < Struct.new(
  :http_endpoint,
  :http_protocol_ipv_6,
  :http_tokens,
  :http_put_response_hop_limit,
  :instance_metadata_tags)
  SENSITIVE = []
  include Aws::Structure
end

#instance_metadata_tagsString

When set to enabled, this parameter allows access to instance tags from the instance metadata. When set to disabled, it turns off access to instance tags from the instance metadata. For more information, see Work with instance tags in instance metadata in the Amazon EC2 User Guide.

Returns:

  • (String)


7767
7768
7769
7770
7771
7772
7773
7774
7775
# File 'lib/aws-sdk-securityhub/types.rb', line 7767

class AwsEc2LaunchTemplateDataMetadataOptionsDetails < Struct.new(
  :http_endpoint,
  :http_protocol_ipv_6,
  :http_tokens,
  :http_put_response_hop_limit,
  :instance_metadata_tags)
  SENSITIVE = []
  include Aws::Structure
end