Class: Aws::SecurityHub::Types::AwsEc2NetworkInterfaceAttachment

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

Information about the network interface attachment.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#attach_timeString

Indicates when the attachment initiated.

For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.



8303
8304
8305
8306
8307
8308
8309
8310
8311
8312
8313
# File 'lib/aws-sdk-securityhub/types.rb', line 8303

class AwsEc2NetworkInterfaceAttachment < Struct.new(
  :attach_time,
  :attachment_id,
  :delete_on_termination,
  :device_index,
  :instance_id,
  :instance_owner_id,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#attachment_idString

The identifier of the network interface attachment



8303
8304
8305
8306
8307
8308
8309
8310
8311
8312
8313
# File 'lib/aws-sdk-securityhub/types.rb', line 8303

class AwsEc2NetworkInterfaceAttachment < Struct.new(
  :attach_time,
  :attachment_id,
  :delete_on_termination,
  :device_index,
  :instance_id,
  :instance_owner_id,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#delete_on_terminationBoolean

Indicates whether the network interface is deleted when the instance is terminated.



8303
8304
8305
8306
8307
8308
8309
8310
8311
8312
8313
# File 'lib/aws-sdk-securityhub/types.rb', line 8303

class AwsEc2NetworkInterfaceAttachment < Struct.new(
  :attach_time,
  :attachment_id,
  :delete_on_termination,
  :device_index,
  :instance_id,
  :instance_owner_id,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#device_indexInteger

The device index of the network interface attachment on the instance.



8303
8304
8305
8306
8307
8308
8309
8310
8311
8312
8313
# File 'lib/aws-sdk-securityhub/types.rb', line 8303

class AwsEc2NetworkInterfaceAttachment < Struct.new(
  :attach_time,
  :attachment_id,
  :delete_on_termination,
  :device_index,
  :instance_id,
  :instance_owner_id,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idString

The ID of the instance.



8303
8304
8305
8306
8307
8308
8309
8310
8311
8312
8313
# File 'lib/aws-sdk-securityhub/types.rb', line 8303

class AwsEc2NetworkInterfaceAttachment < Struct.new(
  :attach_time,
  :attachment_id,
  :delete_on_termination,
  :device_index,
  :instance_id,
  :instance_owner_id,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#instance_owner_idString

The Amazon Web Services account ID of the owner of the instance.



8303
8304
8305
8306
8307
8308
8309
8310
8311
8312
8313
# File 'lib/aws-sdk-securityhub/types.rb', line 8303

class AwsEc2NetworkInterfaceAttachment < Struct.new(
  :attach_time,
  :attachment_id,
  :delete_on_termination,
  :device_index,
  :instance_id,
  :instance_owner_id,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The attachment state.

Valid values: attaching | attached | detaching | detached



8303
8304
8305
8306
8307
8308
8309
8310
8311
8312
8313
# File 'lib/aws-sdk-securityhub/types.rb', line 8303

class AwsEc2NetworkInterfaceAttachment < Struct.new(
  :attach_time,
  :attachment_id,
  :delete_on_termination,
  :device_index,
  :instance_id,
  :instance_owner_id,
  :status)
  SENSITIVE = []
  include Aws::Structure
end