Class: Aws::SecurityHub::Types::AwsEc2SecurityGroupIpPermission
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::AwsEc2SecurityGroupIpPermission
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
An IP permission for an EC2 security group.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#from_port ⇒ Integer
The start of the port range for the TCP and UDP protocols, or an ICMP/ICMPv6 type number.
-
#ip_protocol ⇒ String
The IP protocol name (
tcp,udp,icmp,icmpv6) or number. -
#ip_ranges ⇒ Array<Types::AwsEc2SecurityGroupIpRange>
The IPv4 ranges.
-
#ipv_6_ranges ⇒ Array<Types::AwsEc2SecurityGroupIpv6Range>
The IPv6 ranges.
-
#prefix_list_ids ⇒ Array<Types::AwsEc2SecurityGroupPrefixListId>
[VPC only] The prefix list IDs for an Amazon Web Services service.
-
#to_port ⇒ Integer
The end of the port range for the TCP and UDP protocols, or an ICMP/ICMPv6 code.
-
#user_id_group_pairs ⇒ Array<Types::AwsEc2SecurityGroupUserIdGroupPair>
The security group and Amazon Web Services account ID pairs.
Instance Attribute Details
#from_port ⇒ Integer
The start of the port range for the TCP and UDP protocols, or an ICMP/ICMPv6 type number.
A value of -1 indicates all ICMP/ICMPv6 types. If you specify all ICMP/ICMPv6 types, you must specify all codes.
8423 8424 8425 8426 8427 8428 8429 8430 8431 8432 8433 |
# File 'lib/aws-sdk-securityhub/types.rb', line 8423 class AwsEc2SecurityGroupIpPermission < Struct.new( :ip_protocol, :from_port, :to_port, :user_id_group_pairs, :ip_ranges, :ipv_6_ranges, :prefix_list_ids) SENSITIVE = [] include Aws::Structure end |
#ip_protocol ⇒ String
The IP protocol name (tcp, udp, icmp, icmpv6) or number.
[VPC only] Use -1 to specify all protocols.
When authorizing security group rules, specifying -1 or a protocol
number other than tcp, udp, icmp, or icmpv6 allows traffic
on all ports, regardless of any port range you specify.
For tcp, udp, and icmp, you must specify a port range.
For icmpv6, the port range is optional. If you omit the port
range, traffic for all types and codes is allowed.
8423 8424 8425 8426 8427 8428 8429 8430 8431 8432 8433 |
# File 'lib/aws-sdk-securityhub/types.rb', line 8423 class AwsEc2SecurityGroupIpPermission < Struct.new( :ip_protocol, :from_port, :to_port, :user_id_group_pairs, :ip_ranges, :ipv_6_ranges, :prefix_list_ids) SENSITIVE = [] include Aws::Structure end |
#ip_ranges ⇒ Array<Types::AwsEc2SecurityGroupIpRange>
The IPv4 ranges.
8423 8424 8425 8426 8427 8428 8429 8430 8431 8432 8433 |
# File 'lib/aws-sdk-securityhub/types.rb', line 8423 class AwsEc2SecurityGroupIpPermission < Struct.new( :ip_protocol, :from_port, :to_port, :user_id_group_pairs, :ip_ranges, :ipv_6_ranges, :prefix_list_ids) SENSITIVE = [] include Aws::Structure end |
#ipv_6_ranges ⇒ Array<Types::AwsEc2SecurityGroupIpv6Range>
The IPv6 ranges.
8423 8424 8425 8426 8427 8428 8429 8430 8431 8432 8433 |
# File 'lib/aws-sdk-securityhub/types.rb', line 8423 class AwsEc2SecurityGroupIpPermission < Struct.new( :ip_protocol, :from_port, :to_port, :user_id_group_pairs, :ip_ranges, :ipv_6_ranges, :prefix_list_ids) SENSITIVE = [] include Aws::Structure end |
#prefix_list_ids ⇒ Array<Types::AwsEc2SecurityGroupPrefixListId>
[VPC only] The prefix list IDs for an Amazon Web Services service. With outbound rules, this is the Amazon Web Services service to access through a VPC endpoint from instances associated with the security group.
8423 8424 8425 8426 8427 8428 8429 8430 8431 8432 8433 |
# File 'lib/aws-sdk-securityhub/types.rb', line 8423 class AwsEc2SecurityGroupIpPermission < Struct.new( :ip_protocol, :from_port, :to_port, :user_id_group_pairs, :ip_ranges, :ipv_6_ranges, :prefix_list_ids) SENSITIVE = [] include Aws::Structure end |
#to_port ⇒ Integer
The end of the port range for the TCP and UDP protocols, or an ICMP/ICMPv6 code.
A value of -1 indicates all ICMP/ICMPv6 codes. If you specify all
ICMP/ICMPv6 types, you must specify all codes.
8423 8424 8425 8426 8427 8428 8429 8430 8431 8432 8433 |
# File 'lib/aws-sdk-securityhub/types.rb', line 8423 class AwsEc2SecurityGroupIpPermission < Struct.new( :ip_protocol, :from_port, :to_port, :user_id_group_pairs, :ip_ranges, :ipv_6_ranges, :prefix_list_ids) SENSITIVE = [] include Aws::Structure end |
#user_id_group_pairs ⇒ Array<Types::AwsEc2SecurityGroupUserIdGroupPair>
The security group and Amazon Web Services account ID pairs.
8423 8424 8425 8426 8427 8428 8429 8430 8431 8432 8433 |
# File 'lib/aws-sdk-securityhub/types.rb', line 8423 class AwsEc2SecurityGroupIpPermission < Struct.new( :ip_protocol, :from_port, :to_port, :user_id_group_pairs, :ip_ranges, :ipv_6_ranges, :prefix_list_ids) SENSITIVE = [] include Aws::Structure end |