Class: Aws::SecurityHub::Types::AwsEc2SubnetDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::AwsEc2SubnetDetails
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Contains information about a subnet in Amazon EC2.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#assign_ipv_6_address_on_creation ⇒ Boolean
Whether to assign an IPV6 address to a network interface that is created in this subnet.
-
#availability_zone ⇒ String
The Availability Zone for the subnet.
-
#availability_zone_id ⇒ String
The identifier of the Availability Zone for the subnet.
-
#available_ip_address_count ⇒ Integer
The number of available IPV4 addresses in the subnet.
-
#cidr_block ⇒ String
The IPV4 CIDR block that is assigned to the subnet.
-
#default_for_az ⇒ Boolean
Whether this subnet is the default subnet for the Availability Zone.
-
#ipv_6_cidr_block_association_set ⇒ Array<Types::Ipv6CidrBlockAssociation>
The IPV6 CIDR blocks that are associated with the subnet.
-
#map_public_ip_on_launch ⇒ Boolean
Whether instances in this subnet receive a public IP address.
-
#owner_id ⇒ String
The identifier of the Amazon Web Services account that owns the subnet.
-
#state ⇒ String
The current state of the subnet.
-
#subnet_arn ⇒ String
The ARN of the subnet.
-
#subnet_id ⇒ String
The identifier of the subnet.
-
#vpc_id ⇒ String
The identifier of the VPC that contains the subnet.
Instance Attribute Details
#assign_ipv_6_address_on_creation ⇒ Boolean
Whether to assign an IPV6 address to a network interface that is created in this subnet.
8587 8588 8589 8590 8591 8592 8593 8594 8595 8596 8597 8598 8599 8600 8601 8602 8603 |
# File 'lib/aws-sdk-securityhub/types.rb', line 8587 class AwsEc2SubnetDetails < Struct.new( :assign_ipv_6_address_on_creation, :availability_zone, :availability_zone_id, :available_ip_address_count, :cidr_block, :default_for_az, :map_public_ip_on_launch, :owner_id, :state, :subnet_arn, :subnet_id, :vpc_id, :ipv_6_cidr_block_association_set) SENSITIVE = [] include Aws::Structure end |
#availability_zone ⇒ String
The Availability Zone for the subnet.
8587 8588 8589 8590 8591 8592 8593 8594 8595 8596 8597 8598 8599 8600 8601 8602 8603 |
# File 'lib/aws-sdk-securityhub/types.rb', line 8587 class AwsEc2SubnetDetails < Struct.new( :assign_ipv_6_address_on_creation, :availability_zone, :availability_zone_id, :available_ip_address_count, :cidr_block, :default_for_az, :map_public_ip_on_launch, :owner_id, :state, :subnet_arn, :subnet_id, :vpc_id, :ipv_6_cidr_block_association_set) SENSITIVE = [] include Aws::Structure end |
#availability_zone_id ⇒ String
The identifier of the Availability Zone for the subnet.
8587 8588 8589 8590 8591 8592 8593 8594 8595 8596 8597 8598 8599 8600 8601 8602 8603 |
# File 'lib/aws-sdk-securityhub/types.rb', line 8587 class AwsEc2SubnetDetails < Struct.new( :assign_ipv_6_address_on_creation, :availability_zone, :availability_zone_id, :available_ip_address_count, :cidr_block, :default_for_az, :map_public_ip_on_launch, :owner_id, :state, :subnet_arn, :subnet_id, :vpc_id, :ipv_6_cidr_block_association_set) SENSITIVE = [] include Aws::Structure end |
#available_ip_address_count ⇒ Integer
The number of available IPV4 addresses in the subnet. Does not include addresses for stopped instances.
8587 8588 8589 8590 8591 8592 8593 8594 8595 8596 8597 8598 8599 8600 8601 8602 8603 |
# File 'lib/aws-sdk-securityhub/types.rb', line 8587 class AwsEc2SubnetDetails < Struct.new( :assign_ipv_6_address_on_creation, :availability_zone, :availability_zone_id, :available_ip_address_count, :cidr_block, :default_for_az, :map_public_ip_on_launch, :owner_id, :state, :subnet_arn, :subnet_id, :vpc_id, :ipv_6_cidr_block_association_set) SENSITIVE = [] include Aws::Structure end |
#cidr_block ⇒ String
The IPV4 CIDR block that is assigned to the subnet.
8587 8588 8589 8590 8591 8592 8593 8594 8595 8596 8597 8598 8599 8600 8601 8602 8603 |
# File 'lib/aws-sdk-securityhub/types.rb', line 8587 class AwsEc2SubnetDetails < Struct.new( :assign_ipv_6_address_on_creation, :availability_zone, :availability_zone_id, :available_ip_address_count, :cidr_block, :default_for_az, :map_public_ip_on_launch, :owner_id, :state, :subnet_arn, :subnet_id, :vpc_id, :ipv_6_cidr_block_association_set) SENSITIVE = [] include Aws::Structure end |
#default_for_az ⇒ Boolean
Whether this subnet is the default subnet for the Availability Zone.
8587 8588 8589 8590 8591 8592 8593 8594 8595 8596 8597 8598 8599 8600 8601 8602 8603 |
# File 'lib/aws-sdk-securityhub/types.rb', line 8587 class AwsEc2SubnetDetails < Struct.new( :assign_ipv_6_address_on_creation, :availability_zone, :availability_zone_id, :available_ip_address_count, :cidr_block, :default_for_az, :map_public_ip_on_launch, :owner_id, :state, :subnet_arn, :subnet_id, :vpc_id, :ipv_6_cidr_block_association_set) SENSITIVE = [] include Aws::Structure end |
#ipv_6_cidr_block_association_set ⇒ Array<Types::Ipv6CidrBlockAssociation>
The IPV6 CIDR blocks that are associated with the subnet.
8587 8588 8589 8590 8591 8592 8593 8594 8595 8596 8597 8598 8599 8600 8601 8602 8603 |
# File 'lib/aws-sdk-securityhub/types.rb', line 8587 class AwsEc2SubnetDetails < Struct.new( :assign_ipv_6_address_on_creation, :availability_zone, :availability_zone_id, :available_ip_address_count, :cidr_block, :default_for_az, :map_public_ip_on_launch, :owner_id, :state, :subnet_arn, :subnet_id, :vpc_id, :ipv_6_cidr_block_association_set) SENSITIVE = [] include Aws::Structure end |
#map_public_ip_on_launch ⇒ Boolean
Whether instances in this subnet receive a public IP address.
8587 8588 8589 8590 8591 8592 8593 8594 8595 8596 8597 8598 8599 8600 8601 8602 8603 |
# File 'lib/aws-sdk-securityhub/types.rb', line 8587 class AwsEc2SubnetDetails < Struct.new( :assign_ipv_6_address_on_creation, :availability_zone, :availability_zone_id, :available_ip_address_count, :cidr_block, :default_for_az, :map_public_ip_on_launch, :owner_id, :state, :subnet_arn, :subnet_id, :vpc_id, :ipv_6_cidr_block_association_set) SENSITIVE = [] include Aws::Structure end |
#owner_id ⇒ String
The identifier of the Amazon Web Services account that owns the subnet.
8587 8588 8589 8590 8591 8592 8593 8594 8595 8596 8597 8598 8599 8600 8601 8602 8603 |
# File 'lib/aws-sdk-securityhub/types.rb', line 8587 class AwsEc2SubnetDetails < Struct.new( :assign_ipv_6_address_on_creation, :availability_zone, :availability_zone_id, :available_ip_address_count, :cidr_block, :default_for_az, :map_public_ip_on_launch, :owner_id, :state, :subnet_arn, :subnet_id, :vpc_id, :ipv_6_cidr_block_association_set) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The current state of the subnet. Valid values are available or
pending.
8587 8588 8589 8590 8591 8592 8593 8594 8595 8596 8597 8598 8599 8600 8601 8602 8603 |
# File 'lib/aws-sdk-securityhub/types.rb', line 8587 class AwsEc2SubnetDetails < Struct.new( :assign_ipv_6_address_on_creation, :availability_zone, :availability_zone_id, :available_ip_address_count, :cidr_block, :default_for_az, :map_public_ip_on_launch, :owner_id, :state, :subnet_arn, :subnet_id, :vpc_id, :ipv_6_cidr_block_association_set) SENSITIVE = [] include Aws::Structure end |
#subnet_arn ⇒ String
The ARN of the subnet.
8587 8588 8589 8590 8591 8592 8593 8594 8595 8596 8597 8598 8599 8600 8601 8602 8603 |
# File 'lib/aws-sdk-securityhub/types.rb', line 8587 class AwsEc2SubnetDetails < Struct.new( :assign_ipv_6_address_on_creation, :availability_zone, :availability_zone_id, :available_ip_address_count, :cidr_block, :default_for_az, :map_public_ip_on_launch, :owner_id, :state, :subnet_arn, :subnet_id, :vpc_id, :ipv_6_cidr_block_association_set) SENSITIVE = [] include Aws::Structure end |
#subnet_id ⇒ String
The identifier of the subnet.
8587 8588 8589 8590 8591 8592 8593 8594 8595 8596 8597 8598 8599 8600 8601 8602 8603 |
# File 'lib/aws-sdk-securityhub/types.rb', line 8587 class AwsEc2SubnetDetails < Struct.new( :assign_ipv_6_address_on_creation, :availability_zone, :availability_zone_id, :available_ip_address_count, :cidr_block, :default_for_az, :map_public_ip_on_launch, :owner_id, :state, :subnet_arn, :subnet_id, :vpc_id, :ipv_6_cidr_block_association_set) SENSITIVE = [] include Aws::Structure end |
#vpc_id ⇒ String
The identifier of the VPC that contains the subnet.
8587 8588 8589 8590 8591 8592 8593 8594 8595 8596 8597 8598 8599 8600 8601 8602 8603 |
# File 'lib/aws-sdk-securityhub/types.rb', line 8587 class AwsEc2SubnetDetails < Struct.new( :assign_ipv_6_address_on_creation, :availability_zone, :availability_zone_id, :available_ip_address_count, :cidr_block, :default_for_az, :map_public_ip_on_launch, :owner_id, :state, :subnet_arn, :subnet_id, :vpc_id, :ipv_6_cidr_block_association_set) SENSITIVE = [] include Aws::Structure end |