Class: Aws::SecurityHub::Types::AwsEc2TransitGatewayDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::AwsEc2TransitGatewayDetails
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Information about an Amazon Web Services Amazon EC2 Transit Gateway that interconnects virtual private clouds (VPCs) and on-premises networks.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#amazon_side_asn ⇒ Integer
A private Autonomous System Number (ASN) for the Amazon side of a BGP session.
-
#association_default_route_table_id ⇒ String
The ID of the default association route table.
-
#auto_accept_shared_attachments ⇒ String
Turn on or turn off automatic acceptance of attachment requests.
-
#default_route_table_association ⇒ String
Turn on or turn off automatic association with the default association route table.
-
#default_route_table_propagation ⇒ String
Turn on or turn off automatic propagation of routes to the default propagation route table.
-
#description ⇒ String
The description of the transit gateway.
-
#dns_support ⇒ String
Turn on or turn off DNS support.
-
#id ⇒ String
The ID of the transit gateway.
-
#multicast_support ⇒ String
Indicates whether multicast is supported on the transit gateway.
-
#propagation_default_route_table_id ⇒ String
The ID of the default propagation route table.
-
#transit_gateway_cidr_blocks ⇒ Array<String>
The transit gateway Classless Inter-Domain Routing (CIDR) blocks.
-
#vpn_ecmp_support ⇒ String
Turn on or turn off Equal Cost Multipath Protocol (ECMP) support.
Instance Attribute Details
#amazon_side_asn ⇒ Integer
A private Autonomous System Number (ASN) for the Amazon side of a BGP session.
8792 8793 8794 8795 8796 8797 8798 8799 8800 8801 8802 8803 8804 8805 8806 8807 |
# File 'lib/aws-sdk-securityhub/types.rb', line 8792 class AwsEc2TransitGatewayDetails < Struct.new( :id, :description, :default_route_table_propagation, :auto_accept_shared_attachments, :default_route_table_association, :transit_gateway_cidr_blocks, :association_default_route_table_id, :propagation_default_route_table_id, :vpn_ecmp_support, :dns_support, :multicast_support, :amazon_side_asn) SENSITIVE = [] include Aws::Structure end |
#association_default_route_table_id ⇒ String
The ID of the default association route table.
8792 8793 8794 8795 8796 8797 8798 8799 8800 8801 8802 8803 8804 8805 8806 8807 |
# File 'lib/aws-sdk-securityhub/types.rb', line 8792 class AwsEc2TransitGatewayDetails < Struct.new( :id, :description, :default_route_table_propagation, :auto_accept_shared_attachments, :default_route_table_association, :transit_gateway_cidr_blocks, :association_default_route_table_id, :propagation_default_route_table_id, :vpn_ecmp_support, :dns_support, :multicast_support, :amazon_side_asn) SENSITIVE = [] include Aws::Structure end |
#auto_accept_shared_attachments ⇒ String
Turn on or turn off automatic acceptance of attachment requests.
8792 8793 8794 8795 8796 8797 8798 8799 8800 8801 8802 8803 8804 8805 8806 8807 |
# File 'lib/aws-sdk-securityhub/types.rb', line 8792 class AwsEc2TransitGatewayDetails < Struct.new( :id, :description, :default_route_table_propagation, :auto_accept_shared_attachments, :default_route_table_association, :transit_gateway_cidr_blocks, :association_default_route_table_id, :propagation_default_route_table_id, :vpn_ecmp_support, :dns_support, :multicast_support, :amazon_side_asn) SENSITIVE = [] include Aws::Structure end |
#default_route_table_association ⇒ String
Turn on or turn off automatic association with the default association route table.
8792 8793 8794 8795 8796 8797 8798 8799 8800 8801 8802 8803 8804 8805 8806 8807 |
# File 'lib/aws-sdk-securityhub/types.rb', line 8792 class AwsEc2TransitGatewayDetails < Struct.new( :id, :description, :default_route_table_propagation, :auto_accept_shared_attachments, :default_route_table_association, :transit_gateway_cidr_blocks, :association_default_route_table_id, :propagation_default_route_table_id, :vpn_ecmp_support, :dns_support, :multicast_support, :amazon_side_asn) SENSITIVE = [] include Aws::Structure end |
#default_route_table_propagation ⇒ String
Turn on or turn off automatic propagation of routes to the default propagation route table.
8792 8793 8794 8795 8796 8797 8798 8799 8800 8801 8802 8803 8804 8805 8806 8807 |
# File 'lib/aws-sdk-securityhub/types.rb', line 8792 class AwsEc2TransitGatewayDetails < Struct.new( :id, :description, :default_route_table_propagation, :auto_accept_shared_attachments, :default_route_table_association, :transit_gateway_cidr_blocks, :association_default_route_table_id, :propagation_default_route_table_id, :vpn_ecmp_support, :dns_support, :multicast_support, :amazon_side_asn) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the transit gateway.
8792 8793 8794 8795 8796 8797 8798 8799 8800 8801 8802 8803 8804 8805 8806 8807 |
# File 'lib/aws-sdk-securityhub/types.rb', line 8792 class AwsEc2TransitGatewayDetails < Struct.new( :id, :description, :default_route_table_propagation, :auto_accept_shared_attachments, :default_route_table_association, :transit_gateway_cidr_blocks, :association_default_route_table_id, :propagation_default_route_table_id, :vpn_ecmp_support, :dns_support, :multicast_support, :amazon_side_asn) SENSITIVE = [] include Aws::Structure end |
#dns_support ⇒ String
Turn on or turn off DNS support.
8792 8793 8794 8795 8796 8797 8798 8799 8800 8801 8802 8803 8804 8805 8806 8807 |
# File 'lib/aws-sdk-securityhub/types.rb', line 8792 class AwsEc2TransitGatewayDetails < Struct.new( :id, :description, :default_route_table_propagation, :auto_accept_shared_attachments, :default_route_table_association, :transit_gateway_cidr_blocks, :association_default_route_table_id, :propagation_default_route_table_id, :vpn_ecmp_support, :dns_support, :multicast_support, :amazon_side_asn) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The ID of the transit gateway.
8792 8793 8794 8795 8796 8797 8798 8799 8800 8801 8802 8803 8804 8805 8806 8807 |
# File 'lib/aws-sdk-securityhub/types.rb', line 8792 class AwsEc2TransitGatewayDetails < Struct.new( :id, :description, :default_route_table_propagation, :auto_accept_shared_attachments, :default_route_table_association, :transit_gateway_cidr_blocks, :association_default_route_table_id, :propagation_default_route_table_id, :vpn_ecmp_support, :dns_support, :multicast_support, :amazon_side_asn) SENSITIVE = [] include Aws::Structure end |
#multicast_support ⇒ String
Indicates whether multicast is supported on the transit gateway.
8792 8793 8794 8795 8796 8797 8798 8799 8800 8801 8802 8803 8804 8805 8806 8807 |
# File 'lib/aws-sdk-securityhub/types.rb', line 8792 class AwsEc2TransitGatewayDetails < Struct.new( :id, :description, :default_route_table_propagation, :auto_accept_shared_attachments, :default_route_table_association, :transit_gateway_cidr_blocks, :association_default_route_table_id, :propagation_default_route_table_id, :vpn_ecmp_support, :dns_support, :multicast_support, :amazon_side_asn) SENSITIVE = [] include Aws::Structure end |
#propagation_default_route_table_id ⇒ String
The ID of the default propagation route table.
8792 8793 8794 8795 8796 8797 8798 8799 8800 8801 8802 8803 8804 8805 8806 8807 |
# File 'lib/aws-sdk-securityhub/types.rb', line 8792 class AwsEc2TransitGatewayDetails < Struct.new( :id, :description, :default_route_table_propagation, :auto_accept_shared_attachments, :default_route_table_association, :transit_gateway_cidr_blocks, :association_default_route_table_id, :propagation_default_route_table_id, :vpn_ecmp_support, :dns_support, :multicast_support, :amazon_side_asn) SENSITIVE = [] include Aws::Structure end |
#transit_gateway_cidr_blocks ⇒ Array<String>
The transit gateway Classless Inter-Domain Routing (CIDR) blocks.
8792 8793 8794 8795 8796 8797 8798 8799 8800 8801 8802 8803 8804 8805 8806 8807 |
# File 'lib/aws-sdk-securityhub/types.rb', line 8792 class AwsEc2TransitGatewayDetails < Struct.new( :id, :description, :default_route_table_propagation, :auto_accept_shared_attachments, :default_route_table_association, :transit_gateway_cidr_blocks, :association_default_route_table_id, :propagation_default_route_table_id, :vpn_ecmp_support, :dns_support, :multicast_support, :amazon_side_asn) SENSITIVE = [] include Aws::Structure end |
#vpn_ecmp_support ⇒ String
Turn on or turn off Equal Cost Multipath Protocol (ECMP) support.
8792 8793 8794 8795 8796 8797 8798 8799 8800 8801 8802 8803 8804 8805 8806 8807 |
# File 'lib/aws-sdk-securityhub/types.rb', line 8792 class AwsEc2TransitGatewayDetails < Struct.new( :id, :description, :default_route_table_propagation, :auto_accept_shared_attachments, :default_route_table_association, :transit_gateway_cidr_blocks, :association_default_route_table_id, :propagation_default_route_table_id, :vpn_ecmp_support, :dns_support, :multicast_support, :amazon_side_asn) SENSITIVE = [] include Aws::Structure end |