Class: Aws::SecurityHub::Types::AwsEc2VpcDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::AwsEc2VpcDetails
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Details about an EC2 VPC.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cidr_block_association_set ⇒ Array<Types::CidrBlockAssociation>
Information about the IPv4 CIDR blocks associated with the VPC.
-
#dhcp_options_id ⇒ String
The identifier of the set of Dynamic Host Configuration Protocol (DHCP) options that are associated with the VPC.
-
#ipv_6_cidr_block_association_set ⇒ Array<Types::Ipv6CidrBlockAssociation>
Information about the IPv6 CIDR blocks associated with the VPC.
-
#state ⇒ String
The current state of the VPC.
Instance Attribute Details
#cidr_block_association_set ⇒ Array<Types::CidrBlockAssociation>
Information about the IPv4 CIDR blocks associated with the VPC.
8927 8928 8929 8930 8931 8932 8933 8934 |
# File 'lib/aws-sdk-securityhub/types.rb', line 8927 class AwsEc2VpcDetails < Struct.new( :cidr_block_association_set, :ipv_6_cidr_block_association_set, :dhcp_options_id, :state) SENSITIVE = [] include Aws::Structure end |
#dhcp_options_id ⇒ String
The identifier of the set of Dynamic Host Configuration Protocol (DHCP) options that are associated with the VPC. If the default options are associated with the VPC, then this is default.
8927 8928 8929 8930 8931 8932 8933 8934 |
# File 'lib/aws-sdk-securityhub/types.rb', line 8927 class AwsEc2VpcDetails < Struct.new( :cidr_block_association_set, :ipv_6_cidr_block_association_set, :dhcp_options_id, :state) SENSITIVE = [] include Aws::Structure end |
#ipv_6_cidr_block_association_set ⇒ Array<Types::Ipv6CidrBlockAssociation>
Information about the IPv6 CIDR blocks associated with the VPC.
8927 8928 8929 8930 8931 8932 8933 8934 |
# File 'lib/aws-sdk-securityhub/types.rb', line 8927 class AwsEc2VpcDetails < Struct.new( :cidr_block_association_set, :ipv_6_cidr_block_association_set, :dhcp_options_id, :state) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The current state of the VPC. Valid values are available or
pending.
8927 8928 8929 8930 8931 8932 8933 8934 |
# File 'lib/aws-sdk-securityhub/types.rb', line 8927 class AwsEc2VpcDetails < Struct.new( :cidr_block_association_set, :ipv_6_cidr_block_association_set, :dhcp_options_id, :state) SENSITIVE = [] include Aws::Structure end |