Class: Aws::SecurityHub::Types::AwsEc2VpcEndpointServiceDetails

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

Contains details about the service configuration for a VPC endpoint service.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#acceptance_requiredBoolean

Whether requests from other Amazon Web Services accounts to create an endpoint to the service must first be accepted.



8875
8876
8877
8878
8879
8880
8881
8882
8883
8884
8885
8886
8887
8888
8889
# File 'lib/aws-sdk-securityhub/types.rb', line 8875

class AwsEc2VpcEndpointServiceDetails < Struct.new(
  :acceptance_required,
  :availability_zones,
  :base_endpoint_dns_names,
  :manages_vpc_endpoints,
  :gateway_load_balancer_arns,
  :network_load_balancer_arns,
  :private_dns_name,
  :service_id,
  :service_name,
  :service_state,
  :service_type)
  SENSITIVE = []
  include Aws::Structure
end

#availability_zonesArray<String>

The Availability Zones where the service is available.



8875
8876
8877
8878
8879
8880
8881
8882
8883
8884
8885
8886
8887
8888
8889
# File 'lib/aws-sdk-securityhub/types.rb', line 8875

class AwsEc2VpcEndpointServiceDetails < Struct.new(
  :acceptance_required,
  :availability_zones,
  :base_endpoint_dns_names,
  :manages_vpc_endpoints,
  :gateway_load_balancer_arns,
  :network_load_balancer_arns,
  :private_dns_name,
  :service_id,
  :service_name,
  :service_state,
  :service_type)
  SENSITIVE = []
  include Aws::Structure
end

#base_endpoint_dns_namesArray<String>

The DNS names for the service.



8875
8876
8877
8878
8879
8880
8881
8882
8883
8884
8885
8886
8887
8888
8889
# File 'lib/aws-sdk-securityhub/types.rb', line 8875

class AwsEc2VpcEndpointServiceDetails < Struct.new(
  :acceptance_required,
  :availability_zones,
  :base_endpoint_dns_names,
  :manages_vpc_endpoints,
  :gateway_load_balancer_arns,
  :network_load_balancer_arns,
  :private_dns_name,
  :service_id,
  :service_name,
  :service_state,
  :service_type)
  SENSITIVE = []
  include Aws::Structure
end

#gateway_load_balancer_arnsArray<String>

The ARNs of the Gateway Load Balancers for the service.



8875
8876
8877
8878
8879
8880
8881
8882
8883
8884
8885
8886
8887
8888
8889
# File 'lib/aws-sdk-securityhub/types.rb', line 8875

class AwsEc2VpcEndpointServiceDetails < Struct.new(
  :acceptance_required,
  :availability_zones,
  :base_endpoint_dns_names,
  :manages_vpc_endpoints,
  :gateway_load_balancer_arns,
  :network_load_balancer_arns,
  :private_dns_name,
  :service_id,
  :service_name,
  :service_state,
  :service_type)
  SENSITIVE = []
  include Aws::Structure
end

#manages_vpc_endpointsBoolean

Whether the service manages its VPC endpoints.



8875
8876
8877
8878
8879
8880
8881
8882
8883
8884
8885
8886
8887
8888
8889
# File 'lib/aws-sdk-securityhub/types.rb', line 8875

class AwsEc2VpcEndpointServiceDetails < Struct.new(
  :acceptance_required,
  :availability_zones,
  :base_endpoint_dns_names,
  :manages_vpc_endpoints,
  :gateway_load_balancer_arns,
  :network_load_balancer_arns,
  :private_dns_name,
  :service_id,
  :service_name,
  :service_state,
  :service_type)
  SENSITIVE = []
  include Aws::Structure
end

#network_load_balancer_arnsArray<String>

The ARNs of the Network Load Balancers for the service.



8875
8876
8877
8878
8879
8880
8881
8882
8883
8884
8885
8886
8887
8888
8889
# File 'lib/aws-sdk-securityhub/types.rb', line 8875

class AwsEc2VpcEndpointServiceDetails < Struct.new(
  :acceptance_required,
  :availability_zones,
  :base_endpoint_dns_names,
  :manages_vpc_endpoints,
  :gateway_load_balancer_arns,
  :network_load_balancer_arns,
  :private_dns_name,
  :service_id,
  :service_name,
  :service_state,
  :service_type)
  SENSITIVE = []
  include Aws::Structure
end

#private_dns_nameString

The private DNS name for the service.



8875
8876
8877
8878
8879
8880
8881
8882
8883
8884
8885
8886
8887
8888
8889
# File 'lib/aws-sdk-securityhub/types.rb', line 8875

class AwsEc2VpcEndpointServiceDetails < Struct.new(
  :acceptance_required,
  :availability_zones,
  :base_endpoint_dns_names,
  :manages_vpc_endpoints,
  :gateway_load_balancer_arns,
  :network_load_balancer_arns,
  :private_dns_name,
  :service_id,
  :service_name,
  :service_state,
  :service_type)
  SENSITIVE = []
  include Aws::Structure
end

#service_idString

The identifier of the service.



8875
8876
8877
8878
8879
8880
8881
8882
8883
8884
8885
8886
8887
8888
8889
# File 'lib/aws-sdk-securityhub/types.rb', line 8875

class AwsEc2VpcEndpointServiceDetails < Struct.new(
  :acceptance_required,
  :availability_zones,
  :base_endpoint_dns_names,
  :manages_vpc_endpoints,
  :gateway_load_balancer_arns,
  :network_load_balancer_arns,
  :private_dns_name,
  :service_id,
  :service_name,
  :service_state,
  :service_type)
  SENSITIVE = []
  include Aws::Structure
end

#service_nameString

The name of the service.



8875
8876
8877
8878
8879
8880
8881
8882
8883
8884
8885
8886
8887
8888
8889
# File 'lib/aws-sdk-securityhub/types.rb', line 8875

class AwsEc2VpcEndpointServiceDetails < Struct.new(
  :acceptance_required,
  :availability_zones,
  :base_endpoint_dns_names,
  :manages_vpc_endpoints,
  :gateway_load_balancer_arns,
  :network_load_balancer_arns,
  :private_dns_name,
  :service_id,
  :service_name,
  :service_state,
  :service_type)
  SENSITIVE = []
  include Aws::Structure
end

#service_stateString

The current state of the service. Valid values are as follows:

  • Available

  • Deleted

  • Deleting

  • Failed

  • Pending



8875
8876
8877
8878
8879
8880
8881
8882
8883
8884
8885
8886
8887
8888
8889
# File 'lib/aws-sdk-securityhub/types.rb', line 8875

class AwsEc2VpcEndpointServiceDetails < Struct.new(
  :acceptance_required,
  :availability_zones,
  :base_endpoint_dns_names,
  :manages_vpc_endpoints,
  :gateway_load_balancer_arns,
  :network_load_balancer_arns,
  :private_dns_name,
  :service_id,
  :service_name,
  :service_state,
  :service_type)
  SENSITIVE = []
  include Aws::Structure
end

#service_typeArray<Types::AwsEc2VpcEndpointServiceServiceTypeDetails>

The types for the service.



8875
8876
8877
8878
8879
8880
8881
8882
8883
8884
8885
8886
8887
8888
8889
# File 'lib/aws-sdk-securityhub/types.rb', line 8875

class AwsEc2VpcEndpointServiceDetails < Struct.new(
  :acceptance_required,
  :availability_zones,
  :base_endpoint_dns_names,
  :manages_vpc_endpoints,
  :gateway_load_balancer_arns,
  :network_load_balancer_arns,
  :private_dns_name,
  :service_id,
  :service_name,
  :service_state,
  :service_type)
  SENSITIVE = []
  include Aws::Structure
end