Class: Aws::SecurityHub::Types::AwsEc2VpnConnectionDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::AwsEc2VpnConnectionDetails
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Details about an Amazon EC2 VPN connection.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#category ⇒ String
The category of the VPN connection.
-
#customer_gateway_configuration ⇒ String
The configuration information for the VPN connection's customer gateway, in the native XML format.
-
#customer_gateway_id ⇒ String
The identifier of the customer gateway that is at your end of the VPN connection.
-
#options ⇒ Types::AwsEc2VpnConnectionOptionsDetails
The VPN connection options.
-
#routes ⇒ Array<Types::AwsEc2VpnConnectionRoutesDetails>
The static routes that are associated with the VPN connection.
-
#state ⇒ String
The current state of the VPN connection.
-
#transit_gateway_id ⇒ String
The identifier of the transit gateway that is associated with the VPN connection.
-
#type ⇒ String
The type of VPN connection.
-
#vgw_telemetry ⇒ Array<Types::AwsEc2VpnConnectionVgwTelemetryDetails>
Information about the VPN tunnel.
-
#vpn_connection_id ⇒ String
The identifier of the VPN connection.
-
#vpn_gateway_id ⇒ String
The identifier of the virtual private gateway that is at the Amazon Web Services side of the VPN connection.
Instance Attribute Details
#category ⇒ String
The category of the VPN connection. VPN indicates an Amazon Web
Services VPN connection. VPN-Classic indicates an Amazon Web
Services Classic VPN connection.
9219 9220 9221 9222 9223 9224 9225 9226 9227 9228 9229 9230 9231 9232 9233 |
# File 'lib/aws-sdk-securityhub/types.rb', line 9219 class AwsEc2VpnConnectionDetails < Struct.new( :vpn_connection_id, :state, :customer_gateway_id, :customer_gateway_configuration, :type, :vpn_gateway_id, :category, :vgw_telemetry, :options, :routes, :transit_gateway_id) SENSITIVE = [] include Aws::Structure end |
#customer_gateway_configuration ⇒ String
The configuration information for the VPN connection's customer gateway, in the native XML format.
9219 9220 9221 9222 9223 9224 9225 9226 9227 9228 9229 9230 9231 9232 9233 |
# File 'lib/aws-sdk-securityhub/types.rb', line 9219 class AwsEc2VpnConnectionDetails < Struct.new( :vpn_connection_id, :state, :customer_gateway_id, :customer_gateway_configuration, :type, :vpn_gateway_id, :category, :vgw_telemetry, :options, :routes, :transit_gateway_id) SENSITIVE = [] include Aws::Structure end |
#customer_gateway_id ⇒ String
The identifier of the customer gateway that is at your end of the VPN connection.
9219 9220 9221 9222 9223 9224 9225 9226 9227 9228 9229 9230 9231 9232 9233 |
# File 'lib/aws-sdk-securityhub/types.rb', line 9219 class AwsEc2VpnConnectionDetails < Struct.new( :vpn_connection_id, :state, :customer_gateway_id, :customer_gateway_configuration, :type, :vpn_gateway_id, :category, :vgw_telemetry, :options, :routes, :transit_gateway_id) SENSITIVE = [] include Aws::Structure end |
#options ⇒ Types::AwsEc2VpnConnectionOptionsDetails
The VPN connection options.
9219 9220 9221 9222 9223 9224 9225 9226 9227 9228 9229 9230 9231 9232 9233 |
# File 'lib/aws-sdk-securityhub/types.rb', line 9219 class AwsEc2VpnConnectionDetails < Struct.new( :vpn_connection_id, :state, :customer_gateway_id, :customer_gateway_configuration, :type, :vpn_gateway_id, :category, :vgw_telemetry, :options, :routes, :transit_gateway_id) SENSITIVE = [] include Aws::Structure end |
#routes ⇒ Array<Types::AwsEc2VpnConnectionRoutesDetails>
The static routes that are associated with the VPN connection.
9219 9220 9221 9222 9223 9224 9225 9226 9227 9228 9229 9230 9231 9232 9233 |
# File 'lib/aws-sdk-securityhub/types.rb', line 9219 class AwsEc2VpnConnectionDetails < Struct.new( :vpn_connection_id, :state, :customer_gateway_id, :customer_gateway_configuration, :type, :vpn_gateway_id, :category, :vgw_telemetry, :options, :routes, :transit_gateway_id) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The current state of the VPN connection. Valid values are as follows:
-
available -
deleted -
deleting -
pending
9219 9220 9221 9222 9223 9224 9225 9226 9227 9228 9229 9230 9231 9232 9233 |
# File 'lib/aws-sdk-securityhub/types.rb', line 9219 class AwsEc2VpnConnectionDetails < Struct.new( :vpn_connection_id, :state, :customer_gateway_id, :customer_gateway_configuration, :type, :vpn_gateway_id, :category, :vgw_telemetry, :options, :routes, :transit_gateway_id) SENSITIVE = [] include Aws::Structure end |
#transit_gateway_id ⇒ String
The identifier of the transit gateway that is associated with the VPN connection.
9219 9220 9221 9222 9223 9224 9225 9226 9227 9228 9229 9230 9231 9232 9233 |
# File 'lib/aws-sdk-securityhub/types.rb', line 9219 class AwsEc2VpnConnectionDetails < Struct.new( :vpn_connection_id, :state, :customer_gateway_id, :customer_gateway_configuration, :type, :vpn_gateway_id, :category, :vgw_telemetry, :options, :routes, :transit_gateway_id) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of VPN connection.
9219 9220 9221 9222 9223 9224 9225 9226 9227 9228 9229 9230 9231 9232 9233 |
# File 'lib/aws-sdk-securityhub/types.rb', line 9219 class AwsEc2VpnConnectionDetails < Struct.new( :vpn_connection_id, :state, :customer_gateway_id, :customer_gateway_configuration, :type, :vpn_gateway_id, :category, :vgw_telemetry, :options, :routes, :transit_gateway_id) SENSITIVE = [] include Aws::Structure end |
#vgw_telemetry ⇒ Array<Types::AwsEc2VpnConnectionVgwTelemetryDetails>
Information about the VPN tunnel.
9219 9220 9221 9222 9223 9224 9225 9226 9227 9228 9229 9230 9231 9232 9233 |
# File 'lib/aws-sdk-securityhub/types.rb', line 9219 class AwsEc2VpnConnectionDetails < Struct.new( :vpn_connection_id, :state, :customer_gateway_id, :customer_gateway_configuration, :type, :vpn_gateway_id, :category, :vgw_telemetry, :options, :routes, :transit_gateway_id) SENSITIVE = [] include Aws::Structure end |
#vpn_connection_id ⇒ String
The identifier of the VPN connection.
9219 9220 9221 9222 9223 9224 9225 9226 9227 9228 9229 9230 9231 9232 9233 |
# File 'lib/aws-sdk-securityhub/types.rb', line 9219 class AwsEc2VpnConnectionDetails < Struct.new( :vpn_connection_id, :state, :customer_gateway_id, :customer_gateway_configuration, :type, :vpn_gateway_id, :category, :vgw_telemetry, :options, :routes, :transit_gateway_id) SENSITIVE = [] include Aws::Structure end |
#vpn_gateway_id ⇒ String
The identifier of the virtual private gateway that is at the Amazon Web Services side of the VPN connection.
9219 9220 9221 9222 9223 9224 9225 9226 9227 9228 9229 9230 9231 9232 9233 |
# File 'lib/aws-sdk-securityhub/types.rb', line 9219 class AwsEc2VpnConnectionDetails < Struct.new( :vpn_connection_id, :state, :customer_gateway_id, :customer_gateway_configuration, :type, :vpn_gateway_id, :category, :vgw_telemetry, :options, :routes, :transit_gateway_id) SENSITIVE = [] include Aws::Structure end |