Class: Aws::SecurityHub::Types::AwsEc2VpnConnectionOptionsTunnelOptionsDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::AwsEc2VpnConnectionOptionsTunnelOptionsDetails
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
The VPN tunnel options.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dpd_timeout_seconds ⇒ Integer
The number of seconds after which a Dead Peer Detection (DPD) timeout occurs.
-
#ike_versions ⇒ Array<String>
The Internet Key Exchange (IKE) versions that are permitted for the VPN tunnel.
-
#outside_ip_address ⇒ String
The external IP address of the VPN tunnel.
-
#phase_1_dh_group_numbers ⇒ Array<Integer>
The permitted Diffie-Hellman group numbers for the VPN tunnel for phase 1 IKE negotiations.
-
#phase_1_encryption_algorithms ⇒ Array<String>
The permitted encryption algorithms for the VPN tunnel for phase 1 IKE negotiations.
-
#phase_1_integrity_algorithms ⇒ Array<String>
The permitted integrity algorithms for the VPN tunnel for phase 1 IKE negotiations.
-
#phase_1_lifetime_seconds ⇒ Integer
The lifetime for phase 1 of the IKE negotiation, in seconds.
-
#phase_2_dh_group_numbers ⇒ Array<Integer>
The permitted Diffie-Hellman group numbers for the VPN tunnel for phase 2 IKE negotiations.
-
#phase_2_encryption_algorithms ⇒ Array<String>
The permitted encryption algorithms for the VPN tunnel for phase 2 IKE negotiations.
-
#phase_2_integrity_algorithms ⇒ Array<String>
The permitted integrity algorithms for the VPN tunnel for phase 2 IKE negotiations.
-
#phase_2_lifetime_seconds ⇒ Integer
The lifetime for phase 2 of the IKE negotiation, in seconds.
-
#pre_shared_key ⇒ String
The preshared key to establish initial authentication between the virtual private gateway and the customer gateway.
-
#rekey_fuzz_percentage ⇒ Integer
The percentage of the rekey window, which is determined by
RekeyMarginTimeSecondsduring which the rekey time is randomly selected. -
#rekey_margin_time_seconds ⇒ Integer
The margin time, in seconds, before the phase 2 lifetime expires, during which the Amazon Web Services side of the VPN connection performs an IKE rekey.
-
#replay_window_size ⇒ Integer
The number of packets in an IKE replay window.
-
#tunnel_inside_cidr ⇒ String
The range of inside IPv4 addresses for the tunnel.
Instance Attribute Details
#dpd_timeout_seconds ⇒ Integer
The number of seconds after which a Dead Peer Detection (DPD) timeout occurs.
9335 9336 9337 9338 9339 9340 9341 9342 9343 9344 9345 9346 9347 9348 9349 9350 9351 9352 9353 9354 |
# File 'lib/aws-sdk-securityhub/types.rb', line 9335 class AwsEc2VpnConnectionOptionsTunnelOptionsDetails < Struct.new( :dpd_timeout_seconds, :ike_versions, :outside_ip_address, :phase_1_dh_group_numbers, :phase_1_encryption_algorithms, :phase_1_integrity_algorithms, :phase_1_lifetime_seconds, :phase_2_dh_group_numbers, :phase_2_encryption_algorithms, :phase_2_integrity_algorithms, :phase_2_lifetime_seconds, :pre_shared_key, :rekey_fuzz_percentage, :rekey_margin_time_seconds, :replay_window_size, :tunnel_inside_cidr) SENSITIVE = [] include Aws::Structure end |
#ike_versions ⇒ Array<String>
The Internet Key Exchange (IKE) versions that are permitted for the VPN tunnel.
9335 9336 9337 9338 9339 9340 9341 9342 9343 9344 9345 9346 9347 9348 9349 9350 9351 9352 9353 9354 |
# File 'lib/aws-sdk-securityhub/types.rb', line 9335 class AwsEc2VpnConnectionOptionsTunnelOptionsDetails < Struct.new( :dpd_timeout_seconds, :ike_versions, :outside_ip_address, :phase_1_dh_group_numbers, :phase_1_encryption_algorithms, :phase_1_integrity_algorithms, :phase_1_lifetime_seconds, :phase_2_dh_group_numbers, :phase_2_encryption_algorithms, :phase_2_integrity_algorithms, :phase_2_lifetime_seconds, :pre_shared_key, :rekey_fuzz_percentage, :rekey_margin_time_seconds, :replay_window_size, :tunnel_inside_cidr) SENSITIVE = [] include Aws::Structure end |
#outside_ip_address ⇒ String
The external IP address of the VPN tunnel.
9335 9336 9337 9338 9339 9340 9341 9342 9343 9344 9345 9346 9347 9348 9349 9350 9351 9352 9353 9354 |
# File 'lib/aws-sdk-securityhub/types.rb', line 9335 class AwsEc2VpnConnectionOptionsTunnelOptionsDetails < Struct.new( :dpd_timeout_seconds, :ike_versions, :outside_ip_address, :phase_1_dh_group_numbers, :phase_1_encryption_algorithms, :phase_1_integrity_algorithms, :phase_1_lifetime_seconds, :phase_2_dh_group_numbers, :phase_2_encryption_algorithms, :phase_2_integrity_algorithms, :phase_2_lifetime_seconds, :pre_shared_key, :rekey_fuzz_percentage, :rekey_margin_time_seconds, :replay_window_size, :tunnel_inside_cidr) SENSITIVE = [] include Aws::Structure end |
#phase_1_dh_group_numbers ⇒ Array<Integer>
The permitted Diffie-Hellman group numbers for the VPN tunnel for phase 1 IKE negotiations.
9335 9336 9337 9338 9339 9340 9341 9342 9343 9344 9345 9346 9347 9348 9349 9350 9351 9352 9353 9354 |
# File 'lib/aws-sdk-securityhub/types.rb', line 9335 class AwsEc2VpnConnectionOptionsTunnelOptionsDetails < Struct.new( :dpd_timeout_seconds, :ike_versions, :outside_ip_address, :phase_1_dh_group_numbers, :phase_1_encryption_algorithms, :phase_1_integrity_algorithms, :phase_1_lifetime_seconds, :phase_2_dh_group_numbers, :phase_2_encryption_algorithms, :phase_2_integrity_algorithms, :phase_2_lifetime_seconds, :pre_shared_key, :rekey_fuzz_percentage, :rekey_margin_time_seconds, :replay_window_size, :tunnel_inside_cidr) SENSITIVE = [] include Aws::Structure end |
#phase_1_encryption_algorithms ⇒ Array<String>
The permitted encryption algorithms for the VPN tunnel for phase 1 IKE negotiations.
9335 9336 9337 9338 9339 9340 9341 9342 9343 9344 9345 9346 9347 9348 9349 9350 9351 9352 9353 9354 |
# File 'lib/aws-sdk-securityhub/types.rb', line 9335 class AwsEc2VpnConnectionOptionsTunnelOptionsDetails < Struct.new( :dpd_timeout_seconds, :ike_versions, :outside_ip_address, :phase_1_dh_group_numbers, :phase_1_encryption_algorithms, :phase_1_integrity_algorithms, :phase_1_lifetime_seconds, :phase_2_dh_group_numbers, :phase_2_encryption_algorithms, :phase_2_integrity_algorithms, :phase_2_lifetime_seconds, :pre_shared_key, :rekey_fuzz_percentage, :rekey_margin_time_seconds, :replay_window_size, :tunnel_inside_cidr) SENSITIVE = [] include Aws::Structure end |
#phase_1_integrity_algorithms ⇒ Array<String>
The permitted integrity algorithms for the VPN tunnel for phase 1 IKE negotiations.
9335 9336 9337 9338 9339 9340 9341 9342 9343 9344 9345 9346 9347 9348 9349 9350 9351 9352 9353 9354 |
# File 'lib/aws-sdk-securityhub/types.rb', line 9335 class AwsEc2VpnConnectionOptionsTunnelOptionsDetails < Struct.new( :dpd_timeout_seconds, :ike_versions, :outside_ip_address, :phase_1_dh_group_numbers, :phase_1_encryption_algorithms, :phase_1_integrity_algorithms, :phase_1_lifetime_seconds, :phase_2_dh_group_numbers, :phase_2_encryption_algorithms, :phase_2_integrity_algorithms, :phase_2_lifetime_seconds, :pre_shared_key, :rekey_fuzz_percentage, :rekey_margin_time_seconds, :replay_window_size, :tunnel_inside_cidr) SENSITIVE = [] include Aws::Structure end |
#phase_1_lifetime_seconds ⇒ Integer
The lifetime for phase 1 of the IKE negotiation, in seconds.
9335 9336 9337 9338 9339 9340 9341 9342 9343 9344 9345 9346 9347 9348 9349 9350 9351 9352 9353 9354 |
# File 'lib/aws-sdk-securityhub/types.rb', line 9335 class AwsEc2VpnConnectionOptionsTunnelOptionsDetails < Struct.new( :dpd_timeout_seconds, :ike_versions, :outside_ip_address, :phase_1_dh_group_numbers, :phase_1_encryption_algorithms, :phase_1_integrity_algorithms, :phase_1_lifetime_seconds, :phase_2_dh_group_numbers, :phase_2_encryption_algorithms, :phase_2_integrity_algorithms, :phase_2_lifetime_seconds, :pre_shared_key, :rekey_fuzz_percentage, :rekey_margin_time_seconds, :replay_window_size, :tunnel_inside_cidr) SENSITIVE = [] include Aws::Structure end |
#phase_2_dh_group_numbers ⇒ Array<Integer>
The permitted Diffie-Hellman group numbers for the VPN tunnel for phase 2 IKE negotiations.
9335 9336 9337 9338 9339 9340 9341 9342 9343 9344 9345 9346 9347 9348 9349 9350 9351 9352 9353 9354 |
# File 'lib/aws-sdk-securityhub/types.rb', line 9335 class AwsEc2VpnConnectionOptionsTunnelOptionsDetails < Struct.new( :dpd_timeout_seconds, :ike_versions, :outside_ip_address, :phase_1_dh_group_numbers, :phase_1_encryption_algorithms, :phase_1_integrity_algorithms, :phase_1_lifetime_seconds, :phase_2_dh_group_numbers, :phase_2_encryption_algorithms, :phase_2_integrity_algorithms, :phase_2_lifetime_seconds, :pre_shared_key, :rekey_fuzz_percentage, :rekey_margin_time_seconds, :replay_window_size, :tunnel_inside_cidr) SENSITIVE = [] include Aws::Structure end |
#phase_2_encryption_algorithms ⇒ Array<String>
The permitted encryption algorithms for the VPN tunnel for phase 2 IKE negotiations.
9335 9336 9337 9338 9339 9340 9341 9342 9343 9344 9345 9346 9347 9348 9349 9350 9351 9352 9353 9354 |
# File 'lib/aws-sdk-securityhub/types.rb', line 9335 class AwsEc2VpnConnectionOptionsTunnelOptionsDetails < Struct.new( :dpd_timeout_seconds, :ike_versions, :outside_ip_address, :phase_1_dh_group_numbers, :phase_1_encryption_algorithms, :phase_1_integrity_algorithms, :phase_1_lifetime_seconds, :phase_2_dh_group_numbers, :phase_2_encryption_algorithms, :phase_2_integrity_algorithms, :phase_2_lifetime_seconds, :pre_shared_key, :rekey_fuzz_percentage, :rekey_margin_time_seconds, :replay_window_size, :tunnel_inside_cidr) SENSITIVE = [] include Aws::Structure end |
#phase_2_integrity_algorithms ⇒ Array<String>
The permitted integrity algorithms for the VPN tunnel for phase 2 IKE negotiations.
9335 9336 9337 9338 9339 9340 9341 9342 9343 9344 9345 9346 9347 9348 9349 9350 9351 9352 9353 9354 |
# File 'lib/aws-sdk-securityhub/types.rb', line 9335 class AwsEc2VpnConnectionOptionsTunnelOptionsDetails < Struct.new( :dpd_timeout_seconds, :ike_versions, :outside_ip_address, :phase_1_dh_group_numbers, :phase_1_encryption_algorithms, :phase_1_integrity_algorithms, :phase_1_lifetime_seconds, :phase_2_dh_group_numbers, :phase_2_encryption_algorithms, :phase_2_integrity_algorithms, :phase_2_lifetime_seconds, :pre_shared_key, :rekey_fuzz_percentage, :rekey_margin_time_seconds, :replay_window_size, :tunnel_inside_cidr) SENSITIVE = [] include Aws::Structure end |
#phase_2_lifetime_seconds ⇒ Integer
The lifetime for phase 2 of the IKE negotiation, in seconds.
9335 9336 9337 9338 9339 9340 9341 9342 9343 9344 9345 9346 9347 9348 9349 9350 9351 9352 9353 9354 |
# File 'lib/aws-sdk-securityhub/types.rb', line 9335 class AwsEc2VpnConnectionOptionsTunnelOptionsDetails < Struct.new( :dpd_timeout_seconds, :ike_versions, :outside_ip_address, :phase_1_dh_group_numbers, :phase_1_encryption_algorithms, :phase_1_integrity_algorithms, :phase_1_lifetime_seconds, :phase_2_dh_group_numbers, :phase_2_encryption_algorithms, :phase_2_integrity_algorithms, :phase_2_lifetime_seconds, :pre_shared_key, :rekey_fuzz_percentage, :rekey_margin_time_seconds, :replay_window_size, :tunnel_inside_cidr) SENSITIVE = [] include Aws::Structure end |
#pre_shared_key ⇒ String
The preshared key to establish initial authentication between the virtual private gateway and the customer gateway.
9335 9336 9337 9338 9339 9340 9341 9342 9343 9344 9345 9346 9347 9348 9349 9350 9351 9352 9353 9354 |
# File 'lib/aws-sdk-securityhub/types.rb', line 9335 class AwsEc2VpnConnectionOptionsTunnelOptionsDetails < Struct.new( :dpd_timeout_seconds, :ike_versions, :outside_ip_address, :phase_1_dh_group_numbers, :phase_1_encryption_algorithms, :phase_1_integrity_algorithms, :phase_1_lifetime_seconds, :phase_2_dh_group_numbers, :phase_2_encryption_algorithms, :phase_2_integrity_algorithms, :phase_2_lifetime_seconds, :pre_shared_key, :rekey_fuzz_percentage, :rekey_margin_time_seconds, :replay_window_size, :tunnel_inside_cidr) SENSITIVE = [] include Aws::Structure end |
#rekey_fuzz_percentage ⇒ Integer
The percentage of the rekey window, which is determined by
RekeyMarginTimeSeconds during which the rekey time is randomly
selected.
9335 9336 9337 9338 9339 9340 9341 9342 9343 9344 9345 9346 9347 9348 9349 9350 9351 9352 9353 9354 |
# File 'lib/aws-sdk-securityhub/types.rb', line 9335 class AwsEc2VpnConnectionOptionsTunnelOptionsDetails < Struct.new( :dpd_timeout_seconds, :ike_versions, :outside_ip_address, :phase_1_dh_group_numbers, :phase_1_encryption_algorithms, :phase_1_integrity_algorithms, :phase_1_lifetime_seconds, :phase_2_dh_group_numbers, :phase_2_encryption_algorithms, :phase_2_integrity_algorithms, :phase_2_lifetime_seconds, :pre_shared_key, :rekey_fuzz_percentage, :rekey_margin_time_seconds, :replay_window_size, :tunnel_inside_cidr) SENSITIVE = [] include Aws::Structure end |
#rekey_margin_time_seconds ⇒ Integer
The margin time, in seconds, before the phase 2 lifetime expires, during which the Amazon Web Services side of the VPN connection performs an IKE rekey.
9335 9336 9337 9338 9339 9340 9341 9342 9343 9344 9345 9346 9347 9348 9349 9350 9351 9352 9353 9354 |
# File 'lib/aws-sdk-securityhub/types.rb', line 9335 class AwsEc2VpnConnectionOptionsTunnelOptionsDetails < Struct.new( :dpd_timeout_seconds, :ike_versions, :outside_ip_address, :phase_1_dh_group_numbers, :phase_1_encryption_algorithms, :phase_1_integrity_algorithms, :phase_1_lifetime_seconds, :phase_2_dh_group_numbers, :phase_2_encryption_algorithms, :phase_2_integrity_algorithms, :phase_2_lifetime_seconds, :pre_shared_key, :rekey_fuzz_percentage, :rekey_margin_time_seconds, :replay_window_size, :tunnel_inside_cidr) SENSITIVE = [] include Aws::Structure end |
#replay_window_size ⇒ Integer
The number of packets in an IKE replay window.
9335 9336 9337 9338 9339 9340 9341 9342 9343 9344 9345 9346 9347 9348 9349 9350 9351 9352 9353 9354 |
# File 'lib/aws-sdk-securityhub/types.rb', line 9335 class AwsEc2VpnConnectionOptionsTunnelOptionsDetails < Struct.new( :dpd_timeout_seconds, :ike_versions, :outside_ip_address, :phase_1_dh_group_numbers, :phase_1_encryption_algorithms, :phase_1_integrity_algorithms, :phase_1_lifetime_seconds, :phase_2_dh_group_numbers, :phase_2_encryption_algorithms, :phase_2_integrity_algorithms, :phase_2_lifetime_seconds, :pre_shared_key, :rekey_fuzz_percentage, :rekey_margin_time_seconds, :replay_window_size, :tunnel_inside_cidr) SENSITIVE = [] include Aws::Structure end |
#tunnel_inside_cidr ⇒ String
The range of inside IPv4 addresses for the tunnel.
9335 9336 9337 9338 9339 9340 9341 9342 9343 9344 9345 9346 9347 9348 9349 9350 9351 9352 9353 9354 |
# File 'lib/aws-sdk-securityhub/types.rb', line 9335 class AwsEc2VpnConnectionOptionsTunnelOptionsDetails < Struct.new( :dpd_timeout_seconds, :ike_versions, :outside_ip_address, :phase_1_dh_group_numbers, :phase_1_encryption_algorithms, :phase_1_integrity_algorithms, :phase_1_lifetime_seconds, :phase_2_dh_group_numbers, :phase_2_encryption_algorithms, :phase_2_integrity_algorithms, :phase_2_lifetime_seconds, :pre_shared_key, :rekey_fuzz_percentage, :rekey_margin_time_seconds, :replay_window_size, :tunnel_inside_cidr) SENSITIVE = [] include Aws::Structure end |