Class: Aws::SecurityHub::Types::AwsEc2VpnConnectionVgwTelemetryDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::AwsEc2VpnConnectionVgwTelemetryDetails
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Information about the VPN tunnel.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#accepted_route_count ⇒ Integer
The number of accepted routes.
-
#certificate_arn ⇒ String
The ARN of the VPN tunnel endpoint certificate.
-
#last_status_change ⇒ String
The date and time of the last change in status.
-
#outside_ip_address ⇒ String
The Internet-routable IP address of the virtual private gateway's outside interface.
-
#status ⇒ String
The status of the VPN tunnel.
-
#status_message ⇒ String
If an error occurs, a description of the error.
Instance Attribute Details
#accepted_route_count ⇒ Integer
The number of accepted routes.
9412 9413 9414 9415 9416 9417 9418 9419 9420 9421 |
# File 'lib/aws-sdk-securityhub/types.rb', line 9412 class AwsEc2VpnConnectionVgwTelemetryDetails < Struct.new( :accepted_route_count, :certificate_arn, :last_status_change, :outside_ip_address, :status, :status_message) SENSITIVE = [] include Aws::Structure end |
#certificate_arn ⇒ String
The ARN of the VPN tunnel endpoint certificate.
9412 9413 9414 9415 9416 9417 9418 9419 9420 9421 |
# File 'lib/aws-sdk-securityhub/types.rb', line 9412 class AwsEc2VpnConnectionVgwTelemetryDetails < Struct.new( :accepted_route_count, :certificate_arn, :last_status_change, :outside_ip_address, :status, :status_message) SENSITIVE = [] include Aws::Structure end |
#last_status_change ⇒ String
The date and time of the last change in status.
For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.
9412 9413 9414 9415 9416 9417 9418 9419 9420 9421 |
# File 'lib/aws-sdk-securityhub/types.rb', line 9412 class AwsEc2VpnConnectionVgwTelemetryDetails < Struct.new( :accepted_route_count, :certificate_arn, :last_status_change, :outside_ip_address, :status, :status_message) SENSITIVE = [] include Aws::Structure end |
#outside_ip_address ⇒ String
The Internet-routable IP address of the virtual private gateway's outside interface.
9412 9413 9414 9415 9416 9417 9418 9419 9420 9421 |
# File 'lib/aws-sdk-securityhub/types.rb', line 9412 class AwsEc2VpnConnectionVgwTelemetryDetails < Struct.new( :accepted_route_count, :certificate_arn, :last_status_change, :outside_ip_address, :status, :status_message) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the VPN tunnel. Valid values are DOWN or UP.
9412 9413 9414 9415 9416 9417 9418 9419 9420 9421 |
# File 'lib/aws-sdk-securityhub/types.rb', line 9412 class AwsEc2VpnConnectionVgwTelemetryDetails < Struct.new( :accepted_route_count, :certificate_arn, :last_status_change, :outside_ip_address, :status, :status_message) SENSITIVE = [] include Aws::Structure end |
#status_message ⇒ String
If an error occurs, a description of the error.
9412 9413 9414 9415 9416 9417 9418 9419 9420 9421 |
# File 'lib/aws-sdk-securityhub/types.rb', line 9412 class AwsEc2VpnConnectionVgwTelemetryDetails < Struct.new( :accepted_route_count, :certificate_arn, :last_status_change, :outside_ip_address, :status, :status_message) SENSITIVE = [] include Aws::Structure end |