Class: Aws::SecurityHub::Types::AwsEcsServiceDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::AwsEcsServiceDetails
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Provides details about a service within an ECS cluster.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#capacity_provider_strategy ⇒ Array<Types::AwsEcsServiceCapacityProviderStrategyDetails>
The capacity provider strategy that the service uses.
-
#cluster ⇒ String
The ARN of the cluster that hosts the service.
-
#deployment_configuration ⇒ Types::AwsEcsServiceDeploymentConfigurationDetails
Deployment parameters for the service.
-
#deployment_controller ⇒ Types::AwsEcsServiceDeploymentControllerDetails
Contains the deployment controller type that the service uses.
-
#desired_count ⇒ Integer
The number of instantiations of the task definition to run on the service.
-
#enable_ecs_managed_tags ⇒ Boolean
Whether to enable Amazon ECS managed tags for the tasks in the service.
-
#enable_execute_command ⇒ Boolean
Whether the execute command functionality is enabled for the service.
-
#health_check_grace_period_seconds ⇒ Integer
After a task starts, the amount of time in seconds that the Amazon ECS service scheduler ignores unhealthy Elastic Load Balancing target health checks.
-
#launch_type ⇒ String
The launch type that the service uses.
-
#load_balancers ⇒ Array<Types::AwsEcsServiceLoadBalancersDetails>
Information about the load balancers that the service uses.
-
#name ⇒ String
The name of the service.
-
#network_configuration ⇒ Types::AwsEcsServiceNetworkConfigurationDetails
For tasks that use the
awsvpcnetworking mode, the VPC subnet and security group configuration. -
#placement_constraints ⇒ Array<Types::AwsEcsServicePlacementConstraintsDetails>
The placement constraints for the tasks in the service.
-
#placement_strategies ⇒ Array<Types::AwsEcsServicePlacementStrategiesDetails>
Information about how tasks for the service are placed.
-
#platform_version ⇒ String
The platform version on which to run the service.
-
#propagate_tags ⇒ String
Indicates whether to propagate the tags from the task definition to the task or from the service to the task.
-
#role ⇒ String
The ARN of the IAM role that is associated with the service.
-
#scheduling_strategy ⇒ String
The scheduling strategy to use for the service.
-
#service_arn ⇒ String
The ARN of the service.
-
#service_name ⇒ String
The name of the service.
-
#service_registries ⇒ Array<Types::AwsEcsServiceServiceRegistriesDetails>
Information about the service discovery registries to assign to the service.
-
#task_definition ⇒ String
The task definition to use for tasks in the service.
Instance Attribute Details
#capacity_provider_strategy ⇒ Array<Types::AwsEcsServiceCapacityProviderStrategyDetails>
The capacity provider strategy that the service uses.
10007 10008 10009 10010 10011 10012 10013 10014 10015 10016 10017 10018 10019 10020 10021 10022 10023 10024 10025 10026 10027 10028 10029 10030 10031 10032 |
# File 'lib/aws-sdk-securityhub/types.rb', line 10007 class AwsEcsServiceDetails < Struct.new( :capacity_provider_strategy, :cluster, :deployment_configuration, :deployment_controller, :desired_count, :enable_ecs_managed_tags, :enable_execute_command, :health_check_grace_period_seconds, :launch_type, :load_balancers, :name, :network_configuration, :placement_constraints, :placement_strategies, :platform_version, :propagate_tags, :role, :scheduling_strategy, :service_arn, :service_name, :service_registries, :task_definition) SENSITIVE = [] include Aws::Structure end |
#cluster ⇒ String
The ARN of the cluster that hosts the service.
10007 10008 10009 10010 10011 10012 10013 10014 10015 10016 10017 10018 10019 10020 10021 10022 10023 10024 10025 10026 10027 10028 10029 10030 10031 10032 |
# File 'lib/aws-sdk-securityhub/types.rb', line 10007 class AwsEcsServiceDetails < Struct.new( :capacity_provider_strategy, :cluster, :deployment_configuration, :deployment_controller, :desired_count, :enable_ecs_managed_tags, :enable_execute_command, :health_check_grace_period_seconds, :launch_type, :load_balancers, :name, :network_configuration, :placement_constraints, :placement_strategies, :platform_version, :propagate_tags, :role, :scheduling_strategy, :service_arn, :service_name, :service_registries, :task_definition) SENSITIVE = [] include Aws::Structure end |
#deployment_configuration ⇒ Types::AwsEcsServiceDeploymentConfigurationDetails
Deployment parameters for the service. Includes the number of tasks that run and the order in which to start and stop tasks.
10007 10008 10009 10010 10011 10012 10013 10014 10015 10016 10017 10018 10019 10020 10021 10022 10023 10024 10025 10026 10027 10028 10029 10030 10031 10032 |
# File 'lib/aws-sdk-securityhub/types.rb', line 10007 class AwsEcsServiceDetails < Struct.new( :capacity_provider_strategy, :cluster, :deployment_configuration, :deployment_controller, :desired_count, :enable_ecs_managed_tags, :enable_execute_command, :health_check_grace_period_seconds, :launch_type, :load_balancers, :name, :network_configuration, :placement_constraints, :placement_strategies, :platform_version, :propagate_tags, :role, :scheduling_strategy, :service_arn, :service_name, :service_registries, :task_definition) SENSITIVE = [] include Aws::Structure end |
#deployment_controller ⇒ Types::AwsEcsServiceDeploymentControllerDetails
Contains the deployment controller type that the service uses.
10007 10008 10009 10010 10011 10012 10013 10014 10015 10016 10017 10018 10019 10020 10021 10022 10023 10024 10025 10026 10027 10028 10029 10030 10031 10032 |
# File 'lib/aws-sdk-securityhub/types.rb', line 10007 class AwsEcsServiceDetails < Struct.new( :capacity_provider_strategy, :cluster, :deployment_configuration, :deployment_controller, :desired_count, :enable_ecs_managed_tags, :enable_execute_command, :health_check_grace_period_seconds, :launch_type, :load_balancers, :name, :network_configuration, :placement_constraints, :placement_strategies, :platform_version, :propagate_tags, :role, :scheduling_strategy, :service_arn, :service_name, :service_registries, :task_definition) SENSITIVE = [] include Aws::Structure end |
#desired_count ⇒ Integer
The number of instantiations of the task definition to run on the service.
10007 10008 10009 10010 10011 10012 10013 10014 10015 10016 10017 10018 10019 10020 10021 10022 10023 10024 10025 10026 10027 10028 10029 10030 10031 10032 |
# File 'lib/aws-sdk-securityhub/types.rb', line 10007 class AwsEcsServiceDetails < Struct.new( :capacity_provider_strategy, :cluster, :deployment_configuration, :deployment_controller, :desired_count, :enable_ecs_managed_tags, :enable_execute_command, :health_check_grace_period_seconds, :launch_type, :load_balancers, :name, :network_configuration, :placement_constraints, :placement_strategies, :platform_version, :propagate_tags, :role, :scheduling_strategy, :service_arn, :service_name, :service_registries, :task_definition) SENSITIVE = [] include Aws::Structure end |
#enable_ecs_managed_tags ⇒ Boolean
Whether to enable Amazon ECS managed tags for the tasks in the service.
10007 10008 10009 10010 10011 10012 10013 10014 10015 10016 10017 10018 10019 10020 10021 10022 10023 10024 10025 10026 10027 10028 10029 10030 10031 10032 |
# File 'lib/aws-sdk-securityhub/types.rb', line 10007 class AwsEcsServiceDetails < Struct.new( :capacity_provider_strategy, :cluster, :deployment_configuration, :deployment_controller, :desired_count, :enable_ecs_managed_tags, :enable_execute_command, :health_check_grace_period_seconds, :launch_type, :load_balancers, :name, :network_configuration, :placement_constraints, :placement_strategies, :platform_version, :propagate_tags, :role, :scheduling_strategy, :service_arn, :service_name, :service_registries, :task_definition) SENSITIVE = [] include Aws::Structure end |
#enable_execute_command ⇒ Boolean
Whether the execute command functionality is enabled for the service.
10007 10008 10009 10010 10011 10012 10013 10014 10015 10016 10017 10018 10019 10020 10021 10022 10023 10024 10025 10026 10027 10028 10029 10030 10031 10032 |
# File 'lib/aws-sdk-securityhub/types.rb', line 10007 class AwsEcsServiceDetails < Struct.new( :capacity_provider_strategy, :cluster, :deployment_configuration, :deployment_controller, :desired_count, :enable_ecs_managed_tags, :enable_execute_command, :health_check_grace_period_seconds, :launch_type, :load_balancers, :name, :network_configuration, :placement_constraints, :placement_strategies, :platform_version, :propagate_tags, :role, :scheduling_strategy, :service_arn, :service_name, :service_registries, :task_definition) SENSITIVE = [] include Aws::Structure end |
#health_check_grace_period_seconds ⇒ Integer
After a task starts, the amount of time in seconds that the Amazon ECS service scheduler ignores unhealthy Elastic Load Balancing target health checks.
10007 10008 10009 10010 10011 10012 10013 10014 10015 10016 10017 10018 10019 10020 10021 10022 10023 10024 10025 10026 10027 10028 10029 10030 10031 10032 |
# File 'lib/aws-sdk-securityhub/types.rb', line 10007 class AwsEcsServiceDetails < Struct.new( :capacity_provider_strategy, :cluster, :deployment_configuration, :deployment_controller, :desired_count, :enable_ecs_managed_tags, :enable_execute_command, :health_check_grace_period_seconds, :launch_type, :load_balancers, :name, :network_configuration, :placement_constraints, :placement_strategies, :platform_version, :propagate_tags, :role, :scheduling_strategy, :service_arn, :service_name, :service_registries, :task_definition) SENSITIVE = [] include Aws::Structure end |
#launch_type ⇒ String
The launch type that the service uses.
Valid values: EC2 | FARGATE | EXTERNAL
10007 10008 10009 10010 10011 10012 10013 10014 10015 10016 10017 10018 10019 10020 10021 10022 10023 10024 10025 10026 10027 10028 10029 10030 10031 10032 |
# File 'lib/aws-sdk-securityhub/types.rb', line 10007 class AwsEcsServiceDetails < Struct.new( :capacity_provider_strategy, :cluster, :deployment_configuration, :deployment_controller, :desired_count, :enable_ecs_managed_tags, :enable_execute_command, :health_check_grace_period_seconds, :launch_type, :load_balancers, :name, :network_configuration, :placement_constraints, :placement_strategies, :platform_version, :propagate_tags, :role, :scheduling_strategy, :service_arn, :service_name, :service_registries, :task_definition) SENSITIVE = [] include Aws::Structure end |
#load_balancers ⇒ Array<Types::AwsEcsServiceLoadBalancersDetails>
Information about the load balancers that the service uses.
10007 10008 10009 10010 10011 10012 10013 10014 10015 10016 10017 10018 10019 10020 10021 10022 10023 10024 10025 10026 10027 10028 10029 10030 10031 10032 |
# File 'lib/aws-sdk-securityhub/types.rb', line 10007 class AwsEcsServiceDetails < Struct.new( :capacity_provider_strategy, :cluster, :deployment_configuration, :deployment_controller, :desired_count, :enable_ecs_managed_tags, :enable_execute_command, :health_check_grace_period_seconds, :launch_type, :load_balancers, :name, :network_configuration, :placement_constraints, :placement_strategies, :platform_version, :propagate_tags, :role, :scheduling_strategy, :service_arn, :service_name, :service_registries, :task_definition) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the service.
10007 10008 10009 10010 10011 10012 10013 10014 10015 10016 10017 10018 10019 10020 10021 10022 10023 10024 10025 10026 10027 10028 10029 10030 10031 10032 |
# File 'lib/aws-sdk-securityhub/types.rb', line 10007 class AwsEcsServiceDetails < Struct.new( :capacity_provider_strategy, :cluster, :deployment_configuration, :deployment_controller, :desired_count, :enable_ecs_managed_tags, :enable_execute_command, :health_check_grace_period_seconds, :launch_type, :load_balancers, :name, :network_configuration, :placement_constraints, :placement_strategies, :platform_version, :propagate_tags, :role, :scheduling_strategy, :service_arn, :service_name, :service_registries, :task_definition) SENSITIVE = [] include Aws::Structure end |
#network_configuration ⇒ Types::AwsEcsServiceNetworkConfigurationDetails
For tasks that use the awsvpc networking mode, the VPC subnet and
security group configuration.
10007 10008 10009 10010 10011 10012 10013 10014 10015 10016 10017 10018 10019 10020 10021 10022 10023 10024 10025 10026 10027 10028 10029 10030 10031 10032 |
# File 'lib/aws-sdk-securityhub/types.rb', line 10007 class AwsEcsServiceDetails < Struct.new( :capacity_provider_strategy, :cluster, :deployment_configuration, :deployment_controller, :desired_count, :enable_ecs_managed_tags, :enable_execute_command, :health_check_grace_period_seconds, :launch_type, :load_balancers, :name, :network_configuration, :placement_constraints, :placement_strategies, :platform_version, :propagate_tags, :role, :scheduling_strategy, :service_arn, :service_name, :service_registries, :task_definition) SENSITIVE = [] include Aws::Structure end |
#placement_constraints ⇒ Array<Types::AwsEcsServicePlacementConstraintsDetails>
The placement constraints for the tasks in the service.
10007 10008 10009 10010 10011 10012 10013 10014 10015 10016 10017 10018 10019 10020 10021 10022 10023 10024 10025 10026 10027 10028 10029 10030 10031 10032 |
# File 'lib/aws-sdk-securityhub/types.rb', line 10007 class AwsEcsServiceDetails < Struct.new( :capacity_provider_strategy, :cluster, :deployment_configuration, :deployment_controller, :desired_count, :enable_ecs_managed_tags, :enable_execute_command, :health_check_grace_period_seconds, :launch_type, :load_balancers, :name, :network_configuration, :placement_constraints, :placement_strategies, :platform_version, :propagate_tags, :role, :scheduling_strategy, :service_arn, :service_name, :service_registries, :task_definition) SENSITIVE = [] include Aws::Structure end |
#placement_strategies ⇒ Array<Types::AwsEcsServicePlacementStrategiesDetails>
Information about how tasks for the service are placed.
10007 10008 10009 10010 10011 10012 10013 10014 10015 10016 10017 10018 10019 10020 10021 10022 10023 10024 10025 10026 10027 10028 10029 10030 10031 10032 |
# File 'lib/aws-sdk-securityhub/types.rb', line 10007 class AwsEcsServiceDetails < Struct.new( :capacity_provider_strategy, :cluster, :deployment_configuration, :deployment_controller, :desired_count, :enable_ecs_managed_tags, :enable_execute_command, :health_check_grace_period_seconds, :launch_type, :load_balancers, :name, :network_configuration, :placement_constraints, :placement_strategies, :platform_version, :propagate_tags, :role, :scheduling_strategy, :service_arn, :service_name, :service_registries, :task_definition) SENSITIVE = [] include Aws::Structure end |
#platform_version ⇒ String
The platform version on which to run the service. Only specified for
tasks that are hosted on Fargate. If a platform version is not
specified, the LATEST platform version is used by default.
10007 10008 10009 10010 10011 10012 10013 10014 10015 10016 10017 10018 10019 10020 10021 10022 10023 10024 10025 10026 10027 10028 10029 10030 10031 10032 |
# File 'lib/aws-sdk-securityhub/types.rb', line 10007 class AwsEcsServiceDetails < Struct.new( :capacity_provider_strategy, :cluster, :deployment_configuration, :deployment_controller, :desired_count, :enable_ecs_managed_tags, :enable_execute_command, :health_check_grace_period_seconds, :launch_type, :load_balancers, :name, :network_configuration, :placement_constraints, :placement_strategies, :platform_version, :propagate_tags, :role, :scheduling_strategy, :service_arn, :service_name, :service_registries, :task_definition) SENSITIVE = [] include Aws::Structure end |
#propagate_tags ⇒ String
Indicates whether to propagate the tags from the task definition to the task or from the service to the task. If no value is provided, then tags are not propagated.
Valid values: TASK_DEFINITION | SERVICE
10007 10008 10009 10010 10011 10012 10013 10014 10015 10016 10017 10018 10019 10020 10021 10022 10023 10024 10025 10026 10027 10028 10029 10030 10031 10032 |
# File 'lib/aws-sdk-securityhub/types.rb', line 10007 class AwsEcsServiceDetails < Struct.new( :capacity_provider_strategy, :cluster, :deployment_configuration, :deployment_controller, :desired_count, :enable_ecs_managed_tags, :enable_execute_command, :health_check_grace_period_seconds, :launch_type, :load_balancers, :name, :network_configuration, :placement_constraints, :placement_strategies, :platform_version, :propagate_tags, :role, :scheduling_strategy, :service_arn, :service_name, :service_registries, :task_definition) SENSITIVE = [] include Aws::Structure end |
#role ⇒ String
The ARN of the IAM role that is associated with the service. The role allows the Amazon ECS container agent to register container instances with an Elastic Load Balancing load balancer.
10007 10008 10009 10010 10011 10012 10013 10014 10015 10016 10017 10018 10019 10020 10021 10022 10023 10024 10025 10026 10027 10028 10029 10030 10031 10032 |
# File 'lib/aws-sdk-securityhub/types.rb', line 10007 class AwsEcsServiceDetails < Struct.new( :capacity_provider_strategy, :cluster, :deployment_configuration, :deployment_controller, :desired_count, :enable_ecs_managed_tags, :enable_execute_command, :health_check_grace_period_seconds, :launch_type, :load_balancers, :name, :network_configuration, :placement_constraints, :placement_strategies, :platform_version, :propagate_tags, :role, :scheduling_strategy, :service_arn, :service_name, :service_registries, :task_definition) SENSITIVE = [] include Aws::Structure end |
#scheduling_strategy ⇒ String
The scheduling strategy to use for the service.
The REPLICA scheduling strategy places and maintains the desired
number of tasks across the cluster. By default, the service
scheduler spreads tasks across Availability Zones. Task placement
strategies and constraints are used to customize task placement
decisions.
The DAEMON scheduling strategy deploys exactly one task on each
active container instance that meets all of the task placement
constraints that are specified in the cluster. The service scheduler
also evaluates the task placement constraints for running tasks and
stops tasks that don't meet the placement constraints.
Valid values: REPLICA | DAEMON
10007 10008 10009 10010 10011 10012 10013 10014 10015 10016 10017 10018 10019 10020 10021 10022 10023 10024 10025 10026 10027 10028 10029 10030 10031 10032 |
# File 'lib/aws-sdk-securityhub/types.rb', line 10007 class AwsEcsServiceDetails < Struct.new( :capacity_provider_strategy, :cluster, :deployment_configuration, :deployment_controller, :desired_count, :enable_ecs_managed_tags, :enable_execute_command, :health_check_grace_period_seconds, :launch_type, :load_balancers, :name, :network_configuration, :placement_constraints, :placement_strategies, :platform_version, :propagate_tags, :role, :scheduling_strategy, :service_arn, :service_name, :service_registries, :task_definition) SENSITIVE = [] include Aws::Structure end |
#service_arn ⇒ String
The ARN of the service.
10007 10008 10009 10010 10011 10012 10013 10014 10015 10016 10017 10018 10019 10020 10021 10022 10023 10024 10025 10026 10027 10028 10029 10030 10031 10032 |
# File 'lib/aws-sdk-securityhub/types.rb', line 10007 class AwsEcsServiceDetails < Struct.new( :capacity_provider_strategy, :cluster, :deployment_configuration, :deployment_controller, :desired_count, :enable_ecs_managed_tags, :enable_execute_command, :health_check_grace_period_seconds, :launch_type, :load_balancers, :name, :network_configuration, :placement_constraints, :placement_strategies, :platform_version, :propagate_tags, :role, :scheduling_strategy, :service_arn, :service_name, :service_registries, :task_definition) SENSITIVE = [] include Aws::Structure end |
#service_name ⇒ String
The name of the service.
The name can contain up to 255 characters. It can use letters, numbers, underscores, and hyphens.
10007 10008 10009 10010 10011 10012 10013 10014 10015 10016 10017 10018 10019 10020 10021 10022 10023 10024 10025 10026 10027 10028 10029 10030 10031 10032 |
# File 'lib/aws-sdk-securityhub/types.rb', line 10007 class AwsEcsServiceDetails < Struct.new( :capacity_provider_strategy, :cluster, :deployment_configuration, :deployment_controller, :desired_count, :enable_ecs_managed_tags, :enable_execute_command, :health_check_grace_period_seconds, :launch_type, :load_balancers, :name, :network_configuration, :placement_constraints, :placement_strategies, :platform_version, :propagate_tags, :role, :scheduling_strategy, :service_arn, :service_name, :service_registries, :task_definition) SENSITIVE = [] include Aws::Structure end |
#service_registries ⇒ Array<Types::AwsEcsServiceServiceRegistriesDetails>
Information about the service discovery registries to assign to the service.
10007 10008 10009 10010 10011 10012 10013 10014 10015 10016 10017 10018 10019 10020 10021 10022 10023 10024 10025 10026 10027 10028 10029 10030 10031 10032 |
# File 'lib/aws-sdk-securityhub/types.rb', line 10007 class AwsEcsServiceDetails < Struct.new( :capacity_provider_strategy, :cluster, :deployment_configuration, :deployment_controller, :desired_count, :enable_ecs_managed_tags, :enable_execute_command, :health_check_grace_period_seconds, :launch_type, :load_balancers, :name, :network_configuration, :placement_constraints, :placement_strategies, :platform_version, :propagate_tags, :role, :scheduling_strategy, :service_arn, :service_name, :service_registries, :task_definition) SENSITIVE = [] include Aws::Structure end |
#task_definition ⇒ String
The task definition to use for tasks in the service.
10007 10008 10009 10010 10011 10012 10013 10014 10015 10016 10017 10018 10019 10020 10021 10022 10023 10024 10025 10026 10027 10028 10029 10030 10031 10032 |
# File 'lib/aws-sdk-securityhub/types.rb', line 10007 class AwsEcsServiceDetails < Struct.new( :capacity_provider_strategy, :cluster, :deployment_configuration, :deployment_controller, :desired_count, :enable_ecs_managed_tags, :enable_execute_command, :health_check_grace_period_seconds, :launch_type, :load_balancers, :name, :network_configuration, :placement_constraints, :placement_strategies, :platform_version, :propagate_tags, :role, :scheduling_strategy, :service_arn, :service_name, :service_registries, :task_definition) SENSITIVE = [] include Aws::Structure end |