Class: Aws::SecurityHub::Types::AwsEcsServiceServiceRegistriesDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::AwsEcsServiceServiceRegistriesDetails
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Information about a service discovery registry to assign to the service.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#container_name ⇒ String
The container name value to use for the service discovery service.
-
#container_port ⇒ Integer
The port value to use for the service discovery service.
-
#port ⇒ Integer
The port value to use for a service discovery service that specifies an SRV record.
-
#registry_arn ⇒ String
The ARN of the service registry.
Instance Attribute Details
#container_name ⇒ String
The container name value to use for the service discovery service.
If the task definition uses the bridge or host network mode, you
must specify ContainerName and ContainerPort.
If the task definition uses the awsvpc network mode and a type SRV
DNS record, you must specify either ContainerName and
ContainerPort, or Port , but not both.
10127 10128 10129 10130 10131 10132 10133 10134 |
# File 'lib/aws-sdk-securityhub/types.rb', line 10127 class AwsEcsServiceServiceRegistriesDetails < Struct.new( :container_name, :container_port, :port, :registry_arn) SENSITIVE = [] include Aws::Structure end |
#container_port ⇒ Integer
The port value to use for the service discovery service.
If the task definition uses the bridge or host network mode, you
must specify ContainerName and ContainerPort.
If the task definition uses the awsvpc network mode and a type SRV
DNS record, you must specify either ContainerName and
ContainerPort, or Port , but not both.
10127 10128 10129 10130 10131 10132 10133 10134 |
# File 'lib/aws-sdk-securityhub/types.rb', line 10127 class AwsEcsServiceServiceRegistriesDetails < Struct.new( :container_name, :container_port, :port, :registry_arn) SENSITIVE = [] include Aws::Structure end |
#port ⇒ Integer
The port value to use for a service discovery service that specifies
an SRV record. This field can be used if both the awsvpcawsvpc
network mode and SRV records are used.
10127 10128 10129 10130 10131 10132 10133 10134 |
# File 'lib/aws-sdk-securityhub/types.rb', line 10127 class AwsEcsServiceServiceRegistriesDetails < Struct.new( :container_name, :container_port, :port, :registry_arn) SENSITIVE = [] include Aws::Structure end |
#registry_arn ⇒ String
The ARN of the service registry.
10127 10128 10129 10130 10131 10132 10133 10134 |
# File 'lib/aws-sdk-securityhub/types.rb', line 10127 class AwsEcsServiceServiceRegistriesDetails < Struct.new( :container_name, :container_port, :port, :registry_arn) SENSITIVE = [] include Aws::Structure end |