Class: Aws::SecurityHub::Types::AwsEcsTaskDefinitionContainerDefinitionsDetails

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

A container definition that describes a container in the task.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#commandArray<String>

The command that is passed to the container.

Returns:

  • (Array<String>)


10461
10462
10463
10464
10465
10466
10467
10468
10469
10470
10471
10472
10473
10474
10475
10476
10477
10478
10479
10480
10481
10482
10483
10484
10485
10486
10487
10488
10489
10490
10491
10492
10493
10494
10495
10496
10497
10498
10499
10500
10501
10502
10503
# File 'lib/aws-sdk-securityhub/types.rb', line 10461

class AwsEcsTaskDefinitionContainerDefinitionsDetails < Struct.new(
  :command,
  :cpu,
  :depends_on,
  :disable_networking,
  :dns_search_domains,
  :dns_servers,
  :docker_labels,
  :docker_security_options,
  :entry_point,
  :environment,
  :environment_files,
  :essential,
  :extra_hosts,
  :firelens_configuration,
  :health_check,
  :hostname,
  :image,
  :interactive,
  :links,
  :linux_parameters,
  :log_configuration,
  :memory,
  :memory_reservation,
  :mount_points,
  :name,
  :port_mappings,
  :privileged,
  :pseudo_terminal,
  :readonly_root_filesystem,
  :repository_credentials,
  :resource_requirements,
  :secrets,
  :start_timeout,
  :stop_timeout,
  :system_controls,
  :ulimits,
  :user,
  :volumes_from,
  :working_directory)
  SENSITIVE = []
  include Aws::Structure
end

#cpuInteger

The number of CPU units reserved for the container.

Returns:

  • (Integer)


10461
10462
10463
10464
10465
10466
10467
10468
10469
10470
10471
10472
10473
10474
10475
10476
10477
10478
10479
10480
10481
10482
10483
10484
10485
10486
10487
10488
10489
10490
10491
10492
10493
10494
10495
10496
10497
10498
10499
10500
10501
10502
10503
# File 'lib/aws-sdk-securityhub/types.rb', line 10461

class AwsEcsTaskDefinitionContainerDefinitionsDetails < Struct.new(
  :command,
  :cpu,
  :depends_on,
  :disable_networking,
  :dns_search_domains,
  :dns_servers,
  :docker_labels,
  :docker_security_options,
  :entry_point,
  :environment,
  :environment_files,
  :essential,
  :extra_hosts,
  :firelens_configuration,
  :health_check,
  :hostname,
  :image,
  :interactive,
  :links,
  :linux_parameters,
  :log_configuration,
  :memory,
  :memory_reservation,
  :mount_points,
  :name,
  :port_mappings,
  :privileged,
  :pseudo_terminal,
  :readonly_root_filesystem,
  :repository_credentials,
  :resource_requirements,
  :secrets,
  :start_timeout,
  :stop_timeout,
  :system_controls,
  :ulimits,
  :user,
  :volumes_from,
  :working_directory)
  SENSITIVE = []
  include Aws::Structure
end

#depends_onArray<Types::AwsEcsTaskDefinitionContainerDefinitionsDependsOnDetails>

The dependencies that are defined for container startup and shutdown.



10461
10462
10463
10464
10465
10466
10467
10468
10469
10470
10471
10472
10473
10474
10475
10476
10477
10478
10479
10480
10481
10482
10483
10484
10485
10486
10487
10488
10489
10490
10491
10492
10493
10494
10495
10496
10497
10498
10499
10500
10501
10502
10503
# File 'lib/aws-sdk-securityhub/types.rb', line 10461

class AwsEcsTaskDefinitionContainerDefinitionsDetails < Struct.new(
  :command,
  :cpu,
  :depends_on,
  :disable_networking,
  :dns_search_domains,
  :dns_servers,
  :docker_labels,
  :docker_security_options,
  :entry_point,
  :environment,
  :environment_files,
  :essential,
  :extra_hosts,
  :firelens_configuration,
  :health_check,
  :hostname,
  :image,
  :interactive,
  :links,
  :linux_parameters,
  :log_configuration,
  :memory,
  :memory_reservation,
  :mount_points,
  :name,
  :port_mappings,
  :privileged,
  :pseudo_terminal,
  :readonly_root_filesystem,
  :repository_credentials,
  :resource_requirements,
  :secrets,
  :start_timeout,
  :stop_timeout,
  :system_controls,
  :ulimits,
  :user,
  :volumes_from,
  :working_directory)
  SENSITIVE = []
  include Aws::Structure
end

#disable_networkingBoolean

Whether to disable networking within the container.

Returns:

  • (Boolean)


10461
10462
10463
10464
10465
10466
10467
10468
10469
10470
10471
10472
10473
10474
10475
10476
10477
10478
10479
10480
10481
10482
10483
10484
10485
10486
10487
10488
10489
10490
10491
10492
10493
10494
10495
10496
10497
10498
10499
10500
10501
10502
10503
# File 'lib/aws-sdk-securityhub/types.rb', line 10461

class AwsEcsTaskDefinitionContainerDefinitionsDetails < Struct.new(
  :command,
  :cpu,
  :depends_on,
  :disable_networking,
  :dns_search_domains,
  :dns_servers,
  :docker_labels,
  :docker_security_options,
  :entry_point,
  :environment,
  :environment_files,
  :essential,
  :extra_hosts,
  :firelens_configuration,
  :health_check,
  :hostname,
  :image,
  :interactive,
  :links,
  :linux_parameters,
  :log_configuration,
  :memory,
  :memory_reservation,
  :mount_points,
  :name,
  :port_mappings,
  :privileged,
  :pseudo_terminal,
  :readonly_root_filesystem,
  :repository_credentials,
  :resource_requirements,
  :secrets,
  :start_timeout,
  :stop_timeout,
  :system_controls,
  :ulimits,
  :user,
  :volumes_from,
  :working_directory)
  SENSITIVE = []
  include Aws::Structure
end

#dns_search_domainsArray<String>

A list of DNS search domains that are presented to the container.

Returns:

  • (Array<String>)


10461
10462
10463
10464
10465
10466
10467
10468
10469
10470
10471
10472
10473
10474
10475
10476
10477
10478
10479
10480
10481
10482
10483
10484
10485
10486
10487
10488
10489
10490
10491
10492
10493
10494
10495
10496
10497
10498
10499
10500
10501
10502
10503
# File 'lib/aws-sdk-securityhub/types.rb', line 10461

class AwsEcsTaskDefinitionContainerDefinitionsDetails < Struct.new(
  :command,
  :cpu,
  :depends_on,
  :disable_networking,
  :dns_search_domains,
  :dns_servers,
  :docker_labels,
  :docker_security_options,
  :entry_point,
  :environment,
  :environment_files,
  :essential,
  :extra_hosts,
  :firelens_configuration,
  :health_check,
  :hostname,
  :image,
  :interactive,
  :links,
  :linux_parameters,
  :log_configuration,
  :memory,
  :memory_reservation,
  :mount_points,
  :name,
  :port_mappings,
  :privileged,
  :pseudo_terminal,
  :readonly_root_filesystem,
  :repository_credentials,
  :resource_requirements,
  :secrets,
  :start_timeout,
  :stop_timeout,
  :system_controls,
  :ulimits,
  :user,
  :volumes_from,
  :working_directory)
  SENSITIVE = []
  include Aws::Structure
end

#dns_serversArray<String>

A list of DNS servers that are presented to the container.

Returns:

  • (Array<String>)


10461
10462
10463
10464
10465
10466
10467
10468
10469
10470
10471
10472
10473
10474
10475
10476
10477
10478
10479
10480
10481
10482
10483
10484
10485
10486
10487
10488
10489
10490
10491
10492
10493
10494
10495
10496
10497
10498
10499
10500
10501
10502
10503
# File 'lib/aws-sdk-securityhub/types.rb', line 10461

class AwsEcsTaskDefinitionContainerDefinitionsDetails < Struct.new(
  :command,
  :cpu,
  :depends_on,
  :disable_networking,
  :dns_search_domains,
  :dns_servers,
  :docker_labels,
  :docker_security_options,
  :entry_point,
  :environment,
  :environment_files,
  :essential,
  :extra_hosts,
  :firelens_configuration,
  :health_check,
  :hostname,
  :image,
  :interactive,
  :links,
  :linux_parameters,
  :log_configuration,
  :memory,
  :memory_reservation,
  :mount_points,
  :name,
  :port_mappings,
  :privileged,
  :pseudo_terminal,
  :readonly_root_filesystem,
  :repository_credentials,
  :resource_requirements,
  :secrets,
  :start_timeout,
  :stop_timeout,
  :system_controls,
  :ulimits,
  :user,
  :volumes_from,
  :working_directory)
  SENSITIVE = []
  include Aws::Structure
end

#docker_labelsHash<String,String>

A key-value map of labels to add to the container.

Returns:

  • (Hash<String,String>)


10461
10462
10463
10464
10465
10466
10467
10468
10469
10470
10471
10472
10473
10474
10475
10476
10477
10478
10479
10480
10481
10482
10483
10484
10485
10486
10487
10488
10489
10490
10491
10492
10493
10494
10495
10496
10497
10498
10499
10500
10501
10502
10503
# File 'lib/aws-sdk-securityhub/types.rb', line 10461

class AwsEcsTaskDefinitionContainerDefinitionsDetails < Struct.new(
  :command,
  :cpu,
  :depends_on,
  :disable_networking,
  :dns_search_domains,
  :dns_servers,
  :docker_labels,
  :docker_security_options,
  :entry_point,
  :environment,
  :environment_files,
  :essential,
  :extra_hosts,
  :firelens_configuration,
  :health_check,
  :hostname,
  :image,
  :interactive,
  :links,
  :linux_parameters,
  :log_configuration,
  :memory,
  :memory_reservation,
  :mount_points,
  :name,
  :port_mappings,
  :privileged,
  :pseudo_terminal,
  :readonly_root_filesystem,
  :repository_credentials,
  :resource_requirements,
  :secrets,
  :start_timeout,
  :stop_timeout,
  :system_controls,
  :ulimits,
  :user,
  :volumes_from,
  :working_directory)
  SENSITIVE = []
  include Aws::Structure
end

#docker_security_optionsArray<String>

A list of strings to provide custom labels for SELinux and AppArmor multi-level security systems.

Returns:

  • (Array<String>)


10461
10462
10463
10464
10465
10466
10467
10468
10469
10470
10471
10472
10473
10474
10475
10476
10477
10478
10479
10480
10481
10482
10483
10484
10485
10486
10487
10488
10489
10490
10491
10492
10493
10494
10495
10496
10497
10498
10499
10500
10501
10502
10503
# File 'lib/aws-sdk-securityhub/types.rb', line 10461

class AwsEcsTaskDefinitionContainerDefinitionsDetails < Struct.new(
  :command,
  :cpu,
  :depends_on,
  :disable_networking,
  :dns_search_domains,
  :dns_servers,
  :docker_labels,
  :docker_security_options,
  :entry_point,
  :environment,
  :environment_files,
  :essential,
  :extra_hosts,
  :firelens_configuration,
  :health_check,
  :hostname,
  :image,
  :interactive,
  :links,
  :linux_parameters,
  :log_configuration,
  :memory,
  :memory_reservation,
  :mount_points,
  :name,
  :port_mappings,
  :privileged,
  :pseudo_terminal,
  :readonly_root_filesystem,
  :repository_credentials,
  :resource_requirements,
  :secrets,
  :start_timeout,
  :stop_timeout,
  :system_controls,
  :ulimits,
  :user,
  :volumes_from,
  :working_directory)
  SENSITIVE = []
  include Aws::Structure
end

#entry_pointArray<String>

The entry point that is passed to the container.

Returns:

  • (Array<String>)


10461
10462
10463
10464
10465
10466
10467
10468
10469
10470
10471
10472
10473
10474
10475
10476
10477
10478
10479
10480
10481
10482
10483
10484
10485
10486
10487
10488
10489
10490
10491
10492
10493
10494
10495
10496
10497
10498
10499
10500
10501
10502
10503
# File 'lib/aws-sdk-securityhub/types.rb', line 10461

class AwsEcsTaskDefinitionContainerDefinitionsDetails < Struct.new(
  :command,
  :cpu,
  :depends_on,
  :disable_networking,
  :dns_search_domains,
  :dns_servers,
  :docker_labels,
  :docker_security_options,
  :entry_point,
  :environment,
  :environment_files,
  :essential,
  :extra_hosts,
  :firelens_configuration,
  :health_check,
  :hostname,
  :image,
  :interactive,
  :links,
  :linux_parameters,
  :log_configuration,
  :memory,
  :memory_reservation,
  :mount_points,
  :name,
  :port_mappings,
  :privileged,
  :pseudo_terminal,
  :readonly_root_filesystem,
  :repository_credentials,
  :resource_requirements,
  :secrets,
  :start_timeout,
  :stop_timeout,
  :system_controls,
  :ulimits,
  :user,
  :volumes_from,
  :working_directory)
  SENSITIVE = []
  include Aws::Structure
end

#environmentArray<Types::AwsEcsTaskDefinitionContainerDefinitionsEnvironmentDetails>

The environment variables to pass to a container.



10461
10462
10463
10464
10465
10466
10467
10468
10469
10470
10471
10472
10473
10474
10475
10476
10477
10478
10479
10480
10481
10482
10483
10484
10485
10486
10487
10488
10489
10490
10491
10492
10493
10494
10495
10496
10497
10498
10499
10500
10501
10502
10503
# File 'lib/aws-sdk-securityhub/types.rb', line 10461

class AwsEcsTaskDefinitionContainerDefinitionsDetails < Struct.new(
  :command,
  :cpu,
  :depends_on,
  :disable_networking,
  :dns_search_domains,
  :dns_servers,
  :docker_labels,
  :docker_security_options,
  :entry_point,
  :environment,
  :environment_files,
  :essential,
  :extra_hosts,
  :firelens_configuration,
  :health_check,
  :hostname,
  :image,
  :interactive,
  :links,
  :linux_parameters,
  :log_configuration,
  :memory,
  :memory_reservation,
  :mount_points,
  :name,
  :port_mappings,
  :privileged,
  :pseudo_terminal,
  :readonly_root_filesystem,
  :repository_credentials,
  :resource_requirements,
  :secrets,
  :start_timeout,
  :stop_timeout,
  :system_controls,
  :ulimits,
  :user,
  :volumes_from,
  :working_directory)
  SENSITIVE = []
  include Aws::Structure
end

#environment_filesArray<Types::AwsEcsTaskDefinitionContainerDefinitionsEnvironmentFilesDetails>

A list of files containing the environment variables to pass to a container.



10461
10462
10463
10464
10465
10466
10467
10468
10469
10470
10471
10472
10473
10474
10475
10476
10477
10478
10479
10480
10481
10482
10483
10484
10485
10486
10487
10488
10489
10490
10491
10492
10493
10494
10495
10496
10497
10498
10499
10500
10501
10502
10503
# File 'lib/aws-sdk-securityhub/types.rb', line 10461

class AwsEcsTaskDefinitionContainerDefinitionsDetails < Struct.new(
  :command,
  :cpu,
  :depends_on,
  :disable_networking,
  :dns_search_domains,
  :dns_servers,
  :docker_labels,
  :docker_security_options,
  :entry_point,
  :environment,
  :environment_files,
  :essential,
  :extra_hosts,
  :firelens_configuration,
  :health_check,
  :hostname,
  :image,
  :interactive,
  :links,
  :linux_parameters,
  :log_configuration,
  :memory,
  :memory_reservation,
  :mount_points,
  :name,
  :port_mappings,
  :privileged,
  :pseudo_terminal,
  :readonly_root_filesystem,
  :repository_credentials,
  :resource_requirements,
  :secrets,
  :start_timeout,
  :stop_timeout,
  :system_controls,
  :ulimits,
  :user,
  :volumes_from,
  :working_directory)
  SENSITIVE = []
  include Aws::Structure
end

#essentialBoolean

Whether the container is essential. All tasks must have at least one essential container.

Returns:

  • (Boolean)


10461
10462
10463
10464
10465
10466
10467
10468
10469
10470
10471
10472
10473
10474
10475
10476
10477
10478
10479
10480
10481
10482
10483
10484
10485
10486
10487
10488
10489
10490
10491
10492
10493
10494
10495
10496
10497
10498
10499
10500
10501
10502
10503
# File 'lib/aws-sdk-securityhub/types.rb', line 10461

class AwsEcsTaskDefinitionContainerDefinitionsDetails < Struct.new(
  :command,
  :cpu,
  :depends_on,
  :disable_networking,
  :dns_search_domains,
  :dns_servers,
  :docker_labels,
  :docker_security_options,
  :entry_point,
  :environment,
  :environment_files,
  :essential,
  :extra_hosts,
  :firelens_configuration,
  :health_check,
  :hostname,
  :image,
  :interactive,
  :links,
  :linux_parameters,
  :log_configuration,
  :memory,
  :memory_reservation,
  :mount_points,
  :name,
  :port_mappings,
  :privileged,
  :pseudo_terminal,
  :readonly_root_filesystem,
  :repository_credentials,
  :resource_requirements,
  :secrets,
  :start_timeout,
  :stop_timeout,
  :system_controls,
  :ulimits,
  :user,
  :volumes_from,
  :working_directory)
  SENSITIVE = []
  include Aws::Structure
end

#extra_hostsArray<Types::AwsEcsTaskDefinitionContainerDefinitionsExtraHostsDetails>

A list of hostnames and IP address mappings to append to the /etc/hosts file on the container.



10461
10462
10463
10464
10465
10466
10467
10468
10469
10470
10471
10472
10473
10474
10475
10476
10477
10478
10479
10480
10481
10482
10483
10484
10485
10486
10487
10488
10489
10490
10491
10492
10493
10494
10495
10496
10497
10498
10499
10500
10501
10502
10503
# File 'lib/aws-sdk-securityhub/types.rb', line 10461

class AwsEcsTaskDefinitionContainerDefinitionsDetails < Struct.new(
  :command,
  :cpu,
  :depends_on,
  :disable_networking,
  :dns_search_domains,
  :dns_servers,
  :docker_labels,
  :docker_security_options,
  :entry_point,
  :environment,
  :environment_files,
  :essential,
  :extra_hosts,
  :firelens_configuration,
  :health_check,
  :hostname,
  :image,
  :interactive,
  :links,
  :linux_parameters,
  :log_configuration,
  :memory,
  :memory_reservation,
  :mount_points,
  :name,
  :port_mappings,
  :privileged,
  :pseudo_terminal,
  :readonly_root_filesystem,
  :repository_credentials,
  :resource_requirements,
  :secrets,
  :start_timeout,
  :stop_timeout,
  :system_controls,
  :ulimits,
  :user,
  :volumes_from,
  :working_directory)
  SENSITIVE = []
  include Aws::Structure
end

#firelens_configurationTypes::AwsEcsTaskDefinitionContainerDefinitionsFirelensConfigurationDetails

The FireLens configuration for the container. Specifies and configures a log router for container logs.



10461
10462
10463
10464
10465
10466
10467
10468
10469
10470
10471
10472
10473
10474
10475
10476
10477
10478
10479
10480
10481
10482
10483
10484
10485
10486
10487
10488
10489
10490
10491
10492
10493
10494
10495
10496
10497
10498
10499
10500
10501
10502
10503
# File 'lib/aws-sdk-securityhub/types.rb', line 10461

class AwsEcsTaskDefinitionContainerDefinitionsDetails < Struct.new(
  :command,
  :cpu,
  :depends_on,
  :disable_networking,
  :dns_search_domains,
  :dns_servers,
  :docker_labels,
  :docker_security_options,
  :entry_point,
  :environment,
  :environment_files,
  :essential,
  :extra_hosts,
  :firelens_configuration,
  :health_check,
  :hostname,
  :image,
  :interactive,
  :links,
  :linux_parameters,
  :log_configuration,
  :memory,
  :memory_reservation,
  :mount_points,
  :name,
  :port_mappings,
  :privileged,
  :pseudo_terminal,
  :readonly_root_filesystem,
  :repository_credentials,
  :resource_requirements,
  :secrets,
  :start_timeout,
  :stop_timeout,
  :system_controls,
  :ulimits,
  :user,
  :volumes_from,
  :working_directory)
  SENSITIVE = []
  include Aws::Structure
end

#health_checkTypes::AwsEcsTaskDefinitionContainerDefinitionsHealthCheckDetails

The container health check command and associated configuration parameters for the container.



10461
10462
10463
10464
10465
10466
10467
10468
10469
10470
10471
10472
10473
10474
10475
10476
10477
10478
10479
10480
10481
10482
10483
10484
10485
10486
10487
10488
10489
10490
10491
10492
10493
10494
10495
10496
10497
10498
10499
10500
10501
10502
10503
# File 'lib/aws-sdk-securityhub/types.rb', line 10461

class AwsEcsTaskDefinitionContainerDefinitionsDetails < Struct.new(
  :command,
  :cpu,
  :depends_on,
  :disable_networking,
  :dns_search_domains,
  :dns_servers,
  :docker_labels,
  :docker_security_options,
  :entry_point,
  :environment,
  :environment_files,
  :essential,
  :extra_hosts,
  :firelens_configuration,
  :health_check,
  :hostname,
  :image,
  :interactive,
  :links,
  :linux_parameters,
  :log_configuration,
  :memory,
  :memory_reservation,
  :mount_points,
  :name,
  :port_mappings,
  :privileged,
  :pseudo_terminal,
  :readonly_root_filesystem,
  :repository_credentials,
  :resource_requirements,
  :secrets,
  :start_timeout,
  :stop_timeout,
  :system_controls,
  :ulimits,
  :user,
  :volumes_from,
  :working_directory)
  SENSITIVE = []
  include Aws::Structure
end

#hostnameString

The hostname to use for the container.

Returns:

  • (String)


10461
10462
10463
10464
10465
10466
10467
10468
10469
10470
10471
10472
10473
10474
10475
10476
10477
10478
10479
10480
10481
10482
10483
10484
10485
10486
10487
10488
10489
10490
10491
10492
10493
10494
10495
10496
10497
10498
10499
10500
10501
10502
10503
# File 'lib/aws-sdk-securityhub/types.rb', line 10461

class AwsEcsTaskDefinitionContainerDefinitionsDetails < Struct.new(
  :command,
  :cpu,
  :depends_on,
  :disable_networking,
  :dns_search_domains,
  :dns_servers,
  :docker_labels,
  :docker_security_options,
  :entry_point,
  :environment,
  :environment_files,
  :essential,
  :extra_hosts,
  :firelens_configuration,
  :health_check,
  :hostname,
  :image,
  :interactive,
  :links,
  :linux_parameters,
  :log_configuration,
  :memory,
  :memory_reservation,
  :mount_points,
  :name,
  :port_mappings,
  :privileged,
  :pseudo_terminal,
  :readonly_root_filesystem,
  :repository_credentials,
  :resource_requirements,
  :secrets,
  :start_timeout,
  :stop_timeout,
  :system_controls,
  :ulimits,
  :user,
  :volumes_from,
  :working_directory)
  SENSITIVE = []
  include Aws::Structure
end

#imageString

The image used to start the container.

Returns:

  • (String)


10461
10462
10463
10464
10465
10466
10467
10468
10469
10470
10471
10472
10473
10474
10475
10476
10477
10478
10479
10480
10481
10482
10483
10484
10485
10486
10487
10488
10489
10490
10491
10492
10493
10494
10495
10496
10497
10498
10499
10500
10501
10502
10503
# File 'lib/aws-sdk-securityhub/types.rb', line 10461

class AwsEcsTaskDefinitionContainerDefinitionsDetails < Struct.new(
  :command,
  :cpu,
  :depends_on,
  :disable_networking,
  :dns_search_domains,
  :dns_servers,
  :docker_labels,
  :docker_security_options,
  :entry_point,
  :environment,
  :environment_files,
  :essential,
  :extra_hosts,
  :firelens_configuration,
  :health_check,
  :hostname,
  :image,
  :interactive,
  :links,
  :linux_parameters,
  :log_configuration,
  :memory,
  :memory_reservation,
  :mount_points,
  :name,
  :port_mappings,
  :privileged,
  :pseudo_terminal,
  :readonly_root_filesystem,
  :repository_credentials,
  :resource_requirements,
  :secrets,
  :start_timeout,
  :stop_timeout,
  :system_controls,
  :ulimits,
  :user,
  :volumes_from,
  :working_directory)
  SENSITIVE = []
  include Aws::Structure
end

#interactiveBoolean

If set to true, then containerized applications can be deployed that require stdin or a tty to be allocated.

Returns:

  • (Boolean)


10461
10462
10463
10464
10465
10466
10467
10468
10469
10470
10471
10472
10473
10474
10475
10476
10477
10478
10479
10480
10481
10482
10483
10484
10485
10486
10487
10488
10489
10490
10491
10492
10493
10494
10495
10496
10497
10498
10499
10500
10501
10502
10503
# File 'lib/aws-sdk-securityhub/types.rb', line 10461

class AwsEcsTaskDefinitionContainerDefinitionsDetails < Struct.new(
  :command,
  :cpu,
  :depends_on,
  :disable_networking,
  :dns_search_domains,
  :dns_servers,
  :docker_labels,
  :docker_security_options,
  :entry_point,
  :environment,
  :environment_files,
  :essential,
  :extra_hosts,
  :firelens_configuration,
  :health_check,
  :hostname,
  :image,
  :interactive,
  :links,
  :linux_parameters,
  :log_configuration,
  :memory,
  :memory_reservation,
  :mount_points,
  :name,
  :port_mappings,
  :privileged,
  :pseudo_terminal,
  :readonly_root_filesystem,
  :repository_credentials,
  :resource_requirements,
  :secrets,
  :start_timeout,
  :stop_timeout,
  :system_controls,
  :ulimits,
  :user,
  :volumes_from,
  :working_directory)
  SENSITIVE = []
  include Aws::Structure
end

A list of links for the container in the form container_name:alias. Allows containers to communicate with each other without the need for port mappings.

Returns:

  • (Array<String>)


10461
10462
10463
10464
10465
10466
10467
10468
10469
10470
10471
10472
10473
10474
10475
10476
10477
10478
10479
10480
10481
10482
10483
10484
10485
10486
10487
10488
10489
10490
10491
10492
10493
10494
10495
10496
10497
10498
10499
10500
10501
10502
10503
# File 'lib/aws-sdk-securityhub/types.rb', line 10461

class AwsEcsTaskDefinitionContainerDefinitionsDetails < Struct.new(
  :command,
  :cpu,
  :depends_on,
  :disable_networking,
  :dns_search_domains,
  :dns_servers,
  :docker_labels,
  :docker_security_options,
  :entry_point,
  :environment,
  :environment_files,
  :essential,
  :extra_hosts,
  :firelens_configuration,
  :health_check,
  :hostname,
  :image,
  :interactive,
  :links,
  :linux_parameters,
  :log_configuration,
  :memory,
  :memory_reservation,
  :mount_points,
  :name,
  :port_mappings,
  :privileged,
  :pseudo_terminal,
  :readonly_root_filesystem,
  :repository_credentials,
  :resource_requirements,
  :secrets,
  :start_timeout,
  :stop_timeout,
  :system_controls,
  :ulimits,
  :user,
  :volumes_from,
  :working_directory)
  SENSITIVE = []
  include Aws::Structure
end

#linux_parametersTypes::AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersDetails

Linux-specific modifications that are applied to the container, such as Linux kernel capabilities.



10461
10462
10463
10464
10465
10466
10467
10468
10469
10470
10471
10472
10473
10474
10475
10476
10477
10478
10479
10480
10481
10482
10483
10484
10485
10486
10487
10488
10489
10490
10491
10492
10493
10494
10495
10496
10497
10498
10499
10500
10501
10502
10503
# File 'lib/aws-sdk-securityhub/types.rb', line 10461

class AwsEcsTaskDefinitionContainerDefinitionsDetails < Struct.new(
  :command,
  :cpu,
  :depends_on,
  :disable_networking,
  :dns_search_domains,
  :dns_servers,
  :docker_labels,
  :docker_security_options,
  :entry_point,
  :environment,
  :environment_files,
  :essential,
  :extra_hosts,
  :firelens_configuration,
  :health_check,
  :hostname,
  :image,
  :interactive,
  :links,
  :linux_parameters,
  :log_configuration,
  :memory,
  :memory_reservation,
  :mount_points,
  :name,
  :port_mappings,
  :privileged,
  :pseudo_terminal,
  :readonly_root_filesystem,
  :repository_credentials,
  :resource_requirements,
  :secrets,
  :start_timeout,
  :stop_timeout,
  :system_controls,
  :ulimits,
  :user,
  :volumes_from,
  :working_directory)
  SENSITIVE = []
  include Aws::Structure
end

#log_configurationTypes::AwsEcsTaskDefinitionContainerDefinitionsLogConfigurationDetails

The log configuration specification for the container.



10461
10462
10463
10464
10465
10466
10467
10468
10469
10470
10471
10472
10473
10474
10475
10476
10477
10478
10479
10480
10481
10482
10483
10484
10485
10486
10487
10488
10489
10490
10491
10492
10493
10494
10495
10496
10497
10498
10499
10500
10501
10502
10503
# File 'lib/aws-sdk-securityhub/types.rb', line 10461

class AwsEcsTaskDefinitionContainerDefinitionsDetails < Struct.new(
  :command,
  :cpu,
  :depends_on,
  :disable_networking,
  :dns_search_domains,
  :dns_servers,
  :docker_labels,
  :docker_security_options,
  :entry_point,
  :environment,
  :environment_files,
  :essential,
  :extra_hosts,
  :firelens_configuration,
  :health_check,
  :hostname,
  :image,
  :interactive,
  :links,
  :linux_parameters,
  :log_configuration,
  :memory,
  :memory_reservation,
  :mount_points,
  :name,
  :port_mappings,
  :privileged,
  :pseudo_terminal,
  :readonly_root_filesystem,
  :repository_credentials,
  :resource_requirements,
  :secrets,
  :start_timeout,
  :stop_timeout,
  :system_controls,
  :ulimits,
  :user,
  :volumes_from,
  :working_directory)
  SENSITIVE = []
  include Aws::Structure
end

#memoryInteger

The amount (in MiB) of memory to present to the container. If the container attempts to exceed the memory specified here, the container is shut down. The total amount of memory reserved for all containers within a task must be lower than the task memory value, if one is specified.

Returns:

  • (Integer)


10461
10462
10463
10464
10465
10466
10467
10468
10469
10470
10471
10472
10473
10474
10475
10476
10477
10478
10479
10480
10481
10482
10483
10484
10485
10486
10487
10488
10489
10490
10491
10492
10493
10494
10495
10496
10497
10498
10499
10500
10501
10502
10503
# File 'lib/aws-sdk-securityhub/types.rb', line 10461

class AwsEcsTaskDefinitionContainerDefinitionsDetails < Struct.new(
  :command,
  :cpu,
  :depends_on,
  :disable_networking,
  :dns_search_domains,
  :dns_servers,
  :docker_labels,
  :docker_security_options,
  :entry_point,
  :environment,
  :environment_files,
  :essential,
  :extra_hosts,
  :firelens_configuration,
  :health_check,
  :hostname,
  :image,
  :interactive,
  :links,
  :linux_parameters,
  :log_configuration,
  :memory,
  :memory_reservation,
  :mount_points,
  :name,
  :port_mappings,
  :privileged,
  :pseudo_terminal,
  :readonly_root_filesystem,
  :repository_credentials,
  :resource_requirements,
  :secrets,
  :start_timeout,
  :stop_timeout,
  :system_controls,
  :ulimits,
  :user,
  :volumes_from,
  :working_directory)
  SENSITIVE = []
  include Aws::Structure
end

#memory_reservationInteger

The soft limit (in MiB) of memory to reserve for the container.

Returns:

  • (Integer)


10461
10462
10463
10464
10465
10466
10467
10468
10469
10470
10471
10472
10473
10474
10475
10476
10477
10478
10479
10480
10481
10482
10483
10484
10485
10486
10487
10488
10489
10490
10491
10492
10493
10494
10495
10496
10497
10498
10499
10500
10501
10502
10503
# File 'lib/aws-sdk-securityhub/types.rb', line 10461

class AwsEcsTaskDefinitionContainerDefinitionsDetails < Struct.new(
  :command,
  :cpu,
  :depends_on,
  :disable_networking,
  :dns_search_domains,
  :dns_servers,
  :docker_labels,
  :docker_security_options,
  :entry_point,
  :environment,
  :environment_files,
  :essential,
  :extra_hosts,
  :firelens_configuration,
  :health_check,
  :hostname,
  :image,
  :interactive,
  :links,
  :linux_parameters,
  :log_configuration,
  :memory,
  :memory_reservation,
  :mount_points,
  :name,
  :port_mappings,
  :privileged,
  :pseudo_terminal,
  :readonly_root_filesystem,
  :repository_credentials,
  :resource_requirements,
  :secrets,
  :start_timeout,
  :stop_timeout,
  :system_controls,
  :ulimits,
  :user,
  :volumes_from,
  :working_directory)
  SENSITIVE = []
  include Aws::Structure
end

#mount_pointsArray<Types::AwsEcsTaskDefinitionContainerDefinitionsMountPointsDetails>

The mount points for the data volumes in the container.



10461
10462
10463
10464
10465
10466
10467
10468
10469
10470
10471
10472
10473
10474
10475
10476
10477
10478
10479
10480
10481
10482
10483
10484
10485
10486
10487
10488
10489
10490
10491
10492
10493
10494
10495
10496
10497
10498
10499
10500
10501
10502
10503
# File 'lib/aws-sdk-securityhub/types.rb', line 10461

class AwsEcsTaskDefinitionContainerDefinitionsDetails < Struct.new(
  :command,
  :cpu,
  :depends_on,
  :disable_networking,
  :dns_search_domains,
  :dns_servers,
  :docker_labels,
  :docker_security_options,
  :entry_point,
  :environment,
  :environment_files,
  :essential,
  :extra_hosts,
  :firelens_configuration,
  :health_check,
  :hostname,
  :image,
  :interactive,
  :links,
  :linux_parameters,
  :log_configuration,
  :memory,
  :memory_reservation,
  :mount_points,
  :name,
  :port_mappings,
  :privileged,
  :pseudo_terminal,
  :readonly_root_filesystem,
  :repository_credentials,
  :resource_requirements,
  :secrets,
  :start_timeout,
  :stop_timeout,
  :system_controls,
  :ulimits,
  :user,
  :volumes_from,
  :working_directory)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the container.

Returns:

  • (String)


10461
10462
10463
10464
10465
10466
10467
10468
10469
10470
10471
10472
10473
10474
10475
10476
10477
10478
10479
10480
10481
10482
10483
10484
10485
10486
10487
10488
10489
10490
10491
10492
10493
10494
10495
10496
10497
10498
10499
10500
10501
10502
10503
# File 'lib/aws-sdk-securityhub/types.rb', line 10461

class AwsEcsTaskDefinitionContainerDefinitionsDetails < Struct.new(
  :command,
  :cpu,
  :depends_on,
  :disable_networking,
  :dns_search_domains,
  :dns_servers,
  :docker_labels,
  :docker_security_options,
  :entry_point,
  :environment,
  :environment_files,
  :essential,
  :extra_hosts,
  :firelens_configuration,
  :health_check,
  :hostname,
  :image,
  :interactive,
  :links,
  :linux_parameters,
  :log_configuration,
  :memory,
  :memory_reservation,
  :mount_points,
  :name,
  :port_mappings,
  :privileged,
  :pseudo_terminal,
  :readonly_root_filesystem,
  :repository_credentials,
  :resource_requirements,
  :secrets,
  :start_timeout,
  :stop_timeout,
  :system_controls,
  :ulimits,
  :user,
  :volumes_from,
  :working_directory)
  SENSITIVE = []
  include Aws::Structure
end

#port_mappingsArray<Types::AwsEcsTaskDefinitionContainerDefinitionsPortMappingsDetails>

The list of port mappings for the container.



10461
10462
10463
10464
10465
10466
10467
10468
10469
10470
10471
10472
10473
10474
10475
10476
10477
10478
10479
10480
10481
10482
10483
10484
10485
10486
10487
10488
10489
10490
10491
10492
10493
10494
10495
10496
10497
10498
10499
10500
10501
10502
10503
# File 'lib/aws-sdk-securityhub/types.rb', line 10461

class AwsEcsTaskDefinitionContainerDefinitionsDetails < Struct.new(
  :command,
  :cpu,
  :depends_on,
  :disable_networking,
  :dns_search_domains,
  :dns_servers,
  :docker_labels,
  :docker_security_options,
  :entry_point,
  :environment,
  :environment_files,
  :essential,
  :extra_hosts,
  :firelens_configuration,
  :health_check,
  :hostname,
  :image,
  :interactive,
  :links,
  :linux_parameters,
  :log_configuration,
  :memory,
  :memory_reservation,
  :mount_points,
  :name,
  :port_mappings,
  :privileged,
  :pseudo_terminal,
  :readonly_root_filesystem,
  :repository_credentials,
  :resource_requirements,
  :secrets,
  :start_timeout,
  :stop_timeout,
  :system_controls,
  :ulimits,
  :user,
  :volumes_from,
  :working_directory)
  SENSITIVE = []
  include Aws::Structure
end

#privilegedBoolean

Whether the container is given elevated privileges on the host container instance. The elevated privileges are similar to the root user.

Returns:

  • (Boolean)


10461
10462
10463
10464
10465
10466
10467
10468
10469
10470
10471
10472
10473
10474
10475
10476
10477
10478
10479
10480
10481
10482
10483
10484
10485
10486
10487
10488
10489
10490
10491
10492
10493
10494
10495
10496
10497
10498
10499
10500
10501
10502
10503
# File 'lib/aws-sdk-securityhub/types.rb', line 10461

class AwsEcsTaskDefinitionContainerDefinitionsDetails < Struct.new(
  :command,
  :cpu,
  :depends_on,
  :disable_networking,
  :dns_search_domains,
  :dns_servers,
  :docker_labels,
  :docker_security_options,
  :entry_point,
  :environment,
  :environment_files,
  :essential,
  :extra_hosts,
  :firelens_configuration,
  :health_check,
  :hostname,
  :image,
  :interactive,
  :links,
  :linux_parameters,
  :log_configuration,
  :memory,
  :memory_reservation,
  :mount_points,
  :name,
  :port_mappings,
  :privileged,
  :pseudo_terminal,
  :readonly_root_filesystem,
  :repository_credentials,
  :resource_requirements,
  :secrets,
  :start_timeout,
  :stop_timeout,
  :system_controls,
  :ulimits,
  :user,
  :volumes_from,
  :working_directory)
  SENSITIVE = []
  include Aws::Structure
end

#pseudo_terminalBoolean

Whether to allocate a TTY to the container.

Returns:

  • (Boolean)


10461
10462
10463
10464
10465
10466
10467
10468
10469
10470
10471
10472
10473
10474
10475
10476
10477
10478
10479
10480
10481
10482
10483
10484
10485
10486
10487
10488
10489
10490
10491
10492
10493
10494
10495
10496
10497
10498
10499
10500
10501
10502
10503
# File 'lib/aws-sdk-securityhub/types.rb', line 10461

class AwsEcsTaskDefinitionContainerDefinitionsDetails < Struct.new(
  :command,
  :cpu,
  :depends_on,
  :disable_networking,
  :dns_search_domains,
  :dns_servers,
  :docker_labels,
  :docker_security_options,
  :entry_point,
  :environment,
  :environment_files,
  :essential,
  :extra_hosts,
  :firelens_configuration,
  :health_check,
  :hostname,
  :image,
  :interactive,
  :links,
  :linux_parameters,
  :log_configuration,
  :memory,
  :memory_reservation,
  :mount_points,
  :name,
  :port_mappings,
  :privileged,
  :pseudo_terminal,
  :readonly_root_filesystem,
  :repository_credentials,
  :resource_requirements,
  :secrets,
  :start_timeout,
  :stop_timeout,
  :system_controls,
  :ulimits,
  :user,
  :volumes_from,
  :working_directory)
  SENSITIVE = []
  include Aws::Structure
end

#readonly_root_filesystemBoolean

Whether the container is given read-only access to its root file system.

Returns:

  • (Boolean)


10461
10462
10463
10464
10465
10466
10467
10468
10469
10470
10471
10472
10473
10474
10475
10476
10477
10478
10479
10480
10481
10482
10483
10484
10485
10486
10487
10488
10489
10490
10491
10492
10493
10494
10495
10496
10497
10498
10499
10500
10501
10502
10503
# File 'lib/aws-sdk-securityhub/types.rb', line 10461

class AwsEcsTaskDefinitionContainerDefinitionsDetails < Struct.new(
  :command,
  :cpu,
  :depends_on,
  :disable_networking,
  :dns_search_domains,
  :dns_servers,
  :docker_labels,
  :docker_security_options,
  :entry_point,
  :environment,
  :environment_files,
  :essential,
  :extra_hosts,
  :firelens_configuration,
  :health_check,
  :hostname,
  :image,
  :interactive,
  :links,
  :linux_parameters,
  :log_configuration,
  :memory,
  :memory_reservation,
  :mount_points,
  :name,
  :port_mappings,
  :privileged,
  :pseudo_terminal,
  :readonly_root_filesystem,
  :repository_credentials,
  :resource_requirements,
  :secrets,
  :start_timeout,
  :stop_timeout,
  :system_controls,
  :ulimits,
  :user,
  :volumes_from,
  :working_directory)
  SENSITIVE = []
  include Aws::Structure
end

#repository_credentialsTypes::AwsEcsTaskDefinitionContainerDefinitionsRepositoryCredentialsDetails

The private repository authentication credentials to use.



10461
10462
10463
10464
10465
10466
10467
10468
10469
10470
10471
10472
10473
10474
10475
10476
10477
10478
10479
10480
10481
10482
10483
10484
10485
10486
10487
10488
10489
10490
10491
10492
10493
10494
10495
10496
10497
10498
10499
10500
10501
10502
10503
# File 'lib/aws-sdk-securityhub/types.rb', line 10461

class AwsEcsTaskDefinitionContainerDefinitionsDetails < Struct.new(
  :command,
  :cpu,
  :depends_on,
  :disable_networking,
  :dns_search_domains,
  :dns_servers,
  :docker_labels,
  :docker_security_options,
  :entry_point,
  :environment,
  :environment_files,
  :essential,
  :extra_hosts,
  :firelens_configuration,
  :health_check,
  :hostname,
  :image,
  :interactive,
  :links,
  :linux_parameters,
  :log_configuration,
  :memory,
  :memory_reservation,
  :mount_points,
  :name,
  :port_mappings,
  :privileged,
  :pseudo_terminal,
  :readonly_root_filesystem,
  :repository_credentials,
  :resource_requirements,
  :secrets,
  :start_timeout,
  :stop_timeout,
  :system_controls,
  :ulimits,
  :user,
  :volumes_from,
  :working_directory)
  SENSITIVE = []
  include Aws::Structure
end

#resource_requirementsArray<Types::AwsEcsTaskDefinitionContainerDefinitionsResourceRequirementsDetails>

The type and amount of a resource to assign to a container. The only supported resource is a GPU.



10461
10462
10463
10464
10465
10466
10467
10468
10469
10470
10471
10472
10473
10474
10475
10476
10477
10478
10479
10480
10481
10482
10483
10484
10485
10486
10487
10488
10489
10490
10491
10492
10493
10494
10495
10496
10497
10498
10499
10500
10501
10502
10503
# File 'lib/aws-sdk-securityhub/types.rb', line 10461

class AwsEcsTaskDefinitionContainerDefinitionsDetails < Struct.new(
  :command,
  :cpu,
  :depends_on,
  :disable_networking,
  :dns_search_domains,
  :dns_servers,
  :docker_labels,
  :docker_security_options,
  :entry_point,
  :environment,
  :environment_files,
  :essential,
  :extra_hosts,
  :firelens_configuration,
  :health_check,
  :hostname,
  :image,
  :interactive,
  :links,
  :linux_parameters,
  :log_configuration,
  :memory,
  :memory_reservation,
  :mount_points,
  :name,
  :port_mappings,
  :privileged,
  :pseudo_terminal,
  :readonly_root_filesystem,
  :repository_credentials,
  :resource_requirements,
  :secrets,
  :start_timeout,
  :stop_timeout,
  :system_controls,
  :ulimits,
  :user,
  :volumes_from,
  :working_directory)
  SENSITIVE = []
  include Aws::Structure
end

#secretsArray<Types::AwsEcsTaskDefinitionContainerDefinitionsSecretsDetails>

The secrets to pass to the container.



10461
10462
10463
10464
10465
10466
10467
10468
10469
10470
10471
10472
10473
10474
10475
10476
10477
10478
10479
10480
10481
10482
10483
10484
10485
10486
10487
10488
10489
10490
10491
10492
10493
10494
10495
10496
10497
10498
10499
10500
10501
10502
10503
# File 'lib/aws-sdk-securityhub/types.rb', line 10461

class AwsEcsTaskDefinitionContainerDefinitionsDetails < Struct.new(
  :command,
  :cpu,
  :depends_on,
  :disable_networking,
  :dns_search_domains,
  :dns_servers,
  :docker_labels,
  :docker_security_options,
  :entry_point,
  :environment,
  :environment_files,
  :essential,
  :extra_hosts,
  :firelens_configuration,
  :health_check,
  :hostname,
  :image,
  :interactive,
  :links,
  :linux_parameters,
  :log_configuration,
  :memory,
  :memory_reservation,
  :mount_points,
  :name,
  :port_mappings,
  :privileged,
  :pseudo_terminal,
  :readonly_root_filesystem,
  :repository_credentials,
  :resource_requirements,
  :secrets,
  :start_timeout,
  :stop_timeout,
  :system_controls,
  :ulimits,
  :user,
  :volumes_from,
  :working_directory)
  SENSITIVE = []
  include Aws::Structure
end

#start_timeoutInteger

The number of seconds to wait before giving up on resolving dependencies for a container.

Returns:

  • (Integer)


10461
10462
10463
10464
10465
10466
10467
10468
10469
10470
10471
10472
10473
10474
10475
10476
10477
10478
10479
10480
10481
10482
10483
10484
10485
10486
10487
10488
10489
10490
10491
10492
10493
10494
10495
10496
10497
10498
10499
10500
10501
10502
10503
# File 'lib/aws-sdk-securityhub/types.rb', line 10461

class AwsEcsTaskDefinitionContainerDefinitionsDetails < Struct.new(
  :command,
  :cpu,
  :depends_on,
  :disable_networking,
  :dns_search_domains,
  :dns_servers,
  :docker_labels,
  :docker_security_options,
  :entry_point,
  :environment,
  :environment_files,
  :essential,
  :extra_hosts,
  :firelens_configuration,
  :health_check,
  :hostname,
  :image,
  :interactive,
  :links,
  :linux_parameters,
  :log_configuration,
  :memory,
  :memory_reservation,
  :mount_points,
  :name,
  :port_mappings,
  :privileged,
  :pseudo_terminal,
  :readonly_root_filesystem,
  :repository_credentials,
  :resource_requirements,
  :secrets,
  :start_timeout,
  :stop_timeout,
  :system_controls,
  :ulimits,
  :user,
  :volumes_from,
  :working_directory)
  SENSITIVE = []
  include Aws::Structure
end

#stop_timeoutInteger

The number of seconds to wait before the container is stopped if it doesn't shut down normally on its own.

Returns:

  • (Integer)


10461
10462
10463
10464
10465
10466
10467
10468
10469
10470
10471
10472
10473
10474
10475
10476
10477
10478
10479
10480
10481
10482
10483
10484
10485
10486
10487
10488
10489
10490
10491
10492
10493
10494
10495
10496
10497
10498
10499
10500
10501
10502
10503
# File 'lib/aws-sdk-securityhub/types.rb', line 10461

class AwsEcsTaskDefinitionContainerDefinitionsDetails < Struct.new(
  :command,
  :cpu,
  :depends_on,
  :disable_networking,
  :dns_search_domains,
  :dns_servers,
  :docker_labels,
  :docker_security_options,
  :entry_point,
  :environment,
  :environment_files,
  :essential,
  :extra_hosts,
  :firelens_configuration,
  :health_check,
  :hostname,
  :image,
  :interactive,
  :links,
  :linux_parameters,
  :log_configuration,
  :memory,
  :memory_reservation,
  :mount_points,
  :name,
  :port_mappings,
  :privileged,
  :pseudo_terminal,
  :readonly_root_filesystem,
  :repository_credentials,
  :resource_requirements,
  :secrets,
  :start_timeout,
  :stop_timeout,
  :system_controls,
  :ulimits,
  :user,
  :volumes_from,
  :working_directory)
  SENSITIVE = []
  include Aws::Structure
end

#system_controlsArray<Types::AwsEcsTaskDefinitionContainerDefinitionsSystemControlsDetails>

A list of namespaced kernel parameters to set in the container.



10461
10462
10463
10464
10465
10466
10467
10468
10469
10470
10471
10472
10473
10474
10475
10476
10477
10478
10479
10480
10481
10482
10483
10484
10485
10486
10487
10488
10489
10490
10491
10492
10493
10494
10495
10496
10497
10498
10499
10500
10501
10502
10503
# File 'lib/aws-sdk-securityhub/types.rb', line 10461

class AwsEcsTaskDefinitionContainerDefinitionsDetails < Struct.new(
  :command,
  :cpu,
  :depends_on,
  :disable_networking,
  :dns_search_domains,
  :dns_servers,
  :docker_labels,
  :docker_security_options,
  :entry_point,
  :environment,
  :environment_files,
  :essential,
  :extra_hosts,
  :firelens_configuration,
  :health_check,
  :hostname,
  :image,
  :interactive,
  :links,
  :linux_parameters,
  :log_configuration,
  :memory,
  :memory_reservation,
  :mount_points,
  :name,
  :port_mappings,
  :privileged,
  :pseudo_terminal,
  :readonly_root_filesystem,
  :repository_credentials,
  :resource_requirements,
  :secrets,
  :start_timeout,
  :stop_timeout,
  :system_controls,
  :ulimits,
  :user,
  :volumes_from,
  :working_directory)
  SENSITIVE = []
  include Aws::Structure
end

#ulimitsArray<Types::AwsEcsTaskDefinitionContainerDefinitionsUlimitsDetails>

A list of ulimits to set in the container.



10461
10462
10463
10464
10465
10466
10467
10468
10469
10470
10471
10472
10473
10474
10475
10476
10477
10478
10479
10480
10481
10482
10483
10484
10485
10486
10487
10488
10489
10490
10491
10492
10493
10494
10495
10496
10497
10498
10499
10500
10501
10502
10503
# File 'lib/aws-sdk-securityhub/types.rb', line 10461

class AwsEcsTaskDefinitionContainerDefinitionsDetails < Struct.new(
  :command,
  :cpu,
  :depends_on,
  :disable_networking,
  :dns_search_domains,
  :dns_servers,
  :docker_labels,
  :docker_security_options,
  :entry_point,
  :environment,
  :environment_files,
  :essential,
  :extra_hosts,
  :firelens_configuration,
  :health_check,
  :hostname,
  :image,
  :interactive,
  :links,
  :linux_parameters,
  :log_configuration,
  :memory,
  :memory_reservation,
  :mount_points,
  :name,
  :port_mappings,
  :privileged,
  :pseudo_terminal,
  :readonly_root_filesystem,
  :repository_credentials,
  :resource_requirements,
  :secrets,
  :start_timeout,
  :stop_timeout,
  :system_controls,
  :ulimits,
  :user,
  :volumes_from,
  :working_directory)
  SENSITIVE = []
  include Aws::Structure
end

#userString

The user to use inside the container.

The value can use one of the following formats.

  • user

  • user:group

  • uid

  • uid:gid

  • user:gid

  • uid:group

Returns:

  • (String)


10461
10462
10463
10464
10465
10466
10467
10468
10469
10470
10471
10472
10473
10474
10475
10476
10477
10478
10479
10480
10481
10482
10483
10484
10485
10486
10487
10488
10489
10490
10491
10492
10493
10494
10495
10496
10497
10498
10499
10500
10501
10502
10503
# File 'lib/aws-sdk-securityhub/types.rb', line 10461

class AwsEcsTaskDefinitionContainerDefinitionsDetails < Struct.new(
  :command,
  :cpu,
  :depends_on,
  :disable_networking,
  :dns_search_domains,
  :dns_servers,
  :docker_labels,
  :docker_security_options,
  :entry_point,
  :environment,
  :environment_files,
  :essential,
  :extra_hosts,
  :firelens_configuration,
  :health_check,
  :hostname,
  :image,
  :interactive,
  :links,
  :linux_parameters,
  :log_configuration,
  :memory,
  :memory_reservation,
  :mount_points,
  :name,
  :port_mappings,
  :privileged,
  :pseudo_terminal,
  :readonly_root_filesystem,
  :repository_credentials,
  :resource_requirements,
  :secrets,
  :start_timeout,
  :stop_timeout,
  :system_controls,
  :ulimits,
  :user,
  :volumes_from,
  :working_directory)
  SENSITIVE = []
  include Aws::Structure
end

#volumes_fromArray<Types::AwsEcsTaskDefinitionContainerDefinitionsVolumesFromDetails>

Data volumes to mount from another container.



10461
10462
10463
10464
10465
10466
10467
10468
10469
10470
10471
10472
10473
10474
10475
10476
10477
10478
10479
10480
10481
10482
10483
10484
10485
10486
10487
10488
10489
10490
10491
10492
10493
10494
10495
10496
10497
10498
10499
10500
10501
10502
10503
# File 'lib/aws-sdk-securityhub/types.rb', line 10461

class AwsEcsTaskDefinitionContainerDefinitionsDetails < Struct.new(
  :command,
  :cpu,
  :depends_on,
  :disable_networking,
  :dns_search_domains,
  :dns_servers,
  :docker_labels,
  :docker_security_options,
  :entry_point,
  :environment,
  :environment_files,
  :essential,
  :extra_hosts,
  :firelens_configuration,
  :health_check,
  :hostname,
  :image,
  :interactive,
  :links,
  :linux_parameters,
  :log_configuration,
  :memory,
  :memory_reservation,
  :mount_points,
  :name,
  :port_mappings,
  :privileged,
  :pseudo_terminal,
  :readonly_root_filesystem,
  :repository_credentials,
  :resource_requirements,
  :secrets,
  :start_timeout,
  :stop_timeout,
  :system_controls,
  :ulimits,
  :user,
  :volumes_from,
  :working_directory)
  SENSITIVE = []
  include Aws::Structure
end

#working_directoryString

The working directory in which to run commands inside the container.

Returns:

  • (String)


10461
10462
10463
10464
10465
10466
10467
10468
10469
10470
10471
10472
10473
10474
10475
10476
10477
10478
10479
10480
10481
10482
10483
10484
10485
10486
10487
10488
10489
10490
10491
10492
10493
10494
10495
10496
10497
10498
10499
10500
10501
10502
10503
# File 'lib/aws-sdk-securityhub/types.rb', line 10461

class AwsEcsTaskDefinitionContainerDefinitionsDetails < Struct.new(
  :command,
  :cpu,
  :depends_on,
  :disable_networking,
  :dns_search_domains,
  :dns_servers,
  :docker_labels,
  :docker_security_options,
  :entry_point,
  :environment,
  :environment_files,
  :essential,
  :extra_hosts,
  :firelens_configuration,
  :health_check,
  :hostname,
  :image,
  :interactive,
  :links,
  :linux_parameters,
  :log_configuration,
  :memory,
  :memory_reservation,
  :mount_points,
  :name,
  :port_mappings,
  :privileged,
  :pseudo_terminal,
  :readonly_root_filesystem,
  :repository_credentials,
  :resource_requirements,
  :secrets,
  :start_timeout,
  :stop_timeout,
  :system_controls,
  :ulimits,
  :user,
  :volumes_from,
  :working_directory)
  SENSITIVE = []
  include Aws::Structure
end