Class: Aws::SecurityHub::Types::AwsEcsTaskDefinitionContainerDefinitionsHealthCheckDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::AwsEcsTaskDefinitionContainerDefinitionsHealthCheckDetails
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
The container health check command and associated configuration parameters for the container.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#command ⇒ Array<String>
The command that the container runs to determine whether it is healthy.
-
#interval ⇒ Integer
The time period in seconds between each health check execution.
-
#retries ⇒ Integer
The number of times to retry a failed health check before the container is considered unhealthy.
-
#start_period ⇒ Integer
The optional grace period in seconds that allows containers time to bootstrap before failed health checks count towards the maximum number of retries.
-
#timeout ⇒ Integer
The time period in seconds to wait for a health check to succeed before it is considered a failure.
Instance Attribute Details
#command ⇒ Array<String>
The command that the container runs to determine whether it is healthy.
10623 10624 10625 10626 10627 10628 10629 10630 10631 |
# File 'lib/aws-sdk-securityhub/types.rb', line 10623 class AwsEcsTaskDefinitionContainerDefinitionsHealthCheckDetails < Struct.new( :command, :interval, :retries, :start_period, :timeout) SENSITIVE = [] include Aws::Structure end |
#interval ⇒ Integer
The time period in seconds between each health check execution. The default value is 30 seconds.
10623 10624 10625 10626 10627 10628 10629 10630 10631 |
# File 'lib/aws-sdk-securityhub/types.rb', line 10623 class AwsEcsTaskDefinitionContainerDefinitionsHealthCheckDetails < Struct.new( :command, :interval, :retries, :start_period, :timeout) SENSITIVE = [] include Aws::Structure end |
#retries ⇒ Integer
The number of times to retry a failed health check before the container is considered unhealthy. The default value is 3.
10623 10624 10625 10626 10627 10628 10629 10630 10631 |
# File 'lib/aws-sdk-securityhub/types.rb', line 10623 class AwsEcsTaskDefinitionContainerDefinitionsHealthCheckDetails < Struct.new( :command, :interval, :retries, :start_period, :timeout) SENSITIVE = [] include Aws::Structure end |
#start_period ⇒ Integer
The optional grace period in seconds that allows containers time to bootstrap before failed health checks count towards the maximum number of retries.
10623 10624 10625 10626 10627 10628 10629 10630 10631 |
# File 'lib/aws-sdk-securityhub/types.rb', line 10623 class AwsEcsTaskDefinitionContainerDefinitionsHealthCheckDetails < Struct.new( :command, :interval, :retries, :start_period, :timeout) SENSITIVE = [] include Aws::Structure end |
#timeout ⇒ Integer
The time period in seconds to wait for a health check to succeed before it is considered a failure. The default value is 5.
10623 10624 10625 10626 10627 10628 10629 10630 10631 |
# File 'lib/aws-sdk-securityhub/types.rb', line 10623 class AwsEcsTaskDefinitionContainerDefinitionsHealthCheckDetails < Struct.new( :command, :interval, :retries, :start_period, :timeout) SENSITIVE = [] include Aws::Structure end |