Class: Aws::SecurityHub::Types::AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersDevicesDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersDevicesDetails
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
A host device to expose to the container.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#container_path ⇒ String
The path inside the container at which to expose the host device.
-
#host_path ⇒ String
The path for the device on the host container instance.
-
#permissions ⇒ Array<String>
The explicit permissions to provide to the container for the device.
Instance Attribute Details
#container_path ⇒ String
The path inside the container at which to expose the host device.
10647 10648 10649 10650 10651 10652 10653 |
# File 'lib/aws-sdk-securityhub/types.rb', line 10647 class AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersDevicesDetails < Struct.new( :container_path, :host_path, :permissions) SENSITIVE = [] include Aws::Structure end |
#host_path ⇒ String
The path for the device on the host container instance.
10647 10648 10649 10650 10651 10652 10653 |
# File 'lib/aws-sdk-securityhub/types.rb', line 10647 class AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersDevicesDetails < Struct.new( :container_path, :host_path, :permissions) SENSITIVE = [] include Aws::Structure end |
#permissions ⇒ Array<String>
The explicit permissions to provide to the container for the device.
By default, the container has permissions for read, write, and
mknod for the device.
10647 10648 10649 10650 10651 10652 10653 |
# File 'lib/aws-sdk-securityhub/types.rb', line 10647 class AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersDevicesDetails < Struct.new( :container_path, :host_path, :permissions) SENSITIVE = [] include Aws::Structure end |