Class: Aws::SecurityHub::Types::AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersTmpfsDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersTmpfsDetails
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
The container path, mount options, and size (in MiB) of a tmpfs mount.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#container_path ⇒ String
The absolute file path where the tmpfs volume is to be mounted.
-
#mount_options ⇒ Array<String>
The list of tmpfs volume mount options.
-
#size ⇒ Integer
The maximum size (in MiB) of the tmpfs volume.
Instance Attribute Details
#container_path ⇒ String
The absolute file path where the tmpfs volume is to be mounted.
10662 10663 10664 10665 10666 10667 10668 |
# File 'lib/aws-sdk-securityhub/types.rb', line 10662 class AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersTmpfsDetails < Struct.new( :container_path, :mount_options, :size) SENSITIVE = [] include Aws::Structure end |
#mount_options ⇒ Array<String>
The list of tmpfs volume mount options.
Valid values: ‘“defaults”` \| `“ro”` \| `“rw”` \| `“suid”` \| `“nosuid”` \| `“dev”` \| `“nodev”` \|` “exec”` \| `“noexec”` \| `“sync”` \| `“async”` \| `“dirsync”` \| `“remount”` \| `“mand”` \| `“nomand”` \| `“atime”` \| `“noatime”` \| `“diratime”` \| `“nodiratime”` \| `“bind”` \| `“rbind”` \| `“unbindable”` \| `“runbindable”` \| `“private”` \| `“rprivate”` \| `“shared”` \| `“rshared”` \| `“slave”` \| `“rslave”` \| `“relatime”` \| `“norelatime”` \| `“strictatime”` \| `“nostrictatime”` \|` “mode”` \| `“uid”` \| `“gid”` \| `“nr_inodes”` \|` “nr_blocks”` \| `“mpol”`
10662 10663 10664 10665 10666 10667 10668 |
# File 'lib/aws-sdk-securityhub/types.rb', line 10662 class AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersTmpfsDetails < Struct.new( :container_path, :mount_options, :size) SENSITIVE = [] include Aws::Structure end |
#size ⇒ Integer
The maximum size (in MiB) of the tmpfs volume.
10662 10663 10664 10665 10666 10667 10668 |
# File 'lib/aws-sdk-securityhub/types.rb', line 10662 class AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersTmpfsDetails < Struct.new( :container_path, :mount_options, :size) SENSITIVE = [] include Aws::Structure end |