Class: Aws::SecurityHub::Types::AwsEcsTaskDefinitionContainerDefinitionsLogConfigurationSecretOptionsDetails

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

A secret to pass to the log configuration.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#nameString

The name of the secret.

Returns:

  • (String)


10740
10741
10742
10743
10744
10745
# File 'lib/aws-sdk-securityhub/types.rb', line 10740

class AwsEcsTaskDefinitionContainerDefinitionsLogConfigurationSecretOptionsDetails < Struct.new(
  :name,
  :value_from)
  SENSITIVE = []
  include Aws::Structure
end

#value_fromString

The secret to expose to the container.

The value is either the full ARN of the Secrets Manager secret or the full ARN of the parameter in the Systems Manager Parameter Store.

Returns:

  • (String)


10740
10741
10742
10743
10744
10745
# File 'lib/aws-sdk-securityhub/types.rb', line 10740

class AwsEcsTaskDefinitionContainerDefinitionsLogConfigurationSecretOptionsDetails < Struct.new(
  :name,
  :value_from)
  SENSITIVE = []
  include Aws::Structure
end