Method: Aws::SecurityHub::Types::AwsEcsTaskDefinitionContainerDefinitionsSecretsDetails#value_from
- Defined in:
- lib/aws-sdk-securityhub/types.rb
#value_from ⇒ String
The secret to expose to the container. The value is either the full ARN of the Secrets Manager secret or the full ARN of the parameter in the Systems Manager Parameter Store.
10851 10852 10853 10854 10855 10856 |
# File 'lib/aws-sdk-securityhub/types.rb', line 10851 class AwsEcsTaskDefinitionContainerDefinitionsSecretsDetails < Struct.new( :name, :value_from) SENSITIVE = [] include Aws::Structure end |