Class: Aws::SecurityHub::Types::AwsEcsTaskVolumeDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::AwsEcsTaskVolumeDetails
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Provides information about a data volume that's used in a task definition.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#host ⇒ Types::AwsEcsTaskVolumeHostDetails
This parameter is specified when you use bind mount host volumes.
-
#name ⇒ String
The name of the volume.
Instance Attribute Details
#host ⇒ Types::AwsEcsTaskVolumeHostDetails
This parameter is specified when you use bind mount host volumes.
The contents of the host parameter determine whether your bind
mount host volume persists on the host container instance and where
it's stored.
11509 11510 11511 11512 11513 11514 |
# File 'lib/aws-sdk-securityhub/types.rb', line 11509 class AwsEcsTaskVolumeDetails < Struct.new( :name, :host) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the volume. Up to 255 letters (uppercase and lowercase),
numbers, underscores, and hyphens are allowed. This name is
referenced in the sourceVolume parameter of container definition
mountPoints.
11509 11510 11511 11512 11513 11514 |
# File 'lib/aws-sdk-securityhub/types.rb', line 11509 class AwsEcsTaskVolumeDetails < Struct.new( :name, :host) SENSITIVE = [] include Aws::Structure end |