Class: Aws::SecurityHub::Types::AwsEcsTaskVolumeHostDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::AwsEcsTaskVolumeHostDetails
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Provides details on a container instance bind mount host volume.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#source_path ⇒ String
When the
hostparameter is used, specify asourcePathto declare the path on the host container instance that's presented to the container.
Instance Attribute Details
#source_path ⇒ String
When the host parameter is used, specify a sourcePath to declare
the path on the host container instance that's presented to the
container.
11425 11426 11427 11428 11429 |
# File 'lib/aws-sdk-securityhub/types.rb', line 11425 class AwsEcsTaskVolumeHostDetails < Struct.new( :source_path) SENSITIVE = [] include Aws::Structure end |