Class: Aws::SecurityHub::Types::AwsEfsAccessPointDetails

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

Provides information about an Amazon EFS access point.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#access_point_idString

The ID of the Amazon EFS access point.

Returns:

  • (String)


11464
11465
11466
11467
11468
11469
11470
11471
11472
11473
# File 'lib/aws-sdk-securityhub/types.rb', line 11464

class AwsEfsAccessPointDetails < Struct.new(
  :access_point_id,
  :arn,
  :client_token,
  :file_system_id,
  :posix_user,
  :root_directory)
  SENSITIVE = []
  include Aws::Structure
end

#arnString

The Amazon Resource Name (ARN) of the Amazon EFS access point.

Returns:

  • (String)


11464
11465
11466
11467
11468
11469
11470
11471
11472
11473
# File 'lib/aws-sdk-securityhub/types.rb', line 11464

class AwsEfsAccessPointDetails < Struct.new(
  :access_point_id,
  :arn,
  :client_token,
  :file_system_id,
  :posix_user,
  :root_directory)
  SENSITIVE = []
  include Aws::Structure
end

#client_tokenString

The opaque string specified in the request to ensure idempotent creation.

Returns:

  • (String)


11464
11465
11466
11467
11468
11469
11470
11471
11472
11473
# File 'lib/aws-sdk-securityhub/types.rb', line 11464

class AwsEfsAccessPointDetails < Struct.new(
  :access_point_id,
  :arn,
  :client_token,
  :file_system_id,
  :posix_user,
  :root_directory)
  SENSITIVE = []
  include Aws::Structure
end

#file_system_idString

The ID of the Amazon EFS file system that the access point applies to.

Returns:

  • (String)


11464
11465
11466
11467
11468
11469
11470
11471
11472
11473
# File 'lib/aws-sdk-securityhub/types.rb', line 11464

class AwsEfsAccessPointDetails < Struct.new(
  :access_point_id,
  :arn,
  :client_token,
  :file_system_id,
  :posix_user,
  :root_directory)
  SENSITIVE = []
  include Aws::Structure
end

#posix_userTypes::AwsEfsAccessPointPosixUserDetails

The full POSIX identity, including the user ID, group ID, and secondary group IDs on the access point, that is used for all file operations by NFS clients using the access point.



11464
11465
11466
11467
11468
11469
11470
11471
11472
11473
# File 'lib/aws-sdk-securityhub/types.rb', line 11464

class AwsEfsAccessPointDetails < Struct.new(
  :access_point_id,
  :arn,
  :client_token,
  :file_system_id,
  :posix_user,
  :root_directory)
  SENSITIVE = []
  include Aws::Structure
end

#root_directoryTypes::AwsEfsAccessPointRootDirectoryDetails

The directory on the Amazon EFS file system that the access point exposes as the root directory to NFS clients using the access point.



11464
11465
11466
11467
11468
11469
11470
11471
11472
11473
# File 'lib/aws-sdk-securityhub/types.rb', line 11464

class AwsEfsAccessPointDetails < Struct.new(
  :access_point_id,
  :arn,
  :client_token,
  :file_system_id,
  :posix_user,
  :root_directory)
  SENSITIVE = []
  include Aws::Structure
end