Class: Aws::SecurityHub::Types::AwsEksClusterDetails

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

Provides details about an Amazon EKS cluster.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The ARN of the cluster.



11739
11740
11741
11742
11743
11744
11745
11746
11747
11748
11749
11750
11751
# File 'lib/aws-sdk-securityhub/types.rb', line 11739

class AwsEksClusterDetails < Struct.new(
  :arn,
  :certificate_authority_data,
  :cluster_status,
  :endpoint,
  :name,
  :resources_vpc_config,
  :role_arn,
  :version,
  :logging)
  SENSITIVE = []
  include Aws::Structure
end

#certificate_authority_dataString

The certificate authority data for the cluster.



11739
11740
11741
11742
11743
11744
11745
11746
11747
11748
11749
11750
11751
# File 'lib/aws-sdk-securityhub/types.rb', line 11739

class AwsEksClusterDetails < Struct.new(
  :arn,
  :certificate_authority_data,
  :cluster_status,
  :endpoint,
  :name,
  :resources_vpc_config,
  :role_arn,
  :version,
  :logging)
  SENSITIVE = []
  include Aws::Structure
end

#cluster_statusString

The status of the cluster. Valid values are as follows:

  • ACTIVE

  • CREATING

  • DELETING

  • FAILED

  • PENDING

  • UPDATING



11739
11740
11741
11742
11743
11744
11745
11746
11747
11748
11749
11750
11751
# File 'lib/aws-sdk-securityhub/types.rb', line 11739

class AwsEksClusterDetails < Struct.new(
  :arn,
  :certificate_authority_data,
  :cluster_status,
  :endpoint,
  :name,
  :resources_vpc_config,
  :role_arn,
  :version,
  :logging)
  SENSITIVE = []
  include Aws::Structure
end

#endpointString

The endpoint for the Amazon EKS API server.



11739
11740
11741
11742
11743
11744
11745
11746
11747
11748
11749
11750
11751
# File 'lib/aws-sdk-securityhub/types.rb', line 11739

class AwsEksClusterDetails < Struct.new(
  :arn,
  :certificate_authority_data,
  :cluster_status,
  :endpoint,
  :name,
  :resources_vpc_config,
  :role_arn,
  :version,
  :logging)
  SENSITIVE = []
  include Aws::Structure
end

#loggingTypes::AwsEksClusterLoggingDetails

The logging configuration for the cluster.



11739
11740
11741
11742
11743
11744
11745
11746
11747
11748
11749
11750
11751
# File 'lib/aws-sdk-securityhub/types.rb', line 11739

class AwsEksClusterDetails < Struct.new(
  :arn,
  :certificate_authority_data,
  :cluster_status,
  :endpoint,
  :name,
  :resources_vpc_config,
  :role_arn,
  :version,
  :logging)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the cluster.



11739
11740
11741
11742
11743
11744
11745
11746
11747
11748
11749
11750
11751
# File 'lib/aws-sdk-securityhub/types.rb', line 11739

class AwsEksClusterDetails < Struct.new(
  :arn,
  :certificate_authority_data,
  :cluster_status,
  :endpoint,
  :name,
  :resources_vpc_config,
  :role_arn,
  :version,
  :logging)
  SENSITIVE = []
  include Aws::Structure
end

#resources_vpc_configTypes::AwsEksClusterResourcesVpcConfigDetails

The VPC configuration used by the cluster control plane.



11739
11740
11741
11742
11743
11744
11745
11746
11747
11748
11749
11750
11751
# File 'lib/aws-sdk-securityhub/types.rb', line 11739

class AwsEksClusterDetails < Struct.new(
  :arn,
  :certificate_authority_data,
  :cluster_status,
  :endpoint,
  :name,
  :resources_vpc_config,
  :role_arn,
  :version,
  :logging)
  SENSITIVE = []
  include Aws::Structure
end

#role_arnString

The ARN of the IAM role that provides permissions for the Amazon EKS control plane to make calls to Amazon Web Services API operations on your behalf.



11739
11740
11741
11742
11743
11744
11745
11746
11747
11748
11749
11750
11751
# File 'lib/aws-sdk-securityhub/types.rb', line 11739

class AwsEksClusterDetails < Struct.new(
  :arn,
  :certificate_authority_data,
  :cluster_status,
  :endpoint,
  :name,
  :resources_vpc_config,
  :role_arn,
  :version,
  :logging)
  SENSITIVE = []
  include Aws::Structure
end

#versionString

The Amazon EKS server version for the cluster.



11739
11740
11741
11742
11743
11744
11745
11746
11747
11748
11749
11750
11751
# File 'lib/aws-sdk-securityhub/types.rb', line 11739

class AwsEksClusterDetails < Struct.new(
  :arn,
  :certificate_authority_data,
  :cluster_status,
  :endpoint,
  :name,
  :resources_vpc_config,
  :role_arn,
  :version,
  :logging)
  SENSITIVE = []
  include Aws::Structure
end