Class: Aws::SecurityHub::Types::AwsElasticBeanstalkEnvironmentDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::AwsElasticBeanstalkEnvironmentDetails
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Contains details about an Elastic Beanstalk environment.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#application_name ⇒ String
The name of the application that is associated with the environment.
-
#cname ⇒ String
The URL to the CNAME for this environment.
-
#date_created ⇒ String
The creation date for this environment.
-
#date_updated ⇒ String
The date when this environment was last modified.
-
#description ⇒ String
A description of the environment.
-
#endpoint_url ⇒ String
For load-balanced, autoscaling environments, the URL to the load balancer.
-
#environment_arn ⇒ String
The ARN of the environment.
-
#environment_id ⇒ String
The identifier of the environment.
-
#environment_links ⇒ Array<Types::AwsElasticBeanstalkEnvironmentEnvironmentLink>
Links to other environments in the same group.
-
#environment_name ⇒ String
The name of the environment.
-
#option_settings ⇒ Array<Types::AwsElasticBeanstalkEnvironmentOptionSetting>
The configuration setting for the environment.
-
#platform_arn ⇒ String
The ARN of the platform version for the environment.
-
#solution_stack_name ⇒ String
The name of the solution stack that is deployed with the environment.
-
#status ⇒ String
The current operational status of the environment.
-
#tier ⇒ Types::AwsElasticBeanstalkEnvironmentTier
The tier of the environment.
-
#version_label ⇒ String
The application version of the environment.
Instance Attribute Details
#application_name ⇒ String
The name of the application that is associated with the environment.
11784 11785 11786 11787 11788 11789 11790 11791 11792 11793 11794 11795 11796 11797 11798 11799 11800 11801 11802 11803 |
# File 'lib/aws-sdk-securityhub/types.rb', line 11784 class AwsElasticBeanstalkEnvironmentDetails < Struct.new( :application_name, :cname, :date_created, :date_updated, :description, :endpoint_url, :environment_arn, :environment_id, :environment_links, :environment_name, :option_settings, :platform_arn, :solution_stack_name, :status, :tier, :version_label) SENSITIVE = [] include Aws::Structure end |
#cname ⇒ String
The URL to the CNAME for this environment.
11784 11785 11786 11787 11788 11789 11790 11791 11792 11793 11794 11795 11796 11797 11798 11799 11800 11801 11802 11803 |
# File 'lib/aws-sdk-securityhub/types.rb', line 11784 class AwsElasticBeanstalkEnvironmentDetails < Struct.new( :application_name, :cname, :date_created, :date_updated, :description, :endpoint_url, :environment_arn, :environment_id, :environment_links, :environment_name, :option_settings, :platform_arn, :solution_stack_name, :status, :tier, :version_label) SENSITIVE = [] include Aws::Structure end |
#date_created ⇒ String
The creation date for this environment.
11784 11785 11786 11787 11788 11789 11790 11791 11792 11793 11794 11795 11796 11797 11798 11799 11800 11801 11802 11803 |
# File 'lib/aws-sdk-securityhub/types.rb', line 11784 class AwsElasticBeanstalkEnvironmentDetails < Struct.new( :application_name, :cname, :date_created, :date_updated, :description, :endpoint_url, :environment_arn, :environment_id, :environment_links, :environment_name, :option_settings, :platform_arn, :solution_stack_name, :status, :tier, :version_label) SENSITIVE = [] include Aws::Structure end |
#date_updated ⇒ String
The date when this environment was last modified.
11784 11785 11786 11787 11788 11789 11790 11791 11792 11793 11794 11795 11796 11797 11798 11799 11800 11801 11802 11803 |
# File 'lib/aws-sdk-securityhub/types.rb', line 11784 class AwsElasticBeanstalkEnvironmentDetails < Struct.new( :application_name, :cname, :date_created, :date_updated, :description, :endpoint_url, :environment_arn, :environment_id, :environment_links, :environment_name, :option_settings, :platform_arn, :solution_stack_name, :status, :tier, :version_label) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the environment.
11784 11785 11786 11787 11788 11789 11790 11791 11792 11793 11794 11795 11796 11797 11798 11799 11800 11801 11802 11803 |
# File 'lib/aws-sdk-securityhub/types.rb', line 11784 class AwsElasticBeanstalkEnvironmentDetails < Struct.new( :application_name, :cname, :date_created, :date_updated, :description, :endpoint_url, :environment_arn, :environment_id, :environment_links, :environment_name, :option_settings, :platform_arn, :solution_stack_name, :status, :tier, :version_label) SENSITIVE = [] include Aws::Structure end |
#endpoint_url ⇒ String
For load-balanced, autoscaling environments, the URL to the load balancer. For single-instance environments, the IP address of the instance.
11784 11785 11786 11787 11788 11789 11790 11791 11792 11793 11794 11795 11796 11797 11798 11799 11800 11801 11802 11803 |
# File 'lib/aws-sdk-securityhub/types.rb', line 11784 class AwsElasticBeanstalkEnvironmentDetails < Struct.new( :application_name, :cname, :date_created, :date_updated, :description, :endpoint_url, :environment_arn, :environment_id, :environment_links, :environment_name, :option_settings, :platform_arn, :solution_stack_name, :status, :tier, :version_label) SENSITIVE = [] include Aws::Structure end |
#environment_arn ⇒ String
The ARN of the environment.
11784 11785 11786 11787 11788 11789 11790 11791 11792 11793 11794 11795 11796 11797 11798 11799 11800 11801 11802 11803 |
# File 'lib/aws-sdk-securityhub/types.rb', line 11784 class AwsElasticBeanstalkEnvironmentDetails < Struct.new( :application_name, :cname, :date_created, :date_updated, :description, :endpoint_url, :environment_arn, :environment_id, :environment_links, :environment_name, :option_settings, :platform_arn, :solution_stack_name, :status, :tier, :version_label) SENSITIVE = [] include Aws::Structure end |
#environment_id ⇒ String
The identifier of the environment.
11784 11785 11786 11787 11788 11789 11790 11791 11792 11793 11794 11795 11796 11797 11798 11799 11800 11801 11802 11803 |
# File 'lib/aws-sdk-securityhub/types.rb', line 11784 class AwsElasticBeanstalkEnvironmentDetails < Struct.new( :application_name, :cname, :date_created, :date_updated, :description, :endpoint_url, :environment_arn, :environment_id, :environment_links, :environment_name, :option_settings, :platform_arn, :solution_stack_name, :status, :tier, :version_label) SENSITIVE = [] include Aws::Structure end |
#environment_links ⇒ Array<Types::AwsElasticBeanstalkEnvironmentEnvironmentLink>
Links to other environments in the same group.
11784 11785 11786 11787 11788 11789 11790 11791 11792 11793 11794 11795 11796 11797 11798 11799 11800 11801 11802 11803 |
# File 'lib/aws-sdk-securityhub/types.rb', line 11784 class AwsElasticBeanstalkEnvironmentDetails < Struct.new( :application_name, :cname, :date_created, :date_updated, :description, :endpoint_url, :environment_arn, :environment_id, :environment_links, :environment_name, :option_settings, :platform_arn, :solution_stack_name, :status, :tier, :version_label) SENSITIVE = [] include Aws::Structure end |
#environment_name ⇒ String
The name of the environment.
11784 11785 11786 11787 11788 11789 11790 11791 11792 11793 11794 11795 11796 11797 11798 11799 11800 11801 11802 11803 |
# File 'lib/aws-sdk-securityhub/types.rb', line 11784 class AwsElasticBeanstalkEnvironmentDetails < Struct.new( :application_name, :cname, :date_created, :date_updated, :description, :endpoint_url, :environment_arn, :environment_id, :environment_links, :environment_name, :option_settings, :platform_arn, :solution_stack_name, :status, :tier, :version_label) SENSITIVE = [] include Aws::Structure end |
#option_settings ⇒ Array<Types::AwsElasticBeanstalkEnvironmentOptionSetting>
The configuration setting for the environment.
11784 11785 11786 11787 11788 11789 11790 11791 11792 11793 11794 11795 11796 11797 11798 11799 11800 11801 11802 11803 |
# File 'lib/aws-sdk-securityhub/types.rb', line 11784 class AwsElasticBeanstalkEnvironmentDetails < Struct.new( :application_name, :cname, :date_created, :date_updated, :description, :endpoint_url, :environment_arn, :environment_id, :environment_links, :environment_name, :option_settings, :platform_arn, :solution_stack_name, :status, :tier, :version_label) SENSITIVE = [] include Aws::Structure end |
#platform_arn ⇒ String
The ARN of the platform version for the environment.
11784 11785 11786 11787 11788 11789 11790 11791 11792 11793 11794 11795 11796 11797 11798 11799 11800 11801 11802 11803 |
# File 'lib/aws-sdk-securityhub/types.rb', line 11784 class AwsElasticBeanstalkEnvironmentDetails < Struct.new( :application_name, :cname, :date_created, :date_updated, :description, :endpoint_url, :environment_arn, :environment_id, :environment_links, :environment_name, :option_settings, :platform_arn, :solution_stack_name, :status, :tier, :version_label) SENSITIVE = [] include Aws::Structure end |
#solution_stack_name ⇒ String
The name of the solution stack that is deployed with the environment.
11784 11785 11786 11787 11788 11789 11790 11791 11792 11793 11794 11795 11796 11797 11798 11799 11800 11801 11802 11803 |
# File 'lib/aws-sdk-securityhub/types.rb', line 11784 class AwsElasticBeanstalkEnvironmentDetails < Struct.new( :application_name, :cname, :date_created, :date_updated, :description, :endpoint_url, :environment_arn, :environment_id, :environment_links, :environment_name, :option_settings, :platform_arn, :solution_stack_name, :status, :tier, :version_label) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current operational status of the environment. Valid values are as follows:
-
Aborting -
Launching -
LinkingFrom -
LinkingTo -
Ready -
Terminated -
Terminating -
Updating
11784 11785 11786 11787 11788 11789 11790 11791 11792 11793 11794 11795 11796 11797 11798 11799 11800 11801 11802 11803 |
# File 'lib/aws-sdk-securityhub/types.rb', line 11784 class AwsElasticBeanstalkEnvironmentDetails < Struct.new( :application_name, :cname, :date_created, :date_updated, :description, :endpoint_url, :environment_arn, :environment_id, :environment_links, :environment_name, :option_settings, :platform_arn, :solution_stack_name, :status, :tier, :version_label) SENSITIVE = [] include Aws::Structure end |
#tier ⇒ Types::AwsElasticBeanstalkEnvironmentTier
The tier of the environment.
11784 11785 11786 11787 11788 11789 11790 11791 11792 11793 11794 11795 11796 11797 11798 11799 11800 11801 11802 11803 |
# File 'lib/aws-sdk-securityhub/types.rb', line 11784 class AwsElasticBeanstalkEnvironmentDetails < Struct.new( :application_name, :cname, :date_created, :date_updated, :description, :endpoint_url, :environment_arn, :environment_id, :environment_links, :environment_name, :option_settings, :platform_arn, :solution_stack_name, :status, :tier, :version_label) SENSITIVE = [] include Aws::Structure end |
#version_label ⇒ String
The application version of the environment.
11784 11785 11786 11787 11788 11789 11790 11791 11792 11793 11794 11795 11796 11797 11798 11799 11800 11801 11802 11803 |
# File 'lib/aws-sdk-securityhub/types.rb', line 11784 class AwsElasticBeanstalkEnvironmentDetails < Struct.new( :application_name, :cname, :date_created, :date_updated, :description, :endpoint_url, :environment_arn, :environment_id, :environment_links, :environment_name, :option_settings, :platform_arn, :solution_stack_name, :status, :tier, :version_label) SENSITIVE = [] include Aws::Structure end |