Class: Aws::SecurityHub::Types::AwsElbLoadBalancerConnectionSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::AwsElbLoadBalancerConnectionSettings
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Contains connection settings for the load balancer.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#idle_timeout ⇒ Integer
The time, in seconds, that the connection can be idle (no data is sent over the connection) before it is closed by the load balancer.
Instance Attribute Details
#idle_timeout ⇒ Integer
The time, in seconds, that the connection can be idle (no data is sent over the connection) before it is closed by the load balancer.
12439 12440 12441 12442 12443 |
# File 'lib/aws-sdk-securityhub/types.rb', line 12439 class AwsElbLoadBalancerConnectionSettings < Struct.new( :idle_timeout) SENSITIVE = [] include Aws::Structure end |