Class: Aws::SecurityHub::Types::AwsElbv2LoadBalancerDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::AwsElbv2LoadBalancerDetails
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Information about a load balancer.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#availability_zones ⇒ Array<Types::AvailabilityZone>
The Availability Zones for the load balancer.
-
#canonical_hosted_zone_id ⇒ String
The ID of the Amazon Route 53 hosted zone associated with the load balancer.
-
#created_time ⇒ String
Indicates when the load balancer was created.
-
#dns_name ⇒ String
The public DNS name of the load balancer.
-
#ip_address_type ⇒ String
The type of IP addresses used by the subnets for your load balancer.
-
#load_balancer_attributes ⇒ Array<Types::AwsElbv2LoadBalancerAttribute>
Attributes of the load balancer.
-
#scheme ⇒ String
The nodes of an Internet-facing load balancer have public IP addresses.
-
#security_groups ⇒ Array<String>
The IDs of the security groups for the load balancer.
-
#state ⇒ Types::LoadBalancerState
The state of the load balancer.
-
#type ⇒ String
The type of load balancer.
-
#vpc_id ⇒ String
The ID of the VPC for the load balancer.
Instance Attribute Details
#availability_zones ⇒ Array<Types::AvailabilityZone>
The Availability Zones for the load balancer.
12970 12971 12972 12973 12974 12975 12976 12977 12978 12979 12980 12981 12982 12983 12984 |
# File 'lib/aws-sdk-securityhub/types.rb', line 12970 class AwsElbv2LoadBalancerDetails < Struct.new( :availability_zones, :canonical_hosted_zone_id, :created_time, :dns_name, :ip_address_type, :scheme, :security_groups, :state, :type, :vpc_id, :load_balancer_attributes) SENSITIVE = [] include Aws::Structure end |
#canonical_hosted_zone_id ⇒ String
The ID of the Amazon Route 53 hosted zone associated with the load balancer.
12970 12971 12972 12973 12974 12975 12976 12977 12978 12979 12980 12981 12982 12983 12984 |
# File 'lib/aws-sdk-securityhub/types.rb', line 12970 class AwsElbv2LoadBalancerDetails < Struct.new( :availability_zones, :canonical_hosted_zone_id, :created_time, :dns_name, :ip_address_type, :scheme, :security_groups, :state, :type, :vpc_id, :load_balancer_attributes) SENSITIVE = [] include Aws::Structure end |
#created_time ⇒ String
Indicates when the load balancer was created.
For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.
12970 12971 12972 12973 12974 12975 12976 12977 12978 12979 12980 12981 12982 12983 12984 |
# File 'lib/aws-sdk-securityhub/types.rb', line 12970 class AwsElbv2LoadBalancerDetails < Struct.new( :availability_zones, :canonical_hosted_zone_id, :created_time, :dns_name, :ip_address_type, :scheme, :security_groups, :state, :type, :vpc_id, :load_balancer_attributes) SENSITIVE = [] include Aws::Structure end |
#dns_name ⇒ String
The public DNS name of the load balancer.
12970 12971 12972 12973 12974 12975 12976 12977 12978 12979 12980 12981 12982 12983 12984 |
# File 'lib/aws-sdk-securityhub/types.rb', line 12970 class AwsElbv2LoadBalancerDetails < Struct.new( :availability_zones, :canonical_hosted_zone_id, :created_time, :dns_name, :ip_address_type, :scheme, :security_groups, :state, :type, :vpc_id, :load_balancer_attributes) SENSITIVE = [] include Aws::Structure end |
#ip_address_type ⇒ String
The type of IP addresses used by the subnets for your load balancer.
The possible values are ipv4 (for IPv4 addresses) and dualstack
(for IPv4 and IPv6 addresses).
12970 12971 12972 12973 12974 12975 12976 12977 12978 12979 12980 12981 12982 12983 12984 |
# File 'lib/aws-sdk-securityhub/types.rb', line 12970 class AwsElbv2LoadBalancerDetails < Struct.new( :availability_zones, :canonical_hosted_zone_id, :created_time, :dns_name, :ip_address_type, :scheme, :security_groups, :state, :type, :vpc_id, :load_balancer_attributes) SENSITIVE = [] include Aws::Structure end |
#load_balancer_attributes ⇒ Array<Types::AwsElbv2LoadBalancerAttribute>
Attributes of the load balancer.
12970 12971 12972 12973 12974 12975 12976 12977 12978 12979 12980 12981 12982 12983 12984 |
# File 'lib/aws-sdk-securityhub/types.rb', line 12970 class AwsElbv2LoadBalancerDetails < Struct.new( :availability_zones, :canonical_hosted_zone_id, :created_time, :dns_name, :ip_address_type, :scheme, :security_groups, :state, :type, :vpc_id, :load_balancer_attributes) SENSITIVE = [] include Aws::Structure end |
#scheme ⇒ String
The nodes of an Internet-facing load balancer have public IP addresses.
12970 12971 12972 12973 12974 12975 12976 12977 12978 12979 12980 12981 12982 12983 12984 |
# File 'lib/aws-sdk-securityhub/types.rb', line 12970 class AwsElbv2LoadBalancerDetails < Struct.new( :availability_zones, :canonical_hosted_zone_id, :created_time, :dns_name, :ip_address_type, :scheme, :security_groups, :state, :type, :vpc_id, :load_balancer_attributes) SENSITIVE = [] include Aws::Structure end |
#security_groups ⇒ Array<String>
The IDs of the security groups for the load balancer.
12970 12971 12972 12973 12974 12975 12976 12977 12978 12979 12980 12981 12982 12983 12984 |
# File 'lib/aws-sdk-securityhub/types.rb', line 12970 class AwsElbv2LoadBalancerDetails < Struct.new( :availability_zones, :canonical_hosted_zone_id, :created_time, :dns_name, :ip_address_type, :scheme, :security_groups, :state, :type, :vpc_id, :load_balancer_attributes) SENSITIVE = [] include Aws::Structure end |
#state ⇒ Types::LoadBalancerState
The state of the load balancer.
12970 12971 12972 12973 12974 12975 12976 12977 12978 12979 12980 12981 12982 12983 12984 |
# File 'lib/aws-sdk-securityhub/types.rb', line 12970 class AwsElbv2LoadBalancerDetails < Struct.new( :availability_zones, :canonical_hosted_zone_id, :created_time, :dns_name, :ip_address_type, :scheme, :security_groups, :state, :type, :vpc_id, :load_balancer_attributes) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of load balancer.
12970 12971 12972 12973 12974 12975 12976 12977 12978 12979 12980 12981 12982 12983 12984 |
# File 'lib/aws-sdk-securityhub/types.rb', line 12970 class AwsElbv2LoadBalancerDetails < Struct.new( :availability_zones, :canonical_hosted_zone_id, :created_time, :dns_name, :ip_address_type, :scheme, :security_groups, :state, :type, :vpc_id, :load_balancer_attributes) SENSITIVE = [] include Aws::Structure end |
#vpc_id ⇒ String
The ID of the VPC for the load balancer.
12970 12971 12972 12973 12974 12975 12976 12977 12978 12979 12980 12981 12982 12983 12984 |
# File 'lib/aws-sdk-securityhub/types.rb', line 12970 class AwsElbv2LoadBalancerDetails < Struct.new( :availability_zones, :canonical_hosted_zone_id, :created_time, :dns_name, :ip_address_type, :scheme, :security_groups, :state, :type, :vpc_id, :load_balancer_attributes) SENSITIVE = [] include Aws::Structure end |