Class: Aws::SecurityHub::Types::AwsEventSchemasRegistryDetails

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

A schema defines the structure of events that are sent to Amazon EventBridge. Schema registries are containers for schemas. They collect and organize schemas so that your schemas are in logical groups.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

A description of the registry to be created.

Returns:

  • (String)


12976
12977
12978
12979
12980
12981
12982
# File 'lib/aws-sdk-securityhub/types.rb', line 12976

class AwsEventSchemasRegistryDetails < Struct.new(
  :description,
  :registry_arn,
  :registry_name)
  SENSITIVE = []
  include Aws::Structure
end

#registry_arnString

The Amazon Resource Name (ARN) of the registry.

Returns:

  • (String)


12976
12977
12978
12979
12980
12981
12982
# File 'lib/aws-sdk-securityhub/types.rb', line 12976

class AwsEventSchemasRegistryDetails < Struct.new(
  :description,
  :registry_arn,
  :registry_name)
  SENSITIVE = []
  include Aws::Structure
end

#registry_nameString

The name of the schema registry.

Returns:

  • (String)


12976
12977
12978
12979
12980
12981
12982
# File 'lib/aws-sdk-securityhub/types.rb', line 12976

class AwsEventSchemasRegistryDetails < Struct.new(
  :description,
  :registry_arn,
  :registry_name)
  SENSITIVE = []
  include Aws::Structure
end