Class: Aws::SecurityHub::Types::AwsIamInstanceProfileRole

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

Information about a role associated with an instance profile.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The ARN of the role.



13779
13780
13781
13782
13783
13784
13785
13786
13787
13788
# File 'lib/aws-sdk-securityhub/types.rb', line 13779

class AwsIamInstanceProfileRole < Struct.new(
  :arn,
  :assume_role_policy_document,
  :create_date,
  :path,
  :role_id,
  :role_name)
  SENSITIVE = []
  include Aws::Structure
end

#assume_role_policy_documentString

The policy that grants an entity permission to assume the role.



13779
13780
13781
13782
13783
13784
13785
13786
13787
13788
# File 'lib/aws-sdk-securityhub/types.rb', line 13779

class AwsIamInstanceProfileRole < Struct.new(
  :arn,
  :assume_role_policy_document,
  :create_date,
  :path,
  :role_id,
  :role_name)
  SENSITIVE = []
  include Aws::Structure
end

#create_dateString

Indicates when the role was created.

For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.



13779
13780
13781
13782
13783
13784
13785
13786
13787
13788
# File 'lib/aws-sdk-securityhub/types.rb', line 13779

class AwsIamInstanceProfileRole < Struct.new(
  :arn,
  :assume_role_policy_document,
  :create_date,
  :path,
  :role_id,
  :role_name)
  SENSITIVE = []
  include Aws::Structure
end

#pathString

The path to the role.



13779
13780
13781
13782
13783
13784
13785
13786
13787
13788
# File 'lib/aws-sdk-securityhub/types.rb', line 13779

class AwsIamInstanceProfileRole < Struct.new(
  :arn,
  :assume_role_policy_document,
  :create_date,
  :path,
  :role_id,
  :role_name)
  SENSITIVE = []
  include Aws::Structure
end

#role_idString

The identifier of the role.



13779
13780
13781
13782
13783
13784
13785
13786
13787
13788
# File 'lib/aws-sdk-securityhub/types.rb', line 13779

class AwsIamInstanceProfileRole < Struct.new(
  :arn,
  :assume_role_policy_document,
  :create_date,
  :path,
  :role_id,
  :role_name)
  SENSITIVE = []
  include Aws::Structure
end

#role_nameString

The name of the role.



13779
13780
13781
13782
13783
13784
13785
13786
13787
13788
# File 'lib/aws-sdk-securityhub/types.rb', line 13779

class AwsIamInstanceProfileRole < Struct.new(
  :arn,
  :assume_role_policy_document,
  :create_date,
  :path,
  :role_id,
  :role_name)
  SENSITIVE = []
  include Aws::Structure
end