Class: Aws::SecurityHub::Types::AwsIamPolicyDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::AwsIamPolicyDetails
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Represents an IAM permissions policy.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attachment_count ⇒ Integer
The number of users, groups, and roles that the policy is attached to.
-
#create_date ⇒ String
When the policy was created.
-
#default_version_id ⇒ String
The identifier of the default version of the policy.
-
#description ⇒ String
A description of the policy.
-
#is_attachable ⇒ Boolean
Whether the policy can be attached to a user, group, or role.
-
#path ⇒ String
The path to the policy.
-
#permissions_boundary_usage_count ⇒ Integer
The number of users and roles that use the policy to set the permissions boundary.
-
#policy_id ⇒ String
The unique identifier of the policy.
-
#policy_name ⇒ String
The name of the policy.
-
#policy_version_list ⇒ Array<Types::AwsIamPolicyVersion>
List of versions of the policy.
-
#update_date ⇒ String
When the policy was most recently updated.
Instance Attribute Details
#attachment_count ⇒ Integer
The number of users, groups, and roles that the policy is attached to.
13744 13745 13746 13747 13748 13749 13750 13751 13752 13753 13754 13755 13756 13757 13758 |
# File 'lib/aws-sdk-securityhub/types.rb', line 13744 class AwsIamPolicyDetails < Struct.new( :attachment_count, :create_date, :default_version_id, :description, :is_attachable, :path, :permissions_boundary_usage_count, :policy_id, :policy_name, :policy_version_list, :update_date) SENSITIVE = [] include Aws::Structure end |
#create_date ⇒ String
When the policy was created.
For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.
13744 13745 13746 13747 13748 13749 13750 13751 13752 13753 13754 13755 13756 13757 13758 |
# File 'lib/aws-sdk-securityhub/types.rb', line 13744 class AwsIamPolicyDetails < Struct.new( :attachment_count, :create_date, :default_version_id, :description, :is_attachable, :path, :permissions_boundary_usage_count, :policy_id, :policy_name, :policy_version_list, :update_date) SENSITIVE = [] include Aws::Structure end |
#default_version_id ⇒ String
The identifier of the default version of the policy.
13744 13745 13746 13747 13748 13749 13750 13751 13752 13753 13754 13755 13756 13757 13758 |
# File 'lib/aws-sdk-securityhub/types.rb', line 13744 class AwsIamPolicyDetails < Struct.new( :attachment_count, :create_date, :default_version_id, :description, :is_attachable, :path, :permissions_boundary_usage_count, :policy_id, :policy_name, :policy_version_list, :update_date) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the policy.
13744 13745 13746 13747 13748 13749 13750 13751 13752 13753 13754 13755 13756 13757 13758 |
# File 'lib/aws-sdk-securityhub/types.rb', line 13744 class AwsIamPolicyDetails < Struct.new( :attachment_count, :create_date, :default_version_id, :description, :is_attachable, :path, :permissions_boundary_usage_count, :policy_id, :policy_name, :policy_version_list, :update_date) SENSITIVE = [] include Aws::Structure end |
#is_attachable ⇒ Boolean
Whether the policy can be attached to a user, group, or role.
13744 13745 13746 13747 13748 13749 13750 13751 13752 13753 13754 13755 13756 13757 13758 |
# File 'lib/aws-sdk-securityhub/types.rb', line 13744 class AwsIamPolicyDetails < Struct.new( :attachment_count, :create_date, :default_version_id, :description, :is_attachable, :path, :permissions_boundary_usage_count, :policy_id, :policy_name, :policy_version_list, :update_date) SENSITIVE = [] include Aws::Structure end |
#path ⇒ String
The path to the policy.
13744 13745 13746 13747 13748 13749 13750 13751 13752 13753 13754 13755 13756 13757 13758 |
# File 'lib/aws-sdk-securityhub/types.rb', line 13744 class AwsIamPolicyDetails < Struct.new( :attachment_count, :create_date, :default_version_id, :description, :is_attachable, :path, :permissions_boundary_usage_count, :policy_id, :policy_name, :policy_version_list, :update_date) SENSITIVE = [] include Aws::Structure end |
#permissions_boundary_usage_count ⇒ Integer
The number of users and roles that use the policy to set the permissions boundary.
13744 13745 13746 13747 13748 13749 13750 13751 13752 13753 13754 13755 13756 13757 13758 |
# File 'lib/aws-sdk-securityhub/types.rb', line 13744 class AwsIamPolicyDetails < Struct.new( :attachment_count, :create_date, :default_version_id, :description, :is_attachable, :path, :permissions_boundary_usage_count, :policy_id, :policy_name, :policy_version_list, :update_date) SENSITIVE = [] include Aws::Structure end |
#policy_id ⇒ String
The unique identifier of the policy.
13744 13745 13746 13747 13748 13749 13750 13751 13752 13753 13754 13755 13756 13757 13758 |
# File 'lib/aws-sdk-securityhub/types.rb', line 13744 class AwsIamPolicyDetails < Struct.new( :attachment_count, :create_date, :default_version_id, :description, :is_attachable, :path, :permissions_boundary_usage_count, :policy_id, :policy_name, :policy_version_list, :update_date) SENSITIVE = [] include Aws::Structure end |
#policy_name ⇒ String
The name of the policy.
13744 13745 13746 13747 13748 13749 13750 13751 13752 13753 13754 13755 13756 13757 13758 |
# File 'lib/aws-sdk-securityhub/types.rb', line 13744 class AwsIamPolicyDetails < Struct.new( :attachment_count, :create_date, :default_version_id, :description, :is_attachable, :path, :permissions_boundary_usage_count, :policy_id, :policy_name, :policy_version_list, :update_date) SENSITIVE = [] include Aws::Structure end |
#policy_version_list ⇒ Array<Types::AwsIamPolicyVersion>
List of versions of the policy.
13744 13745 13746 13747 13748 13749 13750 13751 13752 13753 13754 13755 13756 13757 13758 |
# File 'lib/aws-sdk-securityhub/types.rb', line 13744 class AwsIamPolicyDetails < Struct.new( :attachment_count, :create_date, :default_version_id, :description, :is_attachable, :path, :permissions_boundary_usage_count, :policy_id, :policy_name, :policy_version_list, :update_date) SENSITIVE = [] include Aws::Structure end |
#update_date ⇒ String
When the policy was most recently updated.
For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.
13744 13745 13746 13747 13748 13749 13750 13751 13752 13753 13754 13755 13756 13757 13758 |
# File 'lib/aws-sdk-securityhub/types.rb', line 13744 class AwsIamPolicyDetails < Struct.new( :attachment_count, :create_date, :default_version_id, :description, :is_attachable, :path, :permissions_boundary_usage_count, :policy_id, :policy_name, :policy_version_list, :update_date) SENSITIVE = [] include Aws::Structure end |