Class: Aws::SecurityHub::Types::AwsIamRoleDetails

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

Contains information about an IAM role, including all of the role's policies.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#assume_role_policy_documentString

The trust policy that grants permission to assume the role.



13975
13976
13977
13978
13979
13980
13981
13982
13983
13984
13985
13986
13987
13988
# File 'lib/aws-sdk-securityhub/types.rb', line 13975

class AwsIamRoleDetails < Struct.new(
  :assume_role_policy_document,
  :attached_managed_policies,
  :create_date,
  :instance_profile_list,
  :permissions_boundary,
  :role_id,
  :role_name,
  :role_policy_list,
  :max_session_duration,
  :path)
  SENSITIVE = []
  include Aws::Structure
end

#attached_managed_policiesArray<Types::AwsIamAttachedManagedPolicy>

The list of the managed policies that are attached to the role.



13975
13976
13977
13978
13979
13980
13981
13982
13983
13984
13985
13986
13987
13988
# File 'lib/aws-sdk-securityhub/types.rb', line 13975

class AwsIamRoleDetails < Struct.new(
  :assume_role_policy_document,
  :attached_managed_policies,
  :create_date,
  :instance_profile_list,
  :permissions_boundary,
  :role_id,
  :role_name,
  :role_policy_list,
  :max_session_duration,
  :path)
  SENSITIVE = []
  include Aws::Structure
end

#create_dateString

Indicates when the role was created.

For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.



13975
13976
13977
13978
13979
13980
13981
13982
13983
13984
13985
13986
13987
13988
# File 'lib/aws-sdk-securityhub/types.rb', line 13975

class AwsIamRoleDetails < Struct.new(
  :assume_role_policy_document,
  :attached_managed_policies,
  :create_date,
  :instance_profile_list,
  :permissions_boundary,
  :role_id,
  :role_name,
  :role_policy_list,
  :max_session_duration,
  :path)
  SENSITIVE = []
  include Aws::Structure
end

#instance_profile_listArray<Types::AwsIamInstanceProfile>

The list of instance profiles that contain this role.



13975
13976
13977
13978
13979
13980
13981
13982
13983
13984
13985
13986
13987
13988
# File 'lib/aws-sdk-securityhub/types.rb', line 13975

class AwsIamRoleDetails < Struct.new(
  :assume_role_policy_document,
  :attached_managed_policies,
  :create_date,
  :instance_profile_list,
  :permissions_boundary,
  :role_id,
  :role_name,
  :role_policy_list,
  :max_session_duration,
  :path)
  SENSITIVE = []
  include Aws::Structure
end

#max_session_durationInteger

The maximum session duration (in seconds) that you want to set for the specified role.



13975
13976
13977
13978
13979
13980
13981
13982
13983
13984
13985
13986
13987
13988
# File 'lib/aws-sdk-securityhub/types.rb', line 13975

class AwsIamRoleDetails < Struct.new(
  :assume_role_policy_document,
  :attached_managed_policies,
  :create_date,
  :instance_profile_list,
  :permissions_boundary,
  :role_id,
  :role_name,
  :role_policy_list,
  :max_session_duration,
  :path)
  SENSITIVE = []
  include Aws::Structure
end

#pathString

The path to the role.



13975
13976
13977
13978
13979
13980
13981
13982
13983
13984
13985
13986
13987
13988
# File 'lib/aws-sdk-securityhub/types.rb', line 13975

class AwsIamRoleDetails < Struct.new(
  :assume_role_policy_document,
  :attached_managed_policies,
  :create_date,
  :instance_profile_list,
  :permissions_boundary,
  :role_id,
  :role_name,
  :role_policy_list,
  :max_session_duration,
  :path)
  SENSITIVE = []
  include Aws::Structure
end

#permissions_boundaryTypes::AwsIamPermissionsBoundary

Information about the policy used to set the permissions boundary for an IAM principal.



13975
13976
13977
13978
13979
13980
13981
13982
13983
13984
13985
13986
13987
13988
# File 'lib/aws-sdk-securityhub/types.rb', line 13975

class AwsIamRoleDetails < Struct.new(
  :assume_role_policy_document,
  :attached_managed_policies,
  :create_date,
  :instance_profile_list,
  :permissions_boundary,
  :role_id,
  :role_name,
  :role_policy_list,
  :max_session_duration,
  :path)
  SENSITIVE = []
  include Aws::Structure
end

#role_idString

The stable and unique string identifying the role.



13975
13976
13977
13978
13979
13980
13981
13982
13983
13984
13985
13986
13987
13988
# File 'lib/aws-sdk-securityhub/types.rb', line 13975

class AwsIamRoleDetails < Struct.new(
  :assume_role_policy_document,
  :attached_managed_policies,
  :create_date,
  :instance_profile_list,
  :permissions_boundary,
  :role_id,
  :role_name,
  :role_policy_list,
  :max_session_duration,
  :path)
  SENSITIVE = []
  include Aws::Structure
end

#role_nameString

The friendly name that identifies the role.



13975
13976
13977
13978
13979
13980
13981
13982
13983
13984
13985
13986
13987
13988
# File 'lib/aws-sdk-securityhub/types.rb', line 13975

class AwsIamRoleDetails < Struct.new(
  :assume_role_policy_document,
  :attached_managed_policies,
  :create_date,
  :instance_profile_list,
  :permissions_boundary,
  :role_id,
  :role_name,
  :role_policy_list,
  :max_session_duration,
  :path)
  SENSITIVE = []
  include Aws::Structure
end

#role_policy_listArray<Types::AwsIamRolePolicy>

The list of inline policies that are embedded in the role.



13975
13976
13977
13978
13979
13980
13981
13982
13983
13984
13985
13986
13987
13988
# File 'lib/aws-sdk-securityhub/types.rb', line 13975

class AwsIamRoleDetails < Struct.new(
  :assume_role_policy_document,
  :attached_managed_policies,
  :create_date,
  :instance_profile_list,
  :permissions_boundary,
  :role_id,
  :role_name,
  :role_policy_list,
  :max_session_duration,
  :path)
  SENSITIVE = []
  include Aws::Structure
end