Class: Aws::SecurityHub::Types::AwsKmsKeyDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::AwsKmsKeyDetails
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Contains metadata about an KMS key.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_account_id ⇒ String
The twelve-digit account ID of the Amazon Web Services account that owns the KMS key.
-
#creation_date ⇒ Float
Indicates when the KMS key was created.
-
#description ⇒ String
A description of the KMS key.
-
#key_id ⇒ String
The globally unique identifier for the KMS key.
-
#key_manager ⇒ String
The manager of the KMS key.
-
#key_rotation_status ⇒ Boolean
Whether the key has key rotation enabled.
-
#key_state ⇒ String
The state of the KMS key.
-
#origin ⇒ String
The source of the KMS key material.
Instance Attribute Details
#aws_account_id ⇒ String
The twelve-digit account ID of the Amazon Web Services account that owns the KMS key.
14197 14198 14199 14200 14201 14202 14203 14204 14205 14206 14207 14208 |
# File 'lib/aws-sdk-securityhub/types.rb', line 14197 class AwsKmsKeyDetails < Struct.new( :aws_account_id, :creation_date, :key_id, :key_manager, :key_state, :origin, :description, :key_rotation_status) SENSITIVE = [] include Aws::Structure end |
#creation_date ⇒ Float
Indicates when the KMS key was created.
For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.
14197 14198 14199 14200 14201 14202 14203 14204 14205 14206 14207 14208 |
# File 'lib/aws-sdk-securityhub/types.rb', line 14197 class AwsKmsKeyDetails < Struct.new( :aws_account_id, :creation_date, :key_id, :key_manager, :key_state, :origin, :description, :key_rotation_status) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the KMS key.
14197 14198 14199 14200 14201 14202 14203 14204 14205 14206 14207 14208 |
# File 'lib/aws-sdk-securityhub/types.rb', line 14197 class AwsKmsKeyDetails < Struct.new( :aws_account_id, :creation_date, :key_id, :key_manager, :key_state, :origin, :description, :key_rotation_status) SENSITIVE = [] include Aws::Structure end |
#key_id ⇒ String
The globally unique identifier for the KMS key.
14197 14198 14199 14200 14201 14202 14203 14204 14205 14206 14207 14208 |
# File 'lib/aws-sdk-securityhub/types.rb', line 14197 class AwsKmsKeyDetails < Struct.new( :aws_account_id, :creation_date, :key_id, :key_manager, :key_state, :origin, :description, :key_rotation_status) SENSITIVE = [] include Aws::Structure end |
#key_manager ⇒ String
The manager of the KMS key. KMS keys in your Amazon Web Services account are either customer managed or Amazon Web Services managed.
14197 14198 14199 14200 14201 14202 14203 14204 14205 14206 14207 14208 |
# File 'lib/aws-sdk-securityhub/types.rb', line 14197 class AwsKmsKeyDetails < Struct.new( :aws_account_id, :creation_date, :key_id, :key_manager, :key_state, :origin, :description, :key_rotation_status) SENSITIVE = [] include Aws::Structure end |
#key_rotation_status ⇒ Boolean
Whether the key has key rotation enabled.
14197 14198 14199 14200 14201 14202 14203 14204 14205 14206 14207 14208 |
# File 'lib/aws-sdk-securityhub/types.rb', line 14197 class AwsKmsKeyDetails < Struct.new( :aws_account_id, :creation_date, :key_id, :key_manager, :key_state, :origin, :description, :key_rotation_status) SENSITIVE = [] include Aws::Structure end |
#key_state ⇒ String
The state of the KMS key. Valid values are as follows:
-
Disabled -
Enabled -
PendingDeletion -
PendingImport -
Unavailable
14197 14198 14199 14200 14201 14202 14203 14204 14205 14206 14207 14208 |
# File 'lib/aws-sdk-securityhub/types.rb', line 14197 class AwsKmsKeyDetails < Struct.new( :aws_account_id, :creation_date, :key_id, :key_manager, :key_state, :origin, :description, :key_rotation_status) SENSITIVE = [] include Aws::Structure end |
#origin ⇒ String
The source of the KMS key material.
When this value is AWS_KMS, KMS created the key material.
When this value is EXTERNAL, the key material was imported from
your existing key management infrastructure or the KMS key lacks key
material.
When this value is AWS_CLOUDHSM, the key material was created in
the CloudHSM cluster associated with a custom key store.
14197 14198 14199 14200 14201 14202 14203 14204 14205 14206 14207 14208 |
# File 'lib/aws-sdk-securityhub/types.rb', line 14197 class AwsKmsKeyDetails < Struct.new( :aws_account_id, :creation_date, :key_id, :key_manager, :key_state, :origin, :description, :key_rotation_status) SENSITIVE = [] include Aws::Structure end |