Class: Aws::SecurityHub::Types::AwsLambdaLayerVersionDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::AwsLambdaLayerVersionDetails
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Details about a Lambda layer version.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#compatible_runtimes ⇒ Array<String>
The layer's compatible [function runtimes][1].
-
#created_date ⇒ String
Indicates when the version was created.
-
#version ⇒ Integer
The version number.
Instance Attribute Details
#compatible_runtimes ⇒ Array<String>
The layer's compatible function runtimes.
The following list includes deprecated runtimes. For more information, see Runtime deprecation policy in the Lambda Developer Guide.
Array Members: Maximum number of 5 items.
Valid Values: nodejs | nodejs4.3 | nodejs6.10 | nodejs8.10 | nodejs10.x | nodejs12.x | nodejs14.x | nodejs16.x | java8 | java8.al2 | java11 | python2.7 | python3.6 | python3.7 | python3.8 | python3.9 | dotnetcore1.0 | dotnetcore2.0 | dotnetcore2.1 | dotnetcore3.1 | dotnet6 | nodejs4.3-edge | go1.x | ruby2.5 | ruby2.7 | provided | provided.al2 | nodejs18.x | python3.10 | java17 | ruby3.2 | python3.11 | nodejs20.x | provided.al2023 | python3.12 | java21
14491 14492 14493 14494 14495 14496 14497 |
# File 'lib/aws-sdk-securityhub/types.rb', line 14491 class AwsLambdaLayerVersionDetails < Struct.new( :version, :compatible_runtimes, :created_date) SENSITIVE = [] include Aws::Structure end |
#created_date ⇒ String
Indicates when the version was created.
For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.
14491 14492 14493 14494 14495 14496 14497 |
# File 'lib/aws-sdk-securityhub/types.rb', line 14491 class AwsLambdaLayerVersionDetails < Struct.new( :version, :compatible_runtimes, :created_date) SENSITIVE = [] include Aws::Structure end |
#version ⇒ Integer
The version number.
14491 14492 14493 14494 14495 14496 14497 |
# File 'lib/aws-sdk-securityhub/types.rb', line 14491 class AwsLambdaLayerVersionDetails < Struct.new( :version, :compatible_runtimes, :created_date) SENSITIVE = [] include Aws::Structure end |