Class: Aws::SecurityHub::Types::AwsMskClusterClusterInfoEncryptionInfoEncryptionInTransitDetails

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

The settings for encrypting data in transit.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_brokerString

Indicates the encryption setting for data in transit between clients and brokers.

Returns:

  • (String)


14753
14754
14755
14756
14757
14758
# File 'lib/aws-sdk-securityhub/types.rb', line 14753

class AwsMskClusterClusterInfoEncryptionInfoEncryptionInTransitDetails < Struct.new(
  :in_cluster,
  :client_broker)
  SENSITIVE = []
  include Aws::Structure
end

#in_clusterBoolean

When set to true, it indicates that data communication among the broker nodes of the cluster is encrypted. When set to false, the communication happens in plain text. The default value is true.

Returns:

  • (Boolean)


14753
14754
14755
14756
14757
14758
# File 'lib/aws-sdk-securityhub/types.rb', line 14753

class AwsMskClusterClusterInfoEncryptionInfoEncryptionInTransitDetails < Struct.new(
  :in_cluster,
  :client_broker)
  SENSITIVE = []
  include Aws::Structure
end