Class: Aws::SecurityHub::Types::AwsNetworkFirewallRuleGroupDetails

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

Details about an Network Firewall rule group. Rule groups are used to inspect and control network traffic. Stateless rule groups apply to individual packets. Stateful rule groups apply to packets in the context of their traffic flow.

Rule groups are referenced in firewall policies.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#capacityInteger

The maximum number of operating resources that this rule group can use.

Returns:

  • (Integer)


14927
14928
14929
14930
14931
14932
14933
14934
14935
14936
14937
# File 'lib/aws-sdk-securityhub/types.rb', line 14927

class AwsNetworkFirewallRuleGroupDetails < Struct.new(
  :capacity,
  :description,
  :rule_group,
  :rule_group_arn,
  :rule_group_id,
  :rule_group_name,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A description of the rule group.

Returns:

  • (String)


14927
14928
14929
14930
14931
14932
14933
14934
14935
14936
14937
# File 'lib/aws-sdk-securityhub/types.rb', line 14927

class AwsNetworkFirewallRuleGroupDetails < Struct.new(
  :capacity,
  :description,
  :rule_group,
  :rule_group_arn,
  :rule_group_id,
  :rule_group_name,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#rule_groupTypes::RuleGroupDetails

Details about the rule group.



14927
14928
14929
14930
14931
14932
14933
14934
14935
14936
14937
# File 'lib/aws-sdk-securityhub/types.rb', line 14927

class AwsNetworkFirewallRuleGroupDetails < Struct.new(
  :capacity,
  :description,
  :rule_group,
  :rule_group_arn,
  :rule_group_id,
  :rule_group_name,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#rule_group_arnString

The ARN of the rule group.

Returns:

  • (String)


14927
14928
14929
14930
14931
14932
14933
14934
14935
14936
14937
# File 'lib/aws-sdk-securityhub/types.rb', line 14927

class AwsNetworkFirewallRuleGroupDetails < Struct.new(
  :capacity,
  :description,
  :rule_group,
  :rule_group_arn,
  :rule_group_id,
  :rule_group_name,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#rule_group_idString

The identifier of the rule group.

Returns:

  • (String)


14927
14928
14929
14930
14931
14932
14933
14934
14935
14936
14937
# File 'lib/aws-sdk-securityhub/types.rb', line 14927

class AwsNetworkFirewallRuleGroupDetails < Struct.new(
  :capacity,
  :description,
  :rule_group,
  :rule_group_arn,
  :rule_group_id,
  :rule_group_name,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#rule_group_nameString

The descriptive name of the rule group.

Returns:

  • (String)


14927
14928
14929
14930
14931
14932
14933
14934
14935
14936
14937
# File 'lib/aws-sdk-securityhub/types.rb', line 14927

class AwsNetworkFirewallRuleGroupDetails < Struct.new(
  :capacity,
  :description,
  :rule_group,
  :rule_group_arn,
  :rule_group_id,
  :rule_group_name,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The type of rule group. A rule group can be stateful or stateless.

Returns:

  • (String)


14927
14928
14929
14930
14931
14932
14933
14934
14935
14936
14937
# File 'lib/aws-sdk-securityhub/types.rb', line 14927

class AwsNetworkFirewallRuleGroupDetails < Struct.new(
  :capacity,
  :description,
  :rule_group,
  :rule_group_arn,
  :rule_group_id,
  :rule_group_name,
  :type)
  SENSITIVE = []
  include Aws::Structure
end