Class: Aws::SecurityHub::Types::AwsOpenSearchServiceDomainDetails

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

Information about an Amazon OpenSearch Service domain.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#access_policiesString

IAM policy document that specifies the access policies for the OpenSearch Service domain.

Returns:

  • (String)


15129
15130
15131
15132
15133
15134
15135
15136
15137
15138
15139
15140
15141
15142
15143
15144
15145
15146
15147
# File 'lib/aws-sdk-securityhub/types.rb', line 15129

class AwsOpenSearchServiceDomainDetails < Struct.new(
  :arn,
  :access_policies,
  :domain_name,
  :id,
  :domain_endpoint,
  :engine_version,
  :encryption_at_rest_options,
  :node_to_node_encryption_options,
  :service_software_options,
  :cluster_config,
  :domain_endpoint_options,
  :vpc_options,
  :log_publishing_options,
  :domain_endpoints,
  :advanced_security_options)
  SENSITIVE = []
  include Aws::Structure
end

#advanced_security_optionsTypes::AwsOpenSearchServiceDomainAdvancedSecurityOptionsDetails

Specifies options for fine-grained access control.



15129
15130
15131
15132
15133
15134
15135
15136
15137
15138
15139
15140
15141
15142
15143
15144
15145
15146
15147
# File 'lib/aws-sdk-securityhub/types.rb', line 15129

class AwsOpenSearchServiceDomainDetails < Struct.new(
  :arn,
  :access_policies,
  :domain_name,
  :id,
  :domain_endpoint,
  :engine_version,
  :encryption_at_rest_options,
  :node_to_node_encryption_options,
  :service_software_options,
  :cluster_config,
  :domain_endpoint_options,
  :vpc_options,
  :log_publishing_options,
  :domain_endpoints,
  :advanced_security_options)
  SENSITIVE = []
  include Aws::Structure
end

#arnString

The ARN of the OpenSearch Service domain.

Returns:

  • (String)


15129
15130
15131
15132
15133
15134
15135
15136
15137
15138
15139
15140
15141
15142
15143
15144
15145
15146
15147
# File 'lib/aws-sdk-securityhub/types.rb', line 15129

class AwsOpenSearchServiceDomainDetails < Struct.new(
  :arn,
  :access_policies,
  :domain_name,
  :id,
  :domain_endpoint,
  :engine_version,
  :encryption_at_rest_options,
  :node_to_node_encryption_options,
  :service_software_options,
  :cluster_config,
  :domain_endpoint_options,
  :vpc_options,
  :log_publishing_options,
  :domain_endpoints,
  :advanced_security_options)
  SENSITIVE = []
  include Aws::Structure
end

#cluster_configTypes::AwsOpenSearchServiceDomainClusterConfigDetails

Details about the configuration of an OpenSearch cluster.



15129
15130
15131
15132
15133
15134
15135
15136
15137
15138
15139
15140
15141
15142
15143
15144
15145
15146
15147
# File 'lib/aws-sdk-securityhub/types.rb', line 15129

class AwsOpenSearchServiceDomainDetails < Struct.new(
  :arn,
  :access_policies,
  :domain_name,
  :id,
  :domain_endpoint,
  :engine_version,
  :encryption_at_rest_options,
  :node_to_node_encryption_options,
  :service_software_options,
  :cluster_config,
  :domain_endpoint_options,
  :vpc_options,
  :log_publishing_options,
  :domain_endpoints,
  :advanced_security_options)
  SENSITIVE = []
  include Aws::Structure
end

#domain_endpointString

The domain endpoint.

Returns:

  • (String)


15129
15130
15131
15132
15133
15134
15135
15136
15137
15138
15139
15140
15141
15142
15143
15144
15145
15146
15147
# File 'lib/aws-sdk-securityhub/types.rb', line 15129

class AwsOpenSearchServiceDomainDetails < Struct.new(
  :arn,
  :access_policies,
  :domain_name,
  :id,
  :domain_endpoint,
  :engine_version,
  :encryption_at_rest_options,
  :node_to_node_encryption_options,
  :service_software_options,
  :cluster_config,
  :domain_endpoint_options,
  :vpc_options,
  :log_publishing_options,
  :domain_endpoints,
  :advanced_security_options)
  SENSITIVE = []
  include Aws::Structure
end

#domain_endpoint_optionsTypes::AwsOpenSearchServiceDomainDomainEndpointOptionsDetails

Additional options for the domain endpoint.



15129
15130
15131
15132
15133
15134
15135
15136
15137
15138
15139
15140
15141
15142
15143
15144
15145
15146
15147
# File 'lib/aws-sdk-securityhub/types.rb', line 15129

class AwsOpenSearchServiceDomainDetails < Struct.new(
  :arn,
  :access_policies,
  :domain_name,
  :id,
  :domain_endpoint,
  :engine_version,
  :encryption_at_rest_options,
  :node_to_node_encryption_options,
  :service_software_options,
  :cluster_config,
  :domain_endpoint_options,
  :vpc_options,
  :log_publishing_options,
  :domain_endpoints,
  :advanced_security_options)
  SENSITIVE = []
  include Aws::Structure
end

#domain_endpointsHash<String,String>

The domain endpoints. Used if the OpenSearch domain resides in a VPC.

This is a map of key-value pairs. The key is always vpc. The value is the endpoint.

Returns:

  • (Hash<String,String>)


15129
15130
15131
15132
15133
15134
15135
15136
15137
15138
15139
15140
15141
15142
15143
15144
15145
15146
15147
# File 'lib/aws-sdk-securityhub/types.rb', line 15129

class AwsOpenSearchServiceDomainDetails < Struct.new(
  :arn,
  :access_policies,
  :domain_name,
  :id,
  :domain_endpoint,
  :engine_version,
  :encryption_at_rest_options,
  :node_to_node_encryption_options,
  :service_software_options,
  :cluster_config,
  :domain_endpoint_options,
  :vpc_options,
  :log_publishing_options,
  :domain_endpoints,
  :advanced_security_options)
  SENSITIVE = []
  include Aws::Structure
end

#domain_nameString

The name of the endpoint.

Returns:

  • (String)


15129
15130
15131
15132
15133
15134
15135
15136
15137
15138
15139
15140
15141
15142
15143
15144
15145
15146
15147
# File 'lib/aws-sdk-securityhub/types.rb', line 15129

class AwsOpenSearchServiceDomainDetails < Struct.new(
  :arn,
  :access_policies,
  :domain_name,
  :id,
  :domain_endpoint,
  :engine_version,
  :encryption_at_rest_options,
  :node_to_node_encryption_options,
  :service_software_options,
  :cluster_config,
  :domain_endpoint_options,
  :vpc_options,
  :log_publishing_options,
  :domain_endpoints,
  :advanced_security_options)
  SENSITIVE = []
  include Aws::Structure
end

#encryption_at_rest_optionsTypes::AwsOpenSearchServiceDomainEncryptionAtRestOptionsDetails

Details about the configuration for encryption at rest.



15129
15130
15131
15132
15133
15134
15135
15136
15137
15138
15139
15140
15141
15142
15143
15144
15145
15146
15147
# File 'lib/aws-sdk-securityhub/types.rb', line 15129

class AwsOpenSearchServiceDomainDetails < Struct.new(
  :arn,
  :access_policies,
  :domain_name,
  :id,
  :domain_endpoint,
  :engine_version,
  :encryption_at_rest_options,
  :node_to_node_encryption_options,
  :service_software_options,
  :cluster_config,
  :domain_endpoint_options,
  :vpc_options,
  :log_publishing_options,
  :domain_endpoints,
  :advanced_security_options)
  SENSITIVE = []
  include Aws::Structure
end

#engine_versionString

The version of the domain engine.

Returns:

  • (String)


15129
15130
15131
15132
15133
15134
15135
15136
15137
15138
15139
15140
15141
15142
15143
15144
15145
15146
15147
# File 'lib/aws-sdk-securityhub/types.rb', line 15129

class AwsOpenSearchServiceDomainDetails < Struct.new(
  :arn,
  :access_policies,
  :domain_name,
  :id,
  :domain_endpoint,
  :engine_version,
  :encryption_at_rest_options,
  :node_to_node_encryption_options,
  :service_software_options,
  :cluster_config,
  :domain_endpoint_options,
  :vpc_options,
  :log_publishing_options,
  :domain_endpoints,
  :advanced_security_options)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The identifier of the domain.

Returns:

  • (String)


15129
15130
15131
15132
15133
15134
15135
15136
15137
15138
15139
15140
15141
15142
15143
15144
15145
15146
15147
# File 'lib/aws-sdk-securityhub/types.rb', line 15129

class AwsOpenSearchServiceDomainDetails < Struct.new(
  :arn,
  :access_policies,
  :domain_name,
  :id,
  :domain_endpoint,
  :engine_version,
  :encryption_at_rest_options,
  :node_to_node_encryption_options,
  :service_software_options,
  :cluster_config,
  :domain_endpoint_options,
  :vpc_options,
  :log_publishing_options,
  :domain_endpoints,
  :advanced_security_options)
  SENSITIVE = []
  include Aws::Structure
end

#log_publishing_optionsTypes::AwsOpenSearchServiceDomainLogPublishingOptionsDetails

Configures the CloudWatch Logs to publish for the OpenSearch domain.



15129
15130
15131
15132
15133
15134
15135
15136
15137
15138
15139
15140
15141
15142
15143
15144
15145
15146
15147
# File 'lib/aws-sdk-securityhub/types.rb', line 15129

class AwsOpenSearchServiceDomainDetails < Struct.new(
  :arn,
  :access_policies,
  :domain_name,
  :id,
  :domain_endpoint,
  :engine_version,
  :encryption_at_rest_options,
  :node_to_node_encryption_options,
  :service_software_options,
  :cluster_config,
  :domain_endpoint_options,
  :vpc_options,
  :log_publishing_options,
  :domain_endpoints,
  :advanced_security_options)
  SENSITIVE = []
  include Aws::Structure
end

#node_to_node_encryption_optionsTypes::AwsOpenSearchServiceDomainNodeToNodeEncryptionOptionsDetails

Details about the configuration for node-to-node encryption.



15129
15130
15131
15132
15133
15134
15135
15136
15137
15138
15139
15140
15141
15142
15143
15144
15145
15146
15147
# File 'lib/aws-sdk-securityhub/types.rb', line 15129

class AwsOpenSearchServiceDomainDetails < Struct.new(
  :arn,
  :access_policies,
  :domain_name,
  :id,
  :domain_endpoint,
  :engine_version,
  :encryption_at_rest_options,
  :node_to_node_encryption_options,
  :service_software_options,
  :cluster_config,
  :domain_endpoint_options,
  :vpc_options,
  :log_publishing_options,
  :domain_endpoints,
  :advanced_security_options)
  SENSITIVE = []
  include Aws::Structure
end

#service_software_optionsTypes::AwsOpenSearchServiceDomainServiceSoftwareOptionsDetails

Information about the status of a domain relative to the latest service software.



15129
15130
15131
15132
15133
15134
15135
15136
15137
15138
15139
15140
15141
15142
15143
15144
15145
15146
15147
# File 'lib/aws-sdk-securityhub/types.rb', line 15129

class AwsOpenSearchServiceDomainDetails < Struct.new(
  :arn,
  :access_policies,
  :domain_name,
  :id,
  :domain_endpoint,
  :engine_version,
  :encryption_at_rest_options,
  :node_to_node_encryption_options,
  :service_software_options,
  :cluster_config,
  :domain_endpoint_options,
  :vpc_options,
  :log_publishing_options,
  :domain_endpoints,
  :advanced_security_options)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_optionsTypes::AwsOpenSearchServiceDomainVpcOptionsDetails

Information that OpenSearch Service derives based on VPCOptions for the domain.



15129
15130
15131
15132
15133
15134
15135
15136
15137
15138
15139
15140
15141
15142
15143
15144
15145
15146
15147
# File 'lib/aws-sdk-securityhub/types.rb', line 15129

class AwsOpenSearchServiceDomainDetails < Struct.new(
  :arn,
  :access_policies,
  :domain_name,
  :id,
  :domain_endpoint,
  :engine_version,
  :encryption_at_rest_options,
  :node_to_node_encryption_options,
  :service_software_options,
  :cluster_config,
  :domain_endpoint_options,
  :vpc_options,
  :log_publishing_options,
  :domain_endpoints,
  :advanced_security_options)
  SENSITIVE = []
  include Aws::Structure
end