Class: Aws::SecurityHub::Types::AwsRedshiftClusterLoggingStatus
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::AwsRedshiftClusterLoggingStatus
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Provides information about the logging status of the cluster.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bucket_name ⇒ String
The name of the S3 bucket where the log files are stored.
-
#last_failure_message ⇒ String
The message indicating that the logs failed to be delivered.
-
#last_failure_time ⇒ String
The last time when logs failed to be delivered.
-
#last_successful_delivery_time ⇒ String
The last time that logs were delivered successfully.
-
#logging_enabled ⇒ Boolean
Indicates whether logging is enabled.
-
#s3_key_prefix ⇒ String
Provides the prefix applied to the log file names.
Instance Attribute Details
#bucket_name ⇒ String
The name of the S3 bucket where the log files are stored.
17527 17528 17529 17530 17531 17532 17533 17534 17535 17536 |
# File 'lib/aws-sdk-securityhub/types.rb', line 17527 class AwsRedshiftClusterLoggingStatus < Struct.new( :bucket_name, :last_failure_message, :last_failure_time, :last_successful_delivery_time, :logging_enabled, :s3_key_prefix) SENSITIVE = [] include Aws::Structure end |
#last_failure_message ⇒ String
The message indicating that the logs failed to be delivered.
17527 17528 17529 17530 17531 17532 17533 17534 17535 17536 |
# File 'lib/aws-sdk-securityhub/types.rb', line 17527 class AwsRedshiftClusterLoggingStatus < Struct.new( :bucket_name, :last_failure_message, :last_failure_time, :last_successful_delivery_time, :logging_enabled, :s3_key_prefix) SENSITIVE = [] include Aws::Structure end |
#last_failure_time ⇒ String
The last time when logs failed to be delivered.
For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.
17527 17528 17529 17530 17531 17532 17533 17534 17535 17536 |
# File 'lib/aws-sdk-securityhub/types.rb', line 17527 class AwsRedshiftClusterLoggingStatus < Struct.new( :bucket_name, :last_failure_message, :last_failure_time, :last_successful_delivery_time, :logging_enabled, :s3_key_prefix) SENSITIVE = [] include Aws::Structure end |
#last_successful_delivery_time ⇒ String
The last time that logs were delivered successfully.
For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.
17527 17528 17529 17530 17531 17532 17533 17534 17535 17536 |
# File 'lib/aws-sdk-securityhub/types.rb', line 17527 class AwsRedshiftClusterLoggingStatus < Struct.new( :bucket_name, :last_failure_message, :last_failure_time, :last_successful_delivery_time, :logging_enabled, :s3_key_prefix) SENSITIVE = [] include Aws::Structure end |
#logging_enabled ⇒ Boolean
Indicates whether logging is enabled.
17527 17528 17529 17530 17531 17532 17533 17534 17535 17536 |
# File 'lib/aws-sdk-securityhub/types.rb', line 17527 class AwsRedshiftClusterLoggingStatus < Struct.new( :bucket_name, :last_failure_message, :last_failure_time, :last_successful_delivery_time, :logging_enabled, :s3_key_prefix) SENSITIVE = [] include Aws::Structure end |
#s3_key_prefix ⇒ String
Provides the prefix applied to the log file names.
17527 17528 17529 17530 17531 17532 17533 17534 17535 17536 |
# File 'lib/aws-sdk-securityhub/types.rb', line 17527 class AwsRedshiftClusterLoggingStatus < Struct.new( :bucket_name, :last_failure_message, :last_failure_time, :last_successful_delivery_time, :logging_enabled, :s3_key_prefix) SENSITIVE = [] include Aws::Structure end |