Class: Aws::SecurityHub::Types::AwsRedshiftClusterRestoreStatus
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::AwsRedshiftClusterRestoreStatus
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Information about the status of a cluster restore action. It only applies if the cluster was created by restoring a snapshot.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#current_restore_rate_in_mega_bytes_per_second ⇒ Float
The number of megabytes per second being transferred from the backup storage.
-
#elapsed_time_in_seconds ⇒ Integer
The amount of time an in-progress restore has been running, or the amount of time it took a completed restore to finish.
-
#estimated_time_to_completion_in_seconds ⇒ Integer
The estimate of the time remaining before the restore is complete.
-
#progress_in_mega_bytes ⇒ Integer
The number of megabytes that were transferred from snapshot storage.
-
#snapshot_size_in_mega_bytes ⇒ Integer
The size of the set of snapshot data that was used to restore the cluster.
-
#status ⇒ String
The status of the restore action.
Instance Attribute Details
#current_restore_rate_in_mega_bytes_per_second ⇒ Float
The number of megabytes per second being transferred from the backup storage. Returns the average rate for a completed backup.
This field is only updated when you restore to DC2 and DS2 node types.
17660 17661 17662 17663 17664 17665 17666 17667 17668 17669 |
# File 'lib/aws-sdk-securityhub/types.rb', line 17660 class AwsRedshiftClusterRestoreStatus < Struct.new( :current_restore_rate_in_mega_bytes_per_second, :elapsed_time_in_seconds, :estimated_time_to_completion_in_seconds, :progress_in_mega_bytes, :snapshot_size_in_mega_bytes, :status) SENSITIVE = [] include Aws::Structure end |
#elapsed_time_in_seconds ⇒ Integer
The amount of time an in-progress restore has been running, or the amount of time it took a completed restore to finish.
This field is only updated when you restore to DC2 and DS2 node types.
17660 17661 17662 17663 17664 17665 17666 17667 17668 17669 |
# File 'lib/aws-sdk-securityhub/types.rb', line 17660 class AwsRedshiftClusterRestoreStatus < Struct.new( :current_restore_rate_in_mega_bytes_per_second, :elapsed_time_in_seconds, :estimated_time_to_completion_in_seconds, :progress_in_mega_bytes, :snapshot_size_in_mega_bytes, :status) SENSITIVE = [] include Aws::Structure end |
#estimated_time_to_completion_in_seconds ⇒ Integer
The estimate of the time remaining before the restore is complete. Returns 0 for a completed restore.
This field is only updated when you restore to DC2 and DS2 node types.
17660 17661 17662 17663 17664 17665 17666 17667 17668 17669 |
# File 'lib/aws-sdk-securityhub/types.rb', line 17660 class AwsRedshiftClusterRestoreStatus < Struct.new( :current_restore_rate_in_mega_bytes_per_second, :elapsed_time_in_seconds, :estimated_time_to_completion_in_seconds, :progress_in_mega_bytes, :snapshot_size_in_mega_bytes, :status) SENSITIVE = [] include Aws::Structure end |
#progress_in_mega_bytes ⇒ Integer
The number of megabytes that were transferred from snapshot storage.
This field is only updated when you restore to DC2 and DS2 node types.
17660 17661 17662 17663 17664 17665 17666 17667 17668 17669 |
# File 'lib/aws-sdk-securityhub/types.rb', line 17660 class AwsRedshiftClusterRestoreStatus < Struct.new( :current_restore_rate_in_mega_bytes_per_second, :elapsed_time_in_seconds, :estimated_time_to_completion_in_seconds, :progress_in_mega_bytes, :snapshot_size_in_mega_bytes, :status) SENSITIVE = [] include Aws::Structure end |
#snapshot_size_in_mega_bytes ⇒ Integer
The size of the set of snapshot data that was used to restore the cluster.
This field is only updated when you restore to DC2 and DS2 node types.
17660 17661 17662 17663 17664 17665 17666 17667 17668 17669 |
# File 'lib/aws-sdk-securityhub/types.rb', line 17660 class AwsRedshiftClusterRestoreStatus < Struct.new( :current_restore_rate_in_mega_bytes_per_second, :elapsed_time_in_seconds, :estimated_time_to_completion_in_seconds, :progress_in_mega_bytes, :snapshot_size_in_mega_bytes, :status) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the restore action.
Valid values: starting | restoring | completed | failed
17660 17661 17662 17663 17664 17665 17666 17667 17668 17669 |
# File 'lib/aws-sdk-securityhub/types.rb', line 17660 class AwsRedshiftClusterRestoreStatus < Struct.new( :current_restore_rate_in_mega_bytes_per_second, :elapsed_time_in_seconds, :estimated_time_to_completion_in_seconds, :progress_in_mega_bytes, :snapshot_size_in_mega_bytes, :status) SENSITIVE = [] include Aws::Structure end |