Class: Aws::SecurityHub::Types::AwsS3BucketBucketLifecycleConfigurationRulesTransitionsDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::AwsS3BucketBucketLifecycleConfigurationRulesTransitionsDetails
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
A rule for when objects transition to specific storage classes.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#date ⇒ String
A date on which to transition objects to the specified storage class.
-
#days ⇒ Integer
The number of days after which to transition the object to the specified storage class.
-
#storage_class ⇒ String
The storage class to transition the object to.
Instance Attribute Details
#date ⇒ String
A date on which to transition objects to the specified storage class. If you provide Date, you cannot provide Days.
For more information about the validation and formatting of timestamp fields in Security Hub, see [Timestamps].
[1]: docs.aws.amazon.com/securityhub/1.0/APIReference/Welcome.html#timestamps
18150 18151 18152 18153 18154 18155 18156 |
# File 'lib/aws-sdk-securityhub/types.rb', line 18150 class AwsS3BucketBucketLifecycleConfigurationRulesTransitionsDetails < Struct.new( :date, :days, :storage_class) SENSITIVE = [] include Aws::Structure end |
#days ⇒ Integer
The number of days after which to transition the object to the specified storage class. If you provide Days, you cannot provide Date.
18150 18151 18152 18153 18154 18155 18156 |
# File 'lib/aws-sdk-securityhub/types.rb', line 18150 class AwsS3BucketBucketLifecycleConfigurationRulesTransitionsDetails < Struct.new( :date, :days, :storage_class) SENSITIVE = [] include Aws::Structure end |
#storage_class ⇒ String
The storage class to transition the object to. Valid values are as follows:
-
DEEP_ARCHIVE -
GLACIER -
INTELLIGENT_TIERING -
ONEZONE_IA -
STANDARD_IA
18150 18151 18152 18153 18154 18155 18156 |
# File 'lib/aws-sdk-securityhub/types.rb', line 18150 class AwsS3BucketBucketLifecycleConfigurationRulesTransitionsDetails < Struct.new( :date, :days, :storage_class) SENSITIVE = [] include Aws::Structure end |