Method: Aws::SecurityHub::Types::AwsS3BucketBucketLifecycleConfigurationRulesTransitionsDetails#date
- Defined in:
- lib/aws-sdk-securityhub/types.rb
#date ⇒ String
A date on which to transition objects to the specified storage class. If you provide Date, you cannot provide Days.
For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see [Timestamps].
[1]: docs.aws.amazon.com/securityhub/1.0/APIReference/Welcome.html#timestamps
18152 18153 18154 18155 18156 18157 18158 |
# File 'lib/aws-sdk-securityhub/types.rb', line 18152 class AwsS3BucketBucketLifecycleConfigurationRulesTransitionsDetails < Struct.new( :date, :days, :storage_class) SENSITIVE = [] include Aws::Structure end |