Class: Aws::SecurityHub::Types::AwsS3BucketDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::AwsS3BucketDetails
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
The details of an Amazon Simple Storage Service (Amazon S3) bucket.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#access_control_list ⇒ String
The access control list for the S3 bucket.
-
#bucket_lifecycle_configuration ⇒ Types::AwsS3BucketBucketLifecycleConfigurationDetails
The lifecycle configuration for objects in the specified bucket.
-
#bucket_logging_configuration ⇒ Types::AwsS3BucketLoggingConfiguration
The logging configuration for the S3 bucket.
-
#bucket_notification_configuration ⇒ Types::AwsS3BucketNotificationConfiguration
The notification configuration for the S3 bucket.
-
#bucket_versioning_configuration ⇒ Types::AwsS3BucketBucketVersioningConfiguration
The versioning state of an S3 bucket.
-
#bucket_website_configuration ⇒ Types::AwsS3BucketWebsiteConfiguration
The website configuration parameters for the S3 bucket.
-
#created_at ⇒ String
Indicates when the S3 bucket was created.
-
#name ⇒ String
The name of the bucket.
-
#object_lock_configuration ⇒ Types::AwsS3BucketObjectLockConfiguration
Specifies which rule Amazon S3 applies by default to every new object placed in the bucket.
-
#owner_account_id ⇒ String
The Amazon Web Services account identifier of the account that owns the S3 bucket.
-
#owner_id ⇒ String
The canonical user ID of the owner of the S3 bucket.
-
#owner_name ⇒ String
The display name of the owner of the S3 bucket.
-
#public_access_block_configuration ⇒ Types::AwsS3AccountPublicAccessBlockDetails
Provides information about the Amazon S3 Public Access Block configuration for the S3 bucket.
-
#server_side_encryption_configuration ⇒ Types::AwsS3BucketServerSideEncryptionConfiguration
The encryption rules that are applied to the S3 bucket.
Instance Attribute Details
#access_control_list ⇒ String
The access control list for the S3 bucket.
18312 18313 18314 18315 18316 18317 18318 18319 18320 18321 18322 18323 18324 18325 18326 18327 18328 18329 |
# File 'lib/aws-sdk-securityhub/types.rb', line 18312 class AwsS3BucketDetails < Struct.new( :owner_id, :owner_name, :owner_account_id, :created_at, :server_side_encryption_configuration, :bucket_lifecycle_configuration, :public_access_block_configuration, :access_control_list, :bucket_logging_configuration, :bucket_website_configuration, :bucket_notification_configuration, :bucket_versioning_configuration, :object_lock_configuration, :name) SENSITIVE = [] include Aws::Structure end |
#bucket_lifecycle_configuration ⇒ Types::AwsS3BucketBucketLifecycleConfigurationDetails
The lifecycle configuration for objects in the specified bucket.
18312 18313 18314 18315 18316 18317 18318 18319 18320 18321 18322 18323 18324 18325 18326 18327 18328 18329 |
# File 'lib/aws-sdk-securityhub/types.rb', line 18312 class AwsS3BucketDetails < Struct.new( :owner_id, :owner_name, :owner_account_id, :created_at, :server_side_encryption_configuration, :bucket_lifecycle_configuration, :public_access_block_configuration, :access_control_list, :bucket_logging_configuration, :bucket_website_configuration, :bucket_notification_configuration, :bucket_versioning_configuration, :object_lock_configuration, :name) SENSITIVE = [] include Aws::Structure end |
#bucket_logging_configuration ⇒ Types::AwsS3BucketLoggingConfiguration
The logging configuration for the S3 bucket.
18312 18313 18314 18315 18316 18317 18318 18319 18320 18321 18322 18323 18324 18325 18326 18327 18328 18329 |
# File 'lib/aws-sdk-securityhub/types.rb', line 18312 class AwsS3BucketDetails < Struct.new( :owner_id, :owner_name, :owner_account_id, :created_at, :server_side_encryption_configuration, :bucket_lifecycle_configuration, :public_access_block_configuration, :access_control_list, :bucket_logging_configuration, :bucket_website_configuration, :bucket_notification_configuration, :bucket_versioning_configuration, :object_lock_configuration, :name) SENSITIVE = [] include Aws::Structure end |
#bucket_notification_configuration ⇒ Types::AwsS3BucketNotificationConfiguration
The notification configuration for the S3 bucket.
18312 18313 18314 18315 18316 18317 18318 18319 18320 18321 18322 18323 18324 18325 18326 18327 18328 18329 |
# File 'lib/aws-sdk-securityhub/types.rb', line 18312 class AwsS3BucketDetails < Struct.new( :owner_id, :owner_name, :owner_account_id, :created_at, :server_side_encryption_configuration, :bucket_lifecycle_configuration, :public_access_block_configuration, :access_control_list, :bucket_logging_configuration, :bucket_website_configuration, :bucket_notification_configuration, :bucket_versioning_configuration, :object_lock_configuration, :name) SENSITIVE = [] include Aws::Structure end |
#bucket_versioning_configuration ⇒ Types::AwsS3BucketBucketVersioningConfiguration
The versioning state of an S3 bucket.
18312 18313 18314 18315 18316 18317 18318 18319 18320 18321 18322 18323 18324 18325 18326 18327 18328 18329 |
# File 'lib/aws-sdk-securityhub/types.rb', line 18312 class AwsS3BucketDetails < Struct.new( :owner_id, :owner_name, :owner_account_id, :created_at, :server_side_encryption_configuration, :bucket_lifecycle_configuration, :public_access_block_configuration, :access_control_list, :bucket_logging_configuration, :bucket_website_configuration, :bucket_notification_configuration, :bucket_versioning_configuration, :object_lock_configuration, :name) SENSITIVE = [] include Aws::Structure end |
#bucket_website_configuration ⇒ Types::AwsS3BucketWebsiteConfiguration
The website configuration parameters for the S3 bucket.
18312 18313 18314 18315 18316 18317 18318 18319 18320 18321 18322 18323 18324 18325 18326 18327 18328 18329 |
# File 'lib/aws-sdk-securityhub/types.rb', line 18312 class AwsS3BucketDetails < Struct.new( :owner_id, :owner_name, :owner_account_id, :created_at, :server_side_encryption_configuration, :bucket_lifecycle_configuration, :public_access_block_configuration, :access_control_list, :bucket_logging_configuration, :bucket_website_configuration, :bucket_notification_configuration, :bucket_versioning_configuration, :object_lock_configuration, :name) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ String
Indicates when the S3 bucket was created.
For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.
18312 18313 18314 18315 18316 18317 18318 18319 18320 18321 18322 18323 18324 18325 18326 18327 18328 18329 |
# File 'lib/aws-sdk-securityhub/types.rb', line 18312 class AwsS3BucketDetails < Struct.new( :owner_id, :owner_name, :owner_account_id, :created_at, :server_side_encryption_configuration, :bucket_lifecycle_configuration, :public_access_block_configuration, :access_control_list, :bucket_logging_configuration, :bucket_website_configuration, :bucket_notification_configuration, :bucket_versioning_configuration, :object_lock_configuration, :name) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the bucket.
18312 18313 18314 18315 18316 18317 18318 18319 18320 18321 18322 18323 18324 18325 18326 18327 18328 18329 |
# File 'lib/aws-sdk-securityhub/types.rb', line 18312 class AwsS3BucketDetails < Struct.new( :owner_id, :owner_name, :owner_account_id, :created_at, :server_side_encryption_configuration, :bucket_lifecycle_configuration, :public_access_block_configuration, :access_control_list, :bucket_logging_configuration, :bucket_website_configuration, :bucket_notification_configuration, :bucket_versioning_configuration, :object_lock_configuration, :name) SENSITIVE = [] include Aws::Structure end |
#object_lock_configuration ⇒ Types::AwsS3BucketObjectLockConfiguration
Specifies which rule Amazon S3 applies by default to every new object placed in the bucket.
18312 18313 18314 18315 18316 18317 18318 18319 18320 18321 18322 18323 18324 18325 18326 18327 18328 18329 |
# File 'lib/aws-sdk-securityhub/types.rb', line 18312 class AwsS3BucketDetails < Struct.new( :owner_id, :owner_name, :owner_account_id, :created_at, :server_side_encryption_configuration, :bucket_lifecycle_configuration, :public_access_block_configuration, :access_control_list, :bucket_logging_configuration, :bucket_website_configuration, :bucket_notification_configuration, :bucket_versioning_configuration, :object_lock_configuration, :name) SENSITIVE = [] include Aws::Structure end |
#owner_account_id ⇒ String
The Amazon Web Services account identifier of the account that owns the S3 bucket.
18312 18313 18314 18315 18316 18317 18318 18319 18320 18321 18322 18323 18324 18325 18326 18327 18328 18329 |
# File 'lib/aws-sdk-securityhub/types.rb', line 18312 class AwsS3BucketDetails < Struct.new( :owner_id, :owner_name, :owner_account_id, :created_at, :server_side_encryption_configuration, :bucket_lifecycle_configuration, :public_access_block_configuration, :access_control_list, :bucket_logging_configuration, :bucket_website_configuration, :bucket_notification_configuration, :bucket_versioning_configuration, :object_lock_configuration, :name) SENSITIVE = [] include Aws::Structure end |
#owner_id ⇒ String
The canonical user ID of the owner of the S3 bucket.
18312 18313 18314 18315 18316 18317 18318 18319 18320 18321 18322 18323 18324 18325 18326 18327 18328 18329 |
# File 'lib/aws-sdk-securityhub/types.rb', line 18312 class AwsS3BucketDetails < Struct.new( :owner_id, :owner_name, :owner_account_id, :created_at, :server_side_encryption_configuration, :bucket_lifecycle_configuration, :public_access_block_configuration, :access_control_list, :bucket_logging_configuration, :bucket_website_configuration, :bucket_notification_configuration, :bucket_versioning_configuration, :object_lock_configuration, :name) SENSITIVE = [] include Aws::Structure end |
#owner_name ⇒ String
The display name of the owner of the S3 bucket.
18312 18313 18314 18315 18316 18317 18318 18319 18320 18321 18322 18323 18324 18325 18326 18327 18328 18329 |
# File 'lib/aws-sdk-securityhub/types.rb', line 18312 class AwsS3BucketDetails < Struct.new( :owner_id, :owner_name, :owner_account_id, :created_at, :server_side_encryption_configuration, :bucket_lifecycle_configuration, :public_access_block_configuration, :access_control_list, :bucket_logging_configuration, :bucket_website_configuration, :bucket_notification_configuration, :bucket_versioning_configuration, :object_lock_configuration, :name) SENSITIVE = [] include Aws::Structure end |
#public_access_block_configuration ⇒ Types::AwsS3AccountPublicAccessBlockDetails
Provides information about the Amazon S3 Public Access Block configuration for the S3 bucket.
18312 18313 18314 18315 18316 18317 18318 18319 18320 18321 18322 18323 18324 18325 18326 18327 18328 18329 |
# File 'lib/aws-sdk-securityhub/types.rb', line 18312 class AwsS3BucketDetails < Struct.new( :owner_id, :owner_name, :owner_account_id, :created_at, :server_side_encryption_configuration, :bucket_lifecycle_configuration, :public_access_block_configuration, :access_control_list, :bucket_logging_configuration, :bucket_website_configuration, :bucket_notification_configuration, :bucket_versioning_configuration, :object_lock_configuration, :name) SENSITIVE = [] include Aws::Structure end |
#server_side_encryption_configuration ⇒ Types::AwsS3BucketServerSideEncryptionConfiguration
The encryption rules that are applied to the S3 bucket.
18312 18313 18314 18315 18316 18317 18318 18319 18320 18321 18322 18323 18324 18325 18326 18327 18328 18329 |
# File 'lib/aws-sdk-securityhub/types.rb', line 18312 class AwsS3BucketDetails < Struct.new( :owner_id, :owner_name, :owner_account_id, :created_at, :server_side_encryption_configuration, :bucket_lifecycle_configuration, :public_access_block_configuration, :access_control_list, :bucket_logging_configuration, :bucket_website_configuration, :bucket_notification_configuration, :bucket_versioning_configuration, :object_lock_configuration, :name) SENSITIVE = [] include Aws::Structure end |