Class: Aws::SecurityHub::Types::AwsS3BucketWebsiteConfigurationRoutingRule

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

A rule for redirecting requests to the website.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#conditionTypes::AwsS3BucketWebsiteConfigurationRoutingRuleCondition

Provides the condition that must be met in order to apply the routing rule.



18634
18635
18636
18637
18638
18639
# File 'lib/aws-sdk-securityhub/types.rb', line 18634

class AwsS3BucketWebsiteConfigurationRoutingRule < Struct.new(
  :condition,
  :redirect)
  SENSITIVE = []
  include Aws::Structure
end

#redirectTypes::AwsS3BucketWebsiteConfigurationRoutingRuleRedirect

Provides the rules to redirect the request if the condition in Condition is met.



18634
18635
18636
18637
18638
18639
# File 'lib/aws-sdk-securityhub/types.rb', line 18634

class AwsS3BucketWebsiteConfigurationRoutingRule < Struct.new(
  :condition,
  :redirect)
  SENSITIVE = []
  include Aws::Structure
end