Class: Aws::SecurityHub::Types::AwsS3ObjectDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::AwsS3ObjectDetails
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Details about an Amazon S3 object.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#content_type ⇒ String
A standard MIME type describing the format of the object data.
-
#etag ⇒ String
The opaque identifier assigned by a web server to a specific version of a resource found at a URL.
-
#last_modified ⇒ String
Indicates when the object was last modified.
-
#server_side_encryption ⇒ String
If the object is stored using server-side encryption, the value of the server-side encryption algorithm used when storing this object in Amazon S3.
-
#ssekms_key_id ⇒ String
The identifier of the KMS symmetric customer managed key that was used for the object.
-
#version_id ⇒ String
The version of the object.
Instance Attribute Details
#content_type ⇒ String
A standard MIME type describing the format of the object data.
18741 18742 18743 18744 18745 18746 18747 18748 18749 18750 |
# File 'lib/aws-sdk-securityhub/types.rb', line 18741 class AwsS3ObjectDetails < Struct.new( :last_modified, :etag, :version_id, :content_type, :server_side_encryption, :ssekms_key_id) SENSITIVE = [] include Aws::Structure end |
#etag ⇒ String
The opaque identifier assigned by a web server to a specific version of a resource found at a URL.
18741 18742 18743 18744 18745 18746 18747 18748 18749 18750 |
# File 'lib/aws-sdk-securityhub/types.rb', line 18741 class AwsS3ObjectDetails < Struct.new( :last_modified, :etag, :version_id, :content_type, :server_side_encryption, :ssekms_key_id) SENSITIVE = [] include Aws::Structure end |
#last_modified ⇒ String
Indicates when the object was last modified.
For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.
18741 18742 18743 18744 18745 18746 18747 18748 18749 18750 |
# File 'lib/aws-sdk-securityhub/types.rb', line 18741 class AwsS3ObjectDetails < Struct.new( :last_modified, :etag, :version_id, :content_type, :server_side_encryption, :ssekms_key_id) SENSITIVE = [] include Aws::Structure end |
#server_side_encryption ⇒ String
If the object is stored using server-side encryption, the value of the server-side encryption algorithm used when storing this object in Amazon S3.
18741 18742 18743 18744 18745 18746 18747 18748 18749 18750 |
# File 'lib/aws-sdk-securityhub/types.rb', line 18741 class AwsS3ObjectDetails < Struct.new( :last_modified, :etag, :version_id, :content_type, :server_side_encryption, :ssekms_key_id) SENSITIVE = [] include Aws::Structure end |
#ssekms_key_id ⇒ String
The identifier of the KMS symmetric customer managed key that was used for the object.
18741 18742 18743 18744 18745 18746 18747 18748 18749 18750 |
# File 'lib/aws-sdk-securityhub/types.rb', line 18741 class AwsS3ObjectDetails < Struct.new( :last_modified, :etag, :version_id, :content_type, :server_side_encryption, :ssekms_key_id) SENSITIVE = [] include Aws::Structure end |
#version_id ⇒ String
The version of the object.
18741 18742 18743 18744 18745 18746 18747 18748 18749 18750 |
# File 'lib/aws-sdk-securityhub/types.rb', line 18741 class AwsS3ObjectDetails < Struct.new( :last_modified, :etag, :version_id, :content_type, :server_side_encryption, :ssekms_key_id) SENSITIVE = [] include Aws::Structure end |