Class: Aws::SecurityHub::Types::AwsSageMakerNotebookInstanceDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::AwsSageMakerNotebookInstanceDetails
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Provides details about an Amazon SageMaker AI notebook instance.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#accelerator_types ⇒ Array<String>
A list of Amazon Elastic Inference instance types to associate with the notebook instance.
-
#additional_code_repositories ⇒ Array<String>
An array of up to three Git repositories associated with the notebook instance.
-
#default_code_repository ⇒ String
The Git repository associated with the notebook instance as its default code repository.
-
#direct_internet_access ⇒ String
Sets whether SageMaker AI provides internet access to the notebook instance.
-
#failure_reason ⇒ String
If status of the instance is
Failed, the reason it failed. -
#instance_metadata_service_configuration ⇒ Types::AwsSageMakerNotebookInstanceMetadataServiceConfigurationDetails
Information on the IMDS configuration of the notebook instance.
-
#instance_type ⇒ String
The type of machine learning (ML) compute instance to launch for the notebook instance.
-
#kms_key_id ⇒ String
The Amazon Resource Name (ARN) of an Key Management Service (KMS) key that SageMaker AI uses to encrypt data on the storage volume attached to your notebook instance.
-
#network_interface_id ⇒ String
The network interface ID that SageMaker AI created when the instance was created.
-
#notebook_instance_arn ⇒ String
The Amazon Resource Name (ARN) of the notebook instance.
-
#notebook_instance_lifecycle_config_name ⇒ String
The name of a notebook instance lifecycle configuration.
-
#notebook_instance_name ⇒ String
The name of the new notebook instance.
-
#notebook_instance_status ⇒ String
The status of the notebook instance.
-
#platform_identifier ⇒ String
The platform identifier of the notebook instance runtime environment.
-
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role associated with the instance.
-
#root_access ⇒ String
Whether root access is enabled or disabled for users of the notebook instance.
-
#security_groups ⇒ Array<String>
The VPC security group IDs.
-
#subnet_id ⇒ String
The ID of the VPC subnet to which you have a connectivity from your ML compute instance.
-
#url ⇒ String
The URL that you use to connect to the Jupyter notebook that is running in your notebook instance.
-
#volume_size_in_gb ⇒ Integer
The size, in GB, of the ML storage volume to attach to the notebook instance.
Instance Attribute Details
#accelerator_types ⇒ Array<String>
A list of Amazon Elastic Inference instance types to associate with the notebook instance. Currently, only one instance type can be associated with a notebook instance.
19012 19013 19014 19015 19016 19017 19018 19019 19020 19021 19022 19023 19024 19025 19026 19027 19028 19029 19030 19031 19032 19033 19034 19035 |
# File 'lib/aws-sdk-securityhub/types.rb', line 19012 class AwsSageMakerNotebookInstanceDetails < Struct.new( :accelerator_types, :additional_code_repositories, :default_code_repository, :direct_internet_access, :failure_reason, :instance_metadata_service_configuration, :instance_type, :kms_key_id, :network_interface_id, :notebook_instance_arn, :notebook_instance_lifecycle_config_name, :notebook_instance_name, :notebook_instance_status, :platform_identifier, :role_arn, :root_access, :security_groups, :subnet_id, :url, :volume_size_in_gb) SENSITIVE = [] include Aws::Structure end |
#additional_code_repositories ⇒ Array<String>
An array of up to three Git repositories associated with the notebook instance. These can be either the names of Git repositories stored as resources in your account, or the URL of Git repositories in CodeCommit or in any other Git repository. These repositories are cloned at the same level as the default repository of your notebook instance. For more information, see Associating Git repositories with SageMaker AI notebook instances in the Amazon SageMaker AI Developer Guide.
19012 19013 19014 19015 19016 19017 19018 19019 19020 19021 19022 19023 19024 19025 19026 19027 19028 19029 19030 19031 19032 19033 19034 19035 |
# File 'lib/aws-sdk-securityhub/types.rb', line 19012 class AwsSageMakerNotebookInstanceDetails < Struct.new( :accelerator_types, :additional_code_repositories, :default_code_repository, :direct_internet_access, :failure_reason, :instance_metadata_service_configuration, :instance_type, :kms_key_id, :network_interface_id, :notebook_instance_arn, :notebook_instance_lifecycle_config_name, :notebook_instance_name, :notebook_instance_status, :platform_identifier, :role_arn, :root_access, :security_groups, :subnet_id, :url, :volume_size_in_gb) SENSITIVE = [] include Aws::Structure end |
#default_code_repository ⇒ String
The Git repository associated with the notebook instance as its default code repository. This can be either the name of a Git repository stored as a resource in your account, or the URL of a Git repository in CodeCommit or in any other Git repository. When you open a notebook instance, it opens in the directory that contains this repository. For more information, see Associating Git repositories with SageMaker AI notebook instances in the Amazon SageMaker AI Developer Guide.
19012 19013 19014 19015 19016 19017 19018 19019 19020 19021 19022 19023 19024 19025 19026 19027 19028 19029 19030 19031 19032 19033 19034 19035 |
# File 'lib/aws-sdk-securityhub/types.rb', line 19012 class AwsSageMakerNotebookInstanceDetails < Struct.new( :accelerator_types, :additional_code_repositories, :default_code_repository, :direct_internet_access, :failure_reason, :instance_metadata_service_configuration, :instance_type, :kms_key_id, :network_interface_id, :notebook_instance_arn, :notebook_instance_lifecycle_config_name, :notebook_instance_name, :notebook_instance_status, :platform_identifier, :role_arn, :root_access, :security_groups, :subnet_id, :url, :volume_size_in_gb) SENSITIVE = [] include Aws::Structure end |
#direct_internet_access ⇒ String
Sets whether SageMaker AI provides internet access to the notebook
instance. If you set this to Disabled, this notebook instance is
able to access resources only in your VPC, and is not be able to
connect to SageMaker AI training and endpoint services unless you
configure a Network Address Translation (NAT) Gateway in your VPC.
19012 19013 19014 19015 19016 19017 19018 19019 19020 19021 19022 19023 19024 19025 19026 19027 19028 19029 19030 19031 19032 19033 19034 19035 |
# File 'lib/aws-sdk-securityhub/types.rb', line 19012 class AwsSageMakerNotebookInstanceDetails < Struct.new( :accelerator_types, :additional_code_repositories, :default_code_repository, :direct_internet_access, :failure_reason, :instance_metadata_service_configuration, :instance_type, :kms_key_id, :network_interface_id, :notebook_instance_arn, :notebook_instance_lifecycle_config_name, :notebook_instance_name, :notebook_instance_status, :platform_identifier, :role_arn, :root_access, :security_groups, :subnet_id, :url, :volume_size_in_gb) SENSITIVE = [] include Aws::Structure end |
#failure_reason ⇒ String
If status of the instance is Failed, the reason it failed.
19012 19013 19014 19015 19016 19017 19018 19019 19020 19021 19022 19023 19024 19025 19026 19027 19028 19029 19030 19031 19032 19033 19034 19035 |
# File 'lib/aws-sdk-securityhub/types.rb', line 19012 class AwsSageMakerNotebookInstanceDetails < Struct.new( :accelerator_types, :additional_code_repositories, :default_code_repository, :direct_internet_access, :failure_reason, :instance_metadata_service_configuration, :instance_type, :kms_key_id, :network_interface_id, :notebook_instance_arn, :notebook_instance_lifecycle_config_name, :notebook_instance_name, :notebook_instance_status, :platform_identifier, :role_arn, :root_access, :security_groups, :subnet_id, :url, :volume_size_in_gb) SENSITIVE = [] include Aws::Structure end |
#instance_metadata_service_configuration ⇒ Types::AwsSageMakerNotebookInstanceMetadataServiceConfigurationDetails
Information on the IMDS configuration of the notebook instance.
19012 19013 19014 19015 19016 19017 19018 19019 19020 19021 19022 19023 19024 19025 19026 19027 19028 19029 19030 19031 19032 19033 19034 19035 |
# File 'lib/aws-sdk-securityhub/types.rb', line 19012 class AwsSageMakerNotebookInstanceDetails < Struct.new( :accelerator_types, :additional_code_repositories, :default_code_repository, :direct_internet_access, :failure_reason, :instance_metadata_service_configuration, :instance_type, :kms_key_id, :network_interface_id, :notebook_instance_arn, :notebook_instance_lifecycle_config_name, :notebook_instance_name, :notebook_instance_status, :platform_identifier, :role_arn, :root_access, :security_groups, :subnet_id, :url, :volume_size_in_gb) SENSITIVE = [] include Aws::Structure end |
#instance_type ⇒ String
The type of machine learning (ML) compute instance to launch for the notebook instance.
19012 19013 19014 19015 19016 19017 19018 19019 19020 19021 19022 19023 19024 19025 19026 19027 19028 19029 19030 19031 19032 19033 19034 19035 |
# File 'lib/aws-sdk-securityhub/types.rb', line 19012 class AwsSageMakerNotebookInstanceDetails < Struct.new( :accelerator_types, :additional_code_repositories, :default_code_repository, :direct_internet_access, :failure_reason, :instance_metadata_service_configuration, :instance_type, :kms_key_id, :network_interface_id, :notebook_instance_arn, :notebook_instance_lifecycle_config_name, :notebook_instance_name, :notebook_instance_status, :platform_identifier, :role_arn, :root_access, :security_groups, :subnet_id, :url, :volume_size_in_gb) SENSITIVE = [] include Aws::Structure end |
#kms_key_id ⇒ String
The Amazon Resource Name (ARN) of an Key Management Service (KMS) key that SageMaker AI uses to encrypt data on the storage volume attached to your notebook instance. The KMS key you provide must be enabled. For information, see Enabling and disabling keys in the Key Management Service Developer Guide.
19012 19013 19014 19015 19016 19017 19018 19019 19020 19021 19022 19023 19024 19025 19026 19027 19028 19029 19030 19031 19032 19033 19034 19035 |
# File 'lib/aws-sdk-securityhub/types.rb', line 19012 class AwsSageMakerNotebookInstanceDetails < Struct.new( :accelerator_types, :additional_code_repositories, :default_code_repository, :direct_internet_access, :failure_reason, :instance_metadata_service_configuration, :instance_type, :kms_key_id, :network_interface_id, :notebook_instance_arn, :notebook_instance_lifecycle_config_name, :notebook_instance_name, :notebook_instance_status, :platform_identifier, :role_arn, :root_access, :security_groups, :subnet_id, :url, :volume_size_in_gb) SENSITIVE = [] include Aws::Structure end |
#network_interface_id ⇒ String
The network interface ID that SageMaker AI created when the instance was created.
19012 19013 19014 19015 19016 19017 19018 19019 19020 19021 19022 19023 19024 19025 19026 19027 19028 19029 19030 19031 19032 19033 19034 19035 |
# File 'lib/aws-sdk-securityhub/types.rb', line 19012 class AwsSageMakerNotebookInstanceDetails < Struct.new( :accelerator_types, :additional_code_repositories, :default_code_repository, :direct_internet_access, :failure_reason, :instance_metadata_service_configuration, :instance_type, :kms_key_id, :network_interface_id, :notebook_instance_arn, :notebook_instance_lifecycle_config_name, :notebook_instance_name, :notebook_instance_status, :platform_identifier, :role_arn, :root_access, :security_groups, :subnet_id, :url, :volume_size_in_gb) SENSITIVE = [] include Aws::Structure end |
#notebook_instance_arn ⇒ String
The Amazon Resource Name (ARN) of the notebook instance.
19012 19013 19014 19015 19016 19017 19018 19019 19020 19021 19022 19023 19024 19025 19026 19027 19028 19029 19030 19031 19032 19033 19034 19035 |
# File 'lib/aws-sdk-securityhub/types.rb', line 19012 class AwsSageMakerNotebookInstanceDetails < Struct.new( :accelerator_types, :additional_code_repositories, :default_code_repository, :direct_internet_access, :failure_reason, :instance_metadata_service_configuration, :instance_type, :kms_key_id, :network_interface_id, :notebook_instance_arn, :notebook_instance_lifecycle_config_name, :notebook_instance_name, :notebook_instance_status, :platform_identifier, :role_arn, :root_access, :security_groups, :subnet_id, :url, :volume_size_in_gb) SENSITIVE = [] include Aws::Structure end |
#notebook_instance_lifecycle_config_name ⇒ String
The name of a notebook instance lifecycle configuration.
19012 19013 19014 19015 19016 19017 19018 19019 19020 19021 19022 19023 19024 19025 19026 19027 19028 19029 19030 19031 19032 19033 19034 19035 |
# File 'lib/aws-sdk-securityhub/types.rb', line 19012 class AwsSageMakerNotebookInstanceDetails < Struct.new( :accelerator_types, :additional_code_repositories, :default_code_repository, :direct_internet_access, :failure_reason, :instance_metadata_service_configuration, :instance_type, :kms_key_id, :network_interface_id, :notebook_instance_arn, :notebook_instance_lifecycle_config_name, :notebook_instance_name, :notebook_instance_status, :platform_identifier, :role_arn, :root_access, :security_groups, :subnet_id, :url, :volume_size_in_gb) SENSITIVE = [] include Aws::Structure end |
#notebook_instance_name ⇒ String
The name of the new notebook instance.
19012 19013 19014 19015 19016 19017 19018 19019 19020 19021 19022 19023 19024 19025 19026 19027 19028 19029 19030 19031 19032 19033 19034 19035 |
# File 'lib/aws-sdk-securityhub/types.rb', line 19012 class AwsSageMakerNotebookInstanceDetails < Struct.new( :accelerator_types, :additional_code_repositories, :default_code_repository, :direct_internet_access, :failure_reason, :instance_metadata_service_configuration, :instance_type, :kms_key_id, :network_interface_id, :notebook_instance_arn, :notebook_instance_lifecycle_config_name, :notebook_instance_name, :notebook_instance_status, :platform_identifier, :role_arn, :root_access, :security_groups, :subnet_id, :url, :volume_size_in_gb) SENSITIVE = [] include Aws::Structure end |
#notebook_instance_status ⇒ String
The status of the notebook instance.
19012 19013 19014 19015 19016 19017 19018 19019 19020 19021 19022 19023 19024 19025 19026 19027 19028 19029 19030 19031 19032 19033 19034 19035 |
# File 'lib/aws-sdk-securityhub/types.rb', line 19012 class AwsSageMakerNotebookInstanceDetails < Struct.new( :accelerator_types, :additional_code_repositories, :default_code_repository, :direct_internet_access, :failure_reason, :instance_metadata_service_configuration, :instance_type, :kms_key_id, :network_interface_id, :notebook_instance_arn, :notebook_instance_lifecycle_config_name, :notebook_instance_name, :notebook_instance_status, :platform_identifier, :role_arn, :root_access, :security_groups, :subnet_id, :url, :volume_size_in_gb) SENSITIVE = [] include Aws::Structure end |
#platform_identifier ⇒ String
The platform identifier of the notebook instance runtime environment.
19012 19013 19014 19015 19016 19017 19018 19019 19020 19021 19022 19023 19024 19025 19026 19027 19028 19029 19030 19031 19032 19033 19034 19035 |
# File 'lib/aws-sdk-securityhub/types.rb', line 19012 class AwsSageMakerNotebookInstanceDetails < Struct.new( :accelerator_types, :additional_code_repositories, :default_code_repository, :direct_internet_access, :failure_reason, :instance_metadata_service_configuration, :instance_type, :kms_key_id, :network_interface_id, :notebook_instance_arn, :notebook_instance_lifecycle_config_name, :notebook_instance_name, :notebook_instance_status, :platform_identifier, :role_arn, :root_access, :security_groups, :subnet_id, :url, :volume_size_in_gb) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role associated with the instance.
19012 19013 19014 19015 19016 19017 19018 19019 19020 19021 19022 19023 19024 19025 19026 19027 19028 19029 19030 19031 19032 19033 19034 19035 |
# File 'lib/aws-sdk-securityhub/types.rb', line 19012 class AwsSageMakerNotebookInstanceDetails < Struct.new( :accelerator_types, :additional_code_repositories, :default_code_repository, :direct_internet_access, :failure_reason, :instance_metadata_service_configuration, :instance_type, :kms_key_id, :network_interface_id, :notebook_instance_arn, :notebook_instance_lifecycle_config_name, :notebook_instance_name, :notebook_instance_status, :platform_identifier, :role_arn, :root_access, :security_groups, :subnet_id, :url, :volume_size_in_gb) SENSITIVE = [] include Aws::Structure end |
#root_access ⇒ String
Whether root access is enabled or disabled for users of the notebook instance.
19012 19013 19014 19015 19016 19017 19018 19019 19020 19021 19022 19023 19024 19025 19026 19027 19028 19029 19030 19031 19032 19033 19034 19035 |
# File 'lib/aws-sdk-securityhub/types.rb', line 19012 class AwsSageMakerNotebookInstanceDetails < Struct.new( :accelerator_types, :additional_code_repositories, :default_code_repository, :direct_internet_access, :failure_reason, :instance_metadata_service_configuration, :instance_type, :kms_key_id, :network_interface_id, :notebook_instance_arn, :notebook_instance_lifecycle_config_name, :notebook_instance_name, :notebook_instance_status, :platform_identifier, :role_arn, :root_access, :security_groups, :subnet_id, :url, :volume_size_in_gb) SENSITIVE = [] include Aws::Structure end |
#security_groups ⇒ Array<String>
The VPC security group IDs.
19012 19013 19014 19015 19016 19017 19018 19019 19020 19021 19022 19023 19024 19025 19026 19027 19028 19029 19030 19031 19032 19033 19034 19035 |
# File 'lib/aws-sdk-securityhub/types.rb', line 19012 class AwsSageMakerNotebookInstanceDetails < Struct.new( :accelerator_types, :additional_code_repositories, :default_code_repository, :direct_internet_access, :failure_reason, :instance_metadata_service_configuration, :instance_type, :kms_key_id, :network_interface_id, :notebook_instance_arn, :notebook_instance_lifecycle_config_name, :notebook_instance_name, :notebook_instance_status, :platform_identifier, :role_arn, :root_access, :security_groups, :subnet_id, :url, :volume_size_in_gb) SENSITIVE = [] include Aws::Structure end |
#subnet_id ⇒ String
The ID of the VPC subnet to which you have a connectivity from your ML compute instance.
19012 19013 19014 19015 19016 19017 19018 19019 19020 19021 19022 19023 19024 19025 19026 19027 19028 19029 19030 19031 19032 19033 19034 19035 |
# File 'lib/aws-sdk-securityhub/types.rb', line 19012 class AwsSageMakerNotebookInstanceDetails < Struct.new( :accelerator_types, :additional_code_repositories, :default_code_repository, :direct_internet_access, :failure_reason, :instance_metadata_service_configuration, :instance_type, :kms_key_id, :network_interface_id, :notebook_instance_arn, :notebook_instance_lifecycle_config_name, :notebook_instance_name, :notebook_instance_status, :platform_identifier, :role_arn, :root_access, :security_groups, :subnet_id, :url, :volume_size_in_gb) SENSITIVE = [] include Aws::Structure end |
#url ⇒ String
The URL that you use to connect to the Jupyter notebook that is running in your notebook instance.
19012 19013 19014 19015 19016 19017 19018 19019 19020 19021 19022 19023 19024 19025 19026 19027 19028 19029 19030 19031 19032 19033 19034 19035 |
# File 'lib/aws-sdk-securityhub/types.rb', line 19012 class AwsSageMakerNotebookInstanceDetails < Struct.new( :accelerator_types, :additional_code_repositories, :default_code_repository, :direct_internet_access, :failure_reason, :instance_metadata_service_configuration, :instance_type, :kms_key_id, :network_interface_id, :notebook_instance_arn, :notebook_instance_lifecycle_config_name, :notebook_instance_name, :notebook_instance_status, :platform_identifier, :role_arn, :root_access, :security_groups, :subnet_id, :url, :volume_size_in_gb) SENSITIVE = [] include Aws::Structure end |
#volume_size_in_gb ⇒ Integer
The size, in GB, of the ML storage volume to attach to the notebook instance.
19012 19013 19014 19015 19016 19017 19018 19019 19020 19021 19022 19023 19024 19025 19026 19027 19028 19029 19030 19031 19032 19033 19034 19035 |
# File 'lib/aws-sdk-securityhub/types.rb', line 19012 class AwsSageMakerNotebookInstanceDetails < Struct.new( :accelerator_types, :additional_code_repositories, :default_code_repository, :direct_internet_access, :failure_reason, :instance_metadata_service_configuration, :instance_type, :kms_key_id, :network_interface_id, :notebook_instance_arn, :notebook_instance_lifecycle_config_name, :notebook_instance_name, :notebook_instance_status, :platform_identifier, :role_arn, :root_access, :security_groups, :subnet_id, :url, :volume_size_in_gb) SENSITIVE = [] include Aws::Structure end |