Class: Aws::SecurityHub::Types::AwsSecretsManagerSecretDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::AwsSecretsManagerSecretDetails
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Details about an Secrets Manager secret.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#deleted ⇒ Boolean
Whether the secret is deleted.
-
#description ⇒ String
The user-provided description of the secret.
-
#kms_key_id ⇒ String
The ARN, Key ID, or alias of the KMS key used to encrypt the
SecretStringorSecretBinaryvalues for versions of this secret. -
#name ⇒ String
The name of the secret.
-
#rotation_enabled ⇒ Boolean
Whether rotation is enabled.
-
#rotation_lambda_arn ⇒ String
The ARN of the Lambda function that rotates the secret.
-
#rotation_occurred_within_frequency ⇒ Boolean
Whether the rotation occurred within the specified rotation frequency.
-
#rotation_rules ⇒ Types::AwsSecretsManagerSecretRotationRules
Defines the rotation schedule for the secret.
Instance Attribute Details
#deleted ⇒ Boolean
Whether the secret is deleted.
19091 19092 19093 19094 19095 19096 19097 19098 19099 19100 19101 19102 |
# File 'lib/aws-sdk-securityhub/types.rb', line 19091 class AwsSecretsManagerSecretDetails < Struct.new( :rotation_rules, :rotation_occurred_within_frequency, :kms_key_id, :rotation_enabled, :rotation_lambda_arn, :deleted, :name, :description) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The user-provided description of the secret.
19091 19092 19093 19094 19095 19096 19097 19098 19099 19100 19101 19102 |
# File 'lib/aws-sdk-securityhub/types.rb', line 19091 class AwsSecretsManagerSecretDetails < Struct.new( :rotation_rules, :rotation_occurred_within_frequency, :kms_key_id, :rotation_enabled, :rotation_lambda_arn, :deleted, :name, :description) SENSITIVE = [] include Aws::Structure end |
#kms_key_id ⇒ String
The ARN, Key ID, or alias of the KMS key used to encrypt the
SecretString or SecretBinary values for versions of this secret.
19091 19092 19093 19094 19095 19096 19097 19098 19099 19100 19101 19102 |
# File 'lib/aws-sdk-securityhub/types.rb', line 19091 class AwsSecretsManagerSecretDetails < Struct.new( :rotation_rules, :rotation_occurred_within_frequency, :kms_key_id, :rotation_enabled, :rotation_lambda_arn, :deleted, :name, :description) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the secret.
19091 19092 19093 19094 19095 19096 19097 19098 19099 19100 19101 19102 |
# File 'lib/aws-sdk-securityhub/types.rb', line 19091 class AwsSecretsManagerSecretDetails < Struct.new( :rotation_rules, :rotation_occurred_within_frequency, :kms_key_id, :rotation_enabled, :rotation_lambda_arn, :deleted, :name, :description) SENSITIVE = [] include Aws::Structure end |
#rotation_enabled ⇒ Boolean
Whether rotation is enabled.
19091 19092 19093 19094 19095 19096 19097 19098 19099 19100 19101 19102 |
# File 'lib/aws-sdk-securityhub/types.rb', line 19091 class AwsSecretsManagerSecretDetails < Struct.new( :rotation_rules, :rotation_occurred_within_frequency, :kms_key_id, :rotation_enabled, :rotation_lambda_arn, :deleted, :name, :description) SENSITIVE = [] include Aws::Structure end |
#rotation_lambda_arn ⇒ String
The ARN of the Lambda function that rotates the secret.
19091 19092 19093 19094 19095 19096 19097 19098 19099 19100 19101 19102 |
# File 'lib/aws-sdk-securityhub/types.rb', line 19091 class AwsSecretsManagerSecretDetails < Struct.new( :rotation_rules, :rotation_occurred_within_frequency, :kms_key_id, :rotation_enabled, :rotation_lambda_arn, :deleted, :name, :description) SENSITIVE = [] include Aws::Structure end |
#rotation_occurred_within_frequency ⇒ Boolean
Whether the rotation occurred within the specified rotation frequency.
19091 19092 19093 19094 19095 19096 19097 19098 19099 19100 19101 19102 |
# File 'lib/aws-sdk-securityhub/types.rb', line 19091 class AwsSecretsManagerSecretDetails < Struct.new( :rotation_rules, :rotation_occurred_within_frequency, :kms_key_id, :rotation_enabled, :rotation_lambda_arn, :deleted, :name, :description) SENSITIVE = [] include Aws::Structure end |
#rotation_rules ⇒ Types::AwsSecretsManagerSecretRotationRules
Defines the rotation schedule for the secret.
19091 19092 19093 19094 19095 19096 19097 19098 19099 19100 19101 19102 |
# File 'lib/aws-sdk-securityhub/types.rb', line 19091 class AwsSecretsManagerSecretDetails < Struct.new( :rotation_rules, :rotation_occurred_within_frequency, :kms_key_id, :rotation_enabled, :rotation_lambda_arn, :deleted, :name, :description) SENSITIVE = [] include Aws::Structure end |