Class: Aws::SecurityHub::Types::AwsSsmComplianceSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::AwsSsmComplianceSummary
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Provides the details about the compliance status for a patch.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#compliance_type ⇒ String
The type of resource for which the compliance was determined.
-
#compliant_critical_count ⇒ Integer
For the patches that are compliant, the number that have a severity of ‘CRITICAL`.
-
#compliant_high_count ⇒ Integer
For the patches that are compliant, the number that have a severity of ‘HIGH`.
-
#compliant_informational_count ⇒ Integer
For the patches that are compliant, the number that have a severity of ‘INFORMATIONAL`.
-
#compliant_low_count ⇒ Integer
For the patches that are compliant, the number that have a severity of ‘LOW`.
-
#compliant_medium_count ⇒ Integer
For the patches that are compliant, the number that have a severity of ‘MEDIUM`.
-
#compliant_unspecified_count ⇒ Integer
For the patches that are compliant, the number that have a severity of ‘UNSPECIFIED`.
-
#execution_type ⇒ String
The type of execution that was used determine compliance.
-
#non_compliant_critical_count ⇒ Integer
For the patch items that are noncompliant, the number of items that have a severity of ‘CRITICAL`.
-
#non_compliant_high_count ⇒ Integer
For the patches that are noncompliant, the number that have a severity of ‘HIGH`.
-
#non_compliant_informational_count ⇒ Integer
For the patches that are noncompliant, the number that have a severity of ‘INFORMATIONAL`.
-
#non_compliant_low_count ⇒ Integer
For the patches that are noncompliant, the number that have a severity of ‘LOW`.
-
#non_compliant_medium_count ⇒ Integer
For the patches that are noncompliant, the number that have a severity of ‘MEDIUM`.
-
#non_compliant_unspecified_count ⇒ Integer
For the patches that are noncompliant, the number that have a severity of ‘UNSPECIFIED`.
-
#overall_severity ⇒ String
The highest severity for the patches.
-
#patch_baseline_id ⇒ String
The identifier of the patch baseline.
-
#patch_group ⇒ String
The identifier of the patch group for which compliance was determined.
-
#status ⇒ String
The current patch compliance status.
Instance Attribute Details
#compliance_type ⇒ String
The type of resource for which the compliance was determined. For ‘AwsSsmPatchCompliance`, `ComplianceType` is `Patch`.
20336 20337 20338 20339 20340 20341 20342 20343 20344 20345 20346 20347 20348 20349 20350 20351 20352 20353 20354 20355 20356 20357 |
# File 'lib/aws-sdk-securityhub/types.rb', line 20336 class AwsSsmComplianceSummary < Struct.new( :status, :compliant_critical_count, :compliant_high_count, :compliant_medium_count, :execution_type, :non_compliant_critical_count, :compliant_informational_count, :non_compliant_informational_count, :compliant_unspecified_count, :non_compliant_low_count, :non_compliant_high_count, :compliant_low_count, :compliance_type, :patch_baseline_id, :overall_severity, :non_compliant_medium_count, :non_compliant_unspecified_count, :patch_group) SENSITIVE = [] include Aws::Structure end |
#compliant_critical_count ⇒ Integer
For the patches that are compliant, the number that have a severity of ‘CRITICAL`.
20336 20337 20338 20339 20340 20341 20342 20343 20344 20345 20346 20347 20348 20349 20350 20351 20352 20353 20354 20355 20356 20357 |
# File 'lib/aws-sdk-securityhub/types.rb', line 20336 class AwsSsmComplianceSummary < Struct.new( :status, :compliant_critical_count, :compliant_high_count, :compliant_medium_count, :execution_type, :non_compliant_critical_count, :compliant_informational_count, :non_compliant_informational_count, :compliant_unspecified_count, :non_compliant_low_count, :non_compliant_high_count, :compliant_low_count, :compliance_type, :patch_baseline_id, :overall_severity, :non_compliant_medium_count, :non_compliant_unspecified_count, :patch_group) SENSITIVE = [] include Aws::Structure end |
#compliant_high_count ⇒ Integer
For the patches that are compliant, the number that have a severity of ‘HIGH`.
20336 20337 20338 20339 20340 20341 20342 20343 20344 20345 20346 20347 20348 20349 20350 20351 20352 20353 20354 20355 20356 20357 |
# File 'lib/aws-sdk-securityhub/types.rb', line 20336 class AwsSsmComplianceSummary < Struct.new( :status, :compliant_critical_count, :compliant_high_count, :compliant_medium_count, :execution_type, :non_compliant_critical_count, :compliant_informational_count, :non_compliant_informational_count, :compliant_unspecified_count, :non_compliant_low_count, :non_compliant_high_count, :compliant_low_count, :compliance_type, :patch_baseline_id, :overall_severity, :non_compliant_medium_count, :non_compliant_unspecified_count, :patch_group) SENSITIVE = [] include Aws::Structure end |
#compliant_informational_count ⇒ Integer
For the patches that are compliant, the number that have a severity of ‘INFORMATIONAL`.
20336 20337 20338 20339 20340 20341 20342 20343 20344 20345 20346 20347 20348 20349 20350 20351 20352 20353 20354 20355 20356 20357 |
# File 'lib/aws-sdk-securityhub/types.rb', line 20336 class AwsSsmComplianceSummary < Struct.new( :status, :compliant_critical_count, :compliant_high_count, :compliant_medium_count, :execution_type, :non_compliant_critical_count, :compliant_informational_count, :non_compliant_informational_count, :compliant_unspecified_count, :non_compliant_low_count, :non_compliant_high_count, :compliant_low_count, :compliance_type, :patch_baseline_id, :overall_severity, :non_compliant_medium_count, :non_compliant_unspecified_count, :patch_group) SENSITIVE = [] include Aws::Structure end |
#compliant_low_count ⇒ Integer
For the patches that are compliant, the number that have a severity of ‘LOW`.
20336 20337 20338 20339 20340 20341 20342 20343 20344 20345 20346 20347 20348 20349 20350 20351 20352 20353 20354 20355 20356 20357 |
# File 'lib/aws-sdk-securityhub/types.rb', line 20336 class AwsSsmComplianceSummary < Struct.new( :status, :compliant_critical_count, :compliant_high_count, :compliant_medium_count, :execution_type, :non_compliant_critical_count, :compliant_informational_count, :non_compliant_informational_count, :compliant_unspecified_count, :non_compliant_low_count, :non_compliant_high_count, :compliant_low_count, :compliance_type, :patch_baseline_id, :overall_severity, :non_compliant_medium_count, :non_compliant_unspecified_count, :patch_group) SENSITIVE = [] include Aws::Structure end |
#compliant_medium_count ⇒ Integer
For the patches that are compliant, the number that have a severity of ‘MEDIUM`.
20336 20337 20338 20339 20340 20341 20342 20343 20344 20345 20346 20347 20348 20349 20350 20351 20352 20353 20354 20355 20356 20357 |
# File 'lib/aws-sdk-securityhub/types.rb', line 20336 class AwsSsmComplianceSummary < Struct.new( :status, :compliant_critical_count, :compliant_high_count, :compliant_medium_count, :execution_type, :non_compliant_critical_count, :compliant_informational_count, :non_compliant_informational_count, :compliant_unspecified_count, :non_compliant_low_count, :non_compliant_high_count, :compliant_low_count, :compliance_type, :patch_baseline_id, :overall_severity, :non_compliant_medium_count, :non_compliant_unspecified_count, :patch_group) SENSITIVE = [] include Aws::Structure end |
#compliant_unspecified_count ⇒ Integer
For the patches that are compliant, the number that have a severity of ‘UNSPECIFIED`.
20336 20337 20338 20339 20340 20341 20342 20343 20344 20345 20346 20347 20348 20349 20350 20351 20352 20353 20354 20355 20356 20357 |
# File 'lib/aws-sdk-securityhub/types.rb', line 20336 class AwsSsmComplianceSummary < Struct.new( :status, :compliant_critical_count, :compliant_high_count, :compliant_medium_count, :execution_type, :non_compliant_critical_count, :compliant_informational_count, :non_compliant_informational_count, :compliant_unspecified_count, :non_compliant_low_count, :non_compliant_high_count, :compliant_low_count, :compliance_type, :patch_baseline_id, :overall_severity, :non_compliant_medium_count, :non_compliant_unspecified_count, :patch_group) SENSITIVE = [] include Aws::Structure end |
#execution_type ⇒ String
The type of execution that was used determine compliance.
20336 20337 20338 20339 20340 20341 20342 20343 20344 20345 20346 20347 20348 20349 20350 20351 20352 20353 20354 20355 20356 20357 |
# File 'lib/aws-sdk-securityhub/types.rb', line 20336 class AwsSsmComplianceSummary < Struct.new( :status, :compliant_critical_count, :compliant_high_count, :compliant_medium_count, :execution_type, :non_compliant_critical_count, :compliant_informational_count, :non_compliant_informational_count, :compliant_unspecified_count, :non_compliant_low_count, :non_compliant_high_count, :compliant_low_count, :compliance_type, :patch_baseline_id, :overall_severity, :non_compliant_medium_count, :non_compliant_unspecified_count, :patch_group) SENSITIVE = [] include Aws::Structure end |
#non_compliant_critical_count ⇒ Integer
For the patch items that are noncompliant, the number of items that have a severity of ‘CRITICAL`.
20336 20337 20338 20339 20340 20341 20342 20343 20344 20345 20346 20347 20348 20349 20350 20351 20352 20353 20354 20355 20356 20357 |
# File 'lib/aws-sdk-securityhub/types.rb', line 20336 class AwsSsmComplianceSummary < Struct.new( :status, :compliant_critical_count, :compliant_high_count, :compliant_medium_count, :execution_type, :non_compliant_critical_count, :compliant_informational_count, :non_compliant_informational_count, :compliant_unspecified_count, :non_compliant_low_count, :non_compliant_high_count, :compliant_low_count, :compliance_type, :patch_baseline_id, :overall_severity, :non_compliant_medium_count, :non_compliant_unspecified_count, :patch_group) SENSITIVE = [] include Aws::Structure end |
#non_compliant_high_count ⇒ Integer
For the patches that are noncompliant, the number that have a severity of ‘HIGH`.
20336 20337 20338 20339 20340 20341 20342 20343 20344 20345 20346 20347 20348 20349 20350 20351 20352 20353 20354 20355 20356 20357 |
# File 'lib/aws-sdk-securityhub/types.rb', line 20336 class AwsSsmComplianceSummary < Struct.new( :status, :compliant_critical_count, :compliant_high_count, :compliant_medium_count, :execution_type, :non_compliant_critical_count, :compliant_informational_count, :non_compliant_informational_count, :compliant_unspecified_count, :non_compliant_low_count, :non_compliant_high_count, :compliant_low_count, :compliance_type, :patch_baseline_id, :overall_severity, :non_compliant_medium_count, :non_compliant_unspecified_count, :patch_group) SENSITIVE = [] include Aws::Structure end |
#non_compliant_informational_count ⇒ Integer
For the patches that are noncompliant, the number that have a severity of ‘INFORMATIONAL`.
20336 20337 20338 20339 20340 20341 20342 20343 20344 20345 20346 20347 20348 20349 20350 20351 20352 20353 20354 20355 20356 20357 |
# File 'lib/aws-sdk-securityhub/types.rb', line 20336 class AwsSsmComplianceSummary < Struct.new( :status, :compliant_critical_count, :compliant_high_count, :compliant_medium_count, :execution_type, :non_compliant_critical_count, :compliant_informational_count, :non_compliant_informational_count, :compliant_unspecified_count, :non_compliant_low_count, :non_compliant_high_count, :compliant_low_count, :compliance_type, :patch_baseline_id, :overall_severity, :non_compliant_medium_count, :non_compliant_unspecified_count, :patch_group) SENSITIVE = [] include Aws::Structure end |
#non_compliant_low_count ⇒ Integer
For the patches that are noncompliant, the number that have a severity of ‘LOW`.
20336 20337 20338 20339 20340 20341 20342 20343 20344 20345 20346 20347 20348 20349 20350 20351 20352 20353 20354 20355 20356 20357 |
# File 'lib/aws-sdk-securityhub/types.rb', line 20336 class AwsSsmComplianceSummary < Struct.new( :status, :compliant_critical_count, :compliant_high_count, :compliant_medium_count, :execution_type, :non_compliant_critical_count, :compliant_informational_count, :non_compliant_informational_count, :compliant_unspecified_count, :non_compliant_low_count, :non_compliant_high_count, :compliant_low_count, :compliance_type, :patch_baseline_id, :overall_severity, :non_compliant_medium_count, :non_compliant_unspecified_count, :patch_group) SENSITIVE = [] include Aws::Structure end |
#non_compliant_medium_count ⇒ Integer
For the patches that are noncompliant, the number that have a severity of ‘MEDIUM`.
20336 20337 20338 20339 20340 20341 20342 20343 20344 20345 20346 20347 20348 20349 20350 20351 20352 20353 20354 20355 20356 20357 |
# File 'lib/aws-sdk-securityhub/types.rb', line 20336 class AwsSsmComplianceSummary < Struct.new( :status, :compliant_critical_count, :compliant_high_count, :compliant_medium_count, :execution_type, :non_compliant_critical_count, :compliant_informational_count, :non_compliant_informational_count, :compliant_unspecified_count, :non_compliant_low_count, :non_compliant_high_count, :compliant_low_count, :compliance_type, :patch_baseline_id, :overall_severity, :non_compliant_medium_count, :non_compliant_unspecified_count, :patch_group) SENSITIVE = [] include Aws::Structure end |
#non_compliant_unspecified_count ⇒ Integer
For the patches that are noncompliant, the number that have a severity of ‘UNSPECIFIED`.
20336 20337 20338 20339 20340 20341 20342 20343 20344 20345 20346 20347 20348 20349 20350 20351 20352 20353 20354 20355 20356 20357 |
# File 'lib/aws-sdk-securityhub/types.rb', line 20336 class AwsSsmComplianceSummary < Struct.new( :status, :compliant_critical_count, :compliant_high_count, :compliant_medium_count, :execution_type, :non_compliant_critical_count, :compliant_informational_count, :non_compliant_informational_count, :compliant_unspecified_count, :non_compliant_low_count, :non_compliant_high_count, :compliant_low_count, :compliance_type, :patch_baseline_id, :overall_severity, :non_compliant_medium_count, :non_compliant_unspecified_count, :patch_group) SENSITIVE = [] include Aws::Structure end |
#overall_severity ⇒ String
The highest severity for the patches. Valid values are as follows:
-
‘CRITICAL`
-
‘HIGH`
-
‘MEDIUM`
-
‘LOW`
-
‘INFORMATIONAL`
-
‘UNSPECIFIED`
20336 20337 20338 20339 20340 20341 20342 20343 20344 20345 20346 20347 20348 20349 20350 20351 20352 20353 20354 20355 20356 20357 |
# File 'lib/aws-sdk-securityhub/types.rb', line 20336 class AwsSsmComplianceSummary < Struct.new( :status, :compliant_critical_count, :compliant_high_count, :compliant_medium_count, :execution_type, :non_compliant_critical_count, :compliant_informational_count, :non_compliant_informational_count, :compliant_unspecified_count, :non_compliant_low_count, :non_compliant_high_count, :compliant_low_count, :compliance_type, :patch_baseline_id, :overall_severity, :non_compliant_medium_count, :non_compliant_unspecified_count, :patch_group) SENSITIVE = [] include Aws::Structure end |
#patch_baseline_id ⇒ String
The identifier of the patch baseline. The patch baseline lists the patches that are approved for installation.
20336 20337 20338 20339 20340 20341 20342 20343 20344 20345 20346 20347 20348 20349 20350 20351 20352 20353 20354 20355 20356 20357 |
# File 'lib/aws-sdk-securityhub/types.rb', line 20336 class AwsSsmComplianceSummary < Struct.new( :status, :compliant_critical_count, :compliant_high_count, :compliant_medium_count, :execution_type, :non_compliant_critical_count, :compliant_informational_count, :non_compliant_informational_count, :compliant_unspecified_count, :non_compliant_low_count, :non_compliant_high_count, :compliant_low_count, :compliance_type, :patch_baseline_id, :overall_severity, :non_compliant_medium_count, :non_compliant_unspecified_count, :patch_group) SENSITIVE = [] include Aws::Structure end |
#patch_group ⇒ String
The identifier of the patch group for which compliance was determined. A patch group uses tags to group EC2 instances that should have the same patch compliance.
20336 20337 20338 20339 20340 20341 20342 20343 20344 20345 20346 20347 20348 20349 20350 20351 20352 20353 20354 20355 20356 20357 |
# File 'lib/aws-sdk-securityhub/types.rb', line 20336 class AwsSsmComplianceSummary < Struct.new( :status, :compliant_critical_count, :compliant_high_count, :compliant_medium_count, :execution_type, :non_compliant_critical_count, :compliant_informational_count, :non_compliant_informational_count, :compliant_unspecified_count, :non_compliant_low_count, :non_compliant_high_count, :compliant_low_count, :compliance_type, :patch_baseline_id, :overall_severity, :non_compliant_medium_count, :non_compliant_unspecified_count, :patch_group) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current patch compliance status. Valid values are as follows:
-
‘COMPLIANT`
-
‘NON_COMPLIANT`
-
‘UNSPECIFIED_DATA`
20336 20337 20338 20339 20340 20341 20342 20343 20344 20345 20346 20347 20348 20349 20350 20351 20352 20353 20354 20355 20356 20357 |
# File 'lib/aws-sdk-securityhub/types.rb', line 20336 class AwsSsmComplianceSummary < Struct.new( :status, :compliant_critical_count, :compliant_high_count, :compliant_medium_count, :execution_type, :non_compliant_critical_count, :compliant_informational_count, :non_compliant_informational_count, :compliant_unspecified_count, :non_compliant_low_count, :non_compliant_high_count, :compliant_low_count, :compliance_type, :patch_baseline_id, :overall_severity, :non_compliant_medium_count, :non_compliant_unspecified_count, :patch_group) SENSITIVE = [] include Aws::Structure end |