Method: Aws::SecurityHub::Types::AwsWafRegionalRuleGroupRulesActionDetails#type

Defined in:
lib/aws-sdk-securityhub/types.rb

#typeString

Specifies the ByteMatchSet, IPSet, SqlInjectionMatchSet, XssMatchSet, RegexMatchSet, GeoMatchSet, and SizeConstraintSet objects that you want to add to a rule and, for each object, indicates whether you want to negate the settings.



20740
20741
20742
20743
20744
# File 'lib/aws-sdk-securityhub/types.rb', line 20740

class AwsWafRegionalRuleGroupRulesActionDetails < Struct.new(
  :type)
  SENSITIVE = []
  include Aws::Structure
end