Class: Aws::SecurityHub::Types::AwsWafRuleGroupDetails

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

Provides information about an WAF rule group. A rule group is a collection of rules for inspecting and controlling web requests.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#metric_nameString

The name of the metrics for this rule group.

Returns:

  • (String)


21180
21181
21182
21183
21184
21185
21186
21187
# File 'lib/aws-sdk-securityhub/types.rb', line 21180

class AwsWafRuleGroupDetails < Struct.new(
  :metric_name,
  :name,
  :rule_group_id,
  :rules)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the rule group.

Returns:

  • (String)


21180
21181
21182
21183
21184
21185
21186
21187
# File 'lib/aws-sdk-securityhub/types.rb', line 21180

class AwsWafRuleGroupDetails < Struct.new(
  :metric_name,
  :name,
  :rule_group_id,
  :rules)
  SENSITIVE = []
  include Aws::Structure
end

#rule_group_idString

The ID of the rule group.

Returns:

  • (String)


21180
21181
21182
21183
21184
21185
21186
21187
# File 'lib/aws-sdk-securityhub/types.rb', line 21180

class AwsWafRuleGroupDetails < Struct.new(
  :metric_name,
  :name,
  :rule_group_id,
  :rules)
  SENSITIVE = []
  include Aws::Structure
end

#rulesArray<Types::AwsWafRuleGroupRulesDetails>

Provides information about the rules attached to the rule group. These rules identify the web requests that you want to allow, block, or count.



21180
21181
21182
21183
21184
21185
21186
21187
# File 'lib/aws-sdk-securityhub/types.rb', line 21180

class AwsWafRuleGroupDetails < Struct.new(
  :metric_name,
  :name,
  :rule_group_id,
  :rules)
  SENSITIVE = []
  include Aws::Structure
end