Class: Aws::SecurityHub::Types::AwsWafRulePredicateListDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::AwsWafRulePredicateListDetails
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Provides details about the ByteMatchSet, IPSet,
SqlInjectionMatchSet, XssMatchSet, RegexMatchSet, GeoMatchSet,
and SizeConstraintSet objects that you want to add to a rule and,
for each object, indicates whether you want to negate the settings.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#data_id ⇒ String
A unique identifier for a predicate in a rule, such as
ByteMatchSetIdorIPSetId. -
#negated ⇒ Boolean
Specifies if you want WAF to allow, block, or count requests based on the settings in the
ByteMatchSet,IPSet,SqlInjectionMatchSet,XssMatchSet,RegexMatchSet,GeoMatchSet, orSizeConstraintSet. -
#type ⇒ String
The type of predicate in a rule, such as
ByteMatchorIPSet.
Instance Attribute Details
#data_id ⇒ String
A unique identifier for a predicate in a rule, such as
ByteMatchSetId or IPSetId.
21261 21262 21263 21264 21265 21266 21267 |
# File 'lib/aws-sdk-securityhub/types.rb', line 21261 class AwsWafRulePredicateListDetails < Struct.new( :data_id, :negated, :type) SENSITIVE = [] include Aws::Structure end |
#negated ⇒ Boolean
Specifies if you want WAF to allow, block, or count requests based
on the settings in the ByteMatchSet, IPSet,
SqlInjectionMatchSet, XssMatchSet, RegexMatchSet,
GeoMatchSet, or SizeConstraintSet.
21261 21262 21263 21264 21265 21266 21267 |
# File 'lib/aws-sdk-securityhub/types.rb', line 21261 class AwsWafRulePredicateListDetails < Struct.new( :data_id, :negated, :type) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of predicate in a rule, such as ByteMatch or IPSet.
21261 21262 21263 21264 21265 21266 21267 |
# File 'lib/aws-sdk-securityhub/types.rb', line 21261 class AwsWafRulePredicateListDetails < Struct.new( :data_id, :negated, :type) SENSITIVE = [] include Aws::Structure end |