Class: Aws::SecurityHub::Types::AwsWafv2ActionAllowDetails

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

Specifies that WAF should allow the request and optionally defines additional custom handling for the request.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#custom_request_handlingTypes::AwsWafv2CustomRequestHandlingDetails

Defines custom handling for the web request. For information about customizing web requests and responses, see Customizing web requests and responses in WAF in the WAF Developer Guide..



21381
21382
21383
21384
21385
# File 'lib/aws-sdk-securityhub/types.rb', line 21381

class AwsWafv2ActionAllowDetails < Struct.new(
  :custom_request_handling)
  SENSITIVE = []
  include Aws::Structure
end