Class: Aws::SecurityHub::Types::AwsWafv2CustomResponseDetails

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

A custom response to send to the client. You can define a custom response for rule actions and default web ACL actions that are set to block.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#custom_response_body_keyString

References the response body that you want WAF to return to the web request client. You can define a custom response for a rule action or a default web ACL action that is set to block.



21469
21470
21471
21472
21473
21474
21475
# File 'lib/aws-sdk-securityhub/types.rb', line 21469

class AwsWafv2CustomResponseDetails < Struct.new(
  :custom_response_body_key,
  :response_code,
  :response_headers)
  SENSITIVE = []
  include Aws::Structure
end

#response_codeInteger

The HTTP status code to return to the client. For a list of status codes that you can use in your custom responses, see Supported status codes for custom response in the WAF Developer Guide.



21469
21470
21471
21472
21473
21474
21475
# File 'lib/aws-sdk-securityhub/types.rb', line 21469

class AwsWafv2CustomResponseDetails < Struct.new(
  :custom_response_body_key,
  :response_code,
  :response_headers)
  SENSITIVE = []
  include Aws::Structure
end

#response_headersArray<Types::AwsWafv2CustomHttpHeader>

The HTTP headers to use in the response.



21469
21470
21471
21472
21473
21474
21475
# File 'lib/aws-sdk-securityhub/types.rb', line 21469

class AwsWafv2CustomResponseDetails < Struct.new(
  :custom_response_body_key,
  :response_code,
  :response_headers)
  SENSITIVE = []
  include Aws::Structure
end