Class: Aws::SecurityHub::Types::AwsWafv2RuleGroupDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::AwsWafv2RuleGroupDetails
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Details about an WAFv2 rule group.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the entity.
-
#capacity ⇒ Integer
The web ACL capacity units (WCUs) required for this rule group.
-
#description ⇒ String
A description of the rule group that helps with identification.
-
#id ⇒ String
A unique identifier for the rule group.
-
#name ⇒ String
The name of the rule group.
-
#rules ⇒ Array<Types::AwsWafv2RulesDetails>
The Rule statements used to identify the web requests that you want to allow, block, or count.
-
#scope ⇒ String
Specifies whether the rule group is for an Amazon CloudFront distribution or for a regional application.
-
#visibility_config ⇒ Types::AwsWafv2VisibilityConfigDetails
Defines and enables Amazon CloudWatch metrics and web request sample collection.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the entity.
21353 21354 21355 21356 21357 21358 21359 21360 21361 21362 21363 21364 |
# File 'lib/aws-sdk-securityhub/types.rb', line 21353 class AwsWafv2RuleGroupDetails < Struct.new( :capacity, :description, :id, :name, :arn, :rules, :scope, :visibility_config) SENSITIVE = [] include Aws::Structure end |
#capacity ⇒ Integer
The web ACL capacity units (WCUs) required for this rule group.
21353 21354 21355 21356 21357 21358 21359 21360 21361 21362 21363 21364 |
# File 'lib/aws-sdk-securityhub/types.rb', line 21353 class AwsWafv2RuleGroupDetails < Struct.new( :capacity, :description, :id, :name, :arn, :rules, :scope, :visibility_config) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the rule group that helps with identification.
21353 21354 21355 21356 21357 21358 21359 21360 21361 21362 21363 21364 |
# File 'lib/aws-sdk-securityhub/types.rb', line 21353 class AwsWafv2RuleGroupDetails < Struct.new( :capacity, :description, :id, :name, :arn, :rules, :scope, :visibility_config) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
A unique identifier for the rule group.
21353 21354 21355 21356 21357 21358 21359 21360 21361 21362 21363 21364 |
# File 'lib/aws-sdk-securityhub/types.rb', line 21353 class AwsWafv2RuleGroupDetails < Struct.new( :capacity, :description, :id, :name, :arn, :rules, :scope, :visibility_config) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the rule group. You cannot change the name of a rule group after you create it.
21353 21354 21355 21356 21357 21358 21359 21360 21361 21362 21363 21364 |
# File 'lib/aws-sdk-securityhub/types.rb', line 21353 class AwsWafv2RuleGroupDetails < Struct.new( :capacity, :description, :id, :name, :arn, :rules, :scope, :visibility_config) SENSITIVE = [] include Aws::Structure end |
#rules ⇒ Array<Types::AwsWafv2RulesDetails>
The Rule statements used to identify the web requests that you want to allow, block, or count. Each rule includes one top-level statement that WAF uses to identify matching web requests, and parameters that govern how WAF handles them.
21353 21354 21355 21356 21357 21358 21359 21360 21361 21362 21363 21364 |
# File 'lib/aws-sdk-securityhub/types.rb', line 21353 class AwsWafv2RuleGroupDetails < Struct.new( :capacity, :description, :id, :name, :arn, :rules, :scope, :visibility_config) SENSITIVE = [] include Aws::Structure end |
#scope ⇒ String
Specifies whether the rule group is for an Amazon CloudFront distribution or for a regional application. A regional application can be an Application Load Balancer (ALB), an Amazon API Gateway REST API, an AppSync GraphQL API, or an Amazon Cognito user pool.
21353 21354 21355 21356 21357 21358 21359 21360 21361 21362 21363 21364 |
# File 'lib/aws-sdk-securityhub/types.rb', line 21353 class AwsWafv2RuleGroupDetails < Struct.new( :capacity, :description, :id, :name, :arn, :rules, :scope, :visibility_config) SENSITIVE = [] include Aws::Structure end |
#visibility_config ⇒ Types::AwsWafv2VisibilityConfigDetails
Defines and enables Amazon CloudWatch metrics and web request sample collection.
21353 21354 21355 21356 21357 21358 21359 21360 21361 21362 21363 21364 |
# File 'lib/aws-sdk-securityhub/types.rb', line 21353 class AwsWafv2RuleGroupDetails < Struct.new( :capacity, :description, :id, :name, :arn, :rules, :scope, :visibility_config) SENSITIVE = [] include Aws::Structure end |