Class: Aws::SecurityHub::Types::AwsWafv2RulesDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::AwsWafv2RulesDetails
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Provides details about rules in a rule group. A rule identifies web requests that you want to allow, block, or count. Each rule includes one top-level Statement that WAF uses to identify matching web requests, and parameters that govern how WAF handles them.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#action ⇒ Types::AwsWafv2RulesActionDetails
The action that WAF should take on a web request when it matches the rule statement.
-
#name ⇒ String
The name of the rule.
-
#override_action ⇒ String
The action to use in the place of the action that results from the rule group evaluation.
-
#priority ⇒ Integer
If you define more than one Rule in a WebACL, WAF evaluates each request against the Rules in order based on the value of
Priority. -
#visibility_config ⇒ Types::AwsWafv2VisibilityConfigDetails
Defines and enables Amazon CloudWatch metrics and web request sample collection.
Instance Attribute Details
#action ⇒ Types::AwsWafv2RulesActionDetails
The action that WAF should take on a web request when it matches the rule statement. Settings at the web ACL level can override the rule action setting.
21511 21512 21513 21514 21515 21516 21517 21518 21519 |
# File 'lib/aws-sdk-securityhub/types.rb', line 21511 class AwsWafv2RulesDetails < Struct.new( :action, :name, :override_action, :priority, :visibility_config) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the rule.
21511 21512 21513 21514 21515 21516 21517 21518 21519 |
# File 'lib/aws-sdk-securityhub/types.rb', line 21511 class AwsWafv2RulesDetails < Struct.new( :action, :name, :override_action, :priority, :visibility_config) SENSITIVE = [] include Aws::Structure end |
#override_action ⇒ String
The action to use in the place of the action that results from the rule group evaluation.
21511 21512 21513 21514 21515 21516 21517 21518 21519 |
# File 'lib/aws-sdk-securityhub/types.rb', line 21511 class AwsWafv2RulesDetails < Struct.new( :action, :name, :override_action, :priority, :visibility_config) SENSITIVE = [] include Aws::Structure end |
#priority ⇒ Integer
If you define more than one Rule in a WebACL, WAF evaluates each
request against the Rules in order based on the value of Priority.
WAF processes rules with lower priority first. The priorities don't
need to be consecutive, but they must all be different.
21511 21512 21513 21514 21515 21516 21517 21518 21519 |
# File 'lib/aws-sdk-securityhub/types.rb', line 21511 class AwsWafv2RulesDetails < Struct.new( :action, :name, :override_action, :priority, :visibility_config) SENSITIVE = [] include Aws::Structure end |
#visibility_config ⇒ Types::AwsWafv2VisibilityConfigDetails
Defines and enables Amazon CloudWatch metrics and web request sample collection.
21511 21512 21513 21514 21515 21516 21517 21518 21519 |
# File 'lib/aws-sdk-securityhub/types.rb', line 21511 class AwsWafv2RulesDetails < Struct.new( :action, :name, :override_action, :priority, :visibility_config) SENSITIVE = [] include Aws::Structure end |