Class: Aws::SecurityHub::Types::AzureDetail
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::AzureDetail
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
The detailed Azure configuration for a connector.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_config_connector_arn ⇒ String
The ARN of the AWS Config connector used to establish the connection to Azure.
-
#azure_regions ⇒ Array<String>
The list of Azure regions being monitored.
-
#scope_configuration ⇒ Types::AzureScopeConfiguration
The scope configuration that defines which Azure resources are monitored.
Instance Attribute Details
#aws_config_connector_arn ⇒ String
The ARN of the AWS Config connector used to establish the connection to Azure.
21722 21723 21724 21725 21726 21727 21728 |
# File 'lib/aws-sdk-securityhub/types.rb', line 21722 class AzureDetail < Struct.new( :aws_config_connector_arn, :scope_configuration, :azure_regions) SENSITIVE = [] include Aws::Structure end |
#azure_regions ⇒ Array<String>
The list of Azure regions being monitored.
21722 21723 21724 21725 21726 21727 21728 |
# File 'lib/aws-sdk-securityhub/types.rb', line 21722 class AzureDetail < Struct.new( :aws_config_connector_arn, :scope_configuration, :azure_regions) SENSITIVE = [] include Aws::Structure end |
#scope_configuration ⇒ Types::AzureScopeConfiguration
The scope configuration that defines which Azure resources are monitored.
21722 21723 21724 21725 21726 21727 21728 |
# File 'lib/aws-sdk-securityhub/types.rb', line 21722 class AzureDetail < Struct.new( :aws_config_connector_arn, :scope_configuration, :azure_regions) SENSITIVE = [] include Aws::Structure end |