Class: Aws::SecurityHub::Types::AzureScopeConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

The scope configuration for an Azure connector, defining the tenant or subscription scope.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#scope_typeString

The type of scope. Valid values are tenant and subscription.

Returns:

  • (String)


21770
21771
21772
21773
21774
21775
# File 'lib/aws-sdk-securityhub/types.rb', line 21770

class AzureScopeConfiguration < Struct.new(
  :scope_type,
  :scope_values)
  SENSITIVE = []
  include Aws::Structure
end

#scope_valuesArray<String>

The list of scope values, such as subscription IDs, when the scope type is subscription.

Returns:

  • (Array<String>)


21770
21771
21772
21773
21774
21775
# File 'lib/aws-sdk-securityhub/types.rb', line 21770

class AzureScopeConfiguration < Struct.new(
  :scope_type,
  :scope_values)
  SENSITIVE = []
  include Aws::Structure
end