Class: Aws::SecurityHub::Types::BatchUpdateFindingsUnprocessedFinding
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::BatchUpdateFindingsUnprocessedFinding
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
A finding from a BatchUpdateFindings request that Security Hub CSPM
was unable to update.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#error_code ⇒ String
The code associated with the error.
-
#error_message ⇒ String
The message associated with the error.
-
#finding_identifier ⇒ Types::AwsSecurityFindingIdentifier
The identifier of the finding that was not updated.
Instance Attribute Details
#error_code ⇒ String
The code associated with the error. Possible values are:
-
ConcurrentUpdateError- Another request attempted to update the finding while this request was being processed. This error may also occur if you callBatchUpdateFindingsandBatchImportFindingsat the same time. -
DuplicatedFindingIdentifier- The request included two or more findings with the sameFindingIdentifier. -
FindingNotFound- TheFindingIdentifierincluded in the request did not match an existing finding. -
FindingSizeExceeded- The finding size was greater than the permissible value of 240 KB. -
InternalFailure- An internal service failure occurred when updating the finding. -
InvalidInput- The finding update contained an invalid value that did not satisfy the Amazon Web Services Security Finding Format syntax.
22260 22261 22262 22263 22264 22265 22266 |
# File 'lib/aws-sdk-securityhub/types.rb', line 22260 class BatchUpdateFindingsUnprocessedFinding < Struct.new( :finding_identifier, :error_code, :error_message) SENSITIVE = [] include Aws::Structure end |
#error_message ⇒ String
The message associated with the error. Possible values are:
-
Concurrent finding updates detected -
Finding Identifier is duplicated -
Finding Not Found -
Finding size exceeded 240 KB -
Internal service failure -
Invalid Input
22260 22261 22262 22263 22264 22265 22266 |
# File 'lib/aws-sdk-securityhub/types.rb', line 22260 class BatchUpdateFindingsUnprocessedFinding < Struct.new( :finding_identifier, :error_code, :error_message) SENSITIVE = [] include Aws::Structure end |
#finding_identifier ⇒ Types::AwsSecurityFindingIdentifier
The identifier of the finding that was not updated.
22260 22261 22262 22263 22264 22265 22266 |
# File 'lib/aws-sdk-securityhub/types.rb', line 22260 class BatchUpdateFindingsUnprocessedFinding < Struct.new( :finding_identifier, :error_code, :error_message) SENSITIVE = [] include Aws::Structure end |