Class: Aws::SecurityHub::Types::BooleanConfigurationOptions

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

The options for customizing a security control parameter with a boolean. For a boolean parameter, the options are true and false.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#default_valueBoolean

The Security Hub CSPM default value for a boolean parameter.



22246
22247
22248
22249
22250
# File 'lib/aws-sdk-securityhub/types.rb', line 22246

class BooleanConfigurationOptions < Struct.new(
  :default_value)
  SENSITIVE = []
  include Aws::Structure
end