Class: Aws::SecurityHub::Types::Cell

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

An occurrence of sensitive data detected in a Microsoft Excel workbook, comma-separated value (CSV) file, or tab-separated value (TSV) file.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cell_referenceString

For a Microsoft Excel workbook, provides the location of the cell, as an absolute cell reference, that contains the data. For example, Sheet2!C5 for cell C5 on Sheet2.



22595
22596
22597
22598
22599
22600
22601
22602
# File 'lib/aws-sdk-securityhub/types.rb', line 22595

class Cell < Struct.new(
  :column,
  :row,
  :column_name,
  :cell_reference)
  SENSITIVE = []
  include Aws::Structure
end

#columnInteger

The column number of the column that contains the data. For a Microsoft Excel workbook, the column number corresponds to the alphabetical column identifiers. For example, a value of 1 for Column corresponds to the A column in the workbook.



22595
22596
22597
22598
22599
22600
22601
22602
# File 'lib/aws-sdk-securityhub/types.rb', line 22595

class Cell < Struct.new(
  :column,
  :row,
  :column_name,
  :cell_reference)
  SENSITIVE = []
  include Aws::Structure
end

#column_nameString

The name of the column that contains the data.



22595
22596
22597
22598
22599
22600
22601
22602
# File 'lib/aws-sdk-securityhub/types.rb', line 22595

class Cell < Struct.new(
  :column,
  :row,
  :column_name,
  :cell_reference)
  SENSITIVE = []
  include Aws::Structure
end

#rowInteger

The row number of the row that contains the data.



22595
22596
22597
22598
22599
22600
22601
22602
# File 'lib/aws-sdk-securityhub/types.rb', line 22595

class Cell < Struct.new(
  :column,
  :row,
  :column_name,
  :cell_reference)
  SENSITIVE = []
  include Aws::Structure
end