Class: Aws::SecurityHub::Types::ClassificationResult

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

Details about the sensitive data that was detected on the resource.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#additional_occurrencesBoolean

Indicates whether there are additional occurrences of sensitive data that are not included in the finding. This occurs when the number of occurrences exceeds the maximum that can be included.

Returns:

  • (Boolean)


22674
22675
22676
22677
22678
22679
22680
22681
22682
22683
# File 'lib/aws-sdk-securityhub/types.rb', line 22674

class ClassificationResult < Struct.new(
  :mime_type,
  :size_classified,
  :additional_occurrences,
  :status,
  :sensitive_data,
  :custom_data_identifiers)
  SENSITIVE = []
  include Aws::Structure
end

#custom_data_identifiersTypes::CustomDataIdentifiersResult

Provides details about sensitive data that was identified based on customer-defined configuration.



22674
22675
22676
22677
22678
22679
22680
22681
22682
22683
# File 'lib/aws-sdk-securityhub/types.rb', line 22674

class ClassificationResult < Struct.new(
  :mime_type,
  :size_classified,
  :additional_occurrences,
  :status,
  :sensitive_data,
  :custom_data_identifiers)
  SENSITIVE = []
  include Aws::Structure
end

#mime_typeString

The type of content that the finding applies to.

Returns:

  • (String)


22674
22675
22676
22677
22678
22679
22680
22681
22682
22683
# File 'lib/aws-sdk-securityhub/types.rb', line 22674

class ClassificationResult < Struct.new(
  :mime_type,
  :size_classified,
  :additional_occurrences,
  :status,
  :sensitive_data,
  :custom_data_identifiers)
  SENSITIVE = []
  include Aws::Structure
end

#sensitive_dataArray<Types::SensitiveDataResult>

Provides details about sensitive data that was identified based on built-in configuration.

Returns:



22674
22675
22676
22677
22678
22679
22680
22681
22682
22683
# File 'lib/aws-sdk-securityhub/types.rb', line 22674

class ClassificationResult < Struct.new(
  :mime_type,
  :size_classified,
  :additional_occurrences,
  :status,
  :sensitive_data,
  :custom_data_identifiers)
  SENSITIVE = []
  include Aws::Structure
end

#size_classifiedInteger

The total size in bytes of the affected data.

Returns:

  • (Integer)


22674
22675
22676
22677
22678
22679
22680
22681
22682
22683
# File 'lib/aws-sdk-securityhub/types.rb', line 22674

class ClassificationResult < Struct.new(
  :mime_type,
  :size_classified,
  :additional_occurrences,
  :status,
  :sensitive_data,
  :custom_data_identifiers)
  SENSITIVE = []
  include Aws::Structure
end

#statusTypes::ClassificationStatus

The current status of the sensitive data detection.



22674
22675
22676
22677
22678
22679
22680
22681
22682
22683
# File 'lib/aws-sdk-securityhub/types.rb', line 22674

class ClassificationResult < Struct.new(
  :mime_type,
  :size_classified,
  :additional_occurrences,
  :status,
  :sensitive_data,
  :custom_data_identifiers)
  SENSITIVE = []
  include Aws::Structure
end