Class: Aws::SecurityHub::Types::ContainerDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::ContainerDetails
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Container details related to a finding.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#container_runtime ⇒ String
The runtime of the container.
-
#image_id ⇒ String
The identifier of the container image related to a finding.
-
#image_name ⇒ String
The name of the container image related to a finding.
-
#launched_at ⇒ String
Indicates when the container started.
-
#name ⇒ String
The name of the container related to a finding.
-
#privileged ⇒ Boolean
When this parameter is
true, the container is given elevated privileges on the host container instance (similar to the root user). -
#volume_mounts ⇒ Array<Types::VolumeMount>
Provides information about the mounting of a volume in a container.
Instance Attribute Details
#container_runtime ⇒ String
The runtime of the container.
22903 22904 22905 22906 22907 22908 22909 22910 22911 22912 22913 |
# File 'lib/aws-sdk-securityhub/types.rb', line 22903 class ContainerDetails < Struct.new( :container_runtime, :name, :image_id, :image_name, :launched_at, :volume_mounts, :privileged) SENSITIVE = [] include Aws::Structure end |
#image_id ⇒ String
The identifier of the container image related to a finding.
22903 22904 22905 22906 22907 22908 22909 22910 22911 22912 22913 |
# File 'lib/aws-sdk-securityhub/types.rb', line 22903 class ContainerDetails < Struct.new( :container_runtime, :name, :image_id, :image_name, :launched_at, :volume_mounts, :privileged) SENSITIVE = [] include Aws::Structure end |
#image_name ⇒ String
The name of the container image related to a finding.
22903 22904 22905 22906 22907 22908 22909 22910 22911 22912 22913 |
# File 'lib/aws-sdk-securityhub/types.rb', line 22903 class ContainerDetails < Struct.new( :container_runtime, :name, :image_id, :image_name, :launched_at, :volume_mounts, :privileged) SENSITIVE = [] include Aws::Structure end |
#launched_at ⇒ String
Indicates when the container started.
For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see [Timestamps].
[1]: docs.aws.amazon.com/securityhub/1.0/APIReference/Welcome.html#timestamps
22903 22904 22905 22906 22907 22908 22909 22910 22911 22912 22913 |
# File 'lib/aws-sdk-securityhub/types.rb', line 22903 class ContainerDetails < Struct.new( :container_runtime, :name, :image_id, :image_name, :launched_at, :volume_mounts, :privileged) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the container related to a finding.
22903 22904 22905 22906 22907 22908 22909 22910 22911 22912 22913 |
# File 'lib/aws-sdk-securityhub/types.rb', line 22903 class ContainerDetails < Struct.new( :container_runtime, :name, :image_id, :image_name, :launched_at, :volume_mounts, :privileged) SENSITIVE = [] include Aws::Structure end |
#privileged ⇒ Boolean
When this parameter is true, the container is given elevated privileges on the host container instance (similar to the root user).
22903 22904 22905 22906 22907 22908 22909 22910 22911 22912 22913 |
# File 'lib/aws-sdk-securityhub/types.rb', line 22903 class ContainerDetails < Struct.new( :container_runtime, :name, :image_id, :image_name, :launched_at, :volume_mounts, :privileged) SENSITIVE = [] include Aws::Structure end |
#volume_mounts ⇒ Array<Types::VolumeMount>
Provides information about the mounting of a volume in a container.
22903 22904 22905 22906 22907 22908 22909 22910 22911 22912 22913 |
# File 'lib/aws-sdk-securityhub/types.rb', line 22903 class ContainerDetails < Struct.new( :container_runtime, :name, :image_id, :image_name, :launched_at, :volume_mounts, :privileged) SENSITIVE = [] include Aws::Structure end |