Class: Aws::SecurityHub::Types::CreateConfigurationPolicyResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::CreateConfigurationPolicyResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the configuration policy.
-
#configuration_policy ⇒ Types::Policy
An object that defines how Security Hub CSPM is configured.
-
#created_at ⇒ Time
The date and time, in UTC and ISO 8601 format, that the configuration policy was created.
-
#description ⇒ String
The description of the configuration policy.
-
#id ⇒ String
The universally unique identifier (UUID) of the configuration policy.
-
#name ⇒ String
The name of the configuration policy.
-
#updated_at ⇒ Time
The date and time, in UTC and ISO 8601 format, that the configuration policy was last updated.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the configuration policy.
23259 23260 23261 23262 23263 23264 23265 23266 23267 23268 23269 |
# File 'lib/aws-sdk-securityhub/types.rb', line 23259 class CreateConfigurationPolicyResponse < Struct.new( :arn, :id, :name, :description, :updated_at, :created_at, :configuration_policy) SENSITIVE = [] include Aws::Structure end |
#configuration_policy ⇒ Types::Policy
An object that defines how Security Hub CSPM is configured. It includes whether Security Hub CSPM is enabled or disabled, a list of enabled security standards, a list of enabled or disabled security controls, and a list of custom parameter values for specified controls. If the request included a list of security controls that are enabled in the configuration policy, Security Hub CSPM disables all other controls (including newly released controls). If the request included a list of security controls that are disabled in the configuration policy, Security Hub CSPM enables all other controls (including newly released controls).
23259 23260 23261 23262 23263 23264 23265 23266 23267 23268 23269 |
# File 'lib/aws-sdk-securityhub/types.rb', line 23259 class CreateConfigurationPolicyResponse < Struct.new( :arn, :id, :name, :description, :updated_at, :created_at, :configuration_policy) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The date and time, in UTC and ISO 8601 format, that the configuration policy was created.
23259 23260 23261 23262 23263 23264 23265 23266 23267 23268 23269 |
# File 'lib/aws-sdk-securityhub/types.rb', line 23259 class CreateConfigurationPolicyResponse < Struct.new( :arn, :id, :name, :description, :updated_at, :created_at, :configuration_policy) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the configuration policy.
23259 23260 23261 23262 23263 23264 23265 23266 23267 23268 23269 |
# File 'lib/aws-sdk-securityhub/types.rb', line 23259 class CreateConfigurationPolicyResponse < Struct.new( :arn, :id, :name, :description, :updated_at, :created_at, :configuration_policy) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The universally unique identifier (UUID) of the configuration policy.
23259 23260 23261 23262 23263 23264 23265 23266 23267 23268 23269 |
# File 'lib/aws-sdk-securityhub/types.rb', line 23259 class CreateConfigurationPolicyResponse < Struct.new( :arn, :id, :name, :description, :updated_at, :created_at, :configuration_policy) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the configuration policy.
23259 23260 23261 23262 23263 23264 23265 23266 23267 23268 23269 |
# File 'lib/aws-sdk-securityhub/types.rb', line 23259 class CreateConfigurationPolicyResponse < Struct.new( :arn, :id, :name, :description, :updated_at, :created_at, :configuration_policy) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The date and time, in UTC and ISO 8601 format, that the configuration policy was last updated.
23259 23260 23261 23262 23263 23264 23265 23266 23267 23268 23269 |
# File 'lib/aws-sdk-securityhub/types.rb', line 23259 class CreateConfigurationPolicyResponse < Struct.new( :arn, :id, :name, :description, :updated_at, :created_at, :configuration_policy) SENSITIVE = [] include Aws::Structure end |