Class: Aws::SecurityHub::Types::CreateConnectorRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique identifier used to ensure idempotency of the request.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


23480
23481
23482
23483
23484
23485
23486
23487
23488
# File 'lib/aws-sdk-securityhub/types.rb', line 23480

class CreateConnectorRequest < Struct.new(
  :name,
  :description,
  :provider,
  :tags,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the connector.

Returns:

  • (String)


23480
23481
23482
23483
23484
23485
23486
23487
23488
# File 'lib/aws-sdk-securityhub/types.rb', line 23480

class CreateConnectorRequest < Struct.new(
  :name,
  :description,
  :provider,
  :tags,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the connector. Must be unique within the account.

Returns:

  • (String)


23480
23481
23482
23483
23484
23485
23486
23487
23488
# File 'lib/aws-sdk-securityhub/types.rb', line 23480

class CreateConnectorRequest < Struct.new(
  :name,
  :description,
  :provider,
  :tags,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#providerTypes::CspmProviderConfiguration

The configuration for the cloud provider to connect to. Currently supports Azure.



23480
23481
23482
23483
23484
23485
23486
23487
23488
# File 'lib/aws-sdk-securityhub/types.rb', line 23480

class CreateConnectorRequest < Struct.new(
  :name,
  :description,
  :provider,
  :tags,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The tags to add to the connector resource.

Returns:

  • (Hash<String,String>)


23480
23481
23482
23483
23484
23485
23486
23487
23488
# File 'lib/aws-sdk-securityhub/types.rb', line 23480

class CreateConnectorRequest < Struct.new(
  :name,
  :description,
  :provider,
  :tags,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end