Class: Aws::SecurityHub::Types::CreateMembersRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#account_detailsArray<Types::AccountDetails>

The list of accounts to associate with the Security Hub CSPM administrator account. For each account, the list includes the account ID and optionally the email address.



23471
23472
23473
23474
23475
# File 'lib/aws-sdk-securityhub/types.rb', line 23471

class CreateMembersRequest < Struct.new(
  :account_details)
  SENSITIVE = []
  include Aws::Structure
end