Class: Aws::SecurityHub::Types::Criteria
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::Criteria
- Includes:
- Aws::Structure, Aws::Structure::Union
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Note:
Criteria is a union - when making an API calls you must set exactly one of the members.
Note:
Criteria is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of Criteria corresponding to the set member.
Defines the parameters and conditions used to evaluate and filter security findings.
Defined Under Namespace
Classes: OcsfFindingCriteria, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#ocsf_finding_criteria ⇒ Types::OcsfFindingFilters
The filtering conditions that align with OCSF standards.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#ocsf_finding_criteria ⇒ Types::OcsfFindingFilters
The filtering conditions that align with OCSF standards.
23804 23805 23806 23807 23808 23809 23810 23811 23812 23813 |
# File 'lib/aws-sdk-securityhub/types.rb', line 23804 class Criteria < Struct.new( :ocsf_finding_criteria, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class OcsfFindingCriteria < Criteria; end class Unknown < Criteria; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
23804 23805 23806 |
# File 'lib/aws-sdk-securityhub/types.rb', line 23804 def unknown @unknown end |