Class: Aws::SecurityHub::Types::CspmConnectorSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::CspmConnectorSummary
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
A summary of a CSPM connector.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#connector_arn ⇒ String
The Amazon Resource Name (ARN) of the connector.
-
#connector_id ⇒ String
The unique identifier of the connector.
-
#created_at ⇒ Time
The ISO 8601 UTC timestamp indicating when the connector was created.
-
#created_by ⇒ String
The service principal that created the connector.
-
#description ⇒ String
The description of the connector.
-
#enablement_status ⇒ String
The enablement status of the connector.
-
#name ⇒ String
The name of the connector.
-
#provider_summary ⇒ Types::CspmProviderSummary
A summary of the cloud provider configuration for the connector.
Instance Attribute Details
#connector_arn ⇒ String
The Amazon Resource Name (ARN) of the connector.
23852 23853 23854 23855 23856 23857 23858 23859 23860 23861 23862 23863 |
# File 'lib/aws-sdk-securityhub/types.rb', line 23852 class CspmConnectorSummary < Struct.new( :connector_arn, :connector_id, :name, :description, :provider_summary, :created_at, :created_by, :enablement_status) SENSITIVE = [] include Aws::Structure end |
#connector_id ⇒ String
The unique identifier of the connector.
23852 23853 23854 23855 23856 23857 23858 23859 23860 23861 23862 23863 |
# File 'lib/aws-sdk-securityhub/types.rb', line 23852 class CspmConnectorSummary < Struct.new( :connector_arn, :connector_id, :name, :description, :provider_summary, :created_at, :created_by, :enablement_status) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The ISO 8601 UTC timestamp indicating when the connector was created.
23852 23853 23854 23855 23856 23857 23858 23859 23860 23861 23862 23863 |
# File 'lib/aws-sdk-securityhub/types.rb', line 23852 class CspmConnectorSummary < Struct.new( :connector_arn, :connector_id, :name, :description, :provider_summary, :created_at, :created_by, :enablement_status) SENSITIVE = [] include Aws::Structure end |
#created_by ⇒ String
The service principal that created the connector.
23852 23853 23854 23855 23856 23857 23858 23859 23860 23861 23862 23863 |
# File 'lib/aws-sdk-securityhub/types.rb', line 23852 class CspmConnectorSummary < Struct.new( :connector_arn, :connector_id, :name, :description, :provider_summary, :created_at, :created_by, :enablement_status) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the connector.
23852 23853 23854 23855 23856 23857 23858 23859 23860 23861 23862 23863 |
# File 'lib/aws-sdk-securityhub/types.rb', line 23852 class CspmConnectorSummary < Struct.new( :connector_arn, :connector_id, :name, :description, :provider_summary, :created_at, :created_by, :enablement_status) SENSITIVE = [] include Aws::Structure end |
#enablement_status ⇒ String
The enablement status of the connector.
23852 23853 23854 23855 23856 23857 23858 23859 23860 23861 23862 23863 |
# File 'lib/aws-sdk-securityhub/types.rb', line 23852 class CspmConnectorSummary < Struct.new( :connector_arn, :connector_id, :name, :description, :provider_summary, :created_at, :created_by, :enablement_status) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the connector.
23852 23853 23854 23855 23856 23857 23858 23859 23860 23861 23862 23863 |
# File 'lib/aws-sdk-securityhub/types.rb', line 23852 class CspmConnectorSummary < Struct.new( :connector_arn, :connector_id, :name, :description, :provider_summary, :created_at, :created_by, :enablement_status) SENSITIVE = [] include Aws::Structure end |
#provider_summary ⇒ Types::CspmProviderSummary
A summary of the cloud provider configuration for the connector.
23852 23853 23854 23855 23856 23857 23858 23859 23860 23861 23862 23863 |
# File 'lib/aws-sdk-securityhub/types.rb', line 23852 class CspmConnectorSummary < Struct.new( :connector_arn, :connector_id, :name, :description, :provider_summary, :created_at, :created_by, :enablement_status) SENSITIVE = [] include Aws::Structure end |