Class: Aws::SecurityHub::Types::CspmHealthCheck

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

Information about the operational status and health of a CSPM connector.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#connector_statusString

The connectivity status of the connector.

Returns:

  • (String)


23887
23888
23889
23890
23891
23892
23893
23894
# File 'lib/aws-sdk-securityhub/types.rb', line 23887

class CspmHealthCheck < Struct.new(
  :connector_status,
  :message,
  :last_checked_at,
  :issues)
  SENSITIVE = []
  include Aws::Structure
end

#issuesArray<Types::HealthIssue>

A list of health issues associated with the connector.

Returns:



23887
23888
23889
23890
23891
23892
23893
23894
# File 'lib/aws-sdk-securityhub/types.rb', line 23887

class CspmHealthCheck < Struct.new(
  :connector_status,
  :message,
  :last_checked_at,
  :issues)
  SENSITIVE = []
  include Aws::Structure
end

#last_checked_atTime

The ISO 8601 UTC timestamp indicating when the health status was last checked.

Returns:

  • (Time)


23887
23888
23889
23890
23891
23892
23893
23894
# File 'lib/aws-sdk-securityhub/types.rb', line 23887

class CspmHealthCheck < Struct.new(
  :connector_status,
  :message,
  :last_checked_at,
  :issues)
  SENSITIVE = []
  include Aws::Structure
end

#messageString

A message describing the reason for the current connector status.

Returns:

  • (String)


23887
23888
23889
23890
23891
23892
23893
23894
# File 'lib/aws-sdk-securityhub/types.rb', line 23887

class CspmHealthCheck < Struct.new(
  :connector_status,
  :message,
  :last_checked_at,
  :issues)
  SENSITIVE = []
  include Aws::Structure
end