Class: Aws::SecurityHub::Types::CspmProviderConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::CspmProviderConfiguration
- Includes:
- Aws::Structure, Aws::Structure::Union
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Note:
CspmProviderConfiguration is a union - when making an API calls you must set exactly one of the members.
The cloud provider configuration for creating a connector. This is a union type that currently supports Azure.
Defined Under Namespace
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#azure ⇒ Types::AzureProviderConfiguration
The Azure provider configuration.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#azure ⇒ Types::AzureProviderConfiguration
The Azure provider configuration.
24037 24038 24039 24040 24041 24042 24043 24044 24045 24046 |
# File 'lib/aws-sdk-securityhub/types.rb', line 24037 class CspmProviderConfiguration < Struct.new( :azure, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Azure < CspmProviderConfiguration; end class Unknown < CspmProviderConfiguration; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
24037 24038 24039 |
# File 'lib/aws-sdk-securityhub/types.rb', line 24037 def unknown @unknown end |