Class: Aws::SecurityHub::Types::CspmProviderDetail

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure, Aws::Structure::Union
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

Note:

CspmProviderDetail is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of CspmProviderDetail corresponding to the set member.

The detailed cloud provider configuration for a connector. This is a union type that currently supports Azure.

Defined Under Namespace

Classes: Azure, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#azureTypes::AzureDetail

The Azure provider detail.

Returns:



24059
24060
24061
24062
24063
24064
24065
24066
24067
24068
# File 'lib/aws-sdk-securityhub/types.rb', line 24059

class CspmProviderDetail < Struct.new(
  :azure,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Azure < CspmProviderDetail; end
  class Unknown < CspmProviderDetail; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



24059
24060
24061
# File 'lib/aws-sdk-securityhub/types.rb', line 24059

def unknown
  @unknown
end