Class: Aws::SecurityHub::Types::CspmProviderUpdateConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::CspmProviderUpdateConfiguration
- Includes:
- Aws::Structure, Aws::Structure::Union
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Note:
CspmProviderUpdateConfiguration is a union - when making an API calls you must set exactly one of the members.
The cloud provider configuration for updating a connector. This is a union type that currently supports Azure.
Defined Under Namespace
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#azure ⇒ Types::AzureUpdateConfiguration
The Azure update configuration.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#azure ⇒ Types::AzureUpdateConfiguration
The Azure update configuration.
24105 24106 24107 24108 24109 24110 24111 24112 24113 24114 |
# File 'lib/aws-sdk-securityhub/types.rb', line 24105 class CspmProviderUpdateConfiguration < Struct.new( :azure, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Azure < CspmProviderUpdateConfiguration; end class Unknown < CspmProviderUpdateConfiguration; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
24105 24106 24107 |
# File 'lib/aws-sdk-securityhub/types.rb', line 24105 def unknown @unknown end |