Class: Aws::SecurityHub::Types::DeleteConnectorResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::DeleteConnectorResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#enablement_status ⇒ String
The enablement status of the connector after the delete request.
Instance Attribute Details
#enablement_status ⇒ String
The enablement status of the connector after the delete request.
24276 24277 24278 24279 24280 |
# File 'lib/aws-sdk-securityhub/types.rb', line 24276 class DeleteConnectorResponse < Struct.new( :enablement_status) SENSITIVE = [] include Aws::Structure end |