Class: Aws::SecurityHub::Types::DeleteInvitationsResponse

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#unprocessed_accountsArray<Types::Result>

The list of Amazon Web Services accounts for which the invitations were not deleted. For each account, the list includes the account ID and the email address.



24498
24499
24500
24501
24502
# File 'lib/aws-sdk-securityhub/types.rb', line 24498

class DeleteInvitationsResponse < Struct.new(
  :unprocessed_accounts)
  SENSITIVE = []
  include Aws::Structure
end