Class: Aws::SecurityHub::Types::DescribeActionTargetsRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#action_target_arnsArray<String>

A list of custom action target ARNs for the custom action targets to retrieve.

Returns:



23958
23959
23960
23961
23962
23963
23964
# File 'lib/aws-sdk-securityhub/types.rb', line 23958

class DescribeActionTargetsRequest < Struct.new(
  :action_target_arns,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return.

Returns:



23958
23959
23960
23961
23962
23963
23964
# File 'lib/aws-sdk-securityhub/types.rb', line 23958

class DescribeActionTargetsRequest < Struct.new(
  :action_target_arns,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token that is required for pagination. On your first call to the DescribeActionTargets operation, set the value of this parameter to NULL.

For subsequent calls to the operation, to continue listing data, set the value of this parameter to the value returned from the previous response.

Returns:



23958
23959
23960
23961
23962
23963
23964
# File 'lib/aws-sdk-securityhub/types.rb', line 23958

class DescribeActionTargetsRequest < Struct.new(
  :action_target_arns,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end