Class: Aws::SecurityHub::Types::DescribeOrganizationConfigurationResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::DescribeOrganizationConfigurationResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#auto_enable ⇒ Boolean
Whether to automatically enable Security Hub CSPM in new member accounts when they join the organization.
-
#auto_enable_standards ⇒ String
Whether to automatically enable Security Hub CSPM [default standards] in new member accounts when they join the organization.
-
#member_account_limit_reached ⇒ Boolean
Whether the maximum number of allowed member accounts are already associated with the Security Hub CSPM administrator account.
-
#organization_configuration ⇒ Types::OrganizationConfiguration
Provides information about the way an organization is configured in Security Hub CSPM.
Instance Attribute Details
#auto_enable ⇒ Boolean
Whether to automatically enable Security Hub CSPM in new member accounts when they join the organization.
If set to true, then Security Hub CSPM is automatically enabled in new accounts. If set to false, then Security Hub CSPM isn’t enabled in new accounts automatically. The default value is false.
If the ConfigurationType of your organization is set to CENTRAL, then this field is set to false and can’t be changed in the home Region and linked Regions. However, in that case, the delegated administrator can create a configuration policy in which Security Hub CSPM is enabled and associate the policy with new organization accounts.
24108 24109 24110 24111 24112 24113 24114 24115 |
# File 'lib/aws-sdk-securityhub/types.rb', line 24108 class DescribeOrganizationConfigurationResponse < Struct.new( :auto_enable, :member_account_limit_reached, :auto_enable_standards, :organization_configuration) SENSITIVE = [] include Aws::Structure end |
#auto_enable_standards ⇒ String
Whether to automatically enable Security Hub CSPM [default standards] in new member accounts when they join the organization.
If equal to DEFAULT, then Security Hub CSPM default standards are automatically enabled for new member accounts. If equal to NONE, then default standards are not automatically enabled for new member accounts. The default value of this parameter is equal to DEFAULT.
If the ConfigurationType of your organization is set to CENTRAL, then this field is set to NONE and can’t be changed in the home Region and linked Regions. However, in that case, the delegated administrator can create a configuration policy in which specific security standards are enabled and associate the policy with new organization accounts.
[1]: docs.aws.amazon.com/securityhub/latest/userguide/securityhub-standards-enable-disable.html
24108 24109 24110 24111 24112 24113 24114 24115 |
# File 'lib/aws-sdk-securityhub/types.rb', line 24108 class DescribeOrganizationConfigurationResponse < Struct.new( :auto_enable, :member_account_limit_reached, :auto_enable_standards, :organization_configuration) SENSITIVE = [] include Aws::Structure end |
#member_account_limit_reached ⇒ Boolean
Whether the maximum number of allowed member accounts are already associated with the Security Hub CSPM administrator account.
24108 24109 24110 24111 24112 24113 24114 24115 |
# File 'lib/aws-sdk-securityhub/types.rb', line 24108 class DescribeOrganizationConfigurationResponse < Struct.new( :auto_enable, :member_account_limit_reached, :auto_enable_standards, :organization_configuration) SENSITIVE = [] include Aws::Structure end |
#organization_configuration ⇒ Types::OrganizationConfiguration
Provides information about the way an organization is configured in Security Hub CSPM.
24108 24109 24110 24111 24112 24113 24114 24115 |
# File 'lib/aws-sdk-securityhub/types.rb', line 24108 class DescribeOrganizationConfigurationResponse < Struct.new( :auto_enable, :member_account_limit_reached, :auto_enable_standards, :organization_configuration) SENSITIVE = [] include Aws::Structure end |