Class: Aws::SecurityHub::Types::DescribeSecurityHubV2Response

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#featuresHash<String,Types::FeatureDetail>

A map of opt-in features and their current status and metadata for the account in the current Region.

Returns:



24785
24786
24787
24788
24789
24790
24791
# File 'lib/aws-sdk-securityhub/types.rb', line 24785

class DescribeSecurityHubV2Response < Struct.new(
  :hub_v2_arn,
  :subscribed_at,
  :features)
  SENSITIVE = []
  include Aws::Structure
end

#hub_v2_arnString

The ARN of the service resource.

Returns:

  • (String)


24785
24786
24787
24788
24789
24790
24791
# File 'lib/aws-sdk-securityhub/types.rb', line 24785

class DescribeSecurityHubV2Response < Struct.new(
  :hub_v2_arn,
  :subscribed_at,
  :features)
  SENSITIVE = []
  include Aws::Structure
end

#subscribed_atString

The date and time when the service was enabled in the account.

Returns:

  • (String)


24785
24786
24787
24788
24789
24790
24791
# File 'lib/aws-sdk-securityhub/types.rb', line 24785

class DescribeSecurityHubV2Response < Struct.new(
  :hub_v2_arn,
  :subscribed_at,
  :features)
  SENSITIVE = []
  include Aws::Structure
end