Class: Aws::SecurityHub::Types::DescribeStandardsControlsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::DescribeStandardsControlsRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
The maximum number of security standard controls to return.
-
#next_token ⇒ String
The token that is required for pagination.
-
#standards_subscription_arn ⇒ String
The ARN of a resource that represents your subscription to a supported standard.
Instance Attribute Details
#max_results ⇒ Integer
The maximum number of security standard controls to return.
24245 24246 24247 24248 24249 24250 24251 |
# File 'lib/aws-sdk-securityhub/types.rb', line 24245 class DescribeStandardsControlsRequest < Struct.new( :standards_subscription_arn, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token that is required for pagination. On your first call to the DescribeStandardsControls operation, set the value of this parameter to NULL.
For subsequent calls to the operation, to continue listing data, set the value of this parameter to the value returned from the previous response.
24245 24246 24247 24248 24249 24250 24251 |
# File 'lib/aws-sdk-securityhub/types.rb', line 24245 class DescribeStandardsControlsRequest < Struct.new( :standards_subscription_arn, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#standards_subscription_arn ⇒ String
The ARN of a resource that represents your subscription to a supported standard. To get the subscription ARNs of the standards you have enabled, use the GetEnabledStandards operation.
24245 24246 24247 24248 24249 24250 24251 |
# File 'lib/aws-sdk-securityhub/types.rb', line 24245 class DescribeStandardsControlsRequest < Struct.new( :standards_subscription_arn, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |