Class: Aws::SecurityHub::Types::DescribeStandardsRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#max_resultsInteger

The maximum number of standards to return.

Returns:

  • (Integer)


24862
24863
24864
24865
24866
24867
24868
# File 'lib/aws-sdk-securityhub/types.rb', line 24862

class DescribeStandardsRequest < Struct.new(
  :next_token,
  :max_results,
  :providers)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token that is required for pagination. On your first call to the DescribeStandards operation, set the value of this parameter to NULL.

For subsequent calls to the operation, to continue listing data, set the value of this parameter to the value returned from the previous response.

Returns:

  • (String)


24862
24863
24864
24865
24866
24867
24868
# File 'lib/aws-sdk-securityhub/types.rb', line 24862

class DescribeStandardsRequest < Struct.new(
  :next_token,
  :max_results,
  :providers)
  SENSITIVE = []
  include Aws::Structure
end

#providersArray<String>

A list of cloud providers to filter the standards by. For example, specify Azure to return only standards that evaluate Azure resources.

Returns:

  • (Array<String>)


24862
24863
24864
24865
24866
24867
24868
# File 'lib/aws-sdk-securityhub/types.rb', line 24862

class DescribeStandardsRequest < Struct.new(
  :next_token,
  :max_results,
  :providers)
  SENSITIVE = []
  include Aws::Structure
end