Class: Aws::SecurityHub::Types::Detection

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

A top-level object field that provides details about an Amazon GuardDuty Extended Threat Detection attack sequence. GuardDuty generates an attack sequence finding when multiple events align to a potentially suspicious activity. To receive GuardDuty attack sequence findings in Security Hub CSPM, you must have GuardDuty enabled. For more information, see GuardDuty Extended Threat Detection in the Amazon GuardDuty User Guide.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#sequenceTypes::Sequence

Provides details about an attack sequence.

Returns:



24804
24805
24806
24807
24808
# File 'lib/aws-sdk-securityhub/types.rb', line 24804

class Detection < Struct.new(
  :sequence)
  SENSITIVE = []
  include Aws::Structure
end