Class: Aws::SecurityHub::Types::FindingHistoryUpdate

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

An array of objects that provides details about a change to a finding, including the Amazon Web Services Security Finding Format (ASFF) field that changed, the value of the field before the change, and the value of the field after the change.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#new_valueString

The value of the ASFF field after the finding change event. To preserve storage and readability, Security Hub CSPM omits this value if FindingHistoryRecord exceeds database limits.

Returns:

  • (String)


25462
25463
25464
25465
25466
25467
25468
# File 'lib/aws-sdk-securityhub/types.rb', line 25462

class FindingHistoryUpdate < Struct.new(
  :updated_field,
  :old_value,
  :new_value)
  SENSITIVE = []
  include Aws::Structure
end

#old_valueString

The value of the ASFF field before the finding change event.

Returns:

  • (String)


25462
25463
25464
25465
25466
25467
25468
# File 'lib/aws-sdk-securityhub/types.rb', line 25462

class FindingHistoryUpdate < Struct.new(
  :updated_field,
  :old_value,
  :new_value)
  SENSITIVE = []
  include Aws::Structure
end

#updated_fieldString

The ASFF field that changed during the finding change event.

Returns:

  • (String)


25462
25463
25464
25465
25466
25467
25468
# File 'lib/aws-sdk-securityhub/types.rb', line 25462

class FindingHistoryUpdate < Struct.new(
  :updated_field,
  :old_value,
  :new_value)
  SENSITIVE = []
  include Aws::Structure
end