Class: Aws::SecurityHub::Types::FindingHistoryUpdateSource
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::FindingHistoryUpdateSource
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Identifies the source of the finding change event.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#identity ⇒ String
The identity of the source that initiated the finding change event.
-
#type ⇒ String
Describes the type of finding change event, such as a call to [
BatchImportFindings][1] (by an integrated Amazon Web Services service or third party partner integration) or [BatchUpdateFindings][2] (by a Security Hub CSPM customer).
Instance Attribute Details
#identity ⇒ String
The identity of the source that initiated the finding change event. For example, the Amazon Resource Name (ARN) of a partner that calls BatchImportFindings or of a customer that calls BatchUpdateFindings.
25391 25392 25393 25394 25395 25396 |
# File 'lib/aws-sdk-securityhub/types.rb', line 25391 class FindingHistoryUpdateSource < Struct.new( :type, :identity) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
Describes the type of finding change event, such as a call to
BatchImportFindings (by an integrated Amazon Web Services
service or third party partner integration) or
BatchUpdateFindings (by a Security Hub CSPM customer).
25391 25392 25393 25394 25395 25396 |
# File 'lib/aws-sdk-securityhub/types.rb', line 25391 class FindingHistoryUpdateSource < Struct.new( :type, :identity) SENSITIVE = [] include Aws::Structure end |