Class: Aws::SecurityHub::Types::FindingProviderSeverity

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

The severity assigned to a finding by the finding provider. This object may include one or more of the following attributes:

  • Label

  • Normalized

  • Original

  • Product

If a BatchImportFindings request for a new finding only provides Label or only provides Normalized, Security Hub CSPM automatically populates the value of the other field.

The Normalized and Product attributes are included in the FindingProviderSeverity structure to preserve the historical information associated with the finding, even if the top-level Severity object is later modified using the BatchUpdateFindings operation.

If the top-level Finding.Severity object is present, but Finding.FindingProviderFields isn't present, Security Hub CSPM creates the FindingProviderFields.Severity object and copies the entire Finding.Severity object into it. This ensures that the original, provider-supplied details are retained within the FindingProviderFields.Severity object, even if the top-level Severity object is overwritten.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#labelString

The severity label assigned to the finding by the finding provider.

Returns:

  • (String)


25044
25045
25046
25047
25048
25049
# File 'lib/aws-sdk-securityhub/types.rb', line 25044

class FindingProviderSeverity < Struct.new(
  :label,
  :original)
  SENSITIVE = []
  include Aws::Structure
end

#originalString

The finding provider's original value for the severity.

Length Constraints: Minimum length of 1. Maximum length of 64.

Returns:

  • (String)


25044
25045
25046
25047
25048
25049
# File 'lib/aws-sdk-securityhub/types.rb', line 25044

class FindingProviderSeverity < Struct.new(
  :label,
  :original)
  SENSITIVE = []
  include Aws::Structure
end