Class: Aws::SecurityHub::Types::FindingsTrendsStringFilter
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::FindingsTrendsStringFilter
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
A filter for string-based fields in findings trend data.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#field_name ⇒ String
The name of the findings field to filter on.
-
#filter ⇒ Types::StringFilter
A string filter for filtering Security Hub CSPM findings.
Instance Attribute Details
#field_name ⇒ String
The name of the findings field to filter on.
25070 25071 25072 25073 25074 25075 |
# File 'lib/aws-sdk-securityhub/types.rb', line 25070 class FindingsTrendsStringFilter < Struct.new( :field_name, :filter) SENSITIVE = [] include Aws::Structure end |
#filter ⇒ Types::StringFilter
A string filter for filtering Security Hub CSPM findings.
25070 25071 25072 25073 25074 25075 |
# File 'lib/aws-sdk-securityhub/types.rb', line 25070 class FindingsTrendsStringFilter < Struct.new( :field_name, :filter) SENSITIVE = [] include Aws::Structure end |