Class: Aws::SecurityHub::Types::FirewallPolicyDetails

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

Defines the behavior of the firewall.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#stateful_rule_group_referencesArray<Types::FirewallPolicyStatefulRuleGroupReferencesDetails>

The stateful rule groups that are used in the firewall policy.



25171
25172
25173
25174
25175
25176
25177
25178
25179
# File 'lib/aws-sdk-securityhub/types.rb', line 25171

class FirewallPolicyDetails < Struct.new(
  :stateful_rule_group_references,
  :stateless_custom_actions,
  :stateless_default_actions,
  :stateless_fragment_default_actions,
  :stateless_rule_group_references)
  SENSITIVE = []
  include Aws::Structure
end

#stateless_custom_actionsArray<Types::FirewallPolicyStatelessCustomActionsDetails>

The custom action definitions that are available to use in the firewall policy’s ‘StatelessDefaultActions` setting.



25171
25172
25173
25174
25175
25176
25177
25178
25179
# File 'lib/aws-sdk-securityhub/types.rb', line 25171

class FirewallPolicyDetails < Struct.new(
  :stateful_rule_group_references,
  :stateless_custom_actions,
  :stateless_default_actions,
  :stateless_fragment_default_actions,
  :stateless_rule_group_references)
  SENSITIVE = []
  include Aws::Structure
end

#stateless_default_actionsArray<String>

The actions to take on a packet if it doesn’t match any of the stateless rules in the policy.

You must specify a standard action (‘aws:pass`, `aws:drop`, `aws:forward_to_sfe`), and can optionally include a custom action from `StatelessCustomActions`.

Returns:

  • (Array<String>)


25171
25172
25173
25174
25175
25176
25177
25178
25179
# File 'lib/aws-sdk-securityhub/types.rb', line 25171

class FirewallPolicyDetails < Struct.new(
  :stateful_rule_group_references,
  :stateless_custom_actions,
  :stateless_default_actions,
  :stateless_fragment_default_actions,
  :stateless_rule_group_references)
  SENSITIVE = []
  include Aws::Structure
end

#stateless_fragment_default_actionsArray<String>

The actions to take on a fragmented UDP packet if it doesn’t match any of the stateless rules in the policy.

You must specify a standard action (‘aws:pass`, `aws:drop`, `aws:forward_to_sfe`), and can optionally include a custom action from `StatelessCustomActions`.

Returns:

  • (Array<String>)


25171
25172
25173
25174
25175
25176
25177
25178
25179
# File 'lib/aws-sdk-securityhub/types.rb', line 25171

class FirewallPolicyDetails < Struct.new(
  :stateful_rule_group_references,
  :stateless_custom_actions,
  :stateless_default_actions,
  :stateless_fragment_default_actions,
  :stateless_rule_group_references)
  SENSITIVE = []
  include Aws::Structure
end

#stateless_rule_group_referencesArray<Types::FirewallPolicyStatelessRuleGroupReferencesDetails>

The stateless rule groups that are used in the firewall policy.



25171
25172
25173
25174
25175
25176
25177
25178
25179
# File 'lib/aws-sdk-securityhub/types.rb', line 25171

class FirewallPolicyDetails < Struct.new(
  :stateful_rule_group_references,
  :stateless_custom_actions,
  :stateless_default_actions,
  :stateless_fragment_default_actions,
  :stateless_rule_group_references)
  SENSITIVE = []
  include Aws::Structure
end