Class: Aws::SecurityHub::Types::FreeTrialStatus

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

The free trial period for a Security Hub feature, and whether the trial is currently active.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#expires_atTime

The date and time at which the free trial period ends.

Returns:

  • (Time)


25932
25933
25934
25935
25936
25937
25938
25939
# File 'lib/aws-sdk-securityhub/types.rb', line 25932

class FreeTrialStatus < Struct.new(
  :feature_type,
  :status,
  :started_at,
  :expires_at)
  SENSITIVE = []
  include Aws::Structure
end

#feature_typeString

The feature that the free trial period applies to. Valid values:

  • SECURITY_HUB_V2 specifies Security Hub.

  • SECURITY_HUB_V2_MULTI_CLOUD_AZURE specifies Security Hub coverage for Microsoft Azure resources.

Returns:

  • (String)


25932
25933
25934
25935
25936
25937
25938
25939
# File 'lib/aws-sdk-securityhub/types.rb', line 25932

class FreeTrialStatus < Struct.new(
  :feature_type,
  :status,
  :started_at,
  :expires_at)
  SENSITIVE = []
  include Aws::Structure
end

#started_atTime

The date and time at which the free trial period began.

Returns:

  • (Time)


25932
25933
25934
25935
25936
25937
25938
25939
# File 'lib/aws-sdk-securityhub/types.rb', line 25932

class FreeTrialStatus < Struct.new(
  :feature_type,
  :status,
  :started_at,
  :expires_at)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

Whether the free trial period is currently active. Valid values:

  • ACTIVE specifies that the free trial period is ongoing.

  • INACTIVE specifies that the free trial period has ended, or that it never started.

To determine whether a trial has expired, compare ExpiresAt to the current time.

Returns:

  • (String)


25932
25933
25934
25935
25936
25937
25938
25939
# File 'lib/aws-sdk-securityhub/types.rb', line 25932

class FreeTrialStatus < Struct.new(
  :feature_type,
  :status,
  :started_at,
  :expires_at)
  SENSITIVE = []
  include Aws::Structure
end