Class: Aws::SecurityHub::Types::GetConnectorResponse

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#connector_arnString

The Amazon Resource Name (ARN) of the connector.

Returns:

  • (String)


26148
26149
26150
26151
26152
26153
26154
26155
26156
26157
26158
26159
26160
26161
# File 'lib/aws-sdk-securityhub/types.rb', line 26148

class GetConnectorResponse < Struct.new(
  :connector_arn,
  :connector_id,
  :name,
  :description,
  :created_at,
  :last_updated_at,
  :health,
  :provider_detail,
  :created_by,
  :enablement_status)
  SENSITIVE = []
  include Aws::Structure
end

#connector_idString

The unique identifier of the connector.

Returns:

  • (String)


26148
26149
26150
26151
26152
26153
26154
26155
26156
26157
26158
26159
26160
26161
# File 'lib/aws-sdk-securityhub/types.rb', line 26148

class GetConnectorResponse < Struct.new(
  :connector_arn,
  :connector_id,
  :name,
  :description,
  :created_at,
  :last_updated_at,
  :health,
  :provider_detail,
  :created_by,
  :enablement_status)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The ISO 8601 UTC timestamp indicating when the connector was created.

Returns:

  • (Time)


26148
26149
26150
26151
26152
26153
26154
26155
26156
26157
26158
26159
26160
26161
# File 'lib/aws-sdk-securityhub/types.rb', line 26148

class GetConnectorResponse < Struct.new(
  :connector_arn,
  :connector_id,
  :name,
  :description,
  :created_at,
  :last_updated_at,
  :health,
  :provider_detail,
  :created_by,
  :enablement_status)
  SENSITIVE = []
  include Aws::Structure
end

#created_byString

The service principal that created the connector.

Returns:

  • (String)


26148
26149
26150
26151
26152
26153
26154
26155
26156
26157
26158
26159
26160
26161
# File 'lib/aws-sdk-securityhub/types.rb', line 26148

class GetConnectorResponse < Struct.new(
  :connector_arn,
  :connector_id,
  :name,
  :description,
  :created_at,
  :last_updated_at,
  :health,
  :provider_detail,
  :created_by,
  :enablement_status)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the connector.

Returns:

  • (String)


26148
26149
26150
26151
26152
26153
26154
26155
26156
26157
26158
26159
26160
26161
# File 'lib/aws-sdk-securityhub/types.rb', line 26148

class GetConnectorResponse < Struct.new(
  :connector_arn,
  :connector_id,
  :name,
  :description,
  :created_at,
  :last_updated_at,
  :health,
  :provider_detail,
  :created_by,
  :enablement_status)
  SENSITIVE = []
  include Aws::Structure
end

#enablement_statusString

The enablement status of the connector.

Returns:

  • (String)


26148
26149
26150
26151
26152
26153
26154
26155
26156
26157
26158
26159
26160
26161
# File 'lib/aws-sdk-securityhub/types.rb', line 26148

class GetConnectorResponse < Struct.new(
  :connector_arn,
  :connector_id,
  :name,
  :description,
  :created_at,
  :last_updated_at,
  :health,
  :provider_detail,
  :created_by,
  :enablement_status)
  SENSITIVE = []
  include Aws::Structure
end

#healthTypes::CspmHealthCheck

The health status of the connector, including connectivity status and last check time.



26148
26149
26150
26151
26152
26153
26154
26155
26156
26157
26158
26159
26160
26161
# File 'lib/aws-sdk-securityhub/types.rb', line 26148

class GetConnectorResponse < Struct.new(
  :connector_arn,
  :connector_id,
  :name,
  :description,
  :created_at,
  :last_updated_at,
  :health,
  :provider_detail,
  :created_by,
  :enablement_status)
  SENSITIVE = []
  include Aws::Structure
end

#last_updated_atTime

The ISO 8601 UTC timestamp indicating when the connector was last updated.

Returns:

  • (Time)


26148
26149
26150
26151
26152
26153
26154
26155
26156
26157
26158
26159
26160
26161
# File 'lib/aws-sdk-securityhub/types.rb', line 26148

class GetConnectorResponse < Struct.new(
  :connector_arn,
  :connector_id,
  :name,
  :description,
  :created_at,
  :last_updated_at,
  :health,
  :provider_detail,
  :created_by,
  :enablement_status)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the connector.

Returns:

  • (String)


26148
26149
26150
26151
26152
26153
26154
26155
26156
26157
26158
26159
26160
26161
# File 'lib/aws-sdk-securityhub/types.rb', line 26148

class GetConnectorResponse < Struct.new(
  :connector_arn,
  :connector_id,
  :name,
  :description,
  :created_at,
  :last_updated_at,
  :health,
  :provider_detail,
  :created_by,
  :enablement_status)
  SENSITIVE = []
  include Aws::Structure
end

#provider_detailTypes::CspmProviderDetail

The cloud provider configuration details for the connector.



26148
26149
26150
26151
26152
26153
26154
26155
26156
26157
26158
26159
26160
26161
# File 'lib/aws-sdk-securityhub/types.rb', line 26148

class GetConnectorResponse < Struct.new(
  :connector_arn,
  :connector_id,
  :name,
  :description,
  :created_at,
  :last_updated_at,
  :health,
  :provider_detail,
  :created_by,
  :enablement_status)
  SENSITIVE = []
  include Aws::Structure
end