Class: Aws::SecurityHub::Types::GetEnabledStandardsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::GetEnabledStandardsRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
The maximum number of results to return in the response.
-
#next_token ⇒ String
The token that is required for pagination.
-
#standards_subscription_arns ⇒ Array<String>
The list of the standards subscription ARNs for the standards to retrieve.
Instance Attribute Details
#max_results ⇒ Integer
The maximum number of results to return in the response.
25566 25567 25568 25569 25570 25571 25572 |
# File 'lib/aws-sdk-securityhub/types.rb', line 25566 class GetEnabledStandardsRequest < Struct.new( :standards_subscription_arns, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token that is required for pagination. On your first call to the GetEnabledStandards operation, set the value of this parameter to NULL.
For subsequent calls to the operation, to continue listing data, set the value of this parameter to the value returned from the previous response.
25566 25567 25568 25569 25570 25571 25572 |
# File 'lib/aws-sdk-securityhub/types.rb', line 25566 class GetEnabledStandardsRequest < Struct.new( :standards_subscription_arns, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#standards_subscription_arns ⇒ Array<String>
The list of the standards subscription ARNs for the standards to retrieve.
25566 25567 25568 25569 25570 25571 25572 |
# File 'lib/aws-sdk-securityhub/types.rb', line 25566 class GetEnabledStandardsRequest < Struct.new( :standards_subscription_arns, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |