Class: Aws::SecurityHub::Types::GetFindingAggregatorRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::GetFindingAggregatorRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#finding_aggregator_arn ⇒ String
The ARN of the finding aggregator to return details for.
Instance Attribute Details
#finding_aggregator_arn ⇒ String
The ARN of the finding aggregator to return details for. To obtain
the ARN, use ListFindingAggregators.
26300 26301 26302 26303 26304 |
# File 'lib/aws-sdk-securityhub/types.rb', line 26300 class GetFindingAggregatorRequest < Struct.new( :finding_aggregator_arn) SENSITIVE = [] include Aws::Structure end |