Class: Aws::SecurityHub::Types::GetFindingHistoryRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#end_timeTime

An ISO 8601-formatted timestamp that indicates the end time of the requested finding history.

If you provide values for both StartTime and EndTime, Security Hub CSPM returns finding history for the specified time period. If you provide a value for StartTime but not for EndTime, Security Hub CSPM returns finding history from the StartTime to the time at which the API is called. If you provide a value for EndTime but not for StartTime, Security Hub CSPM returns finding history from the [CreatedAt] timestamp of the finding to the EndTime. If you provide neither StartTime nor EndTime, Security Hub CSPM returns finding history from the CreatedAt timestamp of the finding to the time at which the API is called. In all of these scenarios, the response is limited to 100 results.

For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see [Timestamps].

[1]: docs.aws.amazon.com/securityhub/1.0/APIReference/API_AwsSecurityFindingFilters.html#securityhub-Type-AwsSecurityFindingFilters-CreatedAt [2]: docs.aws.amazon.com/securityhub/1.0/APIReference/Welcome.html#timestamps

Returns:

  • (Time)


25703
25704
25705
25706
25707
25708
25709
25710
25711
# File 'lib/aws-sdk-securityhub/types.rb', line 25703

class GetFindingHistoryRequest < Struct.new(
  :finding_identifier,
  :start_time,
  :end_time,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#finding_identifierTypes::AwsSecurityFindingIdentifier

Identifies which finding to get the finding history for.



25703
25704
25705
25706
25707
25708
25709
25710
25711
# File 'lib/aws-sdk-securityhub/types.rb', line 25703

class GetFindingHistoryRequest < Struct.new(
  :finding_identifier,
  :start_time,
  :end_time,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to be returned. If you don’t provide it, Security Hub CSPM returns up to 100 results of finding history.

Returns:

  • (Integer)


25703
25704
25705
25706
25707
25708
25709
25710
25711
# File 'lib/aws-sdk-securityhub/types.rb', line 25703

class GetFindingHistoryRequest < Struct.new(
  :finding_identifier,
  :start_time,
  :end_time,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

A token for pagination purposes. Provide NULL as the initial value. In subsequent requests, provide the token included in the response to get up to an additional 100 results of finding history. If you don’t provide NextToken, Security Hub CSPM returns up to 100 results of finding history for each request.

Returns:

  • (String)


25703
25704
25705
25706
25707
25708
25709
25710
25711
# File 'lib/aws-sdk-securityhub/types.rb', line 25703

class GetFindingHistoryRequest < Struct.new(
  :finding_identifier,
  :start_time,
  :end_time,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#start_timeTime

A timestamp that indicates the start time of the requested finding history.

If you provide values for both StartTime and EndTime, Security Hub CSPM returns finding history for the specified time period. If you provide a value for StartTime but not for EndTime, Security Hub CSPM returns finding history from the StartTime to the time at which the API is called. If you provide a value for EndTime but not for StartTime, Security Hub CSPM returns finding history from the [CreatedAt] timestamp of the finding to the EndTime. If you provide neither StartTime nor EndTime, Security Hub CSPM returns finding history from the CreatedAt timestamp of the finding to the time at which the API is called. In all of these scenarios, the response is limited to 100 results.

For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see [Timestamps].

[1]: docs.aws.amazon.com/securityhub/1.0/APIReference/API_AwsSecurityFindingFilters.html#securityhub-Type-AwsSecurityFindingFilters-CreatedAt [2]: docs.aws.amazon.com/securityhub/1.0/APIReference/Welcome.html#timestamps

Returns:

  • (Time)


25703
25704
25705
25706
25707
25708
25709
25710
25711
# File 'lib/aws-sdk-securityhub/types.rb', line 25703

class GetFindingHistoryRequest < Struct.new(
  :finding_identifier,
  :start_time,
  :end_time,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end