Class: Aws::SecurityHub::Types::GetFindingsRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#filtersTypes::AwsSecurityFindingFilters

The finding attributes used to define a condition to filter the returned findings.

You can filter by up to 10 finding attributes. For each attribute, you can provide up to 20 filter values.

Note that in the available filter fields, WorkflowState is deprecated. To search for a finding based on its workflow status, use WorkflowStatus.



25803
25804
25805
25806
25807
25808
25809
25810
# File 'lib/aws-sdk-securityhub/types.rb', line 25803

class GetFindingsRequest < Struct.new(
  :filters,
  :sort_criteria,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of findings to return.

Returns:

  • (Integer)


25803
25804
25805
25806
25807
25808
25809
25810
# File 'lib/aws-sdk-securityhub/types.rb', line 25803

class GetFindingsRequest < Struct.new(
  :filters,
  :sort_criteria,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token that is required for pagination. On your first call to the GetFindings operation, set the value of this parameter to NULL.

For subsequent calls to the operation, to continue listing data, set the value of this parameter to the value returned from the previous response.

Returns:

  • (String)


25803
25804
25805
25806
25807
25808
25809
25810
# File 'lib/aws-sdk-securityhub/types.rb', line 25803

class GetFindingsRequest < Struct.new(
  :filters,
  :sort_criteria,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#sort_criteriaArray<Types::SortCriterion>

The finding attributes used to sort the list of returned findings.

Returns:



25803
25804
25805
25806
25807
25808
25809
25810
# File 'lib/aws-sdk-securityhub/types.rb', line 25803

class GetFindingsRequest < Struct.new(
  :filters,
  :sort_criteria,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end