Class: Aws::SecurityHub::Types::GetFindingsResponse

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#findingsArray<Types::AwsSecurityFinding>

The findings that matched the filters specified in the request.

Returns:



25924
25925
25926
25927
25928
25929
# File 'lib/aws-sdk-securityhub/types.rb', line 25924

class GetFindingsResponse < Struct.new(
  :findings,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The pagination token to use to request the next page of results.

Returns:

  • (String)


25924
25925
25926
25927
25928
25929
# File 'lib/aws-sdk-securityhub/types.rb', line 25924

class GetFindingsResponse < Struct.new(
  :findings,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end