Class: Aws::SecurityHub::Types::GetFindingsV2Request
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::GetFindingsV2Request
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#filters ⇒ Types::OcsfFindingFilters
The finding attributes used to define a condition to filter the returned OCSF findings.
-
#max_results ⇒ Integer
The maximum number of results to return.
-
#next_token ⇒ String
The token required for pagination.
-
#sort_criteria ⇒ Array<Types::SortCriterion>
The finding attributes used to sort the list of returned findings.
Instance Attribute Details
#filters ⇒ Types::OcsfFindingFilters
The finding attributes used to define a condition to filter the returned OCSF findings. You can filter up to 10 composite filters. For each filter type inside of a composite filter, you can provide up to 20 filters.
25913 25914 25915 25916 25917 25918 25919 25920 |
# File 'lib/aws-sdk-securityhub/types.rb', line 25913 class GetFindingsV2Request < Struct.new( :filters, :sort_criteria, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return.
25913 25914 25915 25916 25917 25918 25919 25920 |
# File 'lib/aws-sdk-securityhub/types.rb', line 25913 class GetFindingsV2Request < Struct.new( :filters, :sort_criteria, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token required for pagination. On your first call, set the value of this parameter to NULL. For subsequent calls, to continue listing data, set the value of this parameter to the value returned in the previous response.
25913 25914 25915 25916 25917 25918 25919 25920 |
# File 'lib/aws-sdk-securityhub/types.rb', line 25913 class GetFindingsV2Request < Struct.new( :filters, :sort_criteria, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#sort_criteria ⇒ Array<Types::SortCriterion>
The finding attributes used to sort the list of returned findings.
25913 25914 25915 25916 25917 25918 25919 25920 |
# File 'lib/aws-sdk-securityhub/types.rb', line 25913 class GetFindingsV2Request < Struct.new( :filters, :sort_criteria, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |