Class: Aws::SecurityHub::Types::GetInsightsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::GetInsightsRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#insight_arns ⇒ Array<String>
The ARNs of the insights to describe.
-
#max_results ⇒ Integer
The maximum number of items to return in the response.
-
#next_token ⇒ String
The token that is required for pagination.
Instance Attribute Details
#insight_arns ⇒ Array<String>
The ARNs of the insights to describe. If you don’t provide any insight ARNs, then GetInsights returns all of your custom insights. It does not return any managed insights.
25985 25986 25987 25988 25989 25990 25991 |
# File 'lib/aws-sdk-securityhub/types.rb', line 25985 class GetInsightsRequest < Struct.new( :insight_arns, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of items to return in the response.
25985 25986 25987 25988 25989 25990 25991 |
# File 'lib/aws-sdk-securityhub/types.rb', line 25985 class GetInsightsRequest < Struct.new( :insight_arns, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token that is required for pagination. On your first call to the GetInsights operation, set the value of this parameter to NULL.
For subsequent calls to the operation, to continue listing data, set the value of this parameter to the value returned from the previous response.
25985 25986 25987 25988 25989 25990 25991 |
# File 'lib/aws-sdk-securityhub/types.rb', line 25985 class GetInsightsRequest < Struct.new( :insight_arns, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |