Class: Aws::SecurityHub::Types::GetRecommendedPolicyV2Response

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#errorTypes::RecommendationError

Detailed information for a ‘FAILED` retrieval status.



26252
26253
26254
26255
26256
26257
26258
26259
26260
26261
# File 'lib/aws-sdk-securityhub/types.rb', line 26252

class GetRecommendedPolicyV2Response < Struct.new(
  :next_token,
  :recommendation_type,
  :recommendation_steps,
  :error,
  :status,
  :resource_arn)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The pagination token to use to request the next page of results.

Returns:

  • (String)


26252
26253
26254
26255
26256
26257
26258
26259
26260
26261
# File 'lib/aws-sdk-securityhub/types.rb', line 26252

class GetRecommendedPolicyV2Response < Struct.new(
  :next_token,
  :recommendation_type,
  :recommendation_steps,
  :error,
  :status,
  :resource_arn)
  SENSITIVE = []
  include Aws::Structure
end

#recommendation_stepsArray<Types::RecommendationStep>

The recommended steps to take to resolve the finding.

Returns:



26252
26253
26254
26255
26256
26257
26258
26259
26260
26261
# File 'lib/aws-sdk-securityhub/types.rb', line 26252

class GetRecommendedPolicyV2Response < Struct.new(
  :next_token,
  :recommendation_type,
  :recommendation_steps,
  :error,
  :status,
  :resource_arn)
  SENSITIVE = []
  include Aws::Structure
end

#recommendation_typeString

The type of recommendation for the finding.

Returns:

  • (String)


26252
26253
26254
26255
26256
26257
26258
26259
26260
26261
# File 'lib/aws-sdk-securityhub/types.rb', line 26252

class GetRecommendedPolicyV2Response < Struct.new(
  :next_token,
  :recommendation_type,
  :recommendation_steps,
  :error,
  :status,
  :resource_arn)
  SENSITIVE = []
  include Aws::Structure
end

#resource_arnString

The ARN of the resource of the finding.

Returns:

  • (String)


26252
26253
26254
26255
26256
26257
26258
26259
26260
26261
# File 'lib/aws-sdk-securityhub/types.rb', line 26252

class GetRecommendedPolicyV2Response < Struct.new(
  :next_token,
  :recommendation_type,
  :recommendation_steps,
  :error,
  :status,
  :resource_arn)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The current status of the recommended policy retrieval.

Returns:

  • (String)


26252
26253
26254
26255
26256
26257
26258
26259
26260
26261
# File 'lib/aws-sdk-securityhub/types.rb', line 26252

class GetRecommendedPolicyV2Response < Struct.new(
  :next_token,
  :recommendation_type,
  :recommendation_steps,
  :error,
  :status,
  :resource_arn)
  SENSITIVE = []
  include Aws::Structure
end