Class: Aws::SecurityHub::Types::GetResourcesStatisticsV2Request

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#group_by_rulesArray<Types::ResourceGroupByRule>

How resource statistics should be aggregated and organized in the response.

Returns:



27083
27084
27085
27086
27087
27088
27089
27090
# File 'lib/aws-sdk-securityhub/types.rb', line 27083

class GetResourcesStatisticsV2Request < Struct.new(
  :group_by_rules,
  :scopes,
  :sort_order,
  :max_statistic_results)
  SENSITIVE = []
  include Aws::Structure
end

#max_statistic_resultsInteger

The maximum number of results to be returned.

Returns:

  • (Integer)


27083
27084
27085
27086
27087
27088
27089
27090
# File 'lib/aws-sdk-securityhub/types.rb', line 27083

class GetResourcesStatisticsV2Request < Struct.new(
  :group_by_rules,
  :scopes,
  :sort_order,
  :max_statistic_results)
  SENSITIVE = []
  include Aws::Structure
end

#scopesTypes::ResourceScopes

Limits the results to resources from specific organizational units or from the delegated administrator's organization. Only the delegated administrator account can use this parameter. Other accounts receive an AccessDeniedException.

This parameter is optional. If you omit it, the delegated administrator sees statistics from all accounts across the entire organization. Other accounts see only statistics for their own resources.

You can specify up to 10 entries in Scopes.AwsOrganizations. If multiple entries are specified, the entries are combined using OR logic.



27083
27084
27085
27086
27087
27088
27089
27090
# File 'lib/aws-sdk-securityhub/types.rb', line 27083

class GetResourcesStatisticsV2Request < Struct.new(
  :group_by_rules,
  :scopes,
  :sort_order,
  :max_statistic_results)
  SENSITIVE = []
  include Aws::Structure
end

#sort_orderString

Sorts aggregated statistics.

Returns:

  • (String)


27083
27084
27085
27086
27087
27088
27089
27090
# File 'lib/aws-sdk-securityhub/types.rb', line 27083

class GetResourcesStatisticsV2Request < Struct.new(
  :group_by_rules,
  :scopes,
  :sort_order,
  :max_statistic_results)
  SENSITIVE = []
  include Aws::Structure
end