Class: Aws::SecurityHub::Types::GetResourcesV2Request

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#filtersTypes::ResourcesFilters

Filters resources based on a set of criteria.



26199
26200
26201
26202
26203
26204
26205
26206
# File 'lib/aws-sdk-securityhub/types.rb', line 26199

class GetResourcesV2Request < Struct.new(
  :filters,
  :sort_criteria,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return.

Returns:

  • (Integer)


26199
26200
26201
26202
26203
26204
26205
26206
# File 'lib/aws-sdk-securityhub/types.rb', line 26199

class GetResourcesV2Request < Struct.new(
  :filters,
  :sort_criteria,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token required for pagination. On your first call, set the value of this parameter to NULL. For subsequent calls, to continue listing data, set the value of this parameter to the value returned in the previous response.

Returns:

  • (String)


26199
26200
26201
26202
26203
26204
26205
26206
# File 'lib/aws-sdk-securityhub/types.rb', line 26199

class GetResourcesV2Request < Struct.new(
  :filters,
  :sort_criteria,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#sort_criteriaArray<Types::SortCriterion>

The finding attributes used to sort the list of returned findings.

Returns:



26199
26200
26201
26202
26203
26204
26205
26206
# File 'lib/aws-sdk-securityhub/types.rb', line 26199

class GetResourcesV2Request < Struct.new(
  :filters,
  :sort_criteria,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end