Class: Aws::SecurityHub::Types::GroupByResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::GroupByResult
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Represents finding statistics grouped by GroupedByField.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#group_by_field ⇒ String
The attribute by which filtered security findings should be grouped.
-
#group_by_values ⇒ Array<Types::GroupByValue>
An array of grouped values and their respective counts for each
GroupByField.
Instance Attribute Details
#group_by_field ⇒ String
The attribute by which filtered security findings should be grouped.
27098 27099 27100 27101 27102 27103 |
# File 'lib/aws-sdk-securityhub/types.rb', line 27098 class GroupByResult < Struct.new( :group_by_field, :group_by_values) SENSITIVE = [] include Aws::Structure end |
#group_by_values ⇒ Array<Types::GroupByValue>
An array of grouped values and their respective counts for each
GroupByField.
27098 27099 27100 27101 27102 27103 |
# File 'lib/aws-sdk-securityhub/types.rb', line 27098 class GroupByResult < Struct.new( :group_by_field, :group_by_values) SENSITIVE = [] include Aws::Structure end |