Class: Aws::SecurityHub::Types::GroupByValue

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

Represents individual aggregated results when grouping security findings for each GroupByField.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#countInteger

The number of findings for a specific FieldValue and GroupByField.

Returns:

  • (Integer)


27139
27140
27141
27142
27143
27144
# File 'lib/aws-sdk-securityhub/types.rb', line 27139

class GroupByValue < Struct.new(
  :field_value,
  :count)
  SENSITIVE = []
  include Aws::Structure
end

#field_valueString

The value of the field by which findings are grouped.

Returns:

  • (String)


27139
27140
27141
27142
27143
27144
# File 'lib/aws-sdk-securityhub/types.rb', line 27139

class GroupByValue < Struct.new(
  :field_value,
  :count)
  SENSITIVE = []
  include Aws::Structure
end