Class: Aws::SecurityHub::Types::HealthCheck

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

Information about the operational status and health of a connectorV2.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#connector_statusString

The status of the connectorV2.

Returns:

  • (String)


27168
27169
27170
27171
27172
27173
27174
27175
# File 'lib/aws-sdk-securityhub/types.rb', line 27168

class HealthCheck < Struct.new(
  :connector_status,
  :message,
  :last_checked_at,
  :issues)
  SENSITIVE = []
  include Aws::Structure
end

#issuesArray<Types::HealthIssue>

A list of health issues associated with the connector, including error codes and messages.

Returns:



27168
27169
27170
27171
27172
27173
27174
27175
# File 'lib/aws-sdk-securityhub/types.rb', line 27168

class HealthCheck < Struct.new(
  :connector_status,
  :message,
  :last_checked_at,
  :issues)
  SENSITIVE = []
  include Aws::Structure
end

#last_checked_atTime

ISO 8601 UTC timestamp for the time check the health status of the connectorV2.

Returns:

  • (Time)


27168
27169
27170
27171
27172
27173
27174
27175
# File 'lib/aws-sdk-securityhub/types.rb', line 27168

class HealthCheck < Struct.new(
  :connector_status,
  :message,
  :last_checked_at,
  :issues)
  SENSITIVE = []
  include Aws::Structure
end

#messageString

The message for the reason of connectorStatus change.

Returns:

  • (String)


27168
27169
27170
27171
27172
27173
27174
27175
# File 'lib/aws-sdk-securityhub/types.rb', line 27168

class HealthCheck < Struct.new(
  :connector_status,
  :message,
  :last_checked_at,
  :issues)
  SENSITIVE = []
  include Aws::Structure
end