Class: Aws::SecurityHub::Types::HealthIssue

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

Represents a specific health issue detected for a connector.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#codeString

The error code that identifies the type of health issue.

Returns:

  • (String)


27189
27190
27191
27192
27193
27194
# File 'lib/aws-sdk-securityhub/types.rb', line 27189

class HealthIssue < Struct.new(
  :code,
  :message)
  SENSITIVE = []
  include Aws::Structure
end

#messageString

A human-readable message that describes the health issue.

Returns:

  • (String)


27189
27190
27191
27192
27193
27194
# File 'lib/aws-sdk-securityhub/types.rb', line 27189

class HealthIssue < Struct.new(
  :code,
  :message)
  SENSITIVE = []
  include Aws::Structure
end