Class: Aws::SecurityHub::Types::Indicator

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

Contains information about the indicators observed in an Amazon GuardDuty Extended Threat Detection attack sequence. Indicators include a set of signals, which can be API activities or findings that GuardDuty uses to detect an attack sequence finding. GuardDuty generates an attack sequence finding when multiple signals align to a potentially suspicious activity. To receive GuardDuty attack sequence findings in Security Hub CSPM, you must have GuardDuty and GuardDuty S3 Protection enabled. For more information, see GuardDuty Extended Threat Detection in the Amazon GuardDuty User Guide.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#keyString

The name of the indicator that’s present in the attack sequence finding.

Returns:

  • (String)


27381
27382
27383
27384
27385
27386
27387
27388
# File 'lib/aws-sdk-securityhub/types.rb', line 27381

class Indicator < Struct.new(
  :key,
  :values,
  :title,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#titleString

The title describing the indicator.

Returns:

  • (String)


27381
27382
27383
27384
27385
27386
27387
27388
# File 'lib/aws-sdk-securityhub/types.rb', line 27381

class Indicator < Struct.new(
  :key,
  :values,
  :title,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The type of indicator.

Returns:

  • (String)


27381
27382
27383
27384
27385
27386
27387
27388
# File 'lib/aws-sdk-securityhub/types.rb', line 27381

class Indicator < Struct.new(
  :key,
  :values,
  :title,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#valuesArray<String>

Values associated with each indicator key. For example, if the indicator key is SUSPICIOUS_NETWORK, then the value will be the name of the network. If the indicator key is ATTACK_TACTIC, then the value will be one of the MITRE tactics.

Returns:

  • (Array<String>)


27381
27382
27383
27384
27385
27386
27387
27388
# File 'lib/aws-sdk-securityhub/types.rb', line 27381

class Indicator < Struct.new(
  :key,
  :values,
  :title,
  :type)
  SENSITIVE = []
  include Aws::Structure
end