Class: Aws::SecurityHub::Types::LimitExceededException

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

The request was rejected because it attempted to create resources beyond the current Amazon Web Services account or throttling limits. The error code describes the limit exceeded.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#codeString

Returns:



26875
26876
26877
26878
26879
26880
# File 'lib/aws-sdk-securityhub/types.rb', line 26875

class LimitExceededException < Struct.new(
  :message,
  :code)
  SENSITIVE = []
  include Aws::Structure
end

#messageString

Returns:



26875
26876
26877
26878
26879
26880
# File 'lib/aws-sdk-securityhub/types.rb', line 26875

class LimitExceededException < Struct.new(
  :message,
  :code)
  SENSITIVE = []
  include Aws::Structure
end