Class: Aws::SecurityHub::Types::ListConfigurationPolicyAssociationsRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#filtersTypes::AssociationFilters

Options for filtering the ListConfigurationPolicyAssociations response. You can filter by the Amazon Resource Name (ARN) or universally unique identifier (UUID) of a configuration, AssociationType, or AssociationStatus.

Returns:



28106
28107
28108
28109
28110
28111
28112
# File 'lib/aws-sdk-securityhub/types.rb', line 28106

class ListConfigurationPolicyAssociationsRequest < Struct.new(
  :next_token,
  :max_results,
  :filters)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results that's returned by ListConfigurationPolicies in each page of the response. When this parameter is used, ListConfigurationPolicyAssociations returns the specified number of results in a single page and a NextToken response element. You can see the remaining results of the initial request by sending another ListConfigurationPolicyAssociations request with the returned NextToken value. A valid range for MaxResults is between 1 and 100.

Returns:



28106
28107
28108
28109
28110
28111
28112
# File 'lib/aws-sdk-securityhub/types.rb', line 28106

class ListConfigurationPolicyAssociationsRequest < Struct.new(
  :next_token,
  :max_results,
  :filters)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The NextToken value that's returned from a previous paginated ListConfigurationPolicyAssociations request where MaxResults was used but the results exceeded the value of that parameter. Pagination continues from the end of the previous response that returned the NextToken value. This value is null when there are no more results to return.

Returns:



28106
28107
28108
28109
28110
28111
28112
# File 'lib/aws-sdk-securityhub/types.rb', line 28106

class ListConfigurationPolicyAssociationsRequest < Struct.new(
  :next_token,
  :max_results,
  :filters)
  SENSITIVE = []
  include Aws::Structure
end