Class: Aws::SecurityHub::Types::ListFreeTrialStatusesV2Request

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#account_idsArray<String>

The Amazon Web Services account identifiers to list free trial status for. You can specify accounts other than your own only if you are a delegated Security Hub administrator.

Returns:

  • (Array<String>)


28344
28345
28346
28347
28348
28349
28350
28351
# File 'lib/aws-sdk-securityhub/types.rb', line 28344

class ListFreeTrialStatusesV2Request < Struct.new(
  :account_ids,
  :statuses,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return. If you don't specify a value, Security Hub returns up to 100 results.

Returns:

  • (Integer)


28344
28345
28346
28347
28348
28349
28350
28351
# File 'lib/aws-sdk-securityhub/types.rb', line 28344

class ListFreeTrialStatusesV2Request < Struct.new(
  :account_ids,
  :statuses,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The pagination token to request the next page of results.

Returns:

  • (String)


28344
28345
28346
28347
28348
28349
28350
28351
# File 'lib/aws-sdk-securityhub/types.rb', line 28344

class ListFreeTrialStatusesV2Request < Struct.new(
  :account_ids,
  :statuses,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#statusesArray<String>

The free trial statuses to filter the results by. Valid values:

  • ACTIVE returns only features with an ongoing free trial period.

  • INACTIVE returns only features whose free trial period has ended, or that never started.

Returns:

  • (Array<String>)


28344
28345
28346
28347
28348
28349
28350
28351
# File 'lib/aws-sdk-securityhub/types.rb', line 28344

class ListFreeTrialStatusesV2Request < Struct.new(
  :account_ids,
  :statuses,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end