Class: Aws::SecurityHub::Types::ListInvitationsRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#max_resultsInteger

The maximum number of items to return in the response.



28387
28388
28389
28390
28391
28392
# File 'lib/aws-sdk-securityhub/types.rb', line 28387

class ListInvitationsRequest < Struct.new(
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token that is required for pagination. On your first call to the ListInvitations operation, set the value of this parameter to NULL.

For subsequent calls to the operation, to continue listing data, set the value of this parameter to the value returned from the previous response.



28387
28388
28389
28390
28391
28392
# File 'lib/aws-sdk-securityhub/types.rb', line 28387

class ListInvitationsRequest < Struct.new(
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end