Class: Aws::SecurityHub::Types::ListInvitationsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::ListInvitationsResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#invitations ⇒ Array<Types::Invitation>
The details of the invitations returned by the operation.
-
#next_token ⇒ String
The pagination token to use to request the next page of results.
Instance Attribute Details
#invitations ⇒ Array<Types::Invitation>
The details of the invitations returned by the operation.
28404 28405 28406 28407 28408 28409 |
# File 'lib/aws-sdk-securityhub/types.rb', line 28404 class ListInvitationsResponse < Struct.new( :invitations, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The pagination token to use to request the next page of results.
28404 28405 28406 28407 28408 28409 |
# File 'lib/aws-sdk-securityhub/types.rb', line 28404 class ListInvitationsResponse < Struct.new( :invitations, :next_token) SENSITIVE = [] include Aws::Structure end |