Class: Aws::SecurityHub::Types::ListSecurityControlDefinitionsRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#max_resultsInteger

An optional parameter that limits the total results of the API response to the specified number. If this parameter isn't provided in the request, the results include the first 25 security controls that apply to the specified standard. The results also include a NextToken parameter that you can use in a subsequent API call to get the next 25 controls. This repeats until all controls for the standard are returned.

Returns:

  • (Integer)


28541
28542
28543
28544
28545
28546
28547
28548
# File 'lib/aws-sdk-securityhub/types.rb', line 28541

class ListSecurityControlDefinitionsRequest < Struct.new(
  :standards_arn,
  :next_token,
  :max_results,
  :providers)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

Optional pagination parameter.

Returns:

  • (String)


28541
28542
28543
28544
28545
28546
28547
28548
# File 'lib/aws-sdk-securityhub/types.rb', line 28541

class ListSecurityControlDefinitionsRequest < Struct.new(
  :standards_arn,
  :next_token,
  :max_results,
  :providers)
  SENSITIVE = []
  include Aws::Structure
end

#providersArray<String>

A list of cloud providers to filter the security control definitions by. For example, specify Azure to return only controls that evaluate Azure resources.

Returns:

  • (Array<String>)


28541
28542
28543
28544
28545
28546
28547
28548
# File 'lib/aws-sdk-securityhub/types.rb', line 28541

class ListSecurityControlDefinitionsRequest < Struct.new(
  :standards_arn,
  :next_token,
  :max_results,
  :providers)
  SENSITIVE = []
  include Aws::Structure
end

#standards_arnString

The Amazon Resource Name (ARN) of the standard that you want to view controls for.

Returns:

  • (String)


28541
28542
28543
28544
28545
28546
28547
28548
# File 'lib/aws-sdk-securityhub/types.rb', line 28541

class ListSecurityControlDefinitionsRequest < Struct.new(
  :standards_arn,
  :next_token,
  :max_results,
  :providers)
  SENSITIVE = []
  include Aws::Structure
end