Class: Aws::SecurityHub::Types::ListStandardsControlAssociationsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::ListStandardsControlAssociationsRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
An optional parameter that limits the total results of the API response to the specified number.
-
#next_token ⇒ String
Optional pagination parameter.
-
#security_control_id ⇒ String
The identifier of the control (identified with
SecurityControlId,SecurityControlArn, or a mix of both parameters) that you want to determine the enablement status of in each enabled standard.
Instance Attribute Details
#max_results ⇒ Integer
An optional parameter that limits the total results of the API
response to the specified number. If this parameter isn't provided
in the request, the results include the first 25 standard and
control associations. The results also include a NextToken
parameter that you can use in a subsequent API call to get the next
25 associations. This repeats until all associations for the
specified control are returned. The number of results is limited by
the number of supported Security Hub CSPM standards that you've
enabled in the calling account.
28592 28593 28594 28595 28596 28597 28598 |
# File 'lib/aws-sdk-securityhub/types.rb', line 28592 class ListStandardsControlAssociationsRequest < Struct.new( :security_control_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
Optional pagination parameter.
28592 28593 28594 28595 28596 28597 28598 |
# File 'lib/aws-sdk-securityhub/types.rb', line 28592 class ListStandardsControlAssociationsRequest < Struct.new( :security_control_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#security_control_id ⇒ String
The identifier of the control (identified with SecurityControlId,
SecurityControlArn, or a mix of both parameters) that you want to
determine the enablement status of in each enabled standard.
28592 28593 28594 28595 28596 28597 28598 |
# File 'lib/aws-sdk-securityhub/types.rb', line 28592 class ListStandardsControlAssociationsRequest < Struct.new( :security_control_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |