Class: Aws::SecurityHub::Types::LoadBalancerState

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

Information about the state of the load balancer.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#codeString

The state code. The initial state of the load balancer is provisioning.

After the load balancer is fully set up and ready to route traffic, its state is active.

If the load balancer could not be set up, its state is failed.

Returns:



27517
27518
27519
27520
27521
27522
# File 'lib/aws-sdk-securityhub/types.rb', line 27517

class LoadBalancerState < Struct.new(
  :code,
  :reason)
  SENSITIVE = []
  include Aws::Structure
end

#reasonString

A description of the state.

Returns:



27517
27518
27519
27520
27521
27522
# File 'lib/aws-sdk-securityhub/types.rb', line 27517

class LoadBalancerState < Struct.new(
  :code,
  :reason)
  SENSITIVE = []
  include Aws::Structure
end