Class: Aws::SecurityHub::Types::Member
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::Member
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
The details about a member account.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#account_id ⇒ String
The Amazon Web Services account ID of the member account.
-
#administrator_id ⇒ String
The Amazon Web Services account ID of the Security Hub CSPM administrator account associated with this member account.
-
#email ⇒ String
The email address of the member account.
-
#invited_at ⇒ Time
A timestamp for the date and time when the invitation was sent to the member account.
-
#master_id ⇒ String
This is replaced by
AdministratorID. -
#member_status ⇒ String
The status of the relationship between the member account and its administrator account.
-
#updated_at ⇒ Time
The timestamp for the date and time when the member account was updated.
Instance Attribute Details
#account_id ⇒ String
The Amazon Web Services account ID of the member account.
27837 27838 27839 27840 27841 27842 27843 27844 27845 27846 27847 |
# File 'lib/aws-sdk-securityhub/types.rb', line 27837 class Member < Struct.new( :account_id, :email, :master_id, :administrator_id, :member_status, :invited_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#administrator_id ⇒ String
The Amazon Web Services account ID of the Security Hub CSPM administrator account associated with this member account.
27837 27838 27839 27840 27841 27842 27843 27844 27845 27846 27847 |
# File 'lib/aws-sdk-securityhub/types.rb', line 27837 class Member < Struct.new( :account_id, :email, :master_id, :administrator_id, :member_status, :invited_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#email ⇒ String
The email address of the member account.
27837 27838 27839 27840 27841 27842 27843 27844 27845 27846 27847 |
# File 'lib/aws-sdk-securityhub/types.rb', line 27837 class Member < Struct.new( :account_id, :email, :master_id, :administrator_id, :member_status, :invited_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#invited_at ⇒ Time
A timestamp for the date and time when the invitation was sent to the member account.
27837 27838 27839 27840 27841 27842 27843 27844 27845 27846 27847 |
# File 'lib/aws-sdk-securityhub/types.rb', line 27837 class Member < Struct.new( :account_id, :email, :master_id, :administrator_id, :member_status, :invited_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#master_id ⇒ String
This is replaced by AdministratorID.
The Amazon Web Services account ID of the Security Hub CSPM administrator account associated with this member account.
27837 27838 27839 27840 27841 27842 27843 27844 27845 27846 27847 |
# File 'lib/aws-sdk-securityhub/types.rb', line 27837 class Member < Struct.new( :account_id, :email, :master_id, :administrator_id, :member_status, :invited_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#member_status ⇒ String
The status of the relationship between the member account and its administrator account.
The status can have one of the following values:
-
Created- Indicates that the administrator account added the member account, but has not yet invited the member account. -
Invited- Indicates that the administrator account invited the member account. The member account has not yet responded to the invitation. -
Enabled- Indicates that the member account is currently active. For manually invited member accounts, indicates that the member account accepted the invitation. -
Removed- Indicates that the administrator account disassociated the member account. -
Resigned- Indicates that the member account disassociated themselves from the administrator account. -
Deleted- Indicates that the administrator account deleted the member account. -
AccountSuspended- Indicates that an organization account was suspended from Amazon Web Services at the same time that the administrator account tried to enable the organization account as a member account.
27837 27838 27839 27840 27841 27842 27843 27844 27845 27846 27847 |
# File 'lib/aws-sdk-securityhub/types.rb', line 27837 class Member < Struct.new( :account_id, :email, :master_id, :administrator_id, :member_status, :invited_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The timestamp for the date and time when the member account was updated.
27837 27838 27839 27840 27841 27842 27843 27844 27845 27846 27847 |
# File 'lib/aws-sdk-securityhub/types.rb', line 27837 class Member < Struct.new( :account_id, :email, :master_id, :administrator_id, :member_status, :invited_at, :updated_at) SENSITIVE = [] include Aws::Structure end |