Class: Aws::SecurityHub::Types::NetworkEndpoint

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

Contains information about network endpoints involved in an Amazon GuardDuty Extended Threat Detection attack sequence. GuardDuty generates an attack sequence finding when multiple events align to a potentially suspicious activity. To receive GuardDuty attack sequence findings in Security Hub CSPM, you must have GuardDuty enabled. For more information, see GuardDuty Extended Threat Detection in the Amazon GuardDuty User Guide.

This field can provide information about the network endpoints associated with the resource in the attack sequence finding, or about a specific network endpoint used for the attack.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#autonomous_systemTypes::NetworkAutonomousSystem

The Autonomous System Number (ASN) of the network endpoint.



29092
29093
29094
29095
29096
29097
29098
29099
29100
29101
29102
# File 'lib/aws-sdk-securityhub/types.rb', line 29092

class NetworkEndpoint < Struct.new(
  :id,
  :ip,
  :domain,
  :port,
  :location,
  :autonomous_system,
  :connection)
  SENSITIVE = []
  include Aws::Structure
end

#connectionTypes::NetworkConnection

Information about the network connection.



29092
29093
29094
29095
29096
29097
29098
29099
29100
29101
29102
# File 'lib/aws-sdk-securityhub/types.rb', line 29092

class NetworkEndpoint < Struct.new(
  :id,
  :ip,
  :domain,
  :port,
  :location,
  :autonomous_system,
  :connection)
  SENSITIVE = []
  include Aws::Structure
end

#domainString

The domain information for the network endpoint.

Returns:

  • (String)


29092
29093
29094
29095
29096
29097
29098
29099
29100
29101
29102
# File 'lib/aws-sdk-securityhub/types.rb', line 29092

class NetworkEndpoint < Struct.new(
  :id,
  :ip,
  :domain,
  :port,
  :location,
  :autonomous_system,
  :connection)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The identifier of the network endpoint involved in the attack sequence.

Returns:

  • (String)


29092
29093
29094
29095
29096
29097
29098
29099
29100
29101
29102
# File 'lib/aws-sdk-securityhub/types.rb', line 29092

class NetworkEndpoint < Struct.new(
  :id,
  :ip,
  :domain,
  :port,
  :location,
  :autonomous_system,
  :connection)
  SENSITIVE = []
  include Aws::Structure
end

#ipString

The IP address used in the network endpoint.

Returns:

  • (String)


29092
29093
29094
29095
29096
29097
29098
29099
29100
29101
29102
# File 'lib/aws-sdk-securityhub/types.rb', line 29092

class NetworkEndpoint < Struct.new(
  :id,
  :ip,
  :domain,
  :port,
  :location,
  :autonomous_system,
  :connection)
  SENSITIVE = []
  include Aws::Structure
end

#locationTypes::NetworkGeoLocation

Information about the location of the network endpoint.



29092
29093
29094
29095
29096
29097
29098
29099
29100
29101
29102
# File 'lib/aws-sdk-securityhub/types.rb', line 29092

class NetworkEndpoint < Struct.new(
  :id,
  :ip,
  :domain,
  :port,
  :location,
  :autonomous_system,
  :connection)
  SENSITIVE = []
  include Aws::Structure
end

#portInteger

The port number associated with the network endpoint.

Returns:

  • (Integer)


29092
29093
29094
29095
29096
29097
29098
29099
29100
29101
29102
# File 'lib/aws-sdk-securityhub/types.rb', line 29092

class NetworkEndpoint < Struct.new(
  :id,
  :ip,
  :domain,
  :port,
  :location,
  :autonomous_system,
  :connection)
  SENSITIVE = []
  include Aws::Structure
end