Class: Aws::SecurityHub::Types::NetworkGeoLocation

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

Contains information about the location of a network endpoint involved in an Amazon GuardDuty Extended Threat Detection attack sequence. GuardDuty generates an attack sequence finding when multiple events align to a potentially suspicious activity. To receive GuardDuty attack sequence findings in Security Hub CSPM, you must have GuardDuty enabled. For more information, see GuardDuty Extended Threat Detection in the Amazon GuardDuty User Guide.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cityString

The name of the city.

Returns:

  • (String)


28115
28116
28117
28118
28119
28120
28121
28122
# File 'lib/aws-sdk-securityhub/types.rb', line 28115

class NetworkGeoLocation < Struct.new(
  :city,
  :country,
  :lat,
  :lon)
  SENSITIVE = []
  include Aws::Structure
end

#countryString

The name of the country.

Returns:

  • (String)


28115
28116
28117
28118
28119
28120
28121
28122
# File 'lib/aws-sdk-securityhub/types.rb', line 28115

class NetworkGeoLocation < Struct.new(
  :city,
  :country,
  :lat,
  :lon)
  SENSITIVE = []
  include Aws::Structure
end

#latFloat

The latitude information of the endpoint location.

Returns:

  • (Float)


28115
28116
28117
28118
28119
28120
28121
28122
# File 'lib/aws-sdk-securityhub/types.rb', line 28115

class NetworkGeoLocation < Struct.new(
  :city,
  :country,
  :lat,
  :lon)
  SENSITIVE = []
  include Aws::Structure
end

#lonFloat

The longitude information of the endpoint location.

Returns:

  • (Float)


28115
28116
28117
28118
28119
28120
28121
28122
# File 'lib/aws-sdk-securityhub/types.rb', line 28115

class NetworkGeoLocation < Struct.new(
  :city,
  :country,
  :lat,
  :lon)
  SENSITIVE = []
  include Aws::Structure
end