Class: Aws::SecurityHub::Types::Note

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

A user-defined note added to a finding.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#textString

The text of a note.

Length Constraints: Minimum of 1. Maximum of 512.



29250
29251
29252
29253
29254
29255
29256
# File 'lib/aws-sdk-securityhub/types.rb', line 29250

class Note < Struct.new(
  :text,
  :updated_by,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#updated_atString

A timestamp that indicates when the note was updated.

For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.



29250
29251
29252
29253
29254
29255
29256
# File 'lib/aws-sdk-securityhub/types.rb', line 29250

class Note < Struct.new(
  :text,
  :updated_by,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#updated_byString

The principal that created a note.



29250
29251
29252
29253
29254
29255
29256
# File 'lib/aws-sdk-securityhub/types.rb', line 29250

class Note < Struct.new(
  :text,
  :updated_by,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end