Class: Aws::SecurityHub::Types::OrganizationConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

Provides information about the way an organization is configured in Security Hub CSPM.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#configuration_typeString

Indicates whether the organization uses local or central configuration.

If you use local configuration, the Security Hub CSPM delegated administrator can set ‘AutoEnable` to `true` and `AutoEnableStandards` to `DEFAULT`. This automatically enables Security Hub CSPM and default security standards in new organization accounts. These new account settings must be set separately in each Amazon Web Services Region, and settings may be different in each Region.

If you use central configuration, the delegated administrator can create configuration policies. Configuration policies can be used to configure Security Hub CSPM, security standards, and security controls in multiple accounts and Regions. If you want new organization accounts to use a specific configuration, you can create a configuration policy and associate it with the root or specific organizational units (OUs). New accounts will inherit the policy from the root or their assigned OU.

Returns:

  • (String)


28545
28546
28547
28548
28549
28550
28551
# File 'lib/aws-sdk-securityhub/types.rb', line 28545

class OrganizationConfiguration < Struct.new(
  :configuration_type,
  :status,
  :status_message)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

Describes whether central configuration could be enabled as the ‘ConfigurationType` for the organization. If your `ConfigurationType` is local configuration, then the value of `Status` is always `ENABLED`.

Returns:

  • (String)


28545
28546
28547
28548
28549
28550
28551
# File 'lib/aws-sdk-securityhub/types.rb', line 28545

class OrganizationConfiguration < Struct.new(
  :configuration_type,
  :status,
  :status_message)
  SENSITIVE = []
  include Aws::Structure
end

#status_messageString

Provides an explanation if the value of ‘Status` is equal to `FAILED` when `ConfigurationType` is equal to `CENTRAL`.

Returns:

  • (String)


28545
28546
28547
28548
28549
28550
28551
# File 'lib/aws-sdk-securityhub/types.rb', line 28545

class OrganizationConfiguration < Struct.new(
  :configuration_type,
  :status,
  :status_message)
  SENSITIVE = []
  include Aws::Structure
end