Class: Aws::SecurityHub::Types::ParameterValue
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::ParameterValue
- Includes:
- Aws::Structure, Aws::Structure::Union
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
ParameterValue is a union - when making an API calls you must set exactly one of the members.
ParameterValue is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of ParameterValue corresponding to the set member.
An object that includes the data type of a security control parameter and its current value.
Defined Under Namespace
Classes: Boolean, Double, Enum, EnumList, Integer, IntegerList, String, StringList, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#boolean ⇒ Boolean
A control parameter that is a boolean.
-
#double ⇒ Float
A control parameter that is a double.
-
#enum ⇒ String
A control parameter that is an enum.
-
#enum_list ⇒ Array<String>
A control parameter that is a list of enums.
-
#integer ⇒ Integer
A control parameter that is an integer.
-
#integer_list ⇒ Array<Integer>
A control parameter that is a list of integers.
-
#string ⇒ String
A control parameter that is a string.
-
#string_list ⇒ Array<String>
A control parameter that is a list of strings.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#boolean ⇒ Boolean
A control parameter that is a boolean.
28708 28709 28710 28711 28712 28713 28714 28715 28716 28717 28718 28719 28720 28721 28722 28723 28724 28725 28726 28727 28728 28729 28730 28731 |
# File 'lib/aws-sdk-securityhub/types.rb', line 28708 class ParameterValue < Struct.new( :integer, :integer_list, :double, :string, :string_list, :boolean, :enum, :enum_list, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Integer < ParameterValue; end class IntegerList < ParameterValue; end class Double < ParameterValue; end class String < ParameterValue; end class StringList < ParameterValue; end class Boolean < ParameterValue; end class Enum < ParameterValue; end class EnumList < ParameterValue; end class Unknown < ParameterValue; end end |
#double ⇒ Float
A control parameter that is a double.
28708 28709 28710 28711 28712 28713 28714 28715 28716 28717 28718 28719 28720 28721 28722 28723 28724 28725 28726 28727 28728 28729 28730 28731 |
# File 'lib/aws-sdk-securityhub/types.rb', line 28708 class ParameterValue < Struct.new( :integer, :integer_list, :double, :string, :string_list, :boolean, :enum, :enum_list, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Integer < ParameterValue; end class IntegerList < ParameterValue; end class Double < ParameterValue; end class String < ParameterValue; end class StringList < ParameterValue; end class Boolean < ParameterValue; end class Enum < ParameterValue; end class EnumList < ParameterValue; end class Unknown < ParameterValue; end end |
#enum ⇒ String
A control parameter that is an enum.
28708 28709 28710 28711 28712 28713 28714 28715 28716 28717 28718 28719 28720 28721 28722 28723 28724 28725 28726 28727 28728 28729 28730 28731 |
# File 'lib/aws-sdk-securityhub/types.rb', line 28708 class ParameterValue < Struct.new( :integer, :integer_list, :double, :string, :string_list, :boolean, :enum, :enum_list, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Integer < ParameterValue; end class IntegerList < ParameterValue; end class Double < ParameterValue; end class String < ParameterValue; end class StringList < ParameterValue; end class Boolean < ParameterValue; end class Enum < ParameterValue; end class EnumList < ParameterValue; end class Unknown < ParameterValue; end end |
#enum_list ⇒ Array<String>
A control parameter that is a list of enums.
28708 28709 28710 28711 28712 28713 28714 28715 28716 28717 28718 28719 28720 28721 28722 28723 28724 28725 28726 28727 28728 28729 28730 28731 |
# File 'lib/aws-sdk-securityhub/types.rb', line 28708 class ParameterValue < Struct.new( :integer, :integer_list, :double, :string, :string_list, :boolean, :enum, :enum_list, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Integer < ParameterValue; end class IntegerList < ParameterValue; end class Double < ParameterValue; end class String < ParameterValue; end class StringList < ParameterValue; end class Boolean < ParameterValue; end class Enum < ParameterValue; end class EnumList < ParameterValue; end class Unknown < ParameterValue; end end |
#integer ⇒ Integer
A control parameter that is an integer.
28708 28709 28710 28711 28712 28713 28714 28715 28716 28717 28718 28719 28720 28721 28722 28723 28724 28725 28726 28727 28728 28729 28730 28731 |
# File 'lib/aws-sdk-securityhub/types.rb', line 28708 class ParameterValue < Struct.new( :integer, :integer_list, :double, :string, :string_list, :boolean, :enum, :enum_list, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Integer < ParameterValue; end class IntegerList < ParameterValue; end class Double < ParameterValue; end class String < ParameterValue; end class StringList < ParameterValue; end class Boolean < ParameterValue; end class Enum < ParameterValue; end class EnumList < ParameterValue; end class Unknown < ParameterValue; end end |
#integer_list ⇒ Array<Integer>
A control parameter that is a list of integers.
28708 28709 28710 28711 28712 28713 28714 28715 28716 28717 28718 28719 28720 28721 28722 28723 28724 28725 28726 28727 28728 28729 28730 28731 |
# File 'lib/aws-sdk-securityhub/types.rb', line 28708 class ParameterValue < Struct.new( :integer, :integer_list, :double, :string, :string_list, :boolean, :enum, :enum_list, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Integer < ParameterValue; end class IntegerList < ParameterValue; end class Double < ParameterValue; end class String < ParameterValue; end class StringList < ParameterValue; end class Boolean < ParameterValue; end class Enum < ParameterValue; end class EnumList < ParameterValue; end class Unknown < ParameterValue; end end |
#string ⇒ String
A control parameter that is a string.
28708 28709 28710 28711 28712 28713 28714 28715 28716 28717 28718 28719 28720 28721 28722 28723 28724 28725 28726 28727 28728 28729 28730 28731 |
# File 'lib/aws-sdk-securityhub/types.rb', line 28708 class ParameterValue < Struct.new( :integer, :integer_list, :double, :string, :string_list, :boolean, :enum, :enum_list, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Integer < ParameterValue; end class IntegerList < ParameterValue; end class Double < ParameterValue; end class String < ParameterValue; end class StringList < ParameterValue; end class Boolean < ParameterValue; end class Enum < ParameterValue; end class EnumList < ParameterValue; end class Unknown < ParameterValue; end end |
#string_list ⇒ Array<String>
A control parameter that is a list of strings.
28708 28709 28710 28711 28712 28713 28714 28715 28716 28717 28718 28719 28720 28721 28722 28723 28724 28725 28726 28727 28728 28729 28730 28731 |
# File 'lib/aws-sdk-securityhub/types.rb', line 28708 class ParameterValue < Struct.new( :integer, :integer_list, :double, :string, :string_list, :boolean, :enum, :enum_list, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Integer < ParameterValue; end class IntegerList < ParameterValue; end class Double < ParameterValue; end class String < ParameterValue; end class StringList < ParameterValue; end class Boolean < ParameterValue; end class Enum < ParameterValue; end class EnumList < ParameterValue; end class Unknown < ParameterValue; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
28708 28709 28710 |
# File 'lib/aws-sdk-securityhub/types.rb', line 28708 def unknown @unknown end |