Class: Aws::SecurityHub::Types::Policy
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::Policy
- Includes:
- Aws::Structure, Aws::Structure::Union
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Policy is a union - when making an API calls you must set exactly one of the members.
Policy is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of Policy corresponding to the set member.
An object that defines how Security Hub CSPM is configured. It includes whether Security Hub CSPM is enabled or disabled, a list of enabled security standards, a list of enabled or disabled security controls, and a list of custom parameter values for specified controls. If you provide a list of security controls that are enabled in the configuration policy, Security Hub CSPM disables all other controls (including newly released controls). If you provide a list of security controls that are disabled in the configuration policy, Security Hub CSPM enables all other controls (including newly released controls).
Defined Under Namespace
Classes: SecurityHub, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#security_hub ⇒ Types::SecurityHubPolicy
The Amazon Web Services service that the configuration policy applies to.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#security_hub ⇒ Types::SecurityHubPolicy
The Amazon Web Services service that the configuration policy applies to.
28861 28862 28863 28864 28865 28866 28867 28868 28869 28870 |
# File 'lib/aws-sdk-securityhub/types.rb', line 28861 class Policy < Struct.new( :security_hub, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class SecurityHub < Policy; end class Unknown < Policy; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
28861 28862 28863 |
# File 'lib/aws-sdk-securityhub/types.rb', line 28861 def unknown @unknown end |