Class: Aws::SecurityHub::Types::PortProbeAction

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

Provided if ActionType is PORT_PROBE. It provides details about the attempted port probe that was detected.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#blockedBoolean

Indicates whether the port probe was blocked.

Returns:

  • (Boolean)


29678
29679
29680
29681
29682
29683
# File 'lib/aws-sdk-securityhub/types.rb', line 29678

class PortProbeAction < Struct.new(
  :port_probe_details,
  :blocked)
  SENSITIVE = []
  include Aws::Structure
end

#port_probe_detailsArray<Types::PortProbeDetail>

Information about the ports affected by the port probe.

Returns:



29678
29679
29680
29681
29682
29683
# File 'lib/aws-sdk-securityhub/types.rb', line 29678

class PortProbeAction < Struct.new(
  :port_probe_details,
  :blocked)
  SENSITIVE = []
  include Aws::Structure
end