Class: Aws::SecurityHub::Types::Product
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::Product
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Contains details about a product.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#activation_url ⇒ String
The URL to the service or product documentation about the integration with Security Hub CSPM, including how to activate the integration.
-
#categories ⇒ Array<String>
The categories assigned to the product.
-
#company_name ⇒ String
The name of the company that provides the product.
-
#description ⇒ String
A description of the product.
-
#integration_types ⇒ Array<String>
The types of integration that the product supports.
-
#marketplace_url ⇒ String
For integrations with Amazon Web Services services, the Amazon Web Services Console URL from which to activate the service.
-
#product_arn ⇒ String
The ARN assigned to the product.
-
#product_name ⇒ String
The name of the product.
-
#product_subscription_resource_policy ⇒ String
The resource policy associated with the product.
Instance Attribute Details
#activation_url ⇒ String
The URL to the service or product documentation about the integration with Security Hub CSPM, including how to activate the integration.
30093 30094 30095 30096 30097 30098 30099 30100 30101 30102 30103 30104 30105 |
# File 'lib/aws-sdk-securityhub/types.rb', line 30093 class Product < Struct.new( :product_arn, :product_name, :company_name, :description, :categories, :integration_types, :marketplace_url, :activation_url, :product_subscription_resource_policy) SENSITIVE = [] include Aws::Structure end |
#categories ⇒ Array<String>
The categories assigned to the product.
30093 30094 30095 30096 30097 30098 30099 30100 30101 30102 30103 30104 30105 |
# File 'lib/aws-sdk-securityhub/types.rb', line 30093 class Product < Struct.new( :product_arn, :product_name, :company_name, :description, :categories, :integration_types, :marketplace_url, :activation_url, :product_subscription_resource_policy) SENSITIVE = [] include Aws::Structure end |
#company_name ⇒ String
The name of the company that provides the product.
30093 30094 30095 30096 30097 30098 30099 30100 30101 30102 30103 30104 30105 |
# File 'lib/aws-sdk-securityhub/types.rb', line 30093 class Product < Struct.new( :product_arn, :product_name, :company_name, :description, :categories, :integration_types, :marketplace_url, :activation_url, :product_subscription_resource_policy) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the product.
30093 30094 30095 30096 30097 30098 30099 30100 30101 30102 30103 30104 30105 |
# File 'lib/aws-sdk-securityhub/types.rb', line 30093 class Product < Struct.new( :product_arn, :product_name, :company_name, :description, :categories, :integration_types, :marketplace_url, :activation_url, :product_subscription_resource_policy) SENSITIVE = [] include Aws::Structure end |
#integration_types ⇒ Array<String>
The types of integration that the product supports. Available values are the following.
-
SEND_FINDINGS_TO_SECURITY_HUB- The integration sends findings to Security Hub CSPM. -
RECEIVE_FINDINGS_FROM_SECURITY_HUB- The integration receives findings from Security Hub CSPM. -
UPDATE_FINDINGS_IN_SECURITY_HUB- The integration does not send new findings to Security Hub CSPM, but does make updates to the findings that it receives from Security Hub CSPM.
30093 30094 30095 30096 30097 30098 30099 30100 30101 30102 30103 30104 30105 |
# File 'lib/aws-sdk-securityhub/types.rb', line 30093 class Product < Struct.new( :product_arn, :product_name, :company_name, :description, :categories, :integration_types, :marketplace_url, :activation_url, :product_subscription_resource_policy) SENSITIVE = [] include Aws::Structure end |
#marketplace_url ⇒ String
For integrations with Amazon Web Services services, the Amazon Web Services Console URL from which to activate the service.
For integrations with third-party products, the Amazon Web Services Marketplace URL from which to subscribe to or purchase the product.
30093 30094 30095 30096 30097 30098 30099 30100 30101 30102 30103 30104 30105 |
# File 'lib/aws-sdk-securityhub/types.rb', line 30093 class Product < Struct.new( :product_arn, :product_name, :company_name, :description, :categories, :integration_types, :marketplace_url, :activation_url, :product_subscription_resource_policy) SENSITIVE = [] include Aws::Structure end |
#product_arn ⇒ String
The ARN assigned to the product.
30093 30094 30095 30096 30097 30098 30099 30100 30101 30102 30103 30104 30105 |
# File 'lib/aws-sdk-securityhub/types.rb', line 30093 class Product < Struct.new( :product_arn, :product_name, :company_name, :description, :categories, :integration_types, :marketplace_url, :activation_url, :product_subscription_resource_policy) SENSITIVE = [] include Aws::Structure end |
#product_name ⇒ String
The name of the product.
30093 30094 30095 30096 30097 30098 30099 30100 30101 30102 30103 30104 30105 |
# File 'lib/aws-sdk-securityhub/types.rb', line 30093 class Product < Struct.new( :product_arn, :product_name, :company_name, :description, :categories, :integration_types, :marketplace_url, :activation_url, :product_subscription_resource_policy) SENSITIVE = [] include Aws::Structure end |
#product_subscription_resource_policy ⇒ String
The resource policy associated with the product.
30093 30094 30095 30096 30097 30098 30099 30100 30101 30102 30103 30104 30105 |
# File 'lib/aws-sdk-securityhub/types.rb', line 30093 class Product < Struct.new( :product_arn, :product_name, :company_name, :description, :categories, :integration_types, :marketplace_url, :activation_url, :product_subscription_resource_policy) SENSITIVE = [] include Aws::Structure end |