Class: Aws::SecurityHub::Types::ProviderConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::ProviderConfiguration
- Includes:
- Aws::Structure, Aws::Structure::Union
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
ProviderConfiguration is a union - when making an API calls you must set exactly one of the members.
The initial configuration settings required to establish an integration between Security Hub and third-party provider.
Defined Under Namespace
Classes: Azure, JiraCloud, ServiceNow, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#azure ⇒ Types::AzureProviderConfiguration
The configuration settings required to establish a CSPM integration with Microsoft Azure.
-
#jira_cloud ⇒ Types::JiraCloudProviderConfiguration
The configuration settings required to establish an integration with Jira Cloud.
-
#service_now ⇒ Types::ServiceNowProviderConfiguration
The configuration settings required to establish an integration with ServiceNow ITSM.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#azure ⇒ Types::AzureProviderConfiguration
The configuration settings required to establish a CSPM integration with Microsoft Azure.
29968 29969 29970 29971 29972 29973 29974 29975 29976 29977 29978 29979 29980 29981 |
# File 'lib/aws-sdk-securityhub/types.rb', line 29968 class ProviderConfiguration < Struct.new( :jira_cloud, :service_now, :azure, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class JiraCloud < ProviderConfiguration; end class ServiceNow < ProviderConfiguration; end class Azure < ProviderConfiguration; end class Unknown < ProviderConfiguration; end end |
#jira_cloud ⇒ Types::JiraCloudProviderConfiguration
The configuration settings required to establish an integration with Jira Cloud.
29968 29969 29970 29971 29972 29973 29974 29975 29976 29977 29978 29979 29980 29981 |
# File 'lib/aws-sdk-securityhub/types.rb', line 29968 class ProviderConfiguration < Struct.new( :jira_cloud, :service_now, :azure, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class JiraCloud < ProviderConfiguration; end class ServiceNow < ProviderConfiguration; end class Azure < ProviderConfiguration; end class Unknown < ProviderConfiguration; end end |
#service_now ⇒ Types::ServiceNowProviderConfiguration
The configuration settings required to establish an integration with ServiceNow ITSM.
29968 29969 29970 29971 29972 29973 29974 29975 29976 29977 29978 29979 29980 29981 |
# File 'lib/aws-sdk-securityhub/types.rb', line 29968 class ProviderConfiguration < Struct.new( :jira_cloud, :service_now, :azure, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class JiraCloud < ProviderConfiguration; end class ServiceNow < ProviderConfiguration; end class Azure < ProviderConfiguration; end class Unknown < ProviderConfiguration; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
29968 29969 29970 |
# File 'lib/aws-sdk-securityhub/types.rb', line 29968 def unknown @unknown end |