Class: Aws::SecurityHub::Types::RecommendationError

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

Contains information about the reason that the retrieval of a recommended policy for a finding failed.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#codeString

The error code for a failed retrieval of a recommended policy for a finding.

Returns:

  • (String)


29417
29418
29419
29420
29421
29422
# File 'lib/aws-sdk-securityhub/types.rb', line 29417

class RecommendationError < Struct.new(
  :code,
  :message)
  SENSITIVE = []
  include Aws::Structure
end

#messageString

The error message for a failed retrieval of a recommended policy for a finding.

Returns:

  • (String)


29417
29418
29419
29420
29421
29422
# File 'lib/aws-sdk-securityhub/types.rb', line 29417

class RecommendationError < Struct.new(
  :code,
  :message)
  SENSITIVE = []
  include Aws::Structure
end