Class: Aws::SecurityHub::Types::RecommendationStep

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure, Aws::Structure::Union
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

Note:

RecommendationStep is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of RecommendationStep corresponding to the set member.

Contains information about a recommended step to remediate a Security Hub finding.

Defined Under Namespace

Classes: Unknown, UnusedPermissions

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



30163
30164
30165
# File 'lib/aws-sdk-securityhub/types.rb', line 30163

def unknown
  @unknown
end

#unused_permissionsTypes::UnusedPermissionsRecommendationStep

A recommended step to remediate an unused permissions finding.



30163
30164
30165
30166
30167
30168
30169
30170
30171
30172
# File 'lib/aws-sdk-securityhub/types.rb', line 30163

class RecommendationStep < Struct.new(
  :unused_permissions,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class UnusedPermissions < RecommendationStep; end
  class Unknown < RecommendationStep; end
end