Class: Aws::SecurityHub::Types::Resource
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::Resource
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
A resource related to a finding.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#application_arn ⇒ String
The Amazon Resource Name (ARN) of the application that is related to a finding.
-
#application_name ⇒ String
The name of the application that is related to a finding.
-
#data_classification ⇒ Types::DataClassificationDetails
Contains information about sensitive data that was detected on the resource.
-
#details ⇒ Types::ResourceDetails
Additional details about the resource related to a finding.
-
#id ⇒ String
The canonical identifier for the given resource type.
-
#owner ⇒ Types::ResourceOwner
Information about the account and organization that own the resource.
-
#partition ⇒ String
The canonical Amazon Web Services partition name that the Region is assigned to.
-
#provider ⇒ String
The cloud provider that the resource belongs to.
-
#region ⇒ String
The canonical Amazon Web Services external Region name where this resource is located.
-
#resource_role ⇒ String
Identifies the role of the resource in the finding.
-
#tags ⇒ Hash<String,String>
A list of Amazon Web Services tags associated with a resource at the time the finding was processed.
-
#type ⇒ String
The type of the resource that details are provided for.
Instance Attribute Details
#application_arn ⇒ String
The Amazon Resource Name (ARN) of the application that is related to a finding.
30569 30570 30571 30572 30573 30574 30575 30576 30577 30578 30579 30580 30581 30582 30583 30584 |
# File 'lib/aws-sdk-securityhub/types.rb', line 30569 class Resource < Struct.new( :type, :id, :partition, :region, :provider, :owner, :resource_role, :tags, :data_classification, :details, :application_name, :application_arn) SENSITIVE = [] include Aws::Structure end |
#application_name ⇒ String
The name of the application that is related to a finding.
30569 30570 30571 30572 30573 30574 30575 30576 30577 30578 30579 30580 30581 30582 30583 30584 |
# File 'lib/aws-sdk-securityhub/types.rb', line 30569 class Resource < Struct.new( :type, :id, :partition, :region, :provider, :owner, :resource_role, :tags, :data_classification, :details, :application_name, :application_arn) SENSITIVE = [] include Aws::Structure end |
#data_classification ⇒ Types::DataClassificationDetails
Contains information about sensitive data that was detected on the resource.
30569 30570 30571 30572 30573 30574 30575 30576 30577 30578 30579 30580 30581 30582 30583 30584 |
# File 'lib/aws-sdk-securityhub/types.rb', line 30569 class Resource < Struct.new( :type, :id, :partition, :region, :provider, :owner, :resource_role, :tags, :data_classification, :details, :application_name, :application_arn) SENSITIVE = [] include Aws::Structure end |
#details ⇒ Types::ResourceDetails
Additional details about the resource related to a finding.
30569 30570 30571 30572 30573 30574 30575 30576 30577 30578 30579 30580 30581 30582 30583 30584 |
# File 'lib/aws-sdk-securityhub/types.rb', line 30569 class Resource < Struct.new( :type, :id, :partition, :region, :provider, :owner, :resource_role, :tags, :data_classification, :details, :application_name, :application_arn) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The canonical identifier for the given resource type.
30569 30570 30571 30572 30573 30574 30575 30576 30577 30578 30579 30580 30581 30582 30583 30584 |
# File 'lib/aws-sdk-securityhub/types.rb', line 30569 class Resource < Struct.new( :type, :id, :partition, :region, :provider, :owner, :resource_role, :tags, :data_classification, :details, :application_name, :application_arn) SENSITIVE = [] include Aws::Structure end |
#owner ⇒ Types::ResourceOwner
Information about the account and organization that own the resource.
30569 30570 30571 30572 30573 30574 30575 30576 30577 30578 30579 30580 30581 30582 30583 30584 |
# File 'lib/aws-sdk-securityhub/types.rb', line 30569 class Resource < Struct.new( :type, :id, :partition, :region, :provider, :owner, :resource_role, :tags, :data_classification, :details, :application_name, :application_arn) SENSITIVE = [] include Aws::Structure end |
#partition ⇒ String
The canonical Amazon Web Services partition name that the Region is assigned to.
30569 30570 30571 30572 30573 30574 30575 30576 30577 30578 30579 30580 30581 30582 30583 30584 |
# File 'lib/aws-sdk-securityhub/types.rb', line 30569 class Resource < Struct.new( :type, :id, :partition, :region, :provider, :owner, :resource_role, :tags, :data_classification, :details, :application_name, :application_arn) SENSITIVE = [] include Aws::Structure end |
#provider ⇒ String
The cloud provider that the resource belongs to. Valid values are
AWS and Azure.
30569 30570 30571 30572 30573 30574 30575 30576 30577 30578 30579 30580 30581 30582 30583 30584 |
# File 'lib/aws-sdk-securityhub/types.rb', line 30569 class Resource < Struct.new( :type, :id, :partition, :region, :provider, :owner, :resource_role, :tags, :data_classification, :details, :application_name, :application_arn) SENSITIVE = [] include Aws::Structure end |
#region ⇒ String
The canonical Amazon Web Services external Region name where this resource is located.
Length Constraints: Minimum length of 1. Maximum length of 16.
30569 30570 30571 30572 30573 30574 30575 30576 30577 30578 30579 30580 30581 30582 30583 30584 |
# File 'lib/aws-sdk-securityhub/types.rb', line 30569 class Resource < Struct.new( :type, :id, :partition, :region, :provider, :owner, :resource_role, :tags, :data_classification, :details, :application_name, :application_arn) SENSITIVE = [] include Aws::Structure end |
#resource_role ⇒ String
Identifies the role of the resource in the finding. A resource is either the actor or target of the finding activity,
30569 30570 30571 30572 30573 30574 30575 30576 30577 30578 30579 30580 30581 30582 30583 30584 |
# File 'lib/aws-sdk-securityhub/types.rb', line 30569 class Resource < Struct.new( :type, :id, :partition, :region, :provider, :owner, :resource_role, :tags, :data_classification, :details, :application_name, :application_arn) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
A list of Amazon Web Services tags associated with a resource at the time the finding was processed. Tags must follow Amazon Web Services tag naming limits and requirements.
30569 30570 30571 30572 30573 30574 30575 30576 30577 30578 30579 30580 30581 30582 30583 30584 |
# File 'lib/aws-sdk-securityhub/types.rb', line 30569 class Resource < Struct.new( :type, :id, :partition, :region, :provider, :owner, :resource_role, :tags, :data_classification, :details, :application_name, :application_arn) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of the resource that details are provided for. If possible,
set Type to one of the supported resource types. For example, if
the resource is an EC2 instance, then set Type to
AwsEc2Instance.
If the resource does not match any of the provided types, then set
Type to Other.
Length Constraints: Minimum length of 1. Maximum length of 256.
30569 30570 30571 30572 30573 30574 30575 30576 30577 30578 30579 30580 30581 30582 30583 30584 |
# File 'lib/aws-sdk-securityhub/types.rb', line 30569 class Resource < Struct.new( :type, :id, :partition, :region, :provider, :owner, :resource_role, :tags, :data_classification, :details, :application_name, :application_arn) SENSITIVE = [] include Aws::Structure end |