Class: Aws::SecurityHub::Types::ResourceInfo
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::ResourceInfo
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Additional details about a resource that are specific to its category.
For AI/ML resources and their host resources, this structure contains
AIDetails.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#ai_details ⇒ Types::AIDetails
Details that are specific to self-hosted AI resources and their host resources.
Instance Attribute Details
#ai_details ⇒ Types::AIDetails
Details that are specific to self-hosted AI resources and their host resources.
31148 31149 31150 31151 31152 |
# File 'lib/aws-sdk-securityhub/types.rb', line 31148 class ResourceInfo < Struct.new( :ai_details) SENSITIVE = [] include Aws::Structure end |