Class: Aws::SecurityHub::Types::ResourceOwner

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

Information about the owner of a resource, including the account and organization that the resource belongs to.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#accountTypes::ResourceOwnerAccount

Information about the account that owns the resource, for example, an Azure Subscription or Amazon Web Services Account.



31069
31070
31071
31072
31073
31074
# File 'lib/aws-sdk-securityhub/types.rb', line 31069

class ResourceOwner < Struct.new(
  :account,
  :org)
  SENSITIVE = []
  include Aws::Structure
end

#orgTypes::ResourceOwnerOrg

Information about the organization that owns the resource, for example, an Azure Tenant.



31069
31070
31071
31072
31073
31074
# File 'lib/aws-sdk-securityhub/types.rb', line 31069

class ResourceOwner < Struct.new(
  :account,
  :org)
  SENSITIVE = []
  include Aws::Structure
end