Class: Aws::SecurityHub::Types::ResourceOwnerOrg

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

Information about the organization that owns a resource, for example, an Azure Tenant.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#idString

The unique identifier of the organization that owns the resource, for example, Azure Tenant Id.

Returns:

  • (String)


31102
31103
31104
31105
31106
# File 'lib/aws-sdk-securityhub/types.rb', line 31102

class ResourceOwnerOrg < Struct.new(
  :id)
  SENSITIVE = []
  include Aws::Structure
end