Class: Aws::SecurityHub::Types::ResourceSeverityBreakdown
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::ResourceSeverityBreakdown
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
A comprehensive distribution of security findings by severity level for Amazon Web Services resources.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#critical ⇒ Integer
The number of findings with a severity level of critical.
-
#fatal ⇒ Integer
The number of findings with a severity level of fatal.
-
#high ⇒ Integer
The number of findings with a severity level of high.
-
#informational ⇒ Integer
The number of findings that provide security-related information.
-
#low ⇒ Integer
The number of findings with a severity level of low.
-
#medium ⇒ Integer
The number of findings with a severity level of medium.
-
#other ⇒ Integer
The number of findings not in any of the severity categories.
-
#unknown ⇒ Integer
The number of findings with a severity level cannot be determined.
Instance Attribute Details
#critical ⇒ Integer
The number of findings with a severity level of critical.
30121 30122 30123 30124 30125 30126 30127 30128 30129 30130 30131 30132 |
# File 'lib/aws-sdk-securityhub/types.rb', line 30121 class ResourceSeverityBreakdown < Struct.new( :other, :fatal, :critical, :high, :medium, :low, :informational, :unknown) SENSITIVE = [] include Aws::Structure end |
#fatal ⇒ Integer
The number of findings with a severity level of fatal.
30121 30122 30123 30124 30125 30126 30127 30128 30129 30130 30131 30132 |
# File 'lib/aws-sdk-securityhub/types.rb', line 30121 class ResourceSeverityBreakdown < Struct.new( :other, :fatal, :critical, :high, :medium, :low, :informational, :unknown) SENSITIVE = [] include Aws::Structure end |
#high ⇒ Integer
The number of findings with a severity level of high.
30121 30122 30123 30124 30125 30126 30127 30128 30129 30130 30131 30132 |
# File 'lib/aws-sdk-securityhub/types.rb', line 30121 class ResourceSeverityBreakdown < Struct.new( :other, :fatal, :critical, :high, :medium, :low, :informational, :unknown) SENSITIVE = [] include Aws::Structure end |
#informational ⇒ Integer
The number of findings that provide security-related information.
30121 30122 30123 30124 30125 30126 30127 30128 30129 30130 30131 30132 |
# File 'lib/aws-sdk-securityhub/types.rb', line 30121 class ResourceSeverityBreakdown < Struct.new( :other, :fatal, :critical, :high, :medium, :low, :informational, :unknown) SENSITIVE = [] include Aws::Structure end |
#low ⇒ Integer
The number of findings with a severity level of low.
30121 30122 30123 30124 30125 30126 30127 30128 30129 30130 30131 30132 |
# File 'lib/aws-sdk-securityhub/types.rb', line 30121 class ResourceSeverityBreakdown < Struct.new( :other, :fatal, :critical, :high, :medium, :low, :informational, :unknown) SENSITIVE = [] include Aws::Structure end |
#medium ⇒ Integer
The number of findings with a severity level of medium.
30121 30122 30123 30124 30125 30126 30127 30128 30129 30130 30131 30132 |
# File 'lib/aws-sdk-securityhub/types.rb', line 30121 class ResourceSeverityBreakdown < Struct.new( :other, :fatal, :critical, :high, :medium, :low, :informational, :unknown) SENSITIVE = [] include Aws::Structure end |
#other ⇒ Integer
The number of findings not in any of the severity categories.
30121 30122 30123 30124 30125 30126 30127 30128 30129 30130 30131 30132 |
# File 'lib/aws-sdk-securityhub/types.rb', line 30121 class ResourceSeverityBreakdown < Struct.new( :other, :fatal, :critical, :high, :medium, :low, :informational, :unknown) SENSITIVE = [] include Aws::Structure end |
#unknown ⇒ Integer
The number of findings with a severity level cannot be determined.
30121 30122 30123 30124 30125 30126 30127 30128 30129 30130 30131 30132 |
# File 'lib/aws-sdk-securityhub/types.rb', line 30121 class ResourceSeverityBreakdown < Struct.new( :other, :fatal, :critical, :high, :medium, :low, :informational, :unknown) SENSITIVE = [] include Aws::Structure end |