Class: Aws::SecurityHub::Types::ResourcesMapFilter

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

Enables filtering of Amazon Web Services resources based on key-value map attributes.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#field_nameString

The name of the field.

Returns:

  • (String)


30270
30271
30272
30273
30274
30275
# File 'lib/aws-sdk-securityhub/types.rb', line 30270

class ResourcesMapFilter < Struct.new(
  :field_name,
  :filter)
  SENSITIVE = []
  include Aws::Structure
end

#filterTypes::MapFilter

A map filter for filtering Security Hub CSPM findings. Each map filter provides the field to check for, the value to check for, and the comparison operator.

Returns:



30270
30271
30272
30273
30274
30275
# File 'lib/aws-sdk-securityhub/types.rb', line 30270

class ResourcesMapFilter < Struct.new(
  :field_name,
  :filter)
  SENSITIVE = []
  include Aws::Structure
end