Class: Aws::SecurityHub::Types::ResourcesTrendsValues

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

Contains the aggregated resource count values for a specific point in the resources trend timeline.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#resources_countTypes::ResourcesCount

The resource count statistics for this data point in the trend timeline.



30417
30418
30419
30420
30421
# File 'lib/aws-sdk-securityhub/types.rb', line 30417

class ResourcesTrendsValues < Struct.new(
  :resources_count)
  SENSITIVE = []
  include Aws::Structure
end