Class: Aws::SecurityHub::Types::RuleGroupSourceStatefulRulesHeaderDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::RuleGroupSourceStatefulRulesHeaderDetails
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
The inspection criteria for a stateful rule.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#destination ⇒ String
The destination IP address or address range to inspect for, in CIDR notation.
-
#destination_port ⇒ String
The destination port to inspect for.
-
#direction ⇒ String
The direction of traffic flow to inspect.
-
#protocol ⇒ String
The protocol to inspect for.
-
#source ⇒ String
The source IP address or address range to inspect for, in CIDR notation.
-
#source_port ⇒ String
The source port to inspect for.
Instance Attribute Details
#destination ⇒ String
The destination IP address or address range to inspect for, in CIDR notation. To match with any address, specify ANY.
30703 30704 30705 30706 30707 30708 30709 30710 30711 30712 |
# File 'lib/aws-sdk-securityhub/types.rb', line 30703 class RuleGroupSourceStatefulRulesHeaderDetails < Struct.new( :destination, :destination_port, :direction, :protocol, :source, :source_port) SENSITIVE = [] include Aws::Structure end |
#destination_port ⇒ String
The destination port to inspect for. You can specify an individual port, such as 1994. You also can specify a port range, such as 1990:1994. To match with any port, specify ANY.
30703 30704 30705 30706 30707 30708 30709 30710 30711 30712 |
# File 'lib/aws-sdk-securityhub/types.rb', line 30703 class RuleGroupSourceStatefulRulesHeaderDetails < Struct.new( :destination, :destination_port, :direction, :protocol, :source, :source_port) SENSITIVE = [] include Aws::Structure end |
#direction ⇒ String
The direction of traffic flow to inspect. If set to ANY, the inspection matches bidirectional traffic, both from the source to the destination and from the destination to the source. If set to FORWARD, the inspection only matches traffic going from the source to the destination.
30703 30704 30705 30706 30707 30708 30709 30710 30711 30712 |
# File 'lib/aws-sdk-securityhub/types.rb', line 30703 class RuleGroupSourceStatefulRulesHeaderDetails < Struct.new( :destination, :destination_port, :direction, :protocol, :source, :source_port) SENSITIVE = [] include Aws::Structure end |
#protocol ⇒ String
The protocol to inspect for. To inspector for all protocols, use IP.
30703 30704 30705 30706 30707 30708 30709 30710 30711 30712 |
# File 'lib/aws-sdk-securityhub/types.rb', line 30703 class RuleGroupSourceStatefulRulesHeaderDetails < Struct.new( :destination, :destination_port, :direction, :protocol, :source, :source_port) SENSITIVE = [] include Aws::Structure end |
#source ⇒ String
The source IP address or address range to inspect for, in CIDR notation. To match with any address, specify ANY.
30703 30704 30705 30706 30707 30708 30709 30710 30711 30712 |
# File 'lib/aws-sdk-securityhub/types.rb', line 30703 class RuleGroupSourceStatefulRulesHeaderDetails < Struct.new( :destination, :destination_port, :direction, :protocol, :source, :source_port) SENSITIVE = [] include Aws::Structure end |
#source_port ⇒ String
The source port to inspect for. You can specify an individual port, such as 1994. You also can specify a port range, such as 1990:1994. To match with any port, specify ANY.
30703 30704 30705 30706 30707 30708 30709 30710 30711 30712 |
# File 'lib/aws-sdk-securityhub/types.rb', line 30703 class RuleGroupSourceStatefulRulesHeaderDetails < Struct.new( :destination, :destination_port, :direction, :protocol, :source, :source_port) SENSITIVE = [] include Aws::Structure end |