Class: Aws::SecurityHub::Types::RuleGroupSourceStatelessRuleMatchAttributesTcpFlags
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::RuleGroupSourceStatelessRuleMatchAttributesTcpFlags
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
A set of TCP flags and masks to inspect for.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#flags ⇒ Array<String>
Defines the flags from the
Maskssetting that must be set in order for the packet to match. -
#masks ⇒ Array<String>
The set of flags to consider in the inspection.
Instance Attribute Details
#flags ⇒ Array<String>
Defines the flags from the Masks setting that must be set in order
for the packet to match. Flags that are listed must be set. Flags
that are not listed must not be set.
32201 32202 32203 32204 32205 32206 |
# File 'lib/aws-sdk-securityhub/types.rb', line 32201 class RuleGroupSourceStatelessRuleMatchAttributesTcpFlags < Struct.new( :flags, :masks) SENSITIVE = [] include Aws::Structure end |
#masks ⇒ Array<String>
The set of flags to consider in the inspection. If not specified, then all flags are inspected.
32201 32202 32203 32204 32205 32206 |
# File 'lib/aws-sdk-securityhub/types.rb', line 32201 class RuleGroupSourceStatelessRuleMatchAttributesTcpFlags < Struct.new( :flags, :masks) SENSITIVE = [] include Aws::Structure end |