Class: Aws::SecurityHub::Types::RuleGroupSourceStatelessRulesDetails

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

A stateless rule in the rule group.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#priorityInteger

Indicates the order in which to run this rule relative to all of the rules in the stateless rule group.

Returns:

  • (Integer)


31231
31232
31233
31234
31235
31236
# File 'lib/aws-sdk-securityhub/types.rb', line 31231

class RuleGroupSourceStatelessRulesDetails < Struct.new(
  :priority,
  :rule_definition)
  SENSITIVE = []
  include Aws::Structure
end

#rule_definitionTypes::RuleGroupSourceStatelessRuleDefinition

Provides the definition of the stateless rule.



31231
31232
31233
31234
31235
31236
# File 'lib/aws-sdk-securityhub/types.rb', line 31231

class RuleGroupSourceStatelessRulesDetails < Struct.new(
  :priority,
  :rule_definition)
  SENSITIVE = []
  include Aws::Structure
end