Class: Aws::SecurityHub::Types::SecurityControlsConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

An object that defines which security controls are enabled in an Security Hub CSPM configuration policy. The enablement status of a control is aligned across all of the enabled standards in an account.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#disabled_security_control_identifiersArray<String>

A list of security controls that are disabled in the configuration policy. Security Hub CSPM enables all other controls (including newly released controls) other than the listed controls.



31200
31201
31202
31203
31204
31205
31206
# File 'lib/aws-sdk-securityhub/types.rb', line 31200

class SecurityControlsConfiguration < Struct.new(
  :enabled_security_control_identifiers,
  :disabled_security_control_identifiers,
  :security_control_custom_parameters)
  SENSITIVE = []
  include Aws::Structure
end

#enabled_security_control_identifiersArray<String>

A list of security controls that are enabled in the configuration policy. Security Hub CSPM disables all other controls (including newly released controls) other than the listed controls.



31200
31201
31202
31203
31204
31205
31206
# File 'lib/aws-sdk-securityhub/types.rb', line 31200

class SecurityControlsConfiguration < Struct.new(
  :enabled_security_control_identifiers,
  :disabled_security_control_identifiers,
  :security_control_custom_parameters)
  SENSITIVE = []
  include Aws::Structure
end

#security_control_custom_parametersArray<Types::SecurityControlCustomParameter>

A list of security controls and control parameter values that are included in a configuration policy.



31200
31201
31202
31203
31204
31205
31206
# File 'lib/aws-sdk-securityhub/types.rb', line 31200

class SecurityControlsConfiguration < Struct.new(
  :enabled_security_control_identifiers,
  :disabled_security_control_identifiers,
  :security_control_custom_parameters)
  SENSITIVE = []
  include Aws::Structure
end