Class: Aws::SecurityHub::Types::SensitiveDataResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::SensitiveDataResult
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Contains a detected instance of sensitive data that are based on built-in identifiers.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#category ⇒ String
The category of sensitive data that was detected.
-
#detections ⇒ Array<Types::SensitiveDataDetections>
The list of detected instances of sensitive data.
-
#total_count ⇒ Integer
The total number of occurrences of sensitive data.
Instance Attribute Details
#category ⇒ String
The category of sensitive data that was detected. For example, the category can indicate that the sensitive data involved credentials, financial information, or personal information.
31289 31290 31291 31292 31293 31294 31295 |
# File 'lib/aws-sdk-securityhub/types.rb', line 31289 class SensitiveDataResult < Struct.new( :category, :detections, :total_count) SENSITIVE = [] include Aws::Structure end |
#detections ⇒ Array<Types::SensitiveDataDetections>
The list of detected instances of sensitive data.
31289 31290 31291 31292 31293 31294 31295 |
# File 'lib/aws-sdk-securityhub/types.rb', line 31289 class SensitiveDataResult < Struct.new( :category, :detections, :total_count) SENSITIVE = [] include Aws::Structure end |
#total_count ⇒ Integer
The total number of occurrences of sensitive data.
31289 31290 31291 31292 31293 31294 31295 |
# File 'lib/aws-sdk-securityhub/types.rb', line 31289 class SensitiveDataResult < Struct.new( :category, :detections, :total_count) SENSITIVE = [] include Aws::Structure end |