Class: Aws::SecurityHub::Types::SeverityTrendsCount

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

Contains counts of findings grouped by severity level for trend analysis.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#criticalInteger

The count of findings with Critical severity level at this point in the trend timeline.



33021
33022
33023
33024
33025
33026
33027
33028
33029
33030
33031
33032
# File 'lib/aws-sdk-securityhub/types.rb', line 33021

class SeverityTrendsCount < Struct.new(
  :unknown,
  :informational,
  :low,
  :medium,
  :high,
  :critical,
  :fatal,
  :other)
  SENSITIVE = []
  include Aws::Structure
end

#fatalInteger

The count of findings with Fatal severity level at this point in the trend timeline.



33021
33022
33023
33024
33025
33026
33027
33028
33029
33030
33031
33032
# File 'lib/aws-sdk-securityhub/types.rb', line 33021

class SeverityTrendsCount < Struct.new(
  :unknown,
  :informational,
  :low,
  :medium,
  :high,
  :critical,
  :fatal,
  :other)
  SENSITIVE = []
  include Aws::Structure
end

#highInteger

The count of findings with High severity level at this point in the trend timeline.



33021
33022
33023
33024
33025
33026
33027
33028
33029
33030
33031
33032
# File 'lib/aws-sdk-securityhub/types.rb', line 33021

class SeverityTrendsCount < Struct.new(
  :unknown,
  :informational,
  :low,
  :medium,
  :high,
  :critical,
  :fatal,
  :other)
  SENSITIVE = []
  include Aws::Structure
end

#informationalInteger

The count of findings with Informational severity level at this point in the trend timeline.



33021
33022
33023
33024
33025
33026
33027
33028
33029
33030
33031
33032
# File 'lib/aws-sdk-securityhub/types.rb', line 33021

class SeverityTrendsCount < Struct.new(
  :unknown,
  :informational,
  :low,
  :medium,
  :high,
  :critical,
  :fatal,
  :other)
  SENSITIVE = []
  include Aws::Structure
end

#lowInteger

The count of findings with Low severity level at this point in the trend timeline.



33021
33022
33023
33024
33025
33026
33027
33028
33029
33030
33031
33032
# File 'lib/aws-sdk-securityhub/types.rb', line 33021

class SeverityTrendsCount < Struct.new(
  :unknown,
  :informational,
  :low,
  :medium,
  :high,
  :critical,
  :fatal,
  :other)
  SENSITIVE = []
  include Aws::Structure
end

#mediumInteger

The count of findings with Medium severity level at this point in the trend timeline.



33021
33022
33023
33024
33025
33026
33027
33028
33029
33030
33031
33032
# File 'lib/aws-sdk-securityhub/types.rb', line 33021

class SeverityTrendsCount < Struct.new(
  :unknown,
  :informational,
  :low,
  :medium,
  :high,
  :critical,
  :fatal,
  :other)
  SENSITIVE = []
  include Aws::Structure
end

#otherInteger

The count of findings with severity levels not fitting into the standard categories at this point in the trend timeline.



33021
33022
33023
33024
33025
33026
33027
33028
33029
33030
33031
33032
# File 'lib/aws-sdk-securityhub/types.rb', line 33021

class SeverityTrendsCount < Struct.new(
  :unknown,
  :informational,
  :low,
  :medium,
  :high,
  :critical,
  :fatal,
  :other)
  SENSITIVE = []
  include Aws::Structure
end

#unknownInteger

The count of findings with Unknown severity level at this point in the trend timeline.



33021
33022
33023
33024
33025
33026
33027
33028
33029
33030
33031
33032
# File 'lib/aws-sdk-securityhub/types.rb', line 33021

class SeverityTrendsCount < Struct.new(
  :unknown,
  :informational,
  :low,
  :medium,
  :high,
  :critical,
  :fatal,
  :other)
  SENSITIVE = []
  include Aws::Structure
end