Class: Aws::SecurityHub::Types::SeverityUpdate
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::SeverityUpdate
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Updates to the severity information for a finding.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#label ⇒ String
The severity value of the finding.
-
#normalized ⇒ Integer
The normalized severity for the finding.
-
#product ⇒ Float
The native severity as defined by the Amazon Web Services service or integrated partner product that generated the finding.
Instance Attribute Details
#label ⇒ String
The severity value of the finding. The allowed values are the following.
-
INFORMATIONAL- No issue was found. -
LOW- The issue does not require action on its own. -
MEDIUM- The issue must be addressed but not urgently. -
HIGH- The issue must be addressed as a priority. -
CRITICAL- The issue must be remediated immediately to avoid it escalating.
33077 33078 33079 33080 33081 33082 33083 |
# File 'lib/aws-sdk-securityhub/types.rb', line 33077 class SeverityUpdate < Struct.new( :normalized, :product, :label) SENSITIVE = [] include Aws::Structure end |
#normalized ⇒ Integer
The normalized severity for the finding. This attribute is to be
deprecated in favor of Label.
If you provide Normalized and don't provide Label, Label is
set automatically as follows.
-
0 -
INFORMATIONAL -
1–39 -
LOW -
40–69 -
MEDIUM -
70–89 -
HIGH -
90–100 -
CRITICAL
33077 33078 33079 33080 33081 33082 33083 |
# File 'lib/aws-sdk-securityhub/types.rb', line 33077 class SeverityUpdate < Struct.new( :normalized, :product, :label) SENSITIVE = [] include Aws::Structure end |
#product ⇒ Float
The native severity as defined by the Amazon Web Services service or integrated partner product that generated the finding.
33077 33078 33079 33080 33081 33082 33083 |
# File 'lib/aws-sdk-securityhub/types.rb', line 33077 class SeverityUpdate < Struct.new( :normalized, :product, :label) SENSITIVE = [] include Aws::Structure end |