Class: Aws::SecurityHub::Types::Signal
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::Signal
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Contains information about the signals involved in an Amazon GuardDuty Extended Threat Detection attack sequence. An attack sequence is a type of threat detected by GuardDuty. GuardDuty generates an attack sequence finding when multiple events, or signals, align to a potentially suspicious activity. When GuardDuty and Security Hub CSPM are integrated, GuardDuty sends attack sequence findings to Security Hub CSPM.
A signal can be an API activity or a finding that GuardDuty uses to detect an attack sequence finding.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#actor_ids ⇒ Array<String>
The IDs of the threat actors involved in the signal.
-
#count ⇒ Integer
The number of times this signal was observed.
-
#created_at ⇒ Integer
The timestamp when the first finding or activity related to this signal was observed.
-
#endpoint_ids ⇒ Array<String>
Information about the endpoint IDs associated with this signal.
-
#first_seen_at ⇒ Integer
The timestamp when the first finding or activity related to this signal was observed.
-
#id ⇒ String
The identifier of the signal.
-
#last_seen_at ⇒ Integer
The timestamp when the last finding or activity related to this signal was observed.
-
#name ⇒ String
The name of the GuardDuty signal.
-
#product_arn ⇒ String
The Amazon Resource Name (ARN) of the product that generated the signal.
-
#resource_ids ⇒ Array<String>
The ARN or ID of the Amazon Web Services resource associated with the signal.
-
#severity ⇒ Float
The severity associated with the signal.
-
#signal_indicators ⇒ Array<Types::Indicator>
Contains information about the indicators associated with the signals in this attack sequence finding.
-
#title ⇒ String
The description of the GuardDuty finding.
-
#type ⇒ String
The type of the signal used to identify an attack sequence.
-
#updated_at ⇒ Integer
The timestamp when this signal was last observed.
Instance Attribute Details
#actor_ids ⇒ Array<String>
The IDs of the threat actors involved in the signal.
32056 32057 32058 32059 32060 32061 32062 32063 32064 32065 32066 32067 32068 32069 32070 32071 32072 32073 32074 |
# File 'lib/aws-sdk-securityhub/types.rb', line 32056 class Signal < Struct.new( :type, :id, :title, :product_arn, :resource_ids, :signal_indicators, :name, :created_at, :updated_at, :first_seen_at, :last_seen_at, :severity, :count, :actor_ids, :endpoint_ids) SENSITIVE = [] include Aws::Structure end |
#count ⇒ Integer
The number of times this signal was observed.
32056 32057 32058 32059 32060 32061 32062 32063 32064 32065 32066 32067 32068 32069 32070 32071 32072 32073 32074 |
# File 'lib/aws-sdk-securityhub/types.rb', line 32056 class Signal < Struct.new( :type, :id, :title, :product_arn, :resource_ids, :signal_indicators, :name, :created_at, :updated_at, :first_seen_at, :last_seen_at, :severity, :count, :actor_ids, :endpoint_ids) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Integer
The timestamp when the first finding or activity related to this signal was observed.
32056 32057 32058 32059 32060 32061 32062 32063 32064 32065 32066 32067 32068 32069 32070 32071 32072 32073 32074 |
# File 'lib/aws-sdk-securityhub/types.rb', line 32056 class Signal < Struct.new( :type, :id, :title, :product_arn, :resource_ids, :signal_indicators, :name, :created_at, :updated_at, :first_seen_at, :last_seen_at, :severity, :count, :actor_ids, :endpoint_ids) SENSITIVE = [] include Aws::Structure end |
#endpoint_ids ⇒ Array<String>
Information about the endpoint IDs associated with this signal.
32056 32057 32058 32059 32060 32061 32062 32063 32064 32065 32066 32067 32068 32069 32070 32071 32072 32073 32074 |
# File 'lib/aws-sdk-securityhub/types.rb', line 32056 class Signal < Struct.new( :type, :id, :title, :product_arn, :resource_ids, :signal_indicators, :name, :created_at, :updated_at, :first_seen_at, :last_seen_at, :severity, :count, :actor_ids, :endpoint_ids) SENSITIVE = [] include Aws::Structure end |
#first_seen_at ⇒ Integer
The timestamp when the first finding or activity related to this signal was observed.
32056 32057 32058 32059 32060 32061 32062 32063 32064 32065 32066 32067 32068 32069 32070 32071 32072 32073 32074 |
# File 'lib/aws-sdk-securityhub/types.rb', line 32056 class Signal < Struct.new( :type, :id, :title, :product_arn, :resource_ids, :signal_indicators, :name, :created_at, :updated_at, :first_seen_at, :last_seen_at, :severity, :count, :actor_ids, :endpoint_ids) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The identifier of the signal.
32056 32057 32058 32059 32060 32061 32062 32063 32064 32065 32066 32067 32068 32069 32070 32071 32072 32073 32074 |
# File 'lib/aws-sdk-securityhub/types.rb', line 32056 class Signal < Struct.new( :type, :id, :title, :product_arn, :resource_ids, :signal_indicators, :name, :created_at, :updated_at, :first_seen_at, :last_seen_at, :severity, :count, :actor_ids, :endpoint_ids) SENSITIVE = [] include Aws::Structure end |
#last_seen_at ⇒ Integer
The timestamp when the last finding or activity related to this signal was observed.
32056 32057 32058 32059 32060 32061 32062 32063 32064 32065 32066 32067 32068 32069 32070 32071 32072 32073 32074 |
# File 'lib/aws-sdk-securityhub/types.rb', line 32056 class Signal < Struct.new( :type, :id, :title, :product_arn, :resource_ids, :signal_indicators, :name, :created_at, :updated_at, :first_seen_at, :last_seen_at, :severity, :count, :actor_ids, :endpoint_ids) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the GuardDuty signal. For example, when signal type is ‘FINDING`, the signal name is the name of the finding.
32056 32057 32058 32059 32060 32061 32062 32063 32064 32065 32066 32067 32068 32069 32070 32071 32072 32073 32074 |
# File 'lib/aws-sdk-securityhub/types.rb', line 32056 class Signal < Struct.new( :type, :id, :title, :product_arn, :resource_ids, :signal_indicators, :name, :created_at, :updated_at, :first_seen_at, :last_seen_at, :severity, :count, :actor_ids, :endpoint_ids) SENSITIVE = [] include Aws::Structure end |
#product_arn ⇒ String
The Amazon Resource Name (ARN) of the product that generated the signal.
32056 32057 32058 32059 32060 32061 32062 32063 32064 32065 32066 32067 32068 32069 32070 32071 32072 32073 32074 |
# File 'lib/aws-sdk-securityhub/types.rb', line 32056 class Signal < Struct.new( :type, :id, :title, :product_arn, :resource_ids, :signal_indicators, :name, :created_at, :updated_at, :first_seen_at, :last_seen_at, :severity, :count, :actor_ids, :endpoint_ids) SENSITIVE = [] include Aws::Structure end |
#resource_ids ⇒ Array<String>
The ARN or ID of the Amazon Web Services resource associated with the signal.
32056 32057 32058 32059 32060 32061 32062 32063 32064 32065 32066 32067 32068 32069 32070 32071 32072 32073 32074 |
# File 'lib/aws-sdk-securityhub/types.rb', line 32056 class Signal < Struct.new( :type, :id, :title, :product_arn, :resource_ids, :signal_indicators, :name, :created_at, :updated_at, :first_seen_at, :last_seen_at, :severity, :count, :actor_ids, :endpoint_ids) SENSITIVE = [] include Aws::Structure end |
#severity ⇒ Float
The severity associated with the signal. For more information about severity, see [Severity levels for GuardDuty findings] in the *Amazon GuardDuty User Guide*.
[1]: docs.aws.amazon.com/guardduty/latest/ug/guardduty_findings-severity.html
32056 32057 32058 32059 32060 32061 32062 32063 32064 32065 32066 32067 32068 32069 32070 32071 32072 32073 32074 |
# File 'lib/aws-sdk-securityhub/types.rb', line 32056 class Signal < Struct.new( :type, :id, :title, :product_arn, :resource_ids, :signal_indicators, :name, :created_at, :updated_at, :first_seen_at, :last_seen_at, :severity, :count, :actor_ids, :endpoint_ids) SENSITIVE = [] include Aws::Structure end |
#signal_indicators ⇒ Array<Types::Indicator>
Contains information about the indicators associated with the signals in this attack sequence finding. The values for ‘SignalIndicators` are a subset of the values for [SequenceIndicators], but the values for these fields don’t always match 1:1.
[1]: docs.aws.amazon.com/securityhub/1.0/APIReference/API_Sequence.html
32056 32057 32058 32059 32060 32061 32062 32063 32064 32065 32066 32067 32068 32069 32070 32071 32072 32073 32074 |
# File 'lib/aws-sdk-securityhub/types.rb', line 32056 class Signal < Struct.new( :type, :id, :title, :product_arn, :resource_ids, :signal_indicators, :name, :created_at, :updated_at, :first_seen_at, :last_seen_at, :severity, :count, :actor_ids, :endpoint_ids) SENSITIVE = [] include Aws::Structure end |
#title ⇒ String
The description of the GuardDuty finding.
32056 32057 32058 32059 32060 32061 32062 32063 32064 32065 32066 32067 32068 32069 32070 32071 32072 32073 32074 |
# File 'lib/aws-sdk-securityhub/types.rb', line 32056 class Signal < Struct.new( :type, :id, :title, :product_arn, :resource_ids, :signal_indicators, :name, :created_at, :updated_at, :first_seen_at, :last_seen_at, :severity, :count, :actor_ids, :endpoint_ids) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of the signal used to identify an attack sequence.
Signals can be GuardDuty findings or activities observed in data sources that GuardDuty monitors. For more information, see
- GuardDuty foundational data sources][1
-
in the *Amazon GuardDuty
User Guide*.
A signal type can be one of the following values. Here are the related descriptions:
-
‘FINDING` - Individually generated GuardDuty finding.
-
‘CLOUD_TRAIL` - Activity observed from CloudTrail logs
-
‘S3_DATA_EVENTS` - Activity observed from CloudTrail data events for Amazon Simple Storage Service (S3). Activities associated with this type will show up only when you have enabled GuardDuty S3 Protection feature in your account. For more information about S3 Protection and the steps to enable it, see [S3 Protection] in the *Amazon GuardDuty User Guide*.
[1]: docs.aws.amazon.com/guardduty/latest/ug/guardduty_data-sources.html [2]: docs.aws.amazon.com/guardduty/latest/ug/s3-protection.html
32056 32057 32058 32059 32060 32061 32062 32063 32064 32065 32066 32067 32068 32069 32070 32071 32072 32073 32074 |
# File 'lib/aws-sdk-securityhub/types.rb', line 32056 class Signal < Struct.new( :type, :id, :title, :product_arn, :resource_ids, :signal_indicators, :name, :created_at, :updated_at, :first_seen_at, :last_seen_at, :severity, :count, :actor_ids, :endpoint_ids) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Integer
The timestamp when this signal was last observed.
32056 32057 32058 32059 32060 32061 32062 32063 32064 32065 32066 32067 32068 32069 32070 32071 32072 32073 32074 |
# File 'lib/aws-sdk-securityhub/types.rb', line 32056 class Signal < Struct.new( :type, :id, :title, :product_arn, :resource_ids, :signal_indicators, :name, :created_at, :updated_at, :first_seen_at, :last_seen_at, :severity, :count, :actor_ids, :endpoint_ids) SENSITIVE = [] include Aws::Structure end |