Class: Aws::SecurityHub::Types::StandardsControl
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::StandardsControl
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Details for an individual security standard control.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#control_id ⇒ String
The identifier of the security standard control.
-
#control_status ⇒ String
The current status of the security standard control.
-
#control_status_updated_at ⇒ Time
The date and time that the status of the security standard control was most recently updated.
-
#description ⇒ String
The longer description of the security standard control.
-
#disabled_reason ⇒ String
The reason provided for the most recent change in status for the control.
-
#related_requirements ⇒ Array<String>
The list of requirements that are related to this control.
-
#remediation_url ⇒ String
A link to remediation information for the control in the Security Hub CSPM user documentation.
-
#severity_rating ⇒ String
The severity of findings generated from this security standard control.
-
#standards_control_arn ⇒ String
The ARN of the security standard control.
-
#title ⇒ String
The title of the security standard control.
Instance Attribute Details
#control_id ⇒ String
The identifier of the security standard control.
31943 31944 31945 31946 31947 31948 31949 31950 31951 31952 31953 31954 31955 31956 |
# File 'lib/aws-sdk-securityhub/types.rb', line 31943 class StandardsControl < Struct.new( :standards_control_arn, :control_status, :disabled_reason, :control_status_updated_at, :control_id, :title, :description, :remediation_url, :severity_rating, :related_requirements) SENSITIVE = [] include Aws::Structure end |
#control_status ⇒ String
The current status of the security standard control. Indicates whether the control is enabled or disabled. Security Hub CSPM does not check against disabled controls.
31943 31944 31945 31946 31947 31948 31949 31950 31951 31952 31953 31954 31955 31956 |
# File 'lib/aws-sdk-securityhub/types.rb', line 31943 class StandardsControl < Struct.new( :standards_control_arn, :control_status, :disabled_reason, :control_status_updated_at, :control_id, :title, :description, :remediation_url, :severity_rating, :related_requirements) SENSITIVE = [] include Aws::Structure end |
#control_status_updated_at ⇒ Time
The date and time that the status of the security standard control was most recently updated.
31943 31944 31945 31946 31947 31948 31949 31950 31951 31952 31953 31954 31955 31956 |
# File 'lib/aws-sdk-securityhub/types.rb', line 31943 class StandardsControl < Struct.new( :standards_control_arn, :control_status, :disabled_reason, :control_status_updated_at, :control_id, :title, :description, :remediation_url, :severity_rating, :related_requirements) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The longer description of the security standard control. Provides information about what the control is checking for.
31943 31944 31945 31946 31947 31948 31949 31950 31951 31952 31953 31954 31955 31956 |
# File 'lib/aws-sdk-securityhub/types.rb', line 31943 class StandardsControl < Struct.new( :standards_control_arn, :control_status, :disabled_reason, :control_status_updated_at, :control_id, :title, :description, :remediation_url, :severity_rating, :related_requirements) SENSITIVE = [] include Aws::Structure end |
#disabled_reason ⇒ String
The reason provided for the most recent change in status for the control.
31943 31944 31945 31946 31947 31948 31949 31950 31951 31952 31953 31954 31955 31956 |
# File 'lib/aws-sdk-securityhub/types.rb', line 31943 class StandardsControl < Struct.new( :standards_control_arn, :control_status, :disabled_reason, :control_status_updated_at, :control_id, :title, :description, :remediation_url, :severity_rating, :related_requirements) SENSITIVE = [] include Aws::Structure end |
#related_requirements ⇒ Array<String>
The list of requirements that are related to this control.
31943 31944 31945 31946 31947 31948 31949 31950 31951 31952 31953 31954 31955 31956 |
# File 'lib/aws-sdk-securityhub/types.rb', line 31943 class StandardsControl < Struct.new( :standards_control_arn, :control_status, :disabled_reason, :control_status_updated_at, :control_id, :title, :description, :remediation_url, :severity_rating, :related_requirements) SENSITIVE = [] include Aws::Structure end |
#remediation_url ⇒ String
A link to remediation information for the control in the Security Hub CSPM user documentation.
31943 31944 31945 31946 31947 31948 31949 31950 31951 31952 31953 31954 31955 31956 |
# File 'lib/aws-sdk-securityhub/types.rb', line 31943 class StandardsControl < Struct.new( :standards_control_arn, :control_status, :disabled_reason, :control_status_updated_at, :control_id, :title, :description, :remediation_url, :severity_rating, :related_requirements) SENSITIVE = [] include Aws::Structure end |
#severity_rating ⇒ String
The severity of findings generated from this security standard control.
The finding severity is based on an assessment of how easy it would be to compromise Amazon Web Services resources if the issue is detected.
31943 31944 31945 31946 31947 31948 31949 31950 31951 31952 31953 31954 31955 31956 |
# File 'lib/aws-sdk-securityhub/types.rb', line 31943 class StandardsControl < Struct.new( :standards_control_arn, :control_status, :disabled_reason, :control_status_updated_at, :control_id, :title, :description, :remediation_url, :severity_rating, :related_requirements) SENSITIVE = [] include Aws::Structure end |
#standards_control_arn ⇒ String
The ARN of the security standard control.
31943 31944 31945 31946 31947 31948 31949 31950 31951 31952 31953 31954 31955 31956 |
# File 'lib/aws-sdk-securityhub/types.rb', line 31943 class StandardsControl < Struct.new( :standards_control_arn, :control_status, :disabled_reason, :control_status_updated_at, :control_id, :title, :description, :remediation_url, :severity_rating, :related_requirements) SENSITIVE = [] include Aws::Structure end |
#title ⇒ String
The title of the security standard control.
31943 31944 31945 31946 31947 31948 31949 31950 31951 31952 31953 31954 31955 31956 |
# File 'lib/aws-sdk-securityhub/types.rb', line 31943 class StandardsControl < Struct.new( :standards_control_arn, :control_status, :disabled_reason, :control_status_updated_at, :control_id, :title, :description, :remediation_url, :severity_rating, :related_requirements) SENSITIVE = [] include Aws::Structure end |