Method: Aws::SecurityHub::Types::StandardsControlAssociationDetail#security_control_id
- Defined in:
- lib/aws-sdk-securityhub/types.rb
#security_control_id ⇒ String
The unique identifier of a security control across standards. Values for this field typically consist of an Amazon Web Services service name and a number, such as APIGateway.3.
32002 32003 32004 32005 32006 32007 32008 32009 32010 32011 32012 32013 32014 32015 |
# File 'lib/aws-sdk-securityhub/types.rb', line 32002 class StandardsControlAssociationDetail < Struct.new( :standards_arn, :security_control_id, :security_control_arn, :association_status, :related_requirements, :updated_at, :updated_reason, :standards_control_title, :standards_control_description, :standards_control_arns) SENSITIVE = [] include Aws::Structure end |