Class: Aws::SecurityHub::Types::StandardsSubscriptionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::StandardsSubscriptionRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
The standard that you want to enable.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#standards_arn ⇒ String
The ARN of the standard that you want to enable.
-
#standards_input ⇒ Hash<String,String>
A key-value pair of input for the standard.
Instance Attribute Details
#standards_arn ⇒ String
The ARN of the standard that you want to enable. To view the list of available standards and their ARNs, use the DescribeStandards operation.
32279 32280 32281 32282 32283 32284 |
# File 'lib/aws-sdk-securityhub/types.rb', line 32279 class StandardsSubscriptionRequest < Struct.new( :standards_arn, :standards_input) SENSITIVE = [] include Aws::Structure end |
#standards_input ⇒ Hash<String,String>
A key-value pair of input for the standard.
32279 32280 32281 32282 32283 32284 |
# File 'lib/aws-sdk-securityhub/types.rb', line 32279 class StandardsSubscriptionRequest < Struct.new( :standards_arn, :standards_input) SENSITIVE = [] include Aws::Structure end |