Method: Aws::SecurityHub::Types::StartConfigurationPolicyAssociationResponse#association_type

Defined in:
lib/aws-sdk-securityhub/types.rb

#association_typeString

Indicates whether the association between the specified target and the configuration was directly applied by the Security Hub delegated administrator or inherited from a parent.

Returns:

  • (String)


32323
32324
32325
32326
32327
32328
32329
32330
32331
32332
32333
# File 'lib/aws-sdk-securityhub/types.rb', line 32323

class StartConfigurationPolicyAssociationResponse < Struct.new(
  :configuration_policy_id,
  :target_id,
  :target_type,
  :association_type,
  :updated_at,
  :association_status,
  :association_status_message)
  SENSITIVE = []
  include Aws::Structure
end