Class: Aws::SecurityHub::Types::ThreatIntelIndicator

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

Details about the threat intelligence related to a finding.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#categoryString

The category of a threat intelligence indicator.



34227
34228
34229
34230
34231
34232
34233
34234
34235
34236
# File 'lib/aws-sdk-securityhub/types.rb', line 34227

class ThreatIntelIndicator < Struct.new(
  :type,
  :value,
  :category,
  :last_observed_at,
  :source,
  :source_url)
  SENSITIVE = []
  include Aws::Structure
end

#last_observed_atString

Indicates when the most recent instance of a threat intelligence indicator was observed.

For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.



34227
34228
34229
34230
34231
34232
34233
34234
34235
34236
# File 'lib/aws-sdk-securityhub/types.rb', line 34227

class ThreatIntelIndicator < Struct.new(
  :type,
  :value,
  :category,
  :last_observed_at,
  :source,
  :source_url)
  SENSITIVE = []
  include Aws::Structure
end

#sourceString

The source of the threat intelligence indicator.

Length Constraints: Minimum of 1 length. Maximum of 64 length.



34227
34228
34229
34230
34231
34232
34233
34234
34235
34236
# File 'lib/aws-sdk-securityhub/types.rb', line 34227

class ThreatIntelIndicator < Struct.new(
  :type,
  :value,
  :category,
  :last_observed_at,
  :source,
  :source_url)
  SENSITIVE = []
  include Aws::Structure
end

#source_urlString

The URL to the page or site where you can get more information about the threat intelligence indicator.



34227
34228
34229
34230
34231
34232
34233
34234
34235
34236
# File 'lib/aws-sdk-securityhub/types.rb', line 34227

class ThreatIntelIndicator < Struct.new(
  :type,
  :value,
  :category,
  :last_observed_at,
  :source,
  :source_url)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The type of threat intelligence indicator.



34227
34228
34229
34230
34231
34232
34233
34234
34235
34236
# File 'lib/aws-sdk-securityhub/types.rb', line 34227

class ThreatIntelIndicator < Struct.new(
  :type,
  :value,
  :category,
  :last_observed_at,
  :source,
  :source_url)
  SENSITIVE = []
  include Aws::Structure
end

#valueString

The value of a threat intelligence indicator.

Length Constraints: Minimum of 1 length. Maximum of 512 length.



34227
34228
34229
34230
34231
34232
34233
34234
34235
34236
# File 'lib/aws-sdk-securityhub/types.rb', line 34227

class ThreatIntelIndicator < Struct.new(
  :type,
  :value,
  :category,
  :last_observed_at,
  :source,
  :source_url)
  SENSITIVE = []
  include Aws::Structure
end