Class: Aws::SecurityHub::Types::TrendsMetricsResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::TrendsMetricsResult
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Contains the findings trend metrics data for a specific time point in the requested time period.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#timestamp ⇒ Time
The timestamp for this data point in the findings trend metrics.
-
#trends_values ⇒ Types::TrendsValues
The finding trend metric values associated with this timestamp, including severity counts.
Instance Attribute Details
#timestamp ⇒ Time
The timestamp for this data point in the findings trend metrics.
32976 32977 32978 32979 32980 32981 |
# File 'lib/aws-sdk-securityhub/types.rb', line 32976 class TrendsMetricsResult < Struct.new( :timestamp, :trends_values) SENSITIVE = [] include Aws::Structure end |
#trends_values ⇒ Types::TrendsValues
The finding trend metric values associated with this timestamp, including severity counts.
32976 32977 32978 32979 32980 32981 |
# File 'lib/aws-sdk-securityhub/types.rb', line 32976 class TrendsMetricsResult < Struct.new( :timestamp, :trends_values) SENSITIVE = [] include Aws::Structure end |