Class: Aws::SecurityHub::Types::TrendsValues

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

Contains the aggregated finding values for a specific point in the findings trend timeline.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

The count of findings organized by severity level for this data point in the trend timeline.



33128
33129
33130
33131
33132
# File 'lib/aws-sdk-securityhub/types.rb', line 33128

class TrendsValues < Struct.new(
  :severity_trends)
  SENSITIVE = []
  include Aws::Structure
end