Class: Aws::SecurityHub::Types::UnusedPermissionsRecommendationStep
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::UnusedPermissionsRecommendationStep
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Contains information about the action to take for a policy in an unused permissions finding.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#existing_policy ⇒ String
The contents of the existing policy identified by
ExistingPolicyIdwhich needs to be replaced, when theRecommendedActionisCREATE_POLICY. -
#existing_policy_id ⇒ String
The ID of an existing policy to be replaced or detached.
-
#policy_updated_at ⇒ Time
The time at which the existing policy for the unused permissions finding was last updated.
-
#recommended_action ⇒ String
A recommendation of whether to create or detach a policy for an unused permissions finding.
-
#recommended_policy ⇒ String
The contents of the least-privileged recommended replacement for
ExistingPolicyId, when theRecommendedActionisCREATE_POLICY.
Instance Attribute Details
#existing_policy ⇒ String
The contents of the existing policy identified by ExistingPolicyId
which needs to be replaced, when the RecommendedAction is
CREATE_POLICY.
34247 34248 34249 34250 34251 34252 34253 34254 34255 |
# File 'lib/aws-sdk-securityhub/types.rb', line 34247 class UnusedPermissionsRecommendationStep < Struct.new( :recommended_action, :existing_policy, :existing_policy_id, :policy_updated_at, :recommended_policy) SENSITIVE = [] include Aws::Structure end |
#existing_policy_id ⇒ String
The ID of an existing policy to be replaced or detached.
34247 34248 34249 34250 34251 34252 34253 34254 34255 |
# File 'lib/aws-sdk-securityhub/types.rb', line 34247 class UnusedPermissionsRecommendationStep < Struct.new( :recommended_action, :existing_policy, :existing_policy_id, :policy_updated_at, :recommended_policy) SENSITIVE = [] include Aws::Structure end |
#policy_updated_at ⇒ Time
The time at which the existing policy for the unused permissions finding was last updated.
34247 34248 34249 34250 34251 34252 34253 34254 34255 |
# File 'lib/aws-sdk-securityhub/types.rb', line 34247 class UnusedPermissionsRecommendationStep < Struct.new( :recommended_action, :existing_policy, :existing_policy_id, :policy_updated_at, :recommended_policy) SENSITIVE = [] include Aws::Structure end |
#recommended_action ⇒ String
A recommendation of whether to create or detach a policy for an unused permissions finding.
34247 34248 34249 34250 34251 34252 34253 34254 34255 |
# File 'lib/aws-sdk-securityhub/types.rb', line 34247 class UnusedPermissionsRecommendationStep < Struct.new( :recommended_action, :existing_policy, :existing_policy_id, :policy_updated_at, :recommended_policy) SENSITIVE = [] include Aws::Structure end |
#recommended_policy ⇒ String
The contents of the least-privileged recommended replacement for
ExistingPolicyId, when the RecommendedAction is CREATE_POLICY.
34247 34248 34249 34250 34251 34252 34253 34254 34255 |
# File 'lib/aws-sdk-securityhub/types.rb', line 34247 class UnusedPermissionsRecommendationStep < Struct.new( :recommended_action, :existing_policy, :existing_policy_id, :policy_updated_at, :recommended_policy) SENSITIVE = [] include Aws::Structure end |