Class: Aws::SecurityHub::Types::UpdateAggregatorV2Response

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#aggregation_regionString

The Amazon Web Services Region where data is aggregated.

Returns:



33080
33081
33082
33083
33084
33085
33086
33087
# File 'lib/aws-sdk-securityhub/types.rb', line 33080

class UpdateAggregatorV2Response < Struct.new(
  :aggregator_v2_arn,
  :aggregation_region,
  :region_linking_mode,
  :linked_regions)
  SENSITIVE = []
  include Aws::Structure
end

#aggregator_v2_arnString

The ARN of the Aggregator V2.

Returns:



33080
33081
33082
33083
33084
33085
33086
33087
# File 'lib/aws-sdk-securityhub/types.rb', line 33080

class UpdateAggregatorV2Response < Struct.new(
  :aggregator_v2_arn,
  :aggregation_region,
  :region_linking_mode,
  :linked_regions)
  SENSITIVE = []
  include Aws::Structure
end

#linked_regionsArray<String>

A list of Amazon Web Services Regions linked to the aggegation Region.

Returns:



33080
33081
33082
33083
33084
33085
33086
33087
# File 'lib/aws-sdk-securityhub/types.rb', line 33080

class UpdateAggregatorV2Response < Struct.new(
  :aggregator_v2_arn,
  :aggregation_region,
  :region_linking_mode,
  :linked_regions)
  SENSITIVE = []
  include Aws::Structure
end

#region_linking_modeString

Determines how Amazon Web Services Regions should be linked to the Aggregator V2.

Returns:



33080
33081
33082
33083
33084
33085
33086
33087
# File 'lib/aws-sdk-securityhub/types.rb', line 33080

class UpdateAggregatorV2Response < Struct.new(
  :aggregator_v2_arn,
  :aggregation_region,
  :region_linking_mode,
  :linked_regions)
  SENSITIVE = []
  include Aws::Structure
end