Class: Aws::SecurityHub::Types::UpdateConnectorResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::UpdateConnectorResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#connector_status ⇒ String
The connectivity status of the connector after the update.
-
#enablement_status ⇒ String
The enablement status of the connector after the update.
Instance Attribute Details
#connector_status ⇒ String
The connectivity status of the connector after the update.
34724 34725 34726 34727 34728 34729 |
# File 'lib/aws-sdk-securityhub/types.rb', line 34724 class UpdateConnectorResponse < Struct.new( :connector_status, :enablement_status) SENSITIVE = [] include Aws::Structure end |
#enablement_status ⇒ String
The enablement status of the connector after the update.
34724 34725 34726 34727 34728 34729 |
# File 'lib/aws-sdk-securityhub/types.rb', line 34724 class UpdateConnectorResponse < Struct.new( :connector_status, :enablement_status) SENSITIVE = [] include Aws::Structure end |