Class: Aws::SecurityHub::Types::UpdateConnectorV2Response
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::UpdateConnectorV2Response
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#connector_status ⇒ String
The status of the connector after the update.
-
#enablement_status ⇒ String
The enablement status of the connector after the update.
Instance Attribute Details
#connector_status ⇒ String
The status of the connector after the update.
34888 34889 34890 34891 34892 34893 |
# File 'lib/aws-sdk-securityhub/types.rb', line 34888 class UpdateConnectorV2Response < Struct.new( :connector_status, :enablement_status) SENSITIVE = [] include Aws::Structure end |
#enablement_status ⇒ String
The enablement status of the connector after the update.
34888 34889 34890 34891 34892 34893 |
# File 'lib/aws-sdk-securityhub/types.rb', line 34888 class UpdateConnectorV2Response < Struct.new( :connector_status, :enablement_status) SENSITIVE = [] include Aws::Structure end |