Class: Aws::SecurityHub::Types::UpdateOrganizationConfigurationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::UpdateOrganizationConfigurationRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#auto_enable ⇒ Boolean
Whether to automatically enable Security Hub CSPM in new member accounts when they join the organization.
-
#auto_enable_standards ⇒ String
Whether to automatically enable Security Hub CSPM [default standards] in new member accounts when they join the organization.
-
#organization_configuration ⇒ Types::OrganizationConfiguration
Provides information about the way an organization is configured in Security Hub CSPM.
Instance Attribute Details
#auto_enable ⇒ Boolean
Whether to automatically enable Security Hub CSPM in new member accounts when they join the organization.
If set to true, then Security Hub CSPM is automatically enabled in new accounts. If set to false, then Security Hub CSPM isn’t enabled in new accounts automatically. The default value is false.
If the ConfigurationType of your organization is set to CENTRAL, then this field is set to false and can’t be changed in the home Region and linked Regions. However, in that case, the delegated administrator can create a configuration policy in which Security Hub CSPM is enabled and associate the policy with new organization accounts.
33524 33525 33526 33527 33528 33529 33530 |
# File 'lib/aws-sdk-securityhub/types.rb', line 33524 class UpdateOrganizationConfigurationRequest < Struct.new( :auto_enable, :auto_enable_standards, :organization_configuration) SENSITIVE = [] include Aws::Structure end |
#auto_enable_standards ⇒ String
Whether to automatically enable Security Hub CSPM [default standards] in new member accounts when they join the organization.
The default value of this parameter is equal to DEFAULT.
If equal to DEFAULT, then Security Hub CSPM default standards are automatically enabled for new member accounts. If equal to NONE, then default standards are not automatically enabled for new member accounts.
If the ConfigurationType of your organization is set to CENTRAL, then this field is set to NONE and can’t be changed in the home Region and linked Regions. However, in that case, the delegated administrator can create a configuration policy in which specific security standards are enabled and associate the policy with new organization accounts.
[1]: docs.aws.amazon.com/securityhub/latest/userguide/securityhub-standards-enable-disable.html
33524 33525 33526 33527 33528 33529 33530 |
# File 'lib/aws-sdk-securityhub/types.rb', line 33524 class UpdateOrganizationConfigurationRequest < Struct.new( :auto_enable, :auto_enable_standards, :organization_configuration) SENSITIVE = [] include Aws::Structure end |
#organization_configuration ⇒ Types::OrganizationConfiguration
Provides information about the way an organization is configured in Security Hub CSPM.
33524 33525 33526 33527 33528 33529 33530 |
# File 'lib/aws-sdk-securityhub/types.rb', line 33524 class UpdateOrganizationConfigurationRequest < Struct.new( :auto_enable, :auto_enable_standards, :organization_configuration) SENSITIVE = [] include Aws::Structure end |