Class: Aws::SecurityHub::Types::UserAccount

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

Provides Amazon Web Services account information of the user involved in an Amazon GuardDuty Extended Threat Detection attack sequence. GuardDuty generates an attack sequence finding when multiple events align to a potentially suspicious activity. To receive GuardDuty attack sequence findings in Security Hub CSPM, you must have GuardDuty enabled. For more information, see [GuardDuty Extended Threat Detection ][1] in the *Amazon GuardDuty User Guide*.

[1]: docs.aws.amazon.com/guardduty/latest/ug/guardduty-extended-threat-detection.html

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#nameString

The name of the user account involved in the attack sequence.

Returns:



33663
33664
33665
33666
33667
33668
# File 'lib/aws-sdk-securityhub/types.rb', line 33663

class UserAccount < Struct.new(
  :uid,
  :name)
  SENSITIVE = []
  include Aws::Structure
end

#uidString

The unique identifier of the user account involved in the attack sequence.

Returns:



33663
33664
33665
33666
33667
33668
# File 'lib/aws-sdk-securityhub/types.rb', line 33663

class UserAccount < Struct.new(
  :uid,
  :name)
  SENSITIVE = []
  include Aws::Structure
end