Class: Aws::SecurityHub::Types::Vulnerability
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::Vulnerability
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
A vulnerability associated with a finding.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#code_vulnerabilities ⇒ Array<Types::VulnerabilityCodeVulnerabilities>
The vulnerabilities found in your Lambda function code.
-
#cvss ⇒ Array<Types::Cvss>
CVSS scores from the advisory related to the vulnerability.
-
#epss_score ⇒ Float
The Exploit Prediction Scoring System (EPSS) score for a finding.
-
#exploit_available ⇒ String
Whether an exploit is available for a finding.
-
#fix_available ⇒ String
Specifies if all vulnerable packages in a finding have a value for
FixedInVersionandRemediation. -
#id ⇒ String
The identifier of the vulnerability.
-
#last_known_exploit_at ⇒ String
The date and time of the last exploit associated with a finding discovered in your environment.
-
#reference_urls ⇒ Array<String>
A list of URLs that provide additional information about the vulnerability.
-
#related_vulnerabilities ⇒ Array<String>
List of vulnerabilities that are related to this vulnerability.
-
#vendor ⇒ Types::VulnerabilityVendor
Information about the vendor that generates the vulnerability report.
-
#vulnerable_packages ⇒ Array<Types::SoftwarePackage>
List of software packages that have the vulnerability.
Instance Attribute Details
#code_vulnerabilities ⇒ Array<Types::VulnerabilityCodeVulnerabilities>
The vulnerabilities found in your Lambda function code. This field pertains to findings that Security Hub CSPM receives from Amazon Inspector.
34007 34008 34009 34010 34011 34012 34013 34014 34015 34016 34017 34018 34019 34020 34021 |
# File 'lib/aws-sdk-securityhub/types.rb', line 34007 class Vulnerability < Struct.new( :id, :vulnerable_packages, :cvss, :related_vulnerabilities, :vendor, :reference_urls, :fix_available, :epss_score, :exploit_available, :last_known_exploit_at, :code_vulnerabilities) SENSITIVE = [] include Aws::Structure end |
#cvss ⇒ Array<Types::Cvss>
CVSS scores from the advisory related to the vulnerability.
34007 34008 34009 34010 34011 34012 34013 34014 34015 34016 34017 34018 34019 34020 34021 |
# File 'lib/aws-sdk-securityhub/types.rb', line 34007 class Vulnerability < Struct.new( :id, :vulnerable_packages, :cvss, :related_vulnerabilities, :vendor, :reference_urls, :fix_available, :epss_score, :exploit_available, :last_known_exploit_at, :code_vulnerabilities) SENSITIVE = [] include Aws::Structure end |
#epss_score ⇒ Float
The Exploit Prediction Scoring System (EPSS) score for a finding.
34007 34008 34009 34010 34011 34012 34013 34014 34015 34016 34017 34018 34019 34020 34021 |
# File 'lib/aws-sdk-securityhub/types.rb', line 34007 class Vulnerability < Struct.new( :id, :vulnerable_packages, :cvss, :related_vulnerabilities, :vendor, :reference_urls, :fix_available, :epss_score, :exploit_available, :last_known_exploit_at, :code_vulnerabilities) SENSITIVE = [] include Aws::Structure end |
#exploit_available ⇒ String
Whether an exploit is available for a finding.
34007 34008 34009 34010 34011 34012 34013 34014 34015 34016 34017 34018 34019 34020 34021 |
# File 'lib/aws-sdk-securityhub/types.rb', line 34007 class Vulnerability < Struct.new( :id, :vulnerable_packages, :cvss, :related_vulnerabilities, :vendor, :reference_urls, :fix_available, :epss_score, :exploit_available, :last_known_exploit_at, :code_vulnerabilities) SENSITIVE = [] include Aws::Structure end |
#fix_available ⇒ String
Specifies if all vulnerable packages in a finding have a value for
FixedInVersion and Remediation. This field is evaluated for each
vulnerability Id based on the number of vulnerable packages that
have a value for both FixedInVersion and Remediation. Valid
values are as follows:
-
YESif all vulnerable packages have a value for bothFixedInVersionandRemediation -
NOif no vulnerable packages have a value forFixedInVersionandRemediation -
PARTIALotherwise
34007 34008 34009 34010 34011 34012 34013 34014 34015 34016 34017 34018 34019 34020 34021 |
# File 'lib/aws-sdk-securityhub/types.rb', line 34007 class Vulnerability < Struct.new( :id, :vulnerable_packages, :cvss, :related_vulnerabilities, :vendor, :reference_urls, :fix_available, :epss_score, :exploit_available, :last_known_exploit_at, :code_vulnerabilities) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The identifier of the vulnerability.
34007 34008 34009 34010 34011 34012 34013 34014 34015 34016 34017 34018 34019 34020 34021 |
# File 'lib/aws-sdk-securityhub/types.rb', line 34007 class Vulnerability < Struct.new( :id, :vulnerable_packages, :cvss, :related_vulnerabilities, :vendor, :reference_urls, :fix_available, :epss_score, :exploit_available, :last_known_exploit_at, :code_vulnerabilities) SENSITIVE = [] include Aws::Structure end |
#last_known_exploit_at ⇒ String
The date and time of the last exploit associated with a finding discovered in your environment.
34007 34008 34009 34010 34011 34012 34013 34014 34015 34016 34017 34018 34019 34020 34021 |
# File 'lib/aws-sdk-securityhub/types.rb', line 34007 class Vulnerability < Struct.new( :id, :vulnerable_packages, :cvss, :related_vulnerabilities, :vendor, :reference_urls, :fix_available, :epss_score, :exploit_available, :last_known_exploit_at, :code_vulnerabilities) SENSITIVE = [] include Aws::Structure end |
#reference_urls ⇒ Array<String>
A list of URLs that provide additional information about the vulnerability.
34007 34008 34009 34010 34011 34012 34013 34014 34015 34016 34017 34018 34019 34020 34021 |
# File 'lib/aws-sdk-securityhub/types.rb', line 34007 class Vulnerability < Struct.new( :id, :vulnerable_packages, :cvss, :related_vulnerabilities, :vendor, :reference_urls, :fix_available, :epss_score, :exploit_available, :last_known_exploit_at, :code_vulnerabilities) SENSITIVE = [] include Aws::Structure end |
#related_vulnerabilities ⇒ Array<String>
List of vulnerabilities that are related to this vulnerability.
34007 34008 34009 34010 34011 34012 34013 34014 34015 34016 34017 34018 34019 34020 34021 |
# File 'lib/aws-sdk-securityhub/types.rb', line 34007 class Vulnerability < Struct.new( :id, :vulnerable_packages, :cvss, :related_vulnerabilities, :vendor, :reference_urls, :fix_available, :epss_score, :exploit_available, :last_known_exploit_at, :code_vulnerabilities) SENSITIVE = [] include Aws::Structure end |
#vendor ⇒ Types::VulnerabilityVendor
Information about the vendor that generates the vulnerability report.
34007 34008 34009 34010 34011 34012 34013 34014 34015 34016 34017 34018 34019 34020 34021 |
# File 'lib/aws-sdk-securityhub/types.rb', line 34007 class Vulnerability < Struct.new( :id, :vulnerable_packages, :cvss, :related_vulnerabilities, :vendor, :reference_urls, :fix_available, :epss_score, :exploit_available, :last_known_exploit_at, :code_vulnerabilities) SENSITIVE = [] include Aws::Structure end |
#vulnerable_packages ⇒ Array<Types::SoftwarePackage>
List of software packages that have the vulnerability.
34007 34008 34009 34010 34011 34012 34013 34014 34015 34016 34017 34018 34019 34020 34021 |
# File 'lib/aws-sdk-securityhub/types.rb', line 34007 class Vulnerability < Struct.new( :id, :vulnerable_packages, :cvss, :related_vulnerabilities, :vendor, :reference_urls, :fix_available, :epss_score, :exploit_available, :last_known_exploit_at, :code_vulnerabilities) SENSITIVE = [] include Aws::Structure end |