Class: Aws::SecurityHub::Types::WafAction
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::WafAction
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Details about the action that CloudFront or WAF takes when a web request matches the conditions in the rule.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#type ⇒ String
Specifies how you want WAF to respond to requests that match the settings in a rule.
Instance Attribute Details
#type ⇒ String
Specifies how you want WAF to respond to requests that match the settings in a rule.
Valid settings include the following:
-
ALLOW- WAF allows requests -
BLOCK- WAF blocks requests -
COUNT- WAF increments a counter of the requests that match all of the conditions in the rule. WAF then continues to inspect the web request based on the remaining rules in the web ACL. You can't specifyCOUNTfor the default action for a web ACL.
35241 35242 35243 35244 35245 |
# File 'lib/aws-sdk-securityhub/types.rb', line 35241 class WafAction < Struct.new( :type) SENSITIVE = [] include Aws::Structure end |