Class: Aws::SecurityHub::Types::AwsApiCallAction
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::AwsApiCallAction
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Provided if ActionType is AWS_API_CALL. It provides details about
the API call that was detected.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#affected_resources ⇒ Hash<String,String>
Identifies the resources that were affected by the API call.
-
#api ⇒ String
The name of the API method that was issued.
-
#caller_type ⇒ String
Indicates whether the API call originated from a remote IP address (
remoteip) or from a DNS domain (domain). -
#domain_details ⇒ Types::AwsApiCallActionDomainDetails
Provided if
CallerTypeisdomain. -
#first_seen ⇒ String
A timestamp that indicates when the API call was first observed.
-
#last_seen ⇒ String
A timestamp that indicates when the API call was most recently observed.
-
#remote_ip_details ⇒ Types::ActionRemoteIpDetails
Provided if
CallerTypeisremoteip. -
#service_name ⇒ String
The name of the Amazon Web Services service that the API method belongs to.
Instance Attribute Details
#affected_resources ⇒ Hash<String,String>
Identifies the resources that were affected by the API call.
1743 1744 1745 1746 1747 1748 1749 1750 1751 1752 1753 1754 |
# File 'lib/aws-sdk-securityhub/types.rb', line 1743 class AwsApiCallAction < Struct.new( :api, :service_name, :caller_type, :remote_ip_details, :domain_details, :affected_resources, :first_seen, :last_seen) SENSITIVE = [] include Aws::Structure end |
#api ⇒ String
The name of the API method that was issued.
Length Constraints: 128.
1743 1744 1745 1746 1747 1748 1749 1750 1751 1752 1753 1754 |
# File 'lib/aws-sdk-securityhub/types.rb', line 1743 class AwsApiCallAction < Struct.new( :api, :service_name, :caller_type, :remote_ip_details, :domain_details, :affected_resources, :first_seen, :last_seen) SENSITIVE = [] include Aws::Structure end |
#caller_type ⇒ String
Indicates whether the API call originated from a remote IP address
(remoteip) or from a DNS domain (domain).
1743 1744 1745 1746 1747 1748 1749 1750 1751 1752 1753 1754 |
# File 'lib/aws-sdk-securityhub/types.rb', line 1743 class AwsApiCallAction < Struct.new( :api, :service_name, :caller_type, :remote_ip_details, :domain_details, :affected_resources, :first_seen, :last_seen) SENSITIVE = [] include Aws::Structure end |
#domain_details ⇒ Types::AwsApiCallActionDomainDetails
Provided if CallerType is domain. Provides information about the
DNS domain that the API call originated from.
1743 1744 1745 1746 1747 1748 1749 1750 1751 1752 1753 1754 |
# File 'lib/aws-sdk-securityhub/types.rb', line 1743 class AwsApiCallAction < Struct.new( :api, :service_name, :caller_type, :remote_ip_details, :domain_details, :affected_resources, :first_seen, :last_seen) SENSITIVE = [] include Aws::Structure end |
#first_seen ⇒ String
A timestamp that indicates when the API call was first observed.
For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.
1743 1744 1745 1746 1747 1748 1749 1750 1751 1752 1753 1754 |
# File 'lib/aws-sdk-securityhub/types.rb', line 1743 class AwsApiCallAction < Struct.new( :api, :service_name, :caller_type, :remote_ip_details, :domain_details, :affected_resources, :first_seen, :last_seen) SENSITIVE = [] include Aws::Structure end |
#last_seen ⇒ String
A timestamp that indicates when the API call was most recently observed.
For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.
1743 1744 1745 1746 1747 1748 1749 1750 1751 1752 1753 1754 |
# File 'lib/aws-sdk-securityhub/types.rb', line 1743 class AwsApiCallAction < Struct.new( :api, :service_name, :caller_type, :remote_ip_details, :domain_details, :affected_resources, :first_seen, :last_seen) SENSITIVE = [] include Aws::Structure end |
#remote_ip_details ⇒ Types::ActionRemoteIpDetails
Provided if CallerType is remoteip. Provides information about
the remote IP address that the API call originated from.
1743 1744 1745 1746 1747 1748 1749 1750 1751 1752 1753 1754 |
# File 'lib/aws-sdk-securityhub/types.rb', line 1743 class AwsApiCallAction < Struct.new( :api, :service_name, :caller_type, :remote_ip_details, :domain_details, :affected_resources, :first_seen, :last_seen) SENSITIVE = [] include Aws::Structure end |
#service_name ⇒ String
The name of the Amazon Web Services service that the API method belongs to.
Length Constraints: 128.
1743 1744 1745 1746 1747 1748 1749 1750 1751 1752 1753 1754 |
# File 'lib/aws-sdk-securityhub/types.rb', line 1743 class AwsApiCallAction < Struct.new( :api, :service_name, :caller_type, :remote_ip_details, :domain_details, :affected_resources, :first_seen, :last_seen) SENSITIVE = [] include Aws::Structure end |