Class: Aws::SecurityHub::Types::AwsApiGatewayV2RouteSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::AwsApiGatewayV2RouteSettings
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Contains route settings for a stage.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#data_trace_enabled ⇒ Boolean
Indicates whether data trace logging is enabled.
-
#detailed_metrics_enabled ⇒ Boolean
Indicates whether detailed metrics are enabled.
-
#logging_level ⇒ String
The logging level.
-
#throttling_burst_limit ⇒ Integer
The throttling burst limit.
-
#throttling_rate_limit ⇒ Float
The throttling rate limit.
Instance Attribute Details
#data_trace_enabled ⇒ Boolean
Indicates whether data trace logging is enabled. Data trace logging affects the log entries that are pushed to CloudWatch Logs. Supported only for WebSocket APIs.
2248 2249 2250 2251 2252 2253 2254 2255 2256 |
# File 'lib/aws-sdk-securityhub/types.rb', line 2248 class AwsApiGatewayV2RouteSettings < Struct.new( :detailed_metrics_enabled, :logging_level, :data_trace_enabled, :throttling_burst_limit, :throttling_rate_limit) SENSITIVE = [] include Aws::Structure end |
#detailed_metrics_enabled ⇒ Boolean
Indicates whether detailed metrics are enabled.
2248 2249 2250 2251 2252 2253 2254 2255 2256 |
# File 'lib/aws-sdk-securityhub/types.rb', line 2248 class AwsApiGatewayV2RouteSettings < Struct.new( :detailed_metrics_enabled, :logging_level, :data_trace_enabled, :throttling_burst_limit, :throttling_rate_limit) SENSITIVE = [] include Aws::Structure end |
#logging_level ⇒ String
The logging level. The logging level affects the log entries that are pushed to CloudWatch Logs. Supported only for WebSocket APIs.
If the logging level is ERROR, then the logs only include
error-level entries.
If the logging level is INFO, then the logs include both ERROR
events and extra informational events.
Valid values: OFF | ERROR | INFO
2248 2249 2250 2251 2252 2253 2254 2255 2256 |
# File 'lib/aws-sdk-securityhub/types.rb', line 2248 class AwsApiGatewayV2RouteSettings < Struct.new( :detailed_metrics_enabled, :logging_level, :data_trace_enabled, :throttling_burst_limit, :throttling_rate_limit) SENSITIVE = [] include Aws::Structure end |
#throttling_burst_limit ⇒ Integer
The throttling burst limit.
2248 2249 2250 2251 2252 2253 2254 2255 2256 |
# File 'lib/aws-sdk-securityhub/types.rb', line 2248 class AwsApiGatewayV2RouteSettings < Struct.new( :detailed_metrics_enabled, :logging_level, :data_trace_enabled, :throttling_burst_limit, :throttling_rate_limit) SENSITIVE = [] include Aws::Structure end |
#throttling_rate_limit ⇒ Float
The throttling rate limit.
2248 2249 2250 2251 2252 2253 2254 2255 2256 |
# File 'lib/aws-sdk-securityhub/types.rb', line 2248 class AwsApiGatewayV2RouteSettings < Struct.new( :detailed_metrics_enabled, :logging_level, :data_trace_enabled, :throttling_burst_limit, :throttling_rate_limit) SENSITIVE = [] include Aws::Structure end |