Class: Aws::SecurityHub::Types::AwsAppSyncGraphQlApiDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::AwsAppSyncGraphQlApiDetails
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Provides details about an AppSync Graph QL API, which lets you query multiple databases, microservices, and APIs from a single GraphQL endpoint.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#additional_authentication_providers ⇒ Array<Types::AwsAppSyncGraphQlApiAdditionalAuthenticationProvidersDetails>
A list of additional authentication providers for the GraphQL API.
-
#api_id ⇒ String
The unique identifier for the API.
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the API.
-
#authentication_type ⇒ String
The type of security configuration for your GraphQL API: API key, Identity and Access Management (IAM), OpenID Connect (OIDC), Amazon Cognito user pools, or Lambda.
-
#id ⇒ String
The unique identifier for the API.
-
#lambda_authorizer_config ⇒ Types::AwsAppSyncGraphQlApiLambdaAuthorizerConfigDetails
Specifies the configuration for Lambda function authorization.
-
#log_config ⇒ Types::AwsAppSyncGraphQlApiLogConfigDetails
The Amazon CloudWatch Logs configuration.
-
#name ⇒ String
The API name.
-
#open_id_connect_config ⇒ Types::AwsAppSyncGraphQlApiOpenIdConnectConfigDetails
Specifies the authorization configuration for using an OpenID Connect compliant service with an AppSync GraphQL API endpoint.
-
#user_pool_config ⇒ Types::AwsAppSyncGraphQlApiUserPoolConfigDetails
The Amazon Cognito user pools configuration.
-
#waf_web_acl_arn ⇒ String
The Amazon Resource Name (ARN) of the WAF web access control list (web ACL) associated with this GraphQL API, if one exists.
-
#xray_enabled ⇒ Boolean
Indicates whether to use X-Ray tracing for the GraphQL API.
Instance Attribute Details
#additional_authentication_providers ⇒ Array<Types::AwsAppSyncGraphQlApiAdditionalAuthenticationProvidersDetails>
A list of additional authentication providers for the GraphQL API.
2578 2579 2580 2581 2582 2583 2584 2585 2586 2587 2588 2589 2590 2591 2592 2593 |
# File 'lib/aws-sdk-securityhub/types.rb', line 2578 class AwsAppSyncGraphQlApiDetails < Struct.new( :api_id, :id, :open_id_connect_config, :name, :lambda_authorizer_config, :xray_enabled, :arn, :user_pool_config, :authentication_type, :log_config, :additional_authentication_providers, :waf_web_acl_arn) SENSITIVE = [] include Aws::Structure end |
#api_id ⇒ String
The unique identifier for the API.
2578 2579 2580 2581 2582 2583 2584 2585 2586 2587 2588 2589 2590 2591 2592 2593 |
# File 'lib/aws-sdk-securityhub/types.rb', line 2578 class AwsAppSyncGraphQlApiDetails < Struct.new( :api_id, :id, :open_id_connect_config, :name, :lambda_authorizer_config, :xray_enabled, :arn, :user_pool_config, :authentication_type, :log_config, :additional_authentication_providers, :waf_web_acl_arn) SENSITIVE = [] include Aws::Structure end |
#arn ⇒ String
The Amazon Resource Name (ARN) of the API.
2578 2579 2580 2581 2582 2583 2584 2585 2586 2587 2588 2589 2590 2591 2592 2593 |
# File 'lib/aws-sdk-securityhub/types.rb', line 2578 class AwsAppSyncGraphQlApiDetails < Struct.new( :api_id, :id, :open_id_connect_config, :name, :lambda_authorizer_config, :xray_enabled, :arn, :user_pool_config, :authentication_type, :log_config, :additional_authentication_providers, :waf_web_acl_arn) SENSITIVE = [] include Aws::Structure end |
#authentication_type ⇒ String
The type of security configuration for your GraphQL API: API key, Identity and Access Management (IAM), OpenID Connect (OIDC), Amazon Cognito user pools, or Lambda.
2578 2579 2580 2581 2582 2583 2584 2585 2586 2587 2588 2589 2590 2591 2592 2593 |
# File 'lib/aws-sdk-securityhub/types.rb', line 2578 class AwsAppSyncGraphQlApiDetails < Struct.new( :api_id, :id, :open_id_connect_config, :name, :lambda_authorizer_config, :xray_enabled, :arn, :user_pool_config, :authentication_type, :log_config, :additional_authentication_providers, :waf_web_acl_arn) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The unique identifier for the API.
2578 2579 2580 2581 2582 2583 2584 2585 2586 2587 2588 2589 2590 2591 2592 2593 |
# File 'lib/aws-sdk-securityhub/types.rb', line 2578 class AwsAppSyncGraphQlApiDetails < Struct.new( :api_id, :id, :open_id_connect_config, :name, :lambda_authorizer_config, :xray_enabled, :arn, :user_pool_config, :authentication_type, :log_config, :additional_authentication_providers, :waf_web_acl_arn) SENSITIVE = [] include Aws::Structure end |
#lambda_authorizer_config ⇒ Types::AwsAppSyncGraphQlApiLambdaAuthorizerConfigDetails
Specifies the configuration for Lambda function authorization.
2578 2579 2580 2581 2582 2583 2584 2585 2586 2587 2588 2589 2590 2591 2592 2593 |
# File 'lib/aws-sdk-securityhub/types.rb', line 2578 class AwsAppSyncGraphQlApiDetails < Struct.new( :api_id, :id, :open_id_connect_config, :name, :lambda_authorizer_config, :xray_enabled, :arn, :user_pool_config, :authentication_type, :log_config, :additional_authentication_providers, :waf_web_acl_arn) SENSITIVE = [] include Aws::Structure end |
#log_config ⇒ Types::AwsAppSyncGraphQlApiLogConfigDetails
The Amazon CloudWatch Logs configuration.
2578 2579 2580 2581 2582 2583 2584 2585 2586 2587 2588 2589 2590 2591 2592 2593 |
# File 'lib/aws-sdk-securityhub/types.rb', line 2578 class AwsAppSyncGraphQlApiDetails < Struct.new( :api_id, :id, :open_id_connect_config, :name, :lambda_authorizer_config, :xray_enabled, :arn, :user_pool_config, :authentication_type, :log_config, :additional_authentication_providers, :waf_web_acl_arn) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The API name.
2578 2579 2580 2581 2582 2583 2584 2585 2586 2587 2588 2589 2590 2591 2592 2593 |
# File 'lib/aws-sdk-securityhub/types.rb', line 2578 class AwsAppSyncGraphQlApiDetails < Struct.new( :api_id, :id, :open_id_connect_config, :name, :lambda_authorizer_config, :xray_enabled, :arn, :user_pool_config, :authentication_type, :log_config, :additional_authentication_providers, :waf_web_acl_arn) SENSITIVE = [] include Aws::Structure end |
#open_id_connect_config ⇒ Types::AwsAppSyncGraphQlApiOpenIdConnectConfigDetails
Specifies the authorization configuration for using an OpenID Connect compliant service with an AppSync GraphQL API endpoint.
2578 2579 2580 2581 2582 2583 2584 2585 2586 2587 2588 2589 2590 2591 2592 2593 |
# File 'lib/aws-sdk-securityhub/types.rb', line 2578 class AwsAppSyncGraphQlApiDetails < Struct.new( :api_id, :id, :open_id_connect_config, :name, :lambda_authorizer_config, :xray_enabled, :arn, :user_pool_config, :authentication_type, :log_config, :additional_authentication_providers, :waf_web_acl_arn) SENSITIVE = [] include Aws::Structure end |
#user_pool_config ⇒ Types::AwsAppSyncGraphQlApiUserPoolConfigDetails
The Amazon Cognito user pools configuration.
2578 2579 2580 2581 2582 2583 2584 2585 2586 2587 2588 2589 2590 2591 2592 2593 |
# File 'lib/aws-sdk-securityhub/types.rb', line 2578 class AwsAppSyncGraphQlApiDetails < Struct.new( :api_id, :id, :open_id_connect_config, :name, :lambda_authorizer_config, :xray_enabled, :arn, :user_pool_config, :authentication_type, :log_config, :additional_authentication_providers, :waf_web_acl_arn) SENSITIVE = [] include Aws::Structure end |
#waf_web_acl_arn ⇒ String
The Amazon Resource Name (ARN) of the WAF web access control list (web ACL) associated with this GraphQL API, if one exists.
2578 2579 2580 2581 2582 2583 2584 2585 2586 2587 2588 2589 2590 2591 2592 2593 |
# File 'lib/aws-sdk-securityhub/types.rb', line 2578 class AwsAppSyncGraphQlApiDetails < Struct.new( :api_id, :id, :open_id_connect_config, :name, :lambda_authorizer_config, :xray_enabled, :arn, :user_pool_config, :authentication_type, :log_config, :additional_authentication_providers, :waf_web_acl_arn) SENSITIVE = [] include Aws::Structure end |
#xray_enabled ⇒ Boolean
Indicates whether to use X-Ray tracing for the GraphQL API.
2578 2579 2580 2581 2582 2583 2584 2585 2586 2587 2588 2589 2590 2591 2592 2593 |
# File 'lib/aws-sdk-securityhub/types.rb', line 2578 class AwsAppSyncGraphQlApiDetails < Struct.new( :api_id, :id, :open_id_connect_config, :name, :lambda_authorizer_config, :xray_enabled, :arn, :user_pool_config, :authentication_type, :log_config, :additional_authentication_providers, :waf_web_acl_arn) SENSITIVE = [] include Aws::Structure end |