Class: Aws::SecurityHub::Types::AwsAppSyncGraphQlApiOpenIdConnectConfigDetails

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

Specifies the authorization configuration for using an OpenID Connect compliant service with your AppSync GraphQL API endpoint.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#auth_tt_lInteger

The number of milliseconds that a token is valid after being authenticated.

Returns:

  • (Integer)


2651
2652
2653
2654
2655
2656
2657
2658
# File 'lib/aws-sdk-securityhub/types.rb', line 2651

class AwsAppSyncGraphQlApiOpenIdConnectConfigDetails < Struct.new(
  :auth_tt_l,
  :client_id,
  :iat_tt_l,
  :issuer)
  SENSITIVE = []
  include Aws::Structure
end

#client_idString

The client identifier of the relying party at the OpenID identity provider. This identifier is typically obtained when the relying party is registered with the OpenID identity provider. You can specify a regular expression so that AppSync can validate against multiple client identifiers at a time.

Returns:

  • (String)


2651
2652
2653
2654
2655
2656
2657
2658
# File 'lib/aws-sdk-securityhub/types.rb', line 2651

class AwsAppSyncGraphQlApiOpenIdConnectConfigDetails < Struct.new(
  :auth_tt_l,
  :client_id,
  :iat_tt_l,
  :issuer)
  SENSITIVE = []
  include Aws::Structure
end

#iat_tt_lInteger

The number of milliseconds that a token is valid after it's issued to a user.

Returns:

  • (Integer)


2651
2652
2653
2654
2655
2656
2657
2658
# File 'lib/aws-sdk-securityhub/types.rb', line 2651

class AwsAppSyncGraphQlApiOpenIdConnectConfigDetails < Struct.new(
  :auth_tt_l,
  :client_id,
  :iat_tt_l,
  :issuer)
  SENSITIVE = []
  include Aws::Structure
end

#issuerString

The issuer for the OIDC configuration. The issuer returned by discovery must exactly match the value of iss in the ID token.

Returns:

  • (String)


2651
2652
2653
2654
2655
2656
2657
2658
# File 'lib/aws-sdk-securityhub/types.rb', line 2651

class AwsAppSyncGraphQlApiOpenIdConnectConfigDetails < Struct.new(
  :auth_tt_l,
  :client_id,
  :iat_tt_l,
  :issuer)
  SENSITIVE = []
  include Aws::Structure
end