Class: Aws::SecurityHub::Types::AwsAthenaWorkGroupDetails

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

Provides information about an Amazon Athena workgroup.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#configurationTypes::AwsAthenaWorkGroupConfigurationDetails

The configuration of the workgroup, which includes the location in Amazon Simple Storage Service (Amazon S3) where query results are stored, the encryption option, if any, used for query results, whether Amazon CloudWatch metrics are enabled for the workgroup, and the limit for the amount of bytes scanned (cutoff) per query, if it is specified.



2785
2786
2787
2788
2789
2790
2791
2792
# File 'lib/aws-sdk-securityhub/types.rb', line 2785

class AwsAthenaWorkGroupDetails < Struct.new(
  :name,
  :description,
  :state,
  :configuration)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The workgroup description.

Returns:

  • (String)


2785
2786
2787
2788
2789
2790
2791
2792
# File 'lib/aws-sdk-securityhub/types.rb', line 2785

class AwsAthenaWorkGroupDetails < Struct.new(
  :name,
  :description,
  :state,
  :configuration)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The workgroup name.

Returns:

  • (String)


2785
2786
2787
2788
2789
2790
2791
2792
# File 'lib/aws-sdk-securityhub/types.rb', line 2785

class AwsAthenaWorkGroupDetails < Struct.new(
  :name,
  :description,
  :state,
  :configuration)
  SENSITIVE = []
  include Aws::Structure
end

#stateString

Whether the workgroup is enabled or disabled.

Returns:

  • (String)


2785
2786
2787
2788
2789
2790
2791
2792
# File 'lib/aws-sdk-securityhub/types.rb', line 2785

class AwsAthenaWorkGroupDetails < Struct.new(
  :name,
  :description,
  :state,
  :configuration)
  SENSITIVE = []
  include Aws::Structure
end