Class: Aws::SecurityHub::Types::AwsAthenaWorkGroupDetails

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

Provides information about an Amazon Athena workgroup.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#configurationTypes::AwsAthenaWorkGroupConfigurationDetails

The configuration of the workgroup, which includes the location in Amazon Simple Storage Service (Amazon S3) where query results are stored, the encryption option, if any, used for query results, whether Amazon CloudWatch metrics are enabled for the workgroup, and the limit for the amount of bytes scanned (cutoff) per query, if it is specified.



2684
2685
2686
2687
2688
2689
2690
2691
# File 'lib/aws-sdk-securityhub/types.rb', line 2684

class AwsAthenaWorkGroupDetails < Struct.new(
  :name,
  :description,
  :state,
  :configuration)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The workgroup description.

Returns:

  • (String)


2684
2685
2686
2687
2688
2689
2690
2691
# File 'lib/aws-sdk-securityhub/types.rb', line 2684

class AwsAthenaWorkGroupDetails < Struct.new(
  :name,
  :description,
  :state,
  :configuration)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The workgroup name.

Returns:

  • (String)


2684
2685
2686
2687
2688
2689
2690
2691
# File 'lib/aws-sdk-securityhub/types.rb', line 2684

class AwsAthenaWorkGroupDetails < Struct.new(
  :name,
  :description,
  :state,
  :configuration)
  SENSITIVE = []
  include Aws::Structure
end

#stateString

Whether the workgroup is enabled or disabled.

Returns:

  • (String)


2684
2685
2686
2687
2688
2689
2690
2691
# File 'lib/aws-sdk-securityhub/types.rb', line 2684

class AwsAthenaWorkGroupDetails < Struct.new(
  :name,
  :description,
  :state,
  :configuration)
  SENSITIVE = []
  include Aws::Structure
end