Method: Aws::SecurityHub::Types::AwsAthenaWorkGroupDetails#configuration
- Defined in:
- lib/aws-sdk-securityhub/types.rb
#configuration ⇒ Types::AwsAthenaWorkGroupConfigurationDetails
The configuration of the workgroup, which includes the location in Amazon Simple Storage Service (Amazon S3) where query results are stored, the encryption option, if any, used for query results, whether Amazon CloudWatch metrics are enabled for the workgroup, and the limit for the amount of bytes scanned (cutoff) per query, if it is specified.
2664 2665 2666 2667 2668 2669 2670 2671 |
# File 'lib/aws-sdk-securityhub/types.rb', line 2664 class AwsAthenaWorkGroupDetails < Struct.new( :name, :description, :state, :configuration) SENSITIVE = [] include Aws::Structure end |