Class: Aws::SecurityHub::Types::AwsAutoScalingLaunchConfigurationInstanceMonitoringDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::AwsAutoScalingLaunchConfigurationInstanceMonitoringDetails
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Information about the type of monitoring for instances in the group.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#enabled ⇒ Boolean
If set to
true, then instances in the group launch with detailed monitoring.
Instance Attribute Details
#enabled ⇒ Boolean
If set to true, then instances in the group launch with detailed
monitoring.
If set to false, then instances in the group launch with basic
monitoring.
3282 3283 3284 3285 3286 |
# File 'lib/aws-sdk-securityhub/types.rb', line 3282 class AwsAutoScalingLaunchConfigurationInstanceMonitoringDetails < Struct.new( :enabled) SENSITIVE = [] include Aws::Structure end |