Class: Aws::SecurityHub::Types::AwsCertificateManagerCertificateRenewalSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::AwsCertificateManagerCertificateRenewalSummary
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Contains information about the Certificate Manager managed renewal for
an AMAZON_ISSUED certificate.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#domain_validation_options ⇒ Array<Types::AwsCertificateManagerCertificateDomainValidationOption>
Information about the validation of each domain name in the certificate, as it pertains to Certificate Manager managed renewal.
-
#renewal_status ⇒ String
The status of the Certificate Manager managed renewal of the certificate.
-
#renewal_status_reason ⇒ String
The reason that a renewal request was unsuccessful.
-
#updated_at ⇒ String
Indicates when the renewal summary was last updated.
Instance Attribute Details
#domain_validation_options ⇒ Array<Types::AwsCertificateManagerCertificateDomainValidationOption>
Information about the validation of each domain name in the
certificate, as it pertains to Certificate Manager managed renewal.
Provided only when the certificate type is AMAZON_ISSUED.
4079 4080 4081 4082 4083 4084 4085 4086 |
# File 'lib/aws-sdk-securityhub/types.rb', line 4079 class AwsCertificateManagerCertificateRenewalSummary < Struct.new( :domain_validation_options, :renewal_status, :renewal_status_reason, :updated_at) SENSITIVE = [] include Aws::Structure end |
#renewal_status ⇒ String
The status of the Certificate Manager managed renewal of the certificate.
Valid values: PENDING_AUTO_RENEWAL | PENDING_VALIDATION |
SUCCESS | FAILED
4079 4080 4081 4082 4083 4084 4085 4086 |
# File 'lib/aws-sdk-securityhub/types.rb', line 4079 class AwsCertificateManagerCertificateRenewalSummary < Struct.new( :domain_validation_options, :renewal_status, :renewal_status_reason, :updated_at) SENSITIVE = [] include Aws::Structure end |
#renewal_status_reason ⇒ String
The reason that a renewal request was unsuccessful. This attribute
is used only when RenewalStatus is FAILED.
Valid values: NO_AVAILABLE_CONTACTS |
ADDITIONAL_VERIFICATION_REQUIRED | DOMAIN_NOT_ALLOWED |
INVALID_PUBLIC_DOMAIN | DOMAIN_VALIDATION_DENIED | CAA_ERROR
| PCA_LIMIT_EXCEEDED | PCA_INVALID_ARN | PCA_INVALID_STATE
| PCA_REQUEST_FAILED | PCA_NAME_CONSTRAINTS_VALIDATION |
PCA_RESOURCE_NOT_FOUND | PCA_INVALID_ARGS |
PCA_INVALID_DURATION | PCA_ACCESS_DENIED | SLR_NOT_FOUND |
OTHER
4079 4080 4081 4082 4083 4084 4085 4086 |
# File 'lib/aws-sdk-securityhub/types.rb', line 4079 class AwsCertificateManagerCertificateRenewalSummary < Struct.new( :domain_validation_options, :renewal_status, :renewal_status_reason, :updated_at) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ String
Indicates when the renewal summary was last updated.
For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.
4079 4080 4081 4082 4083 4084 4085 4086 |
# File 'lib/aws-sdk-securityhub/types.rb', line 4079 class AwsCertificateManagerCertificateRenewalSummary < Struct.new( :domain_validation_options, :renewal_status, :renewal_status_reason, :updated_at) SENSITIVE = [] include Aws::Structure end |