Class: Aws::SecurityHub::Types::AwsCloudFrontDistributionDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::AwsCloudFrontDistributionDetails
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
A CloudFront distribution configuration.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cache_behaviors ⇒ Types::AwsCloudFrontDistributionCacheBehaviors
Provides information about the cache configuration for the distribution.
-
#default_cache_behavior ⇒ Types::AwsCloudFrontDistributionDefaultCacheBehavior
The default cache behavior for the configuration.
-
#default_root_object ⇒ String
The object that CloudFront sends in response to requests from the origin (for example, index.html) when a viewer requests the root URL for the distribution (http://www.example.com) instead of an object in your distribution (http://www.example.com/product-description.html).
-
#domain_name ⇒ String
The domain name corresponding to the distribution.
-
#etag ⇒ String
The entity tag is a hash of the object.
-
#last_modified_time ⇒ String
Indicates when that the distribution was last modified.
-
#logging ⇒ Types::AwsCloudFrontDistributionLogging
A complex type that controls whether access logs are written for the distribution.
-
#origin_groups ⇒ Types::AwsCloudFrontDistributionOriginGroups
Provides information about the origin groups in the distribution.
-
#origins ⇒ Types::AwsCloudFrontDistributionOrigins
A complex type that contains information about origins for this distribution.
-
#status ⇒ String
Indicates the current status of the distribution.
-
#viewer_certificate ⇒ Types::AwsCloudFrontDistributionViewerCertificate
Provides information about the TLS/SSL configuration that the distribution uses to communicate with viewers.
-
#web_acl_id ⇒ String
A unique identifier that specifies the WAF web ACL, if any, to associate with this distribution.
Instance Attribute Details
#cache_behaviors ⇒ Types::AwsCloudFrontDistributionCacheBehaviors
Provides information about the cache configuration for the distribution.
4475 4476 4477 4478 4479 4480 4481 4482 4483 4484 4485 4486 4487 4488 4489 4490 |
# File 'lib/aws-sdk-securityhub/types.rb', line 4475 class AwsCloudFrontDistributionDetails < Struct.new( :cache_behaviors, :default_cache_behavior, :default_root_object, :domain_name, :etag, :last_modified_time, :logging, :origins, :origin_groups, :viewer_certificate, :status, :web_acl_id) SENSITIVE = [] include Aws::Structure end |
#default_cache_behavior ⇒ Types::AwsCloudFrontDistributionDefaultCacheBehavior
The default cache behavior for the configuration.
4475 4476 4477 4478 4479 4480 4481 4482 4483 4484 4485 4486 4487 4488 4489 4490 |
# File 'lib/aws-sdk-securityhub/types.rb', line 4475 class AwsCloudFrontDistributionDetails < Struct.new( :cache_behaviors, :default_cache_behavior, :default_root_object, :domain_name, :etag, :last_modified_time, :logging, :origins, :origin_groups, :viewer_certificate, :status, :web_acl_id) SENSITIVE = [] include Aws::Structure end |
#default_root_object ⇒ String
The object that CloudFront sends in response to requests from the origin (for example, index.html) when a viewer requests the root URL for the distribution (http://www.example.com) instead of an object in your distribution (http://www.example.com/product-description.html).
4475 4476 4477 4478 4479 4480 4481 4482 4483 4484 4485 4486 4487 4488 4489 4490 |
# File 'lib/aws-sdk-securityhub/types.rb', line 4475 class AwsCloudFrontDistributionDetails < Struct.new( :cache_behaviors, :default_cache_behavior, :default_root_object, :domain_name, :etag, :last_modified_time, :logging, :origins, :origin_groups, :viewer_certificate, :status, :web_acl_id) SENSITIVE = [] include Aws::Structure end |
#domain_name ⇒ String
The domain name corresponding to the distribution.
4475 4476 4477 4478 4479 4480 4481 4482 4483 4484 4485 4486 4487 4488 4489 4490 |
# File 'lib/aws-sdk-securityhub/types.rb', line 4475 class AwsCloudFrontDistributionDetails < Struct.new( :cache_behaviors, :default_cache_behavior, :default_root_object, :domain_name, :etag, :last_modified_time, :logging, :origins, :origin_groups, :viewer_certificate, :status, :web_acl_id) SENSITIVE = [] include Aws::Structure end |
#etag ⇒ String
The entity tag is a hash of the object.
4475 4476 4477 4478 4479 4480 4481 4482 4483 4484 4485 4486 4487 4488 4489 4490 |
# File 'lib/aws-sdk-securityhub/types.rb', line 4475 class AwsCloudFrontDistributionDetails < Struct.new( :cache_behaviors, :default_cache_behavior, :default_root_object, :domain_name, :etag, :last_modified_time, :logging, :origins, :origin_groups, :viewer_certificate, :status, :web_acl_id) SENSITIVE = [] include Aws::Structure end |
#last_modified_time ⇒ String
Indicates when that the distribution was last modified.
For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.
4475 4476 4477 4478 4479 4480 4481 4482 4483 4484 4485 4486 4487 4488 4489 4490 |
# File 'lib/aws-sdk-securityhub/types.rb', line 4475 class AwsCloudFrontDistributionDetails < Struct.new( :cache_behaviors, :default_cache_behavior, :default_root_object, :domain_name, :etag, :last_modified_time, :logging, :origins, :origin_groups, :viewer_certificate, :status, :web_acl_id) SENSITIVE = [] include Aws::Structure end |
#logging ⇒ Types::AwsCloudFrontDistributionLogging
A complex type that controls whether access logs are written for the distribution.
4475 4476 4477 4478 4479 4480 4481 4482 4483 4484 4485 4486 4487 4488 4489 4490 |
# File 'lib/aws-sdk-securityhub/types.rb', line 4475 class AwsCloudFrontDistributionDetails < Struct.new( :cache_behaviors, :default_cache_behavior, :default_root_object, :domain_name, :etag, :last_modified_time, :logging, :origins, :origin_groups, :viewer_certificate, :status, :web_acl_id) SENSITIVE = [] include Aws::Structure end |
#origin_groups ⇒ Types::AwsCloudFrontDistributionOriginGroups
Provides information about the origin groups in the distribution.
4475 4476 4477 4478 4479 4480 4481 4482 4483 4484 4485 4486 4487 4488 4489 4490 |
# File 'lib/aws-sdk-securityhub/types.rb', line 4475 class AwsCloudFrontDistributionDetails < Struct.new( :cache_behaviors, :default_cache_behavior, :default_root_object, :domain_name, :etag, :last_modified_time, :logging, :origins, :origin_groups, :viewer_certificate, :status, :web_acl_id) SENSITIVE = [] include Aws::Structure end |
#origins ⇒ Types::AwsCloudFrontDistributionOrigins
A complex type that contains information about origins for this distribution.
4475 4476 4477 4478 4479 4480 4481 4482 4483 4484 4485 4486 4487 4488 4489 4490 |
# File 'lib/aws-sdk-securityhub/types.rb', line 4475 class AwsCloudFrontDistributionDetails < Struct.new( :cache_behaviors, :default_cache_behavior, :default_root_object, :domain_name, :etag, :last_modified_time, :logging, :origins, :origin_groups, :viewer_certificate, :status, :web_acl_id) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
Indicates the current status of the distribution.
4475 4476 4477 4478 4479 4480 4481 4482 4483 4484 4485 4486 4487 4488 4489 4490 |
# File 'lib/aws-sdk-securityhub/types.rb', line 4475 class AwsCloudFrontDistributionDetails < Struct.new( :cache_behaviors, :default_cache_behavior, :default_root_object, :domain_name, :etag, :last_modified_time, :logging, :origins, :origin_groups, :viewer_certificate, :status, :web_acl_id) SENSITIVE = [] include Aws::Structure end |
#viewer_certificate ⇒ Types::AwsCloudFrontDistributionViewerCertificate
Provides information about the TLS/SSL configuration that the distribution uses to communicate with viewers.
4475 4476 4477 4478 4479 4480 4481 4482 4483 4484 4485 4486 4487 4488 4489 4490 |
# File 'lib/aws-sdk-securityhub/types.rb', line 4475 class AwsCloudFrontDistributionDetails < Struct.new( :cache_behaviors, :default_cache_behavior, :default_root_object, :domain_name, :etag, :last_modified_time, :logging, :origins, :origin_groups, :viewer_certificate, :status, :web_acl_id) SENSITIVE = [] include Aws::Structure end |
#web_acl_id ⇒ String
A unique identifier that specifies the WAF web ACL, if any, to associate with this distribution.
4475 4476 4477 4478 4479 4480 4481 4482 4483 4484 4485 4486 4487 4488 4489 4490 |
# File 'lib/aws-sdk-securityhub/types.rb', line 4475 class AwsCloudFrontDistributionDetails < Struct.new( :cache_behaviors, :default_cache_behavior, :default_root_object, :domain_name, :etag, :last_modified_time, :logging, :origins, :origin_groups, :viewer_certificate, :status, :web_acl_id) SENSITIVE = [] include Aws::Structure end |