Class: Aws::SecurityHub::Types::AwsCodeBuildProjectDetails

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

Information about an CodeBuild project.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#artifactsArray<Types::AwsCodeBuildProjectArtifactsDetails>

Information about the build artifacts for the CodeBuild project.



5160
5161
5162
5163
5164
5165
5166
5167
5168
5169
5170
5171
5172
# File 'lib/aws-sdk-securityhub/types.rb', line 5160

class AwsCodeBuildProjectDetails < Struct.new(
  :encryption_key,
  :artifacts,
  :environment,
  :name,
  :source,
  :service_role,
  :logs_config,
  :vpc_config,
  :secondary_artifacts)
  SENSITIVE = []
  include Aws::Structure
end

#encryption_keyString

The KMS key used to encrypt the build output artifacts.

You can specify either the ARN of the KMS key or, if available, the KMS key alias (using the format alias/alias-name).

Returns:

  • (String)


5160
5161
5162
5163
5164
5165
5166
5167
5168
5169
5170
5171
5172
# File 'lib/aws-sdk-securityhub/types.rb', line 5160

class AwsCodeBuildProjectDetails < Struct.new(
  :encryption_key,
  :artifacts,
  :environment,
  :name,
  :source,
  :service_role,
  :logs_config,
  :vpc_config,
  :secondary_artifacts)
  SENSITIVE = []
  include Aws::Structure
end

#environmentTypes::AwsCodeBuildProjectEnvironment

Information about the build environment for this build project.



5160
5161
5162
5163
5164
5165
5166
5167
5168
5169
5170
5171
5172
# File 'lib/aws-sdk-securityhub/types.rb', line 5160

class AwsCodeBuildProjectDetails < Struct.new(
  :encryption_key,
  :artifacts,
  :environment,
  :name,
  :source,
  :service_role,
  :logs_config,
  :vpc_config,
  :secondary_artifacts)
  SENSITIVE = []
  include Aws::Structure
end

#logs_configTypes::AwsCodeBuildProjectLogsConfigDetails

Information about logs for the build project.



5160
5161
5162
5163
5164
5165
5166
5167
5168
5169
5170
5171
5172
# File 'lib/aws-sdk-securityhub/types.rb', line 5160

class AwsCodeBuildProjectDetails < Struct.new(
  :encryption_key,
  :artifacts,
  :environment,
  :name,
  :source,
  :service_role,
  :logs_config,
  :vpc_config,
  :secondary_artifacts)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the build project.

Returns:

  • (String)


5160
5161
5162
5163
5164
5165
5166
5167
5168
5169
5170
5171
5172
# File 'lib/aws-sdk-securityhub/types.rb', line 5160

class AwsCodeBuildProjectDetails < Struct.new(
  :encryption_key,
  :artifacts,
  :environment,
  :name,
  :source,
  :service_role,
  :logs_config,
  :vpc_config,
  :secondary_artifacts)
  SENSITIVE = []
  include Aws::Structure
end

#secondary_artifactsArray<Types::AwsCodeBuildProjectArtifactsDetails>

Information about the secondary artifacts for the CodeBuild project.



5160
5161
5162
5163
5164
5165
5166
5167
5168
5169
5170
5171
5172
# File 'lib/aws-sdk-securityhub/types.rb', line 5160

class AwsCodeBuildProjectDetails < Struct.new(
  :encryption_key,
  :artifacts,
  :environment,
  :name,
  :source,
  :service_role,
  :logs_config,
  :vpc_config,
  :secondary_artifacts)
  SENSITIVE = []
  include Aws::Structure
end

#service_roleString

The ARN of the IAM role that enables CodeBuild to interact with dependent Amazon Web Services services on behalf of the Amazon Web Services account.

Returns:

  • (String)


5160
5161
5162
5163
5164
5165
5166
5167
5168
5169
5170
5171
5172
# File 'lib/aws-sdk-securityhub/types.rb', line 5160

class AwsCodeBuildProjectDetails < Struct.new(
  :encryption_key,
  :artifacts,
  :environment,
  :name,
  :source,
  :service_role,
  :logs_config,
  :vpc_config,
  :secondary_artifacts)
  SENSITIVE = []
  include Aws::Structure
end

#sourceTypes::AwsCodeBuildProjectSource

Information about the build input source code for this build project.



5160
5161
5162
5163
5164
5165
5166
5167
5168
5169
5170
5171
5172
# File 'lib/aws-sdk-securityhub/types.rb', line 5160

class AwsCodeBuildProjectDetails < Struct.new(
  :encryption_key,
  :artifacts,
  :environment,
  :name,
  :source,
  :service_role,
  :logs_config,
  :vpc_config,
  :secondary_artifacts)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_configTypes::AwsCodeBuildProjectVpcConfig

Information about the VPC configuration that CodeBuild accesses.



5160
5161
5162
5163
5164
5165
5166
5167
5168
5169
5170
5171
5172
# File 'lib/aws-sdk-securityhub/types.rb', line 5160

class AwsCodeBuildProjectDetails < Struct.new(
  :encryption_key,
  :artifacts,
  :environment,
  :name,
  :source,
  :service_role,
  :logs_config,
  :vpc_config,
  :secondary_artifacts)
  SENSITIVE = []
  include Aws::Structure
end