Class: Aws::SecurityHub::Types::AwsCodeBuildProjectDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::AwsCodeBuildProjectDetails
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Information about an CodeBuild project.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#artifacts ⇒ Array<Types::AwsCodeBuildProjectArtifactsDetails>
Information about the build artifacts for the CodeBuild project.
-
#encryption_key ⇒ String
The KMS key used to encrypt the build output artifacts.
-
#environment ⇒ Types::AwsCodeBuildProjectEnvironment
Information about the build environment for this build project.
-
#logs_config ⇒ Types::AwsCodeBuildProjectLogsConfigDetails
Information about logs for the build project.
-
#name ⇒ String
The name of the build project.
-
#secondary_artifacts ⇒ Array<Types::AwsCodeBuildProjectArtifactsDetails>
Information about the secondary artifacts for the CodeBuild project.
-
#service_role ⇒ String
The ARN of the IAM role that enables CodeBuild to interact with dependent Amazon Web Services services on behalf of the Amazon Web Services account.
-
#source ⇒ Types::AwsCodeBuildProjectSource
Information about the build input source code for this build project.
-
#vpc_config ⇒ Types::AwsCodeBuildProjectVpcConfig
Information about the VPC configuration that CodeBuild accesses.
Instance Attribute Details
#artifacts ⇒ Array<Types::AwsCodeBuildProjectArtifactsDetails>
Information about the build artifacts for the CodeBuild project.
3423 3424 3425 3426 3427 3428 3429 3430 3431 3432 3433 3434 3435 |
# File 'lib/aws-sdk-securityhub/types.rb', line 3423 class AwsCodeBuildProjectDetails < Struct.new( :encryption_key, :artifacts, :environment, :name, :source, :service_role, :logs_config, :vpc_config, :secondary_artifacts) SENSITIVE = [] include Aws::Structure end |
#encryption_key ⇒ String
The KMS key used to encrypt the build output artifacts.
You can specify either the ARN of the KMS key or, if available, the KMS key alias (using the format alias/alias-name).
3423 3424 3425 3426 3427 3428 3429 3430 3431 3432 3433 3434 3435 |
# File 'lib/aws-sdk-securityhub/types.rb', line 3423 class AwsCodeBuildProjectDetails < Struct.new( :encryption_key, :artifacts, :environment, :name, :source, :service_role, :logs_config, :vpc_config, :secondary_artifacts) SENSITIVE = [] include Aws::Structure end |
#environment ⇒ Types::AwsCodeBuildProjectEnvironment
Information about the build environment for this build project.
3423 3424 3425 3426 3427 3428 3429 3430 3431 3432 3433 3434 3435 |
# File 'lib/aws-sdk-securityhub/types.rb', line 3423 class AwsCodeBuildProjectDetails < Struct.new( :encryption_key, :artifacts, :environment, :name, :source, :service_role, :logs_config, :vpc_config, :secondary_artifacts) SENSITIVE = [] include Aws::Structure end |
#logs_config ⇒ Types::AwsCodeBuildProjectLogsConfigDetails
Information about logs for the build project.
3423 3424 3425 3426 3427 3428 3429 3430 3431 3432 3433 3434 3435 |
# File 'lib/aws-sdk-securityhub/types.rb', line 3423 class AwsCodeBuildProjectDetails < Struct.new( :encryption_key, :artifacts, :environment, :name, :source, :service_role, :logs_config, :vpc_config, :secondary_artifacts) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the build project.
3423 3424 3425 3426 3427 3428 3429 3430 3431 3432 3433 3434 3435 |
# File 'lib/aws-sdk-securityhub/types.rb', line 3423 class AwsCodeBuildProjectDetails < Struct.new( :encryption_key, :artifacts, :environment, :name, :source, :service_role, :logs_config, :vpc_config, :secondary_artifacts) SENSITIVE = [] include Aws::Structure end |
#secondary_artifacts ⇒ Array<Types::AwsCodeBuildProjectArtifactsDetails>
Information about the secondary artifacts for the CodeBuild project.
3423 3424 3425 3426 3427 3428 3429 3430 3431 3432 3433 3434 3435 |
# File 'lib/aws-sdk-securityhub/types.rb', line 3423 class AwsCodeBuildProjectDetails < Struct.new( :encryption_key, :artifacts, :environment, :name, :source, :service_role, :logs_config, :vpc_config, :secondary_artifacts) SENSITIVE = [] include Aws::Structure end |
#service_role ⇒ String
The ARN of the IAM role that enables CodeBuild to interact with dependent Amazon Web Services services on behalf of the Amazon Web Services account.
3423 3424 3425 3426 3427 3428 3429 3430 3431 3432 3433 3434 3435 |
# File 'lib/aws-sdk-securityhub/types.rb', line 3423 class AwsCodeBuildProjectDetails < Struct.new( :encryption_key, :artifacts, :environment, :name, :source, :service_role, :logs_config, :vpc_config, :secondary_artifacts) SENSITIVE = [] include Aws::Structure end |
#source ⇒ Types::AwsCodeBuildProjectSource
Information about the build input source code for this build project.
3423 3424 3425 3426 3427 3428 3429 3430 3431 3432 3433 3434 3435 |
# File 'lib/aws-sdk-securityhub/types.rb', line 3423 class AwsCodeBuildProjectDetails < Struct.new( :encryption_key, :artifacts, :environment, :name, :source, :service_role, :logs_config, :vpc_config, :secondary_artifacts) SENSITIVE = [] include Aws::Structure end |
#vpc_config ⇒ Types::AwsCodeBuildProjectVpcConfig
Information about the VPC configuration that CodeBuild accesses.
3423 3424 3425 3426 3427 3428 3429 3430 3431 3432 3433 3434 3435 |
# File 'lib/aws-sdk-securityhub/types.rb', line 3423 class AwsCodeBuildProjectDetails < Struct.new( :encryption_key, :artifacts, :environment, :name, :source, :service_role, :logs_config, :vpc_config, :secondary_artifacts) SENSITIVE = [] include Aws::Structure end |