Class: Aws::SecurityHub::Types::AwsCodeBuildProjectEnvironmentRegistryCredential

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

The credentials for access to a private registry.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#credentialString

The ARN or name of credentials created using Secrets Manager.

The credential can use the name of the credentials only if they exist in your current Amazon Web Services Region.

Returns:

  • (String)


5296
5297
5298
5299
5300
5301
# File 'lib/aws-sdk-securityhub/types.rb', line 5296

class AwsCodeBuildProjectEnvironmentRegistryCredential < Struct.new(
  :credential,
  :credential_provider)
  SENSITIVE = []
  include Aws::Structure
end

#credential_providerString

The service that created the credentials to access a private Docker registry.

The valid value, SECRETS_MANAGER, is for Secrets Manager.

Returns:

  • (String)


5296
5297
5298
5299
5300
5301
# File 'lib/aws-sdk-securityhub/types.rb', line 5296

class AwsCodeBuildProjectEnvironmentRegistryCredential < Struct.new(
  :credential,
  :credential_provider)
  SENSITIVE = []
  include Aws::Structure
end