Class: Aws::SecurityHub::Types::AwsDynamoDbTableDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::AwsDynamoDbTableDetails
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Provides details about a DynamoDB table.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attribute_definitions ⇒ Array<Types::AwsDynamoDbTableAttributeDefinition>
A list of attribute definitions for the table.
-
#billing_mode_summary ⇒ Types::AwsDynamoDbTableBillingModeSummary
Information about the billing for read/write capacity on the table.
-
#creation_date_time ⇒ String
Indicates when the table was created.
-
#deletion_protection_enabled ⇒ Boolean
Indicates whether deletion protection is to be enabled (true) or disabled (false) on the table.
-
#global_secondary_indexes ⇒ Array<Types::AwsDynamoDbTableGlobalSecondaryIndex>
List of global secondary indexes for the table.
-
#global_table_version ⇒ String
The version of global tables being used.
-
#item_count ⇒ Integer
The number of items in the table.
-
#key_schema ⇒ Array<Types::AwsDynamoDbTableKeySchema>
The primary key structure for the table.
-
#latest_stream_arn ⇒ String
The ARN of the latest stream for the table.
-
#latest_stream_label ⇒ String
The label of the latest stream.
-
#local_secondary_indexes ⇒ Array<Types::AwsDynamoDbTableLocalSecondaryIndex>
The list of local secondary indexes for the table.
-
#provisioned_throughput ⇒ Types::AwsDynamoDbTableProvisionedThroughput
Information about the provisioned throughput for the table.
-
#replicas ⇒ Array<Types::AwsDynamoDbTableReplica>
The list of replicas of this table.
-
#restore_summary ⇒ Types::AwsDynamoDbTableRestoreSummary
Information about the restore for the table.
-
#sse_description ⇒ Types::AwsDynamoDbTableSseDescription
Information about the server-side encryption for the table.
-
#stream_specification ⇒ Types::AwsDynamoDbTableStreamSpecification
The current DynamoDB Streams configuration for the table.
-
#table_id ⇒ String
The identifier of the table.
-
#table_name ⇒ String
The name of the table.
-
#table_size_bytes ⇒ Integer
The total size of the table in bytes.
-
#table_status ⇒ String
The current status of the table.
Instance Attribute Details
#attribute_definitions ⇒ Array<Types::AwsDynamoDbTableAttributeDefinition>
A list of attribute definitions for the table.
5985 5986 5987 5988 5989 5990 5991 5992 5993 5994 5995 5996 5997 5998 5999 6000 6001 6002 6003 6004 6005 6006 6007 6008 |
# File 'lib/aws-sdk-securityhub/types.rb', line 5985 class AwsDynamoDbTableDetails < Struct.new( :attribute_definitions, :billing_mode_summary, :creation_date_time, :global_secondary_indexes, :global_table_version, :item_count, :key_schema, :latest_stream_arn, :latest_stream_label, :local_secondary_indexes, :provisioned_throughput, :replicas, :restore_summary, :sse_description, :stream_specification, :table_id, :table_name, :table_size_bytes, :table_status, :deletion_protection_enabled) SENSITIVE = [] include Aws::Structure end |
#billing_mode_summary ⇒ Types::AwsDynamoDbTableBillingModeSummary
Information about the billing for read/write capacity on the table.
5985 5986 5987 5988 5989 5990 5991 5992 5993 5994 5995 5996 5997 5998 5999 6000 6001 6002 6003 6004 6005 6006 6007 6008 |
# File 'lib/aws-sdk-securityhub/types.rb', line 5985 class AwsDynamoDbTableDetails < Struct.new( :attribute_definitions, :billing_mode_summary, :creation_date_time, :global_secondary_indexes, :global_table_version, :item_count, :key_schema, :latest_stream_arn, :latest_stream_label, :local_secondary_indexes, :provisioned_throughput, :replicas, :restore_summary, :sse_description, :stream_specification, :table_id, :table_name, :table_size_bytes, :table_status, :deletion_protection_enabled) SENSITIVE = [] include Aws::Structure end |
#creation_date_time ⇒ String
Indicates when the table was created.
For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.
5985 5986 5987 5988 5989 5990 5991 5992 5993 5994 5995 5996 5997 5998 5999 6000 6001 6002 6003 6004 6005 6006 6007 6008 |
# File 'lib/aws-sdk-securityhub/types.rb', line 5985 class AwsDynamoDbTableDetails < Struct.new( :attribute_definitions, :billing_mode_summary, :creation_date_time, :global_secondary_indexes, :global_table_version, :item_count, :key_schema, :latest_stream_arn, :latest_stream_label, :local_secondary_indexes, :provisioned_throughput, :replicas, :restore_summary, :sse_description, :stream_specification, :table_id, :table_name, :table_size_bytes, :table_status, :deletion_protection_enabled) SENSITIVE = [] include Aws::Structure end |
#deletion_protection_enabled ⇒ Boolean
Indicates whether deletion protection is to be enabled (true) or disabled (false) on the table.
5985 5986 5987 5988 5989 5990 5991 5992 5993 5994 5995 5996 5997 5998 5999 6000 6001 6002 6003 6004 6005 6006 6007 6008 |
# File 'lib/aws-sdk-securityhub/types.rb', line 5985 class AwsDynamoDbTableDetails < Struct.new( :attribute_definitions, :billing_mode_summary, :creation_date_time, :global_secondary_indexes, :global_table_version, :item_count, :key_schema, :latest_stream_arn, :latest_stream_label, :local_secondary_indexes, :provisioned_throughput, :replicas, :restore_summary, :sse_description, :stream_specification, :table_id, :table_name, :table_size_bytes, :table_status, :deletion_protection_enabled) SENSITIVE = [] include Aws::Structure end |
#global_secondary_indexes ⇒ Array<Types::AwsDynamoDbTableGlobalSecondaryIndex>
List of global secondary indexes for the table.
5985 5986 5987 5988 5989 5990 5991 5992 5993 5994 5995 5996 5997 5998 5999 6000 6001 6002 6003 6004 6005 6006 6007 6008 |
# File 'lib/aws-sdk-securityhub/types.rb', line 5985 class AwsDynamoDbTableDetails < Struct.new( :attribute_definitions, :billing_mode_summary, :creation_date_time, :global_secondary_indexes, :global_table_version, :item_count, :key_schema, :latest_stream_arn, :latest_stream_label, :local_secondary_indexes, :provisioned_throughput, :replicas, :restore_summary, :sse_description, :stream_specification, :table_id, :table_name, :table_size_bytes, :table_status, :deletion_protection_enabled) SENSITIVE = [] include Aws::Structure end |
#global_table_version ⇒ String
The version of global tables being used.
5985 5986 5987 5988 5989 5990 5991 5992 5993 5994 5995 5996 5997 5998 5999 6000 6001 6002 6003 6004 6005 6006 6007 6008 |
# File 'lib/aws-sdk-securityhub/types.rb', line 5985 class AwsDynamoDbTableDetails < Struct.new( :attribute_definitions, :billing_mode_summary, :creation_date_time, :global_secondary_indexes, :global_table_version, :item_count, :key_schema, :latest_stream_arn, :latest_stream_label, :local_secondary_indexes, :provisioned_throughput, :replicas, :restore_summary, :sse_description, :stream_specification, :table_id, :table_name, :table_size_bytes, :table_status, :deletion_protection_enabled) SENSITIVE = [] include Aws::Structure end |
#item_count ⇒ Integer
The number of items in the table.
5985 5986 5987 5988 5989 5990 5991 5992 5993 5994 5995 5996 5997 5998 5999 6000 6001 6002 6003 6004 6005 6006 6007 6008 |
# File 'lib/aws-sdk-securityhub/types.rb', line 5985 class AwsDynamoDbTableDetails < Struct.new( :attribute_definitions, :billing_mode_summary, :creation_date_time, :global_secondary_indexes, :global_table_version, :item_count, :key_schema, :latest_stream_arn, :latest_stream_label, :local_secondary_indexes, :provisioned_throughput, :replicas, :restore_summary, :sse_description, :stream_specification, :table_id, :table_name, :table_size_bytes, :table_status, :deletion_protection_enabled) SENSITIVE = [] include Aws::Structure end |
#key_schema ⇒ Array<Types::AwsDynamoDbTableKeySchema>
The primary key structure for the table.
5985 5986 5987 5988 5989 5990 5991 5992 5993 5994 5995 5996 5997 5998 5999 6000 6001 6002 6003 6004 6005 6006 6007 6008 |
# File 'lib/aws-sdk-securityhub/types.rb', line 5985 class AwsDynamoDbTableDetails < Struct.new( :attribute_definitions, :billing_mode_summary, :creation_date_time, :global_secondary_indexes, :global_table_version, :item_count, :key_schema, :latest_stream_arn, :latest_stream_label, :local_secondary_indexes, :provisioned_throughput, :replicas, :restore_summary, :sse_description, :stream_specification, :table_id, :table_name, :table_size_bytes, :table_status, :deletion_protection_enabled) SENSITIVE = [] include Aws::Structure end |
#latest_stream_arn ⇒ String
The ARN of the latest stream for the table.
5985 5986 5987 5988 5989 5990 5991 5992 5993 5994 5995 5996 5997 5998 5999 6000 6001 6002 6003 6004 6005 6006 6007 6008 |
# File 'lib/aws-sdk-securityhub/types.rb', line 5985 class AwsDynamoDbTableDetails < Struct.new( :attribute_definitions, :billing_mode_summary, :creation_date_time, :global_secondary_indexes, :global_table_version, :item_count, :key_schema, :latest_stream_arn, :latest_stream_label, :local_secondary_indexes, :provisioned_throughput, :replicas, :restore_summary, :sse_description, :stream_specification, :table_id, :table_name, :table_size_bytes, :table_status, :deletion_protection_enabled) SENSITIVE = [] include Aws::Structure end |
#latest_stream_label ⇒ String
The label of the latest stream. The label is not a unique identifier.
5985 5986 5987 5988 5989 5990 5991 5992 5993 5994 5995 5996 5997 5998 5999 6000 6001 6002 6003 6004 6005 6006 6007 6008 |
# File 'lib/aws-sdk-securityhub/types.rb', line 5985 class AwsDynamoDbTableDetails < Struct.new( :attribute_definitions, :billing_mode_summary, :creation_date_time, :global_secondary_indexes, :global_table_version, :item_count, :key_schema, :latest_stream_arn, :latest_stream_label, :local_secondary_indexes, :provisioned_throughput, :replicas, :restore_summary, :sse_description, :stream_specification, :table_id, :table_name, :table_size_bytes, :table_status, :deletion_protection_enabled) SENSITIVE = [] include Aws::Structure end |
#local_secondary_indexes ⇒ Array<Types::AwsDynamoDbTableLocalSecondaryIndex>
The list of local secondary indexes for the table.
5985 5986 5987 5988 5989 5990 5991 5992 5993 5994 5995 5996 5997 5998 5999 6000 6001 6002 6003 6004 6005 6006 6007 6008 |
# File 'lib/aws-sdk-securityhub/types.rb', line 5985 class AwsDynamoDbTableDetails < Struct.new( :attribute_definitions, :billing_mode_summary, :creation_date_time, :global_secondary_indexes, :global_table_version, :item_count, :key_schema, :latest_stream_arn, :latest_stream_label, :local_secondary_indexes, :provisioned_throughput, :replicas, :restore_summary, :sse_description, :stream_specification, :table_id, :table_name, :table_size_bytes, :table_status, :deletion_protection_enabled) SENSITIVE = [] include Aws::Structure end |
#provisioned_throughput ⇒ Types::AwsDynamoDbTableProvisionedThroughput
Information about the provisioned throughput for the table.
5985 5986 5987 5988 5989 5990 5991 5992 5993 5994 5995 5996 5997 5998 5999 6000 6001 6002 6003 6004 6005 6006 6007 6008 |
# File 'lib/aws-sdk-securityhub/types.rb', line 5985 class AwsDynamoDbTableDetails < Struct.new( :attribute_definitions, :billing_mode_summary, :creation_date_time, :global_secondary_indexes, :global_table_version, :item_count, :key_schema, :latest_stream_arn, :latest_stream_label, :local_secondary_indexes, :provisioned_throughput, :replicas, :restore_summary, :sse_description, :stream_specification, :table_id, :table_name, :table_size_bytes, :table_status, :deletion_protection_enabled) SENSITIVE = [] include Aws::Structure end |
#replicas ⇒ Array<Types::AwsDynamoDbTableReplica>
The list of replicas of this table.
5985 5986 5987 5988 5989 5990 5991 5992 5993 5994 5995 5996 5997 5998 5999 6000 6001 6002 6003 6004 6005 6006 6007 6008 |
# File 'lib/aws-sdk-securityhub/types.rb', line 5985 class AwsDynamoDbTableDetails < Struct.new( :attribute_definitions, :billing_mode_summary, :creation_date_time, :global_secondary_indexes, :global_table_version, :item_count, :key_schema, :latest_stream_arn, :latest_stream_label, :local_secondary_indexes, :provisioned_throughput, :replicas, :restore_summary, :sse_description, :stream_specification, :table_id, :table_name, :table_size_bytes, :table_status, :deletion_protection_enabled) SENSITIVE = [] include Aws::Structure end |
#restore_summary ⇒ Types::AwsDynamoDbTableRestoreSummary
Information about the restore for the table.
5985 5986 5987 5988 5989 5990 5991 5992 5993 5994 5995 5996 5997 5998 5999 6000 6001 6002 6003 6004 6005 6006 6007 6008 |
# File 'lib/aws-sdk-securityhub/types.rb', line 5985 class AwsDynamoDbTableDetails < Struct.new( :attribute_definitions, :billing_mode_summary, :creation_date_time, :global_secondary_indexes, :global_table_version, :item_count, :key_schema, :latest_stream_arn, :latest_stream_label, :local_secondary_indexes, :provisioned_throughput, :replicas, :restore_summary, :sse_description, :stream_specification, :table_id, :table_name, :table_size_bytes, :table_status, :deletion_protection_enabled) SENSITIVE = [] include Aws::Structure end |
#sse_description ⇒ Types::AwsDynamoDbTableSseDescription
Information about the server-side encryption for the table.
5985 5986 5987 5988 5989 5990 5991 5992 5993 5994 5995 5996 5997 5998 5999 6000 6001 6002 6003 6004 6005 6006 6007 6008 |
# File 'lib/aws-sdk-securityhub/types.rb', line 5985 class AwsDynamoDbTableDetails < Struct.new( :attribute_definitions, :billing_mode_summary, :creation_date_time, :global_secondary_indexes, :global_table_version, :item_count, :key_schema, :latest_stream_arn, :latest_stream_label, :local_secondary_indexes, :provisioned_throughput, :replicas, :restore_summary, :sse_description, :stream_specification, :table_id, :table_name, :table_size_bytes, :table_status, :deletion_protection_enabled) SENSITIVE = [] include Aws::Structure end |
#stream_specification ⇒ Types::AwsDynamoDbTableStreamSpecification
The current DynamoDB Streams configuration for the table.
5985 5986 5987 5988 5989 5990 5991 5992 5993 5994 5995 5996 5997 5998 5999 6000 6001 6002 6003 6004 6005 6006 6007 6008 |
# File 'lib/aws-sdk-securityhub/types.rb', line 5985 class AwsDynamoDbTableDetails < Struct.new( :attribute_definitions, :billing_mode_summary, :creation_date_time, :global_secondary_indexes, :global_table_version, :item_count, :key_schema, :latest_stream_arn, :latest_stream_label, :local_secondary_indexes, :provisioned_throughput, :replicas, :restore_summary, :sse_description, :stream_specification, :table_id, :table_name, :table_size_bytes, :table_status, :deletion_protection_enabled) SENSITIVE = [] include Aws::Structure end |
#table_id ⇒ String
The identifier of the table.
5985 5986 5987 5988 5989 5990 5991 5992 5993 5994 5995 5996 5997 5998 5999 6000 6001 6002 6003 6004 6005 6006 6007 6008 |
# File 'lib/aws-sdk-securityhub/types.rb', line 5985 class AwsDynamoDbTableDetails < Struct.new( :attribute_definitions, :billing_mode_summary, :creation_date_time, :global_secondary_indexes, :global_table_version, :item_count, :key_schema, :latest_stream_arn, :latest_stream_label, :local_secondary_indexes, :provisioned_throughput, :replicas, :restore_summary, :sse_description, :stream_specification, :table_id, :table_name, :table_size_bytes, :table_status, :deletion_protection_enabled) SENSITIVE = [] include Aws::Structure end |
#table_name ⇒ String
The name of the table.
5985 5986 5987 5988 5989 5990 5991 5992 5993 5994 5995 5996 5997 5998 5999 6000 6001 6002 6003 6004 6005 6006 6007 6008 |
# File 'lib/aws-sdk-securityhub/types.rb', line 5985 class AwsDynamoDbTableDetails < Struct.new( :attribute_definitions, :billing_mode_summary, :creation_date_time, :global_secondary_indexes, :global_table_version, :item_count, :key_schema, :latest_stream_arn, :latest_stream_label, :local_secondary_indexes, :provisioned_throughput, :replicas, :restore_summary, :sse_description, :stream_specification, :table_id, :table_name, :table_size_bytes, :table_status, :deletion_protection_enabled) SENSITIVE = [] include Aws::Structure end |
#table_size_bytes ⇒ Integer
The total size of the table in bytes.
5985 5986 5987 5988 5989 5990 5991 5992 5993 5994 5995 5996 5997 5998 5999 6000 6001 6002 6003 6004 6005 6006 6007 6008 |
# File 'lib/aws-sdk-securityhub/types.rb', line 5985 class AwsDynamoDbTableDetails < Struct.new( :attribute_definitions, :billing_mode_summary, :creation_date_time, :global_secondary_indexes, :global_table_version, :item_count, :key_schema, :latest_stream_arn, :latest_stream_label, :local_secondary_indexes, :provisioned_throughput, :replicas, :restore_summary, :sse_description, :stream_specification, :table_id, :table_name, :table_size_bytes, :table_status, :deletion_protection_enabled) SENSITIVE = [] include Aws::Structure end |
#table_status ⇒ String
The current status of the table. Valid values are as follows:
-
ACTIVE -
ARCHIVED -
ARCHIVING -
CREATING -
DELETING -
INACCESSIBLE_ENCRYPTION_CREDENTIALS -
UPDATING
5985 5986 5987 5988 5989 5990 5991 5992 5993 5994 5995 5996 5997 5998 5999 6000 6001 6002 6003 6004 6005 6006 6007 6008 |
# File 'lib/aws-sdk-securityhub/types.rb', line 5985 class AwsDynamoDbTableDetails < Struct.new( :attribute_definitions, :billing_mode_summary, :creation_date_time, :global_secondary_indexes, :global_table_version, :item_count, :key_schema, :latest_stream_arn, :latest_stream_label, :local_secondary_indexes, :provisioned_throughput, :replicas, :restore_summary, :sse_description, :stream_specification, :table_id, :table_name, :table_size_bytes, :table_status, :deletion_protection_enabled) SENSITIVE = [] include Aws::Structure end |