Class: Aws::SecurityHub::Types::AwsDynamoDbTableDetails

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

Provides details about a DynamoDB table.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#attribute_definitionsArray<Types::AwsDynamoDbTableAttributeDefinition>

A list of attribute definitions for the table.



5956
5957
5958
5959
5960
5961
5962
5963
5964
5965
5966
5967
5968
5969
5970
5971
5972
5973
5974
5975
5976
5977
5978
5979
# File 'lib/aws-sdk-securityhub/types.rb', line 5956

class AwsDynamoDbTableDetails < Struct.new(
  :attribute_definitions,
  :billing_mode_summary,
  :creation_date_time,
  :global_secondary_indexes,
  :global_table_version,
  :item_count,
  :key_schema,
  :latest_stream_arn,
  :latest_stream_label,
  :local_secondary_indexes,
  :provisioned_throughput,
  :replicas,
  :restore_summary,
  :sse_description,
  :stream_specification,
  :table_id,
  :table_name,
  :table_size_bytes,
  :table_status,
  :deletion_protection_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#billing_mode_summaryTypes::AwsDynamoDbTableBillingModeSummary

Information about the billing for read/write capacity on the table.



5956
5957
5958
5959
5960
5961
5962
5963
5964
5965
5966
5967
5968
5969
5970
5971
5972
5973
5974
5975
5976
5977
5978
5979
# File 'lib/aws-sdk-securityhub/types.rb', line 5956

class AwsDynamoDbTableDetails < Struct.new(
  :attribute_definitions,
  :billing_mode_summary,
  :creation_date_time,
  :global_secondary_indexes,
  :global_table_version,
  :item_count,
  :key_schema,
  :latest_stream_arn,
  :latest_stream_label,
  :local_secondary_indexes,
  :provisioned_throughput,
  :replicas,
  :restore_summary,
  :sse_description,
  :stream_specification,
  :table_id,
  :table_name,
  :table_size_bytes,
  :table_status,
  :deletion_protection_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#creation_date_timeString

Indicates when the table was created.

For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.

Returns:

  • (String)


5956
5957
5958
5959
5960
5961
5962
5963
5964
5965
5966
5967
5968
5969
5970
5971
5972
5973
5974
5975
5976
5977
5978
5979
# File 'lib/aws-sdk-securityhub/types.rb', line 5956

class AwsDynamoDbTableDetails < Struct.new(
  :attribute_definitions,
  :billing_mode_summary,
  :creation_date_time,
  :global_secondary_indexes,
  :global_table_version,
  :item_count,
  :key_schema,
  :latest_stream_arn,
  :latest_stream_label,
  :local_secondary_indexes,
  :provisioned_throughput,
  :replicas,
  :restore_summary,
  :sse_description,
  :stream_specification,
  :table_id,
  :table_name,
  :table_size_bytes,
  :table_status,
  :deletion_protection_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#deletion_protection_enabledBoolean

Indicates whether deletion protection is to be enabled (true) or disabled (false) on the table.

Returns:

  • (Boolean)


5956
5957
5958
5959
5960
5961
5962
5963
5964
5965
5966
5967
5968
5969
5970
5971
5972
5973
5974
5975
5976
5977
5978
5979
# File 'lib/aws-sdk-securityhub/types.rb', line 5956

class AwsDynamoDbTableDetails < Struct.new(
  :attribute_definitions,
  :billing_mode_summary,
  :creation_date_time,
  :global_secondary_indexes,
  :global_table_version,
  :item_count,
  :key_schema,
  :latest_stream_arn,
  :latest_stream_label,
  :local_secondary_indexes,
  :provisioned_throughput,
  :replicas,
  :restore_summary,
  :sse_description,
  :stream_specification,
  :table_id,
  :table_name,
  :table_size_bytes,
  :table_status,
  :deletion_protection_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#global_secondary_indexesArray<Types::AwsDynamoDbTableGlobalSecondaryIndex>

List of global secondary indexes for the table.



5956
5957
5958
5959
5960
5961
5962
5963
5964
5965
5966
5967
5968
5969
5970
5971
5972
5973
5974
5975
5976
5977
5978
5979
# File 'lib/aws-sdk-securityhub/types.rb', line 5956

class AwsDynamoDbTableDetails < Struct.new(
  :attribute_definitions,
  :billing_mode_summary,
  :creation_date_time,
  :global_secondary_indexes,
  :global_table_version,
  :item_count,
  :key_schema,
  :latest_stream_arn,
  :latest_stream_label,
  :local_secondary_indexes,
  :provisioned_throughput,
  :replicas,
  :restore_summary,
  :sse_description,
  :stream_specification,
  :table_id,
  :table_name,
  :table_size_bytes,
  :table_status,
  :deletion_protection_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#global_table_versionString

The version of global tables being used.

Returns:

  • (String)


5956
5957
5958
5959
5960
5961
5962
5963
5964
5965
5966
5967
5968
5969
5970
5971
5972
5973
5974
5975
5976
5977
5978
5979
# File 'lib/aws-sdk-securityhub/types.rb', line 5956

class AwsDynamoDbTableDetails < Struct.new(
  :attribute_definitions,
  :billing_mode_summary,
  :creation_date_time,
  :global_secondary_indexes,
  :global_table_version,
  :item_count,
  :key_schema,
  :latest_stream_arn,
  :latest_stream_label,
  :local_secondary_indexes,
  :provisioned_throughput,
  :replicas,
  :restore_summary,
  :sse_description,
  :stream_specification,
  :table_id,
  :table_name,
  :table_size_bytes,
  :table_status,
  :deletion_protection_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#item_countInteger

The number of items in the table.

Returns:

  • (Integer)


5956
5957
5958
5959
5960
5961
5962
5963
5964
5965
5966
5967
5968
5969
5970
5971
5972
5973
5974
5975
5976
5977
5978
5979
# File 'lib/aws-sdk-securityhub/types.rb', line 5956

class AwsDynamoDbTableDetails < Struct.new(
  :attribute_definitions,
  :billing_mode_summary,
  :creation_date_time,
  :global_secondary_indexes,
  :global_table_version,
  :item_count,
  :key_schema,
  :latest_stream_arn,
  :latest_stream_label,
  :local_secondary_indexes,
  :provisioned_throughput,
  :replicas,
  :restore_summary,
  :sse_description,
  :stream_specification,
  :table_id,
  :table_name,
  :table_size_bytes,
  :table_status,
  :deletion_protection_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#key_schemaArray<Types::AwsDynamoDbTableKeySchema>

The primary key structure for the table.



5956
5957
5958
5959
5960
5961
5962
5963
5964
5965
5966
5967
5968
5969
5970
5971
5972
5973
5974
5975
5976
5977
5978
5979
# File 'lib/aws-sdk-securityhub/types.rb', line 5956

class AwsDynamoDbTableDetails < Struct.new(
  :attribute_definitions,
  :billing_mode_summary,
  :creation_date_time,
  :global_secondary_indexes,
  :global_table_version,
  :item_count,
  :key_schema,
  :latest_stream_arn,
  :latest_stream_label,
  :local_secondary_indexes,
  :provisioned_throughput,
  :replicas,
  :restore_summary,
  :sse_description,
  :stream_specification,
  :table_id,
  :table_name,
  :table_size_bytes,
  :table_status,
  :deletion_protection_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#latest_stream_arnString

The ARN of the latest stream for the table.

Returns:

  • (String)


5956
5957
5958
5959
5960
5961
5962
5963
5964
5965
5966
5967
5968
5969
5970
5971
5972
5973
5974
5975
5976
5977
5978
5979
# File 'lib/aws-sdk-securityhub/types.rb', line 5956

class AwsDynamoDbTableDetails < Struct.new(
  :attribute_definitions,
  :billing_mode_summary,
  :creation_date_time,
  :global_secondary_indexes,
  :global_table_version,
  :item_count,
  :key_schema,
  :latest_stream_arn,
  :latest_stream_label,
  :local_secondary_indexes,
  :provisioned_throughput,
  :replicas,
  :restore_summary,
  :sse_description,
  :stream_specification,
  :table_id,
  :table_name,
  :table_size_bytes,
  :table_status,
  :deletion_protection_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#latest_stream_labelString

The label of the latest stream. The label is not a unique identifier.

Returns:

  • (String)


5956
5957
5958
5959
5960
5961
5962
5963
5964
5965
5966
5967
5968
5969
5970
5971
5972
5973
5974
5975
5976
5977
5978
5979
# File 'lib/aws-sdk-securityhub/types.rb', line 5956

class AwsDynamoDbTableDetails < Struct.new(
  :attribute_definitions,
  :billing_mode_summary,
  :creation_date_time,
  :global_secondary_indexes,
  :global_table_version,
  :item_count,
  :key_schema,
  :latest_stream_arn,
  :latest_stream_label,
  :local_secondary_indexes,
  :provisioned_throughput,
  :replicas,
  :restore_summary,
  :sse_description,
  :stream_specification,
  :table_id,
  :table_name,
  :table_size_bytes,
  :table_status,
  :deletion_protection_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#local_secondary_indexesArray<Types::AwsDynamoDbTableLocalSecondaryIndex>

The list of local secondary indexes for the table.



5956
5957
5958
5959
5960
5961
5962
5963
5964
5965
5966
5967
5968
5969
5970
5971
5972
5973
5974
5975
5976
5977
5978
5979
# File 'lib/aws-sdk-securityhub/types.rb', line 5956

class AwsDynamoDbTableDetails < Struct.new(
  :attribute_definitions,
  :billing_mode_summary,
  :creation_date_time,
  :global_secondary_indexes,
  :global_table_version,
  :item_count,
  :key_schema,
  :latest_stream_arn,
  :latest_stream_label,
  :local_secondary_indexes,
  :provisioned_throughput,
  :replicas,
  :restore_summary,
  :sse_description,
  :stream_specification,
  :table_id,
  :table_name,
  :table_size_bytes,
  :table_status,
  :deletion_protection_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#provisioned_throughputTypes::AwsDynamoDbTableProvisionedThroughput

Information about the provisioned throughput for the table.



5956
5957
5958
5959
5960
5961
5962
5963
5964
5965
5966
5967
5968
5969
5970
5971
5972
5973
5974
5975
5976
5977
5978
5979
# File 'lib/aws-sdk-securityhub/types.rb', line 5956

class AwsDynamoDbTableDetails < Struct.new(
  :attribute_definitions,
  :billing_mode_summary,
  :creation_date_time,
  :global_secondary_indexes,
  :global_table_version,
  :item_count,
  :key_schema,
  :latest_stream_arn,
  :latest_stream_label,
  :local_secondary_indexes,
  :provisioned_throughput,
  :replicas,
  :restore_summary,
  :sse_description,
  :stream_specification,
  :table_id,
  :table_name,
  :table_size_bytes,
  :table_status,
  :deletion_protection_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#replicasArray<Types::AwsDynamoDbTableReplica>

The list of replicas of this table.

Returns:



5956
5957
5958
5959
5960
5961
5962
5963
5964
5965
5966
5967
5968
5969
5970
5971
5972
5973
5974
5975
5976
5977
5978
5979
# File 'lib/aws-sdk-securityhub/types.rb', line 5956

class AwsDynamoDbTableDetails < Struct.new(
  :attribute_definitions,
  :billing_mode_summary,
  :creation_date_time,
  :global_secondary_indexes,
  :global_table_version,
  :item_count,
  :key_schema,
  :latest_stream_arn,
  :latest_stream_label,
  :local_secondary_indexes,
  :provisioned_throughput,
  :replicas,
  :restore_summary,
  :sse_description,
  :stream_specification,
  :table_id,
  :table_name,
  :table_size_bytes,
  :table_status,
  :deletion_protection_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#restore_summaryTypes::AwsDynamoDbTableRestoreSummary

Information about the restore for the table.



5956
5957
5958
5959
5960
5961
5962
5963
5964
5965
5966
5967
5968
5969
5970
5971
5972
5973
5974
5975
5976
5977
5978
5979
# File 'lib/aws-sdk-securityhub/types.rb', line 5956

class AwsDynamoDbTableDetails < Struct.new(
  :attribute_definitions,
  :billing_mode_summary,
  :creation_date_time,
  :global_secondary_indexes,
  :global_table_version,
  :item_count,
  :key_schema,
  :latest_stream_arn,
  :latest_stream_label,
  :local_secondary_indexes,
  :provisioned_throughput,
  :replicas,
  :restore_summary,
  :sse_description,
  :stream_specification,
  :table_id,
  :table_name,
  :table_size_bytes,
  :table_status,
  :deletion_protection_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#sse_descriptionTypes::AwsDynamoDbTableSseDescription

Information about the server-side encryption for the table.



5956
5957
5958
5959
5960
5961
5962
5963
5964
5965
5966
5967
5968
5969
5970
5971
5972
5973
5974
5975
5976
5977
5978
5979
# File 'lib/aws-sdk-securityhub/types.rb', line 5956

class AwsDynamoDbTableDetails < Struct.new(
  :attribute_definitions,
  :billing_mode_summary,
  :creation_date_time,
  :global_secondary_indexes,
  :global_table_version,
  :item_count,
  :key_schema,
  :latest_stream_arn,
  :latest_stream_label,
  :local_secondary_indexes,
  :provisioned_throughput,
  :replicas,
  :restore_summary,
  :sse_description,
  :stream_specification,
  :table_id,
  :table_name,
  :table_size_bytes,
  :table_status,
  :deletion_protection_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#stream_specificationTypes::AwsDynamoDbTableStreamSpecification

The current DynamoDB Streams configuration for the table.



5956
5957
5958
5959
5960
5961
5962
5963
5964
5965
5966
5967
5968
5969
5970
5971
5972
5973
5974
5975
5976
5977
5978
5979
# File 'lib/aws-sdk-securityhub/types.rb', line 5956

class AwsDynamoDbTableDetails < Struct.new(
  :attribute_definitions,
  :billing_mode_summary,
  :creation_date_time,
  :global_secondary_indexes,
  :global_table_version,
  :item_count,
  :key_schema,
  :latest_stream_arn,
  :latest_stream_label,
  :local_secondary_indexes,
  :provisioned_throughput,
  :replicas,
  :restore_summary,
  :sse_description,
  :stream_specification,
  :table_id,
  :table_name,
  :table_size_bytes,
  :table_status,
  :deletion_protection_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#table_idString

The identifier of the table.

Returns:

  • (String)


5956
5957
5958
5959
5960
5961
5962
5963
5964
5965
5966
5967
5968
5969
5970
5971
5972
5973
5974
5975
5976
5977
5978
5979
# File 'lib/aws-sdk-securityhub/types.rb', line 5956

class AwsDynamoDbTableDetails < Struct.new(
  :attribute_definitions,
  :billing_mode_summary,
  :creation_date_time,
  :global_secondary_indexes,
  :global_table_version,
  :item_count,
  :key_schema,
  :latest_stream_arn,
  :latest_stream_label,
  :local_secondary_indexes,
  :provisioned_throughput,
  :replicas,
  :restore_summary,
  :sse_description,
  :stream_specification,
  :table_id,
  :table_name,
  :table_size_bytes,
  :table_status,
  :deletion_protection_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#table_nameString

The name of the table.

Returns:

  • (String)


5956
5957
5958
5959
5960
5961
5962
5963
5964
5965
5966
5967
5968
5969
5970
5971
5972
5973
5974
5975
5976
5977
5978
5979
# File 'lib/aws-sdk-securityhub/types.rb', line 5956

class AwsDynamoDbTableDetails < Struct.new(
  :attribute_definitions,
  :billing_mode_summary,
  :creation_date_time,
  :global_secondary_indexes,
  :global_table_version,
  :item_count,
  :key_schema,
  :latest_stream_arn,
  :latest_stream_label,
  :local_secondary_indexes,
  :provisioned_throughput,
  :replicas,
  :restore_summary,
  :sse_description,
  :stream_specification,
  :table_id,
  :table_name,
  :table_size_bytes,
  :table_status,
  :deletion_protection_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#table_size_bytesInteger

The total size of the table in bytes.

Returns:

  • (Integer)


5956
5957
5958
5959
5960
5961
5962
5963
5964
5965
5966
5967
5968
5969
5970
5971
5972
5973
5974
5975
5976
5977
5978
5979
# File 'lib/aws-sdk-securityhub/types.rb', line 5956

class AwsDynamoDbTableDetails < Struct.new(
  :attribute_definitions,
  :billing_mode_summary,
  :creation_date_time,
  :global_secondary_indexes,
  :global_table_version,
  :item_count,
  :key_schema,
  :latest_stream_arn,
  :latest_stream_label,
  :local_secondary_indexes,
  :provisioned_throughput,
  :replicas,
  :restore_summary,
  :sse_description,
  :stream_specification,
  :table_id,
  :table_name,
  :table_size_bytes,
  :table_status,
  :deletion_protection_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#table_statusString

The current status of the table. Valid values are as follows:

  • ACTIVE

  • ARCHIVED

  • ARCHIVING

  • CREATING

  • DELETING

  • INACCESSIBLE_ENCRYPTION_CREDENTIALS

  • UPDATING

Returns:

  • (String)


5956
5957
5958
5959
5960
5961
5962
5963
5964
5965
5966
5967
5968
5969
5970
5971
5972
5973
5974
5975
5976
5977
5978
5979
# File 'lib/aws-sdk-securityhub/types.rb', line 5956

class AwsDynamoDbTableDetails < Struct.new(
  :attribute_definitions,
  :billing_mode_summary,
  :creation_date_time,
  :global_secondary_indexes,
  :global_table_version,
  :item_count,
  :key_schema,
  :latest_stream_arn,
  :latest_stream_label,
  :local_secondary_indexes,
  :provisioned_throughput,
  :replicas,
  :restore_summary,
  :sse_description,
  :stream_specification,
  :table_id,
  :table_name,
  :table_size_bytes,
  :table_status,
  :deletion_protection_enabled)
  SENSITIVE = []
  include Aws::Structure
end