Class: Aws::SecurityHub::Types::AwsDynamoDbTableLocalSecondaryIndex

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

Information about a local secondary index for a DynamoDB table.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#index_arnString

The ARN of the index.

Returns:

  • (String)


6087
6088
6089
6090
6091
6092
6093
6094
# File 'lib/aws-sdk-securityhub/types.rb', line 6087

class AwsDynamoDbTableLocalSecondaryIndex < Struct.new(
  :index_arn,
  :index_name,
  :key_schema,
  :projection)
  SENSITIVE = []
  include Aws::Structure
end

#index_nameString

The name of the index.

Returns:

  • (String)


6087
6088
6089
6090
6091
6092
6093
6094
# File 'lib/aws-sdk-securityhub/types.rb', line 6087

class AwsDynamoDbTableLocalSecondaryIndex < Struct.new(
  :index_arn,
  :index_name,
  :key_schema,
  :projection)
  SENSITIVE = []
  include Aws::Structure
end

#key_schemaArray<Types::AwsDynamoDbTableKeySchema>

The complete key schema for the index.



6087
6088
6089
6090
6091
6092
6093
6094
# File 'lib/aws-sdk-securityhub/types.rb', line 6087

class AwsDynamoDbTableLocalSecondaryIndex < Struct.new(
  :index_arn,
  :index_name,
  :key_schema,
  :projection)
  SENSITIVE = []
  include Aws::Structure
end

#projectionTypes::AwsDynamoDbTableProjection

Attributes that are copied from the table into the index. These are in addition to the primary key attributes and index key attributes, which are automatically projected.



6087
6088
6089
6090
6091
6092
6093
6094
# File 'lib/aws-sdk-securityhub/types.rb', line 6087

class AwsDynamoDbTableLocalSecondaryIndex < Struct.new(
  :index_arn,
  :index_name,
  :key_schema,
  :projection)
  SENSITIVE = []
  include Aws::Structure
end