Class: Aws::SecurityHub::Types::AwsDynamoDbTableLocalSecondaryIndex
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::AwsDynamoDbTableLocalSecondaryIndex
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Information about a local secondary index for a DynamoDB table.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#index_arn ⇒ String
The ARN of the index.
-
#index_name ⇒ String
The name of the index.
-
#key_schema ⇒ Array<Types::AwsDynamoDbTableKeySchema>
The complete key schema for the index.
-
#projection ⇒ Types::AwsDynamoDbTableProjection
Attributes that are copied from the table into the index.
Instance Attribute Details
#index_arn ⇒ String
The ARN of the index.
5986 5987 5988 5989 5990 5991 5992 5993 |
# File 'lib/aws-sdk-securityhub/types.rb', line 5986 class AwsDynamoDbTableLocalSecondaryIndex < Struct.new( :index_arn, :index_name, :key_schema, :projection) SENSITIVE = [] include Aws::Structure end |
#index_name ⇒ String
The name of the index.
5986 5987 5988 5989 5990 5991 5992 5993 |
# File 'lib/aws-sdk-securityhub/types.rb', line 5986 class AwsDynamoDbTableLocalSecondaryIndex < Struct.new( :index_arn, :index_name, :key_schema, :projection) SENSITIVE = [] include Aws::Structure end |
#key_schema ⇒ Array<Types::AwsDynamoDbTableKeySchema>
The complete key schema for the index.
5986 5987 5988 5989 5990 5991 5992 5993 |
# File 'lib/aws-sdk-securityhub/types.rb', line 5986 class AwsDynamoDbTableLocalSecondaryIndex < Struct.new( :index_arn, :index_name, :key_schema, :projection) SENSITIVE = [] include Aws::Structure end |
#projection ⇒ Types::AwsDynamoDbTableProjection
Attributes that are copied from the table into the index. These are in addition to the primary key attributes and index key attributes, which are automatically projected.
5986 5987 5988 5989 5990 5991 5992 5993 |
# File 'lib/aws-sdk-securityhub/types.rb', line 5986 class AwsDynamoDbTableLocalSecondaryIndex < Struct.new( :index_arn, :index_name, :key_schema, :projection) SENSITIVE = [] include Aws::Structure end |