Class: Aws::SecurityHub::Types::AwsDynamoDbTableSseDescription

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

Information about the server-side encryption for the table.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#inaccessible_encryption_date_timeString

If the key is inaccessible, the date and time when DynamoDB detected that the key was inaccessible.

For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.

Returns:

  • (String)


6325
6326
6327
6328
6329
6330
6331
6332
# File 'lib/aws-sdk-securityhub/types.rb', line 6325

class AwsDynamoDbTableSseDescription < Struct.new(
  :inaccessible_encryption_date_time,
  :status,
  :sse_type,
  :kms_master_key_arn)
  SENSITIVE = []
  include Aws::Structure
end

#kms_master_key_arnString

The ARN of the KMS key that is used for the KMS encryption.

Returns:

  • (String)


6325
6326
6327
6328
6329
6330
6331
6332
# File 'lib/aws-sdk-securityhub/types.rb', line 6325

class AwsDynamoDbTableSseDescription < Struct.new(
  :inaccessible_encryption_date_time,
  :status,
  :sse_type,
  :kms_master_key_arn)
  SENSITIVE = []
  include Aws::Structure
end

#sse_typeString

The type of server-side encryption.

Returns:

  • (String)


6325
6326
6327
6328
6329
6330
6331
6332
# File 'lib/aws-sdk-securityhub/types.rb', line 6325

class AwsDynamoDbTableSseDescription < Struct.new(
  :inaccessible_encryption_date_time,
  :status,
  :sse_type,
  :kms_master_key_arn)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the server-side encryption.

Returns:

  • (String)


6325
6326
6327
6328
6329
6330
6331
6332
# File 'lib/aws-sdk-securityhub/types.rb', line 6325

class AwsDynamoDbTableSseDescription < Struct.new(
  :inaccessible_encryption_date_time,
  :status,
  :sse_type,
  :kms_master_key_arn)
  SENSITIVE = []
  include Aws::Structure
end