Class: Aws::SecurityHub::Types::AwsEc2InstanceDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::AwsEc2InstanceDetails
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
The details of an Amazon EC2 instance.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#iam_instance_profile_arn ⇒ String
The IAM profile ARN of the instance.
-
#image_id ⇒ String
The Amazon Machine Image (AMI) ID of the instance.
-
#ip_v4_addresses ⇒ Array<String>
The IPv4 addresses associated with the instance.
-
#ip_v6_addresses ⇒ Array<String>
The IPv6 addresses associated with the instance.
-
#key_name ⇒ String
The key name associated with the instance.
-
#launched_at ⇒ String
Indicates when the instance was launched.
-
#metadata_options ⇒ Types::AwsEc2InstanceMetadataOptions
Details about the metadata options for the Amazon EC2 instance.
-
#monitoring ⇒ Types::AwsEc2InstanceMonitoringDetails
Describes the type of monitoring that’s turned on for an instance.
-
#network_interfaces ⇒ Array<Types::AwsEc2InstanceNetworkInterfacesDetails>
The identifiers of the network interfaces for the EC2 instance.
-
#subnet_id ⇒ String
The identifier of the subnet that the instance was launched in.
-
#type ⇒ String
The instance type of the instance.
-
#virtualization_type ⇒ String
The virtualization type of the Amazon Machine Image (AMI) required to launch the instance.
-
#vpc_id ⇒ String
The identifier of the VPC that the instance was launched in.
Instance Attribute Details
#iam_instance_profile_arn ⇒ String
The IAM profile ARN of the instance.
6661 6662 6663 6664 6665 6666 6667 6668 6669 6670 6671 6672 6673 6674 6675 6676 6677 |
# File 'lib/aws-sdk-securityhub/types.rb', line 6661 class AwsEc2InstanceDetails < Struct.new( :type, :image_id, :ip_v4_addresses, :ip_v6_addresses, :key_name, :iam_instance_profile_arn, :vpc_id, :subnet_id, :launched_at, :network_interfaces, :virtualization_type, :metadata_options, :monitoring) SENSITIVE = [] include Aws::Structure end |
#image_id ⇒ String
The Amazon Machine Image (AMI) ID of the instance.
6661 6662 6663 6664 6665 6666 6667 6668 6669 6670 6671 6672 6673 6674 6675 6676 6677 |
# File 'lib/aws-sdk-securityhub/types.rb', line 6661 class AwsEc2InstanceDetails < Struct.new( :type, :image_id, :ip_v4_addresses, :ip_v6_addresses, :key_name, :iam_instance_profile_arn, :vpc_id, :subnet_id, :launched_at, :network_interfaces, :virtualization_type, :metadata_options, :monitoring) SENSITIVE = [] include Aws::Structure end |
#ip_v4_addresses ⇒ Array<String>
The IPv4 addresses associated with the instance.
6661 6662 6663 6664 6665 6666 6667 6668 6669 6670 6671 6672 6673 6674 6675 6676 6677 |
# File 'lib/aws-sdk-securityhub/types.rb', line 6661 class AwsEc2InstanceDetails < Struct.new( :type, :image_id, :ip_v4_addresses, :ip_v6_addresses, :key_name, :iam_instance_profile_arn, :vpc_id, :subnet_id, :launched_at, :network_interfaces, :virtualization_type, :metadata_options, :monitoring) SENSITIVE = [] include Aws::Structure end |
#ip_v6_addresses ⇒ Array<String>
The IPv6 addresses associated with the instance.
6661 6662 6663 6664 6665 6666 6667 6668 6669 6670 6671 6672 6673 6674 6675 6676 6677 |
# File 'lib/aws-sdk-securityhub/types.rb', line 6661 class AwsEc2InstanceDetails < Struct.new( :type, :image_id, :ip_v4_addresses, :ip_v6_addresses, :key_name, :iam_instance_profile_arn, :vpc_id, :subnet_id, :launched_at, :network_interfaces, :virtualization_type, :metadata_options, :monitoring) SENSITIVE = [] include Aws::Structure end |
#key_name ⇒ String
The key name associated with the instance.
6661 6662 6663 6664 6665 6666 6667 6668 6669 6670 6671 6672 6673 6674 6675 6676 6677 |
# File 'lib/aws-sdk-securityhub/types.rb', line 6661 class AwsEc2InstanceDetails < Struct.new( :type, :image_id, :ip_v4_addresses, :ip_v6_addresses, :key_name, :iam_instance_profile_arn, :vpc_id, :subnet_id, :launched_at, :network_interfaces, :virtualization_type, :metadata_options, :monitoring) SENSITIVE = [] include Aws::Structure end |
#launched_at ⇒ String
Indicates when the instance was launched.
For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.
6661 6662 6663 6664 6665 6666 6667 6668 6669 6670 6671 6672 6673 6674 6675 6676 6677 |
# File 'lib/aws-sdk-securityhub/types.rb', line 6661 class AwsEc2InstanceDetails < Struct.new( :type, :image_id, :ip_v4_addresses, :ip_v6_addresses, :key_name, :iam_instance_profile_arn, :vpc_id, :subnet_id, :launched_at, :network_interfaces, :virtualization_type, :metadata_options, :monitoring) SENSITIVE = [] include Aws::Structure end |
#metadata_options ⇒ Types::AwsEc2InstanceMetadataOptions
Details about the metadata options for the Amazon EC2 instance.
6661 6662 6663 6664 6665 6666 6667 6668 6669 6670 6671 6672 6673 6674 6675 6676 6677 |
# File 'lib/aws-sdk-securityhub/types.rb', line 6661 class AwsEc2InstanceDetails < Struct.new( :type, :image_id, :ip_v4_addresses, :ip_v6_addresses, :key_name, :iam_instance_profile_arn, :vpc_id, :subnet_id, :launched_at, :network_interfaces, :virtualization_type, :metadata_options, :monitoring) SENSITIVE = [] include Aws::Structure end |
#monitoring ⇒ Types::AwsEc2InstanceMonitoringDetails
Describes the type of monitoring that’s turned on for an instance.
6661 6662 6663 6664 6665 6666 6667 6668 6669 6670 6671 6672 6673 6674 6675 6676 6677 |
# File 'lib/aws-sdk-securityhub/types.rb', line 6661 class AwsEc2InstanceDetails < Struct.new( :type, :image_id, :ip_v4_addresses, :ip_v6_addresses, :key_name, :iam_instance_profile_arn, :vpc_id, :subnet_id, :launched_at, :network_interfaces, :virtualization_type, :metadata_options, :monitoring) SENSITIVE = [] include Aws::Structure end |
#network_interfaces ⇒ Array<Types::AwsEc2InstanceNetworkInterfacesDetails>
The identifiers of the network interfaces for the EC2 instance. The
details for each network interface are in a corresponding
AwsEc2NetworkInterfacesDetails object.
6661 6662 6663 6664 6665 6666 6667 6668 6669 6670 6671 6672 6673 6674 6675 6676 6677 |
# File 'lib/aws-sdk-securityhub/types.rb', line 6661 class AwsEc2InstanceDetails < Struct.new( :type, :image_id, :ip_v4_addresses, :ip_v6_addresses, :key_name, :iam_instance_profile_arn, :vpc_id, :subnet_id, :launched_at, :network_interfaces, :virtualization_type, :metadata_options, :monitoring) SENSITIVE = [] include Aws::Structure end |
#subnet_id ⇒ String
The identifier of the subnet that the instance was launched in.
6661 6662 6663 6664 6665 6666 6667 6668 6669 6670 6671 6672 6673 6674 6675 6676 6677 |
# File 'lib/aws-sdk-securityhub/types.rb', line 6661 class AwsEc2InstanceDetails < Struct.new( :type, :image_id, :ip_v4_addresses, :ip_v6_addresses, :key_name, :iam_instance_profile_arn, :vpc_id, :subnet_id, :launched_at, :network_interfaces, :virtualization_type, :metadata_options, :monitoring) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The instance type of the instance.
6661 6662 6663 6664 6665 6666 6667 6668 6669 6670 6671 6672 6673 6674 6675 6676 6677 |
# File 'lib/aws-sdk-securityhub/types.rb', line 6661 class AwsEc2InstanceDetails < Struct.new( :type, :image_id, :ip_v4_addresses, :ip_v6_addresses, :key_name, :iam_instance_profile_arn, :vpc_id, :subnet_id, :launched_at, :network_interfaces, :virtualization_type, :metadata_options, :monitoring) SENSITIVE = [] include Aws::Structure end |
#virtualization_type ⇒ String
The virtualization type of the Amazon Machine Image (AMI) required to launch the instance.
6661 6662 6663 6664 6665 6666 6667 6668 6669 6670 6671 6672 6673 6674 6675 6676 6677 |
# File 'lib/aws-sdk-securityhub/types.rb', line 6661 class AwsEc2InstanceDetails < Struct.new( :type, :image_id, :ip_v4_addresses, :ip_v6_addresses, :key_name, :iam_instance_profile_arn, :vpc_id, :subnet_id, :launched_at, :network_interfaces, :virtualization_type, :metadata_options, :monitoring) SENSITIVE = [] include Aws::Structure end |
#vpc_id ⇒ String
The identifier of the VPC that the instance was launched in.
6661 6662 6663 6664 6665 6666 6667 6668 6669 6670 6671 6672 6673 6674 6675 6676 6677 |
# File 'lib/aws-sdk-securityhub/types.rb', line 6661 class AwsEc2InstanceDetails < Struct.new( :type, :image_id, :ip_v4_addresses, :ip_v6_addresses, :key_name, :iam_instance_profile_arn, :vpc_id, :subnet_id, :launched_at, :network_interfaces, :virtualization_type, :metadata_options, :monitoring) SENSITIVE = [] include Aws::Structure end |