Class: Aws::SecurityHub::Types::AwsEc2LaunchTemplateDataBlockDeviceMappingSetDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::AwsEc2LaunchTemplateDataBlockDeviceMappingSetDetails
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Information about a block device mapping for an Amazon Elastic Compute Cloud (Amazon EC2) launch template.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#device_name ⇒ String
The device name.
-
#ebs ⇒ Types::AwsEc2LaunchTemplateDataBlockDeviceMappingSetEbsDetails
Parameters used to automatically set up Amazon EBS volumes when the instance is launched.
-
#no_device ⇒ String
Omits the device from the block device mapping when an empty string is specified.
-
#virtual_name ⇒ String
The virtual device name (ephemeralN).
Instance Attribute Details
#device_name ⇒ String
The device name.
6876 6877 6878 6879 6880 6881 6882 6883 |
# File 'lib/aws-sdk-securityhub/types.rb', line 6876 class AwsEc2LaunchTemplateDataBlockDeviceMappingSetDetails < Struct.new( :device_name, :ebs, :no_device, :virtual_name) SENSITIVE = [] include Aws::Structure end |
#ebs ⇒ Types::AwsEc2LaunchTemplateDataBlockDeviceMappingSetEbsDetails
Parameters used to automatically set up Amazon EBS volumes when the instance is launched.
6876 6877 6878 6879 6880 6881 6882 6883 |
# File 'lib/aws-sdk-securityhub/types.rb', line 6876 class AwsEc2LaunchTemplateDataBlockDeviceMappingSetDetails < Struct.new( :device_name, :ebs, :no_device, :virtual_name) SENSITIVE = [] include Aws::Structure end |
#no_device ⇒ String
Omits the device from the block device mapping when an empty string is specified.
6876 6877 6878 6879 6880 6881 6882 6883 |
# File 'lib/aws-sdk-securityhub/types.rb', line 6876 class AwsEc2LaunchTemplateDataBlockDeviceMappingSetDetails < Struct.new( :device_name, :ebs, :no_device, :virtual_name) SENSITIVE = [] include Aws::Structure end |
#virtual_name ⇒ String
The virtual device name (ephemeralN). Instance store volumes are
numbered starting from 0. An instance type with 2 available instance
store volumes can specify mappings for ephemeral0 and
ephemeral1. The number of available instance store volumes depends
on the instance type.
6876 6877 6878 6879 6880 6881 6882 6883 |
# File 'lib/aws-sdk-securityhub/types.rb', line 6876 class AwsEc2LaunchTemplateDataBlockDeviceMappingSetDetails < Struct.new( :device_name, :ebs, :no_device, :virtual_name) SENSITIVE = [] include Aws::Structure end |