Class: Aws::SecurityHub::Types::AwsEc2LaunchTemplateDataMonitoringDetails

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

The monitoring for an Amazon EC2 instance.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#enabledBoolean

Enables detailed monitoring when true is specified. Otherwise, basic monitoring is enabled. For more information about detailed monitoring, see Enable or turn off detailed monitoring for your instances in the Amazon EC2 User Guide.

Returns:

  • (Boolean)


7792
7793
7794
7795
7796
# File 'lib/aws-sdk-securityhub/types.rb', line 7792

class AwsEc2LaunchTemplateDataMonitoringDetails < Struct.new(
  :enabled)
  SENSITIVE = []
  include Aws::Structure
end