Class: Aws::SecurityHub::Types::AwsEc2NetworkInterfaceAttachment
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::AwsEc2NetworkInterfaceAttachment
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Information about the network interface attachment.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attach_time ⇒ String
Indicates when the attachment initiated.
-
#attachment_id ⇒ String
The identifier of the network interface attachment.
-
#delete_on_termination ⇒ Boolean
Indicates whether the network interface is deleted when the instance is terminated.
-
#device_index ⇒ Integer
The device index of the network interface attachment on the instance.
-
#instance_id ⇒ String
The ID of the instance.
-
#instance_owner_id ⇒ String
The Amazon Web Services account ID of the owner of the instance.
-
#status ⇒ String
The attachment state.
Instance Attribute Details
#attach_time ⇒ String
Indicates when the attachment initiated.
For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.
8274 8275 8276 8277 8278 8279 8280 8281 8282 8283 8284 |
# File 'lib/aws-sdk-securityhub/types.rb', line 8274 class AwsEc2NetworkInterfaceAttachment < Struct.new( :attach_time, :attachment_id, :delete_on_termination, :device_index, :instance_id, :instance_owner_id, :status) SENSITIVE = [] include Aws::Structure end |
#attachment_id ⇒ String
The identifier of the network interface attachment
8274 8275 8276 8277 8278 8279 8280 8281 8282 8283 8284 |
# File 'lib/aws-sdk-securityhub/types.rb', line 8274 class AwsEc2NetworkInterfaceAttachment < Struct.new( :attach_time, :attachment_id, :delete_on_termination, :device_index, :instance_id, :instance_owner_id, :status) SENSITIVE = [] include Aws::Structure end |
#delete_on_termination ⇒ Boolean
Indicates whether the network interface is deleted when the instance is terminated.
8274 8275 8276 8277 8278 8279 8280 8281 8282 8283 8284 |
# File 'lib/aws-sdk-securityhub/types.rb', line 8274 class AwsEc2NetworkInterfaceAttachment < Struct.new( :attach_time, :attachment_id, :delete_on_termination, :device_index, :instance_id, :instance_owner_id, :status) SENSITIVE = [] include Aws::Structure end |
#device_index ⇒ Integer
The device index of the network interface attachment on the instance.
8274 8275 8276 8277 8278 8279 8280 8281 8282 8283 8284 |
# File 'lib/aws-sdk-securityhub/types.rb', line 8274 class AwsEc2NetworkInterfaceAttachment < Struct.new( :attach_time, :attachment_id, :delete_on_termination, :device_index, :instance_id, :instance_owner_id, :status) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The ID of the instance.
8274 8275 8276 8277 8278 8279 8280 8281 8282 8283 8284 |
# File 'lib/aws-sdk-securityhub/types.rb', line 8274 class AwsEc2NetworkInterfaceAttachment < Struct.new( :attach_time, :attachment_id, :delete_on_termination, :device_index, :instance_id, :instance_owner_id, :status) SENSITIVE = [] include Aws::Structure end |
#instance_owner_id ⇒ String
The Amazon Web Services account ID of the owner of the instance.
8274 8275 8276 8277 8278 8279 8280 8281 8282 8283 8284 |
# File 'lib/aws-sdk-securityhub/types.rb', line 8274 class AwsEc2NetworkInterfaceAttachment < Struct.new( :attach_time, :attachment_id, :delete_on_termination, :device_index, :instance_id, :instance_owner_id, :status) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The attachment state.
Valid values: attaching | attached | detaching | detached
8274 8275 8276 8277 8278 8279 8280 8281 8282 8283 8284 |
# File 'lib/aws-sdk-securityhub/types.rb', line 8274 class AwsEc2NetworkInterfaceAttachment < Struct.new( :attach_time, :attachment_id, :delete_on_termination, :device_index, :instance_id, :instance_owner_id, :status) SENSITIVE = [] include Aws::Structure end |