Class: Aws::SecurityHub::Types::AwsEc2SecurityGroupUserIdGroupPair
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::AwsEc2SecurityGroupUserIdGroupPair
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
A relationship between a security group and a user.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#group_id ⇒ String
The ID of the security group.
-
#group_name ⇒ String
The name of the security group.
-
#peering_status ⇒ String
The status of a VPC peering connection, if applicable.
-
#user_id ⇒ String
The ID of an Amazon Web Services account.
-
#vpc_id ⇒ String
The ID of the VPC for the referenced security group, if applicable.
-
#vpc_peering_connection_id ⇒ String
The ID of the VPC peering connection, if applicable.
Instance Attribute Details
#group_id ⇒ String
The ID of the security group.
8516 8517 8518 8519 8520 8521 8522 8523 8524 8525 |
# File 'lib/aws-sdk-securityhub/types.rb', line 8516 class AwsEc2SecurityGroupUserIdGroupPair < Struct.new( :group_id, :group_name, :peering_status, :user_id, :vpc_id, :vpc_peering_connection_id) SENSITIVE = [] include Aws::Structure end |
#group_name ⇒ String
The name of the security group.
8516 8517 8518 8519 8520 8521 8522 8523 8524 8525 |
# File 'lib/aws-sdk-securityhub/types.rb', line 8516 class AwsEc2SecurityGroupUserIdGroupPair < Struct.new( :group_id, :group_name, :peering_status, :user_id, :vpc_id, :vpc_peering_connection_id) SENSITIVE = [] include Aws::Structure end |
#peering_status ⇒ String
The status of a VPC peering connection, if applicable.
8516 8517 8518 8519 8520 8521 8522 8523 8524 8525 |
# File 'lib/aws-sdk-securityhub/types.rb', line 8516 class AwsEc2SecurityGroupUserIdGroupPair < Struct.new( :group_id, :group_name, :peering_status, :user_id, :vpc_id, :vpc_peering_connection_id) SENSITIVE = [] include Aws::Structure end |
#user_id ⇒ String
The ID of an Amazon Web Services account.
For a referenced security group in another VPC, the account ID of the referenced security group is returned in the response. If the referenced security group is deleted, this value is not returned.
[EC2-Classic] Required when adding or removing rules that reference a security group in another VPC.
8516 8517 8518 8519 8520 8521 8522 8523 8524 8525 |
# File 'lib/aws-sdk-securityhub/types.rb', line 8516 class AwsEc2SecurityGroupUserIdGroupPair < Struct.new( :group_id, :group_name, :peering_status, :user_id, :vpc_id, :vpc_peering_connection_id) SENSITIVE = [] include Aws::Structure end |
#vpc_id ⇒ String
The ID of the VPC for the referenced security group, if applicable.
8516 8517 8518 8519 8520 8521 8522 8523 8524 8525 |
# File 'lib/aws-sdk-securityhub/types.rb', line 8516 class AwsEc2SecurityGroupUserIdGroupPair < Struct.new( :group_id, :group_name, :peering_status, :user_id, :vpc_id, :vpc_peering_connection_id) SENSITIVE = [] include Aws::Structure end |
#vpc_peering_connection_id ⇒ String
The ID of the VPC peering connection, if applicable.
8516 8517 8518 8519 8520 8521 8522 8523 8524 8525 |
# File 'lib/aws-sdk-securityhub/types.rb', line 8516 class AwsEc2SecurityGroupUserIdGroupPair < Struct.new( :group_id, :group_name, :peering_status, :user_id, :vpc_id, :vpc_peering_connection_id) SENSITIVE = [] include Aws::Structure end |