Class: Aws::SecurityHub::Types::AwsEc2VolumeDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::AwsEc2VolumeDetails
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Details about an EC2 volume.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attachments ⇒ Array<Types::AwsEc2VolumeAttachment>
The volume attachments.
-
#create_time ⇒ String
Indicates when the volume was created.
-
#device_name ⇒ String
The device name for the volume that is attached to the instance.
-
#encrypted ⇒ Boolean
Specifies whether the volume is encrypted.
-
#kms_key_id ⇒ String
The ARN of the KMS key that was used to protect the volume encryption key for the volume.
-
#size ⇒ Integer
The size of the volume, in GiBs.
-
#snapshot_id ⇒ String
The snapshot from which the volume was created.
-
#status ⇒ String
The volume state.
-
#volume_id ⇒ String
The ID of the volume.
-
#volume_scan_status ⇒ String
Indicates whether the volume was scanned or skipped.
-
#volume_type ⇒ String
The volume type.
Instance Attribute Details
#attachments ⇒ Array<Types::AwsEc2VolumeAttachment>
The volume attachments.
8787 8788 8789 8790 8791 8792 8793 8794 8795 8796 8797 8798 8799 8800 8801 |
# File 'lib/aws-sdk-securityhub/types.rb', line 8787 class AwsEc2VolumeDetails < Struct.new( :create_time, :device_name, :encrypted, :size, :snapshot_id, :status, :kms_key_id, :attachments, :volume_id, :volume_type, :volume_scan_status) SENSITIVE = [] include Aws::Structure end |
#create_time ⇒ String
Indicates when the volume was created.
For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.
8787 8788 8789 8790 8791 8792 8793 8794 8795 8796 8797 8798 8799 8800 8801 |
# File 'lib/aws-sdk-securityhub/types.rb', line 8787 class AwsEc2VolumeDetails < Struct.new( :create_time, :device_name, :encrypted, :size, :snapshot_id, :status, :kms_key_id, :attachments, :volume_id, :volume_type, :volume_scan_status) SENSITIVE = [] include Aws::Structure end |
#device_name ⇒ String
The device name for the volume that is attached to the instance.
8787 8788 8789 8790 8791 8792 8793 8794 8795 8796 8797 8798 8799 8800 8801 |
# File 'lib/aws-sdk-securityhub/types.rb', line 8787 class AwsEc2VolumeDetails < Struct.new( :create_time, :device_name, :encrypted, :size, :snapshot_id, :status, :kms_key_id, :attachments, :volume_id, :volume_type, :volume_scan_status) SENSITIVE = [] include Aws::Structure end |
#encrypted ⇒ Boolean
Specifies whether the volume is encrypted.
8787 8788 8789 8790 8791 8792 8793 8794 8795 8796 8797 8798 8799 8800 8801 |
# File 'lib/aws-sdk-securityhub/types.rb', line 8787 class AwsEc2VolumeDetails < Struct.new( :create_time, :device_name, :encrypted, :size, :snapshot_id, :status, :kms_key_id, :attachments, :volume_id, :volume_type, :volume_scan_status) SENSITIVE = [] include Aws::Structure end |
#kms_key_id ⇒ String
The ARN of the KMS key that was used to protect the volume encryption key for the volume.
8787 8788 8789 8790 8791 8792 8793 8794 8795 8796 8797 8798 8799 8800 8801 |
# File 'lib/aws-sdk-securityhub/types.rb', line 8787 class AwsEc2VolumeDetails < Struct.new( :create_time, :device_name, :encrypted, :size, :snapshot_id, :status, :kms_key_id, :attachments, :volume_id, :volume_type, :volume_scan_status) SENSITIVE = [] include Aws::Structure end |
#size ⇒ Integer
The size of the volume, in GiBs.
8787 8788 8789 8790 8791 8792 8793 8794 8795 8796 8797 8798 8799 8800 8801 |
# File 'lib/aws-sdk-securityhub/types.rb', line 8787 class AwsEc2VolumeDetails < Struct.new( :create_time, :device_name, :encrypted, :size, :snapshot_id, :status, :kms_key_id, :attachments, :volume_id, :volume_type, :volume_scan_status) SENSITIVE = [] include Aws::Structure end |
#snapshot_id ⇒ String
The snapshot from which the volume was created.
8787 8788 8789 8790 8791 8792 8793 8794 8795 8796 8797 8798 8799 8800 8801 |
# File 'lib/aws-sdk-securityhub/types.rb', line 8787 class AwsEc2VolumeDetails < Struct.new( :create_time, :device_name, :encrypted, :size, :snapshot_id, :status, :kms_key_id, :attachments, :volume_id, :volume_type, :volume_scan_status) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The volume state. Valid values are as follows:
-
available -
creating -
deleted -
deleting -
error -
in-use
8787 8788 8789 8790 8791 8792 8793 8794 8795 8796 8797 8798 8799 8800 8801 |
# File 'lib/aws-sdk-securityhub/types.rb', line 8787 class AwsEc2VolumeDetails < Struct.new( :create_time, :device_name, :encrypted, :size, :snapshot_id, :status, :kms_key_id, :attachments, :volume_id, :volume_type, :volume_scan_status) SENSITIVE = [] include Aws::Structure end |
#volume_id ⇒ String
The ID of the volume.
8787 8788 8789 8790 8791 8792 8793 8794 8795 8796 8797 8798 8799 8800 8801 |
# File 'lib/aws-sdk-securityhub/types.rb', line 8787 class AwsEc2VolumeDetails < Struct.new( :create_time, :device_name, :encrypted, :size, :snapshot_id, :status, :kms_key_id, :attachments, :volume_id, :volume_type, :volume_scan_status) SENSITIVE = [] include Aws::Structure end |
#volume_scan_status ⇒ String
Indicates whether the volume was scanned or skipped.
8787 8788 8789 8790 8791 8792 8793 8794 8795 8796 8797 8798 8799 8800 8801 |
# File 'lib/aws-sdk-securityhub/types.rb', line 8787 class AwsEc2VolumeDetails < Struct.new( :create_time, :device_name, :encrypted, :size, :snapshot_id, :status, :kms_key_id, :attachments, :volume_id, :volume_type, :volume_scan_status) SENSITIVE = [] include Aws::Structure end |
#volume_type ⇒ String
The volume type.
8787 8788 8789 8790 8791 8792 8793 8794 8795 8796 8797 8798 8799 8800 8801 |
# File 'lib/aws-sdk-securityhub/types.rb', line 8787 class AwsEc2VolumeDetails < Struct.new( :create_time, :device_name, :encrypted, :size, :snapshot_id, :status, :kms_key_id, :attachments, :volume_id, :volume_type, :volume_scan_status) SENSITIVE = [] include Aws::Structure end |