Class: Aws::SecurityHub::Types::AwsEcrContainerImageDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::AwsEcrContainerImageDetails
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Information about an Amazon ECR image.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#architecture ⇒ String
The architecture of the image.
-
#image_digest ⇒ String
The sha256 digest of the image manifest.
-
#image_published_at ⇒ String
The date and time when the image was pushed to the repository.
-
#image_tags ⇒ Array<String>
The list of tags that are associated with the image.
-
#registry_id ⇒ String
The Amazon Web Services account identifier that is associated with the registry that the image belongs to.
-
#repository_name ⇒ String
The name of the repository that the image belongs to.
Instance Attribute Details
#architecture ⇒ String
The architecture of the image. Valid values are as follows:
-
arm64 -
i386 -
x86_64
9465 9466 9467 9468 9469 9470 9471 9472 9473 9474 |
# File 'lib/aws-sdk-securityhub/types.rb', line 9465 class AwsEcrContainerImageDetails < Struct.new( :registry_id, :repository_name, :architecture, :image_digest, :image_tags, :image_published_at) SENSITIVE = [] include Aws::Structure end |
#image_digest ⇒ String
The sha256 digest of the image manifest.
9465 9466 9467 9468 9469 9470 9471 9472 9473 9474 |
# File 'lib/aws-sdk-securityhub/types.rb', line 9465 class AwsEcrContainerImageDetails < Struct.new( :registry_id, :repository_name, :architecture, :image_digest, :image_tags, :image_published_at) SENSITIVE = [] include Aws::Structure end |
#image_published_at ⇒ String
The date and time when the image was pushed to the repository.
For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.
9465 9466 9467 9468 9469 9470 9471 9472 9473 9474 |
# File 'lib/aws-sdk-securityhub/types.rb', line 9465 class AwsEcrContainerImageDetails < Struct.new( :registry_id, :repository_name, :architecture, :image_digest, :image_tags, :image_published_at) SENSITIVE = [] include Aws::Structure end |
#image_tags ⇒ Array<String>
The list of tags that are associated with the image.
9465 9466 9467 9468 9469 9470 9471 9472 9473 9474 |
# File 'lib/aws-sdk-securityhub/types.rb', line 9465 class AwsEcrContainerImageDetails < Struct.new( :registry_id, :repository_name, :architecture, :image_digest, :image_tags, :image_published_at) SENSITIVE = [] include Aws::Structure end |
#registry_id ⇒ String
The Amazon Web Services account identifier that is associated with the registry that the image belongs to.
9465 9466 9467 9468 9469 9470 9471 9472 9473 9474 |
# File 'lib/aws-sdk-securityhub/types.rb', line 9465 class AwsEcrContainerImageDetails < Struct.new( :registry_id, :repository_name, :architecture, :image_digest, :image_tags, :image_published_at) SENSITIVE = [] include Aws::Structure end |
#repository_name ⇒ String
The name of the repository that the image belongs to.
9465 9466 9467 9468 9469 9470 9471 9472 9473 9474 |
# File 'lib/aws-sdk-securityhub/types.rb', line 9465 class AwsEcrContainerImageDetails < Struct.new( :registry_id, :repository_name, :architecture, :image_digest, :image_tags, :image_published_at) SENSITIVE = [] include Aws::Structure end |