Class: Aws::SecurityHub::Types::AwsEcrContainerImageDetails

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

Information about an Amazon ECR image.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#architectureString

The architecture of the image. Valid values are as follows:

  • arm64

  • i386

  • x86_64

Returns:

  • (String)


9436
9437
9438
9439
9440
9441
9442
9443
9444
9445
# File 'lib/aws-sdk-securityhub/types.rb', line 9436

class AwsEcrContainerImageDetails < Struct.new(
  :registry_id,
  :repository_name,
  :architecture,
  :image_digest,
  :image_tags,
  :image_published_at)
  SENSITIVE = []
  include Aws::Structure
end

#image_digestString

The sha256 digest of the image manifest.

Returns:

  • (String)


9436
9437
9438
9439
9440
9441
9442
9443
9444
9445
# File 'lib/aws-sdk-securityhub/types.rb', line 9436

class AwsEcrContainerImageDetails < Struct.new(
  :registry_id,
  :repository_name,
  :architecture,
  :image_digest,
  :image_tags,
  :image_published_at)
  SENSITIVE = []
  include Aws::Structure
end

#image_published_atString

The date and time when the image was pushed to the repository.

For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.

Returns:

  • (String)


9436
9437
9438
9439
9440
9441
9442
9443
9444
9445
# File 'lib/aws-sdk-securityhub/types.rb', line 9436

class AwsEcrContainerImageDetails < Struct.new(
  :registry_id,
  :repository_name,
  :architecture,
  :image_digest,
  :image_tags,
  :image_published_at)
  SENSITIVE = []
  include Aws::Structure
end

#image_tagsArray<String>

The list of tags that are associated with the image.

Returns:

  • (Array<String>)


9436
9437
9438
9439
9440
9441
9442
9443
9444
9445
# File 'lib/aws-sdk-securityhub/types.rb', line 9436

class AwsEcrContainerImageDetails < Struct.new(
  :registry_id,
  :repository_name,
  :architecture,
  :image_digest,
  :image_tags,
  :image_published_at)
  SENSITIVE = []
  include Aws::Structure
end

#registry_idString

The Amazon Web Services account identifier that is associated with the registry that the image belongs to.

Returns:

  • (String)


9436
9437
9438
9439
9440
9441
9442
9443
9444
9445
# File 'lib/aws-sdk-securityhub/types.rb', line 9436

class AwsEcrContainerImageDetails < Struct.new(
  :registry_id,
  :repository_name,
  :architecture,
  :image_digest,
  :image_tags,
  :image_published_at)
  SENSITIVE = []
  include Aws::Structure
end

#repository_nameString

The name of the repository that the image belongs to.

Returns:

  • (String)


9436
9437
9438
9439
9440
9441
9442
9443
9444
9445
# File 'lib/aws-sdk-securityhub/types.rb', line 9436

class AwsEcrContainerImageDetails < Struct.new(
  :registry_id,
  :repository_name,
  :architecture,
  :image_digest,
  :image_tags,
  :image_published_at)
  SENSITIVE = []
  include Aws::Structure
end