Class: Aws::SecurityHub::Types::AwsEcsClusterDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::AwsEcsClusterDetails
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Provides details about an Amazon ECS cluster.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#active_services_count ⇒ Integer
The number of services that are running on the cluster in an
ACTIVEstate. -
#capacity_providers ⇒ Array<String>
The short name of one or more capacity providers to associate with the cluster.
-
#cluster_arn ⇒ String
The Amazon Resource Name (ARN) that identifies the cluster.
-
#cluster_name ⇒ String
A name that you use to identify your cluster.
-
#cluster_settings ⇒ Array<Types::AwsEcsClusterClusterSettingsDetails>
The setting to use to create the cluster.
-
#configuration ⇒ Types::AwsEcsClusterConfigurationDetails
The run command configuration for the cluster.
-
#default_capacity_provider_strategy ⇒ Array<Types::AwsEcsClusterDefaultCapacityProviderStrategyDetails>
The default capacity provider strategy for the cluster.
-
#registered_container_instances_count ⇒ Integer
The number of container instances registered into the cluster.
-
#running_tasks_count ⇒ Integer
The number of tasks in the cluster that are in the
RUNNINGstate. -
#status ⇒ String
The status of the cluster.
Instance Attribute Details
#active_services_count ⇒ Integer
The number of services that are running on the cluster in an
ACTIVE state. You can view these services with the Amazon ECS
ListServices API operation.
9729 9730 9731 9732 9733 9734 9735 9736 9737 9738 9739 9740 9741 9742 |
# File 'lib/aws-sdk-securityhub/types.rb', line 9729 class AwsEcsClusterDetails < Struct.new( :cluster_arn, :active_services_count, :capacity_providers, :cluster_settings, :configuration, :default_capacity_provider_strategy, :cluster_name, :registered_container_instances_count, :running_tasks_count, :status) SENSITIVE = [] include Aws::Structure end |
#capacity_providers ⇒ Array<String>
The short name of one or more capacity providers to associate with the cluster.
9729 9730 9731 9732 9733 9734 9735 9736 9737 9738 9739 9740 9741 9742 |
# File 'lib/aws-sdk-securityhub/types.rb', line 9729 class AwsEcsClusterDetails < Struct.new( :cluster_arn, :active_services_count, :capacity_providers, :cluster_settings, :configuration, :default_capacity_provider_strategy, :cluster_name, :registered_container_instances_count, :running_tasks_count, :status) SENSITIVE = [] include Aws::Structure end |
#cluster_arn ⇒ String
The Amazon Resource Name (ARN) that identifies the cluster.
9729 9730 9731 9732 9733 9734 9735 9736 9737 9738 9739 9740 9741 9742 |
# File 'lib/aws-sdk-securityhub/types.rb', line 9729 class AwsEcsClusterDetails < Struct.new( :cluster_arn, :active_services_count, :capacity_providers, :cluster_settings, :configuration, :default_capacity_provider_strategy, :cluster_name, :registered_container_instances_count, :running_tasks_count, :status) SENSITIVE = [] include Aws::Structure end |
#cluster_name ⇒ String
A name that you use to identify your cluster.
9729 9730 9731 9732 9733 9734 9735 9736 9737 9738 9739 9740 9741 9742 |
# File 'lib/aws-sdk-securityhub/types.rb', line 9729 class AwsEcsClusterDetails < Struct.new( :cluster_arn, :active_services_count, :capacity_providers, :cluster_settings, :configuration, :default_capacity_provider_strategy, :cluster_name, :registered_container_instances_count, :running_tasks_count, :status) SENSITIVE = [] include Aws::Structure end |
#cluster_settings ⇒ Array<Types::AwsEcsClusterClusterSettingsDetails>
The setting to use to create the cluster. Specifically used to configure whether to enable CloudWatch Container Insights for the cluster.
9729 9730 9731 9732 9733 9734 9735 9736 9737 9738 9739 9740 9741 9742 |
# File 'lib/aws-sdk-securityhub/types.rb', line 9729 class AwsEcsClusterDetails < Struct.new( :cluster_arn, :active_services_count, :capacity_providers, :cluster_settings, :configuration, :default_capacity_provider_strategy, :cluster_name, :registered_container_instances_count, :running_tasks_count, :status) SENSITIVE = [] include Aws::Structure end |
#configuration ⇒ Types::AwsEcsClusterConfigurationDetails
The run command configuration for the cluster.
9729 9730 9731 9732 9733 9734 9735 9736 9737 9738 9739 9740 9741 9742 |
# File 'lib/aws-sdk-securityhub/types.rb', line 9729 class AwsEcsClusterDetails < Struct.new( :cluster_arn, :active_services_count, :capacity_providers, :cluster_settings, :configuration, :default_capacity_provider_strategy, :cluster_name, :registered_container_instances_count, :running_tasks_count, :status) SENSITIVE = [] include Aws::Structure end |
#default_capacity_provider_strategy ⇒ Array<Types::AwsEcsClusterDefaultCapacityProviderStrategyDetails>
The default capacity provider strategy for the cluster. The default capacity provider strategy is used when services or tasks are run without a specified launch type or capacity provider strategy.
9729 9730 9731 9732 9733 9734 9735 9736 9737 9738 9739 9740 9741 9742 |
# File 'lib/aws-sdk-securityhub/types.rb', line 9729 class AwsEcsClusterDetails < Struct.new( :cluster_arn, :active_services_count, :capacity_providers, :cluster_settings, :configuration, :default_capacity_provider_strategy, :cluster_name, :registered_container_instances_count, :running_tasks_count, :status) SENSITIVE = [] include Aws::Structure end |
#registered_container_instances_count ⇒ Integer
The number of container instances registered into the cluster. This
includes container instances in both ACTIVE and DRAINING status.
9729 9730 9731 9732 9733 9734 9735 9736 9737 9738 9739 9740 9741 9742 |
# File 'lib/aws-sdk-securityhub/types.rb', line 9729 class AwsEcsClusterDetails < Struct.new( :cluster_arn, :active_services_count, :capacity_providers, :cluster_settings, :configuration, :default_capacity_provider_strategy, :cluster_name, :registered_container_instances_count, :running_tasks_count, :status) SENSITIVE = [] include Aws::Structure end |
#running_tasks_count ⇒ Integer
The number of tasks in the cluster that are in the RUNNING state.
9729 9730 9731 9732 9733 9734 9735 9736 9737 9738 9739 9740 9741 9742 |
# File 'lib/aws-sdk-securityhub/types.rb', line 9729 class AwsEcsClusterDetails < Struct.new( :cluster_arn, :active_services_count, :capacity_providers, :cluster_settings, :configuration, :default_capacity_provider_strategy, :cluster_name, :registered_container_instances_count, :running_tasks_count, :status) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the cluster.
9729 9730 9731 9732 9733 9734 9735 9736 9737 9738 9739 9740 9741 9742 |
# File 'lib/aws-sdk-securityhub/types.rb', line 9729 class AwsEcsClusterDetails < Struct.new( :cluster_arn, :active_services_count, :capacity_providers, :cluster_settings, :configuration, :default_capacity_provider_strategy, :cluster_name, :registered_container_instances_count, :running_tasks_count, :status) SENSITIVE = [] include Aws::Structure end |