Class: Aws::SecurityHub::Types::AwsEcsClusterDetails

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

Provides details about an Amazon ECS cluster.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#active_services_countInteger

The number of services that are running on the cluster in an ACTIVE state. You can view these services with the Amazon ECS ListServices API operation.

Returns:

  • (Integer)


9599
9600
9601
9602
9603
9604
9605
9606
9607
9608
9609
9610
9611
9612
# File 'lib/aws-sdk-securityhub/types.rb', line 9599

class AwsEcsClusterDetails < Struct.new(
  :cluster_arn,
  :active_services_count,
  :capacity_providers,
  :cluster_settings,
  :configuration,
  :default_capacity_provider_strategy,
  :cluster_name,
  :registered_container_instances_count,
  :running_tasks_count,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#capacity_providersArray<String>

The short name of one or more capacity providers to associate with the cluster.

Returns:

  • (Array<String>)


9599
9600
9601
9602
9603
9604
9605
9606
9607
9608
9609
9610
9611
9612
# File 'lib/aws-sdk-securityhub/types.rb', line 9599

class AwsEcsClusterDetails < Struct.new(
  :cluster_arn,
  :active_services_count,
  :capacity_providers,
  :cluster_settings,
  :configuration,
  :default_capacity_provider_strategy,
  :cluster_name,
  :registered_container_instances_count,
  :running_tasks_count,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#cluster_arnString

The Amazon Resource Name (ARN) that identifies the cluster.

Returns:

  • (String)


9599
9600
9601
9602
9603
9604
9605
9606
9607
9608
9609
9610
9611
9612
# File 'lib/aws-sdk-securityhub/types.rb', line 9599

class AwsEcsClusterDetails < Struct.new(
  :cluster_arn,
  :active_services_count,
  :capacity_providers,
  :cluster_settings,
  :configuration,
  :default_capacity_provider_strategy,
  :cluster_name,
  :registered_container_instances_count,
  :running_tasks_count,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#cluster_nameString

A name that you use to identify your cluster.

Returns:

  • (String)


9599
9600
9601
9602
9603
9604
9605
9606
9607
9608
9609
9610
9611
9612
# File 'lib/aws-sdk-securityhub/types.rb', line 9599

class AwsEcsClusterDetails < Struct.new(
  :cluster_arn,
  :active_services_count,
  :capacity_providers,
  :cluster_settings,
  :configuration,
  :default_capacity_provider_strategy,
  :cluster_name,
  :registered_container_instances_count,
  :running_tasks_count,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#cluster_settingsArray<Types::AwsEcsClusterClusterSettingsDetails>

The setting to use to create the cluster. Specifically used to configure whether to enable CloudWatch Container Insights for the cluster.



9599
9600
9601
9602
9603
9604
9605
9606
9607
9608
9609
9610
9611
9612
# File 'lib/aws-sdk-securityhub/types.rb', line 9599

class AwsEcsClusterDetails < Struct.new(
  :cluster_arn,
  :active_services_count,
  :capacity_providers,
  :cluster_settings,
  :configuration,
  :default_capacity_provider_strategy,
  :cluster_name,
  :registered_container_instances_count,
  :running_tasks_count,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#configurationTypes::AwsEcsClusterConfigurationDetails

The run command configuration for the cluster.



9599
9600
9601
9602
9603
9604
9605
9606
9607
9608
9609
9610
9611
9612
# File 'lib/aws-sdk-securityhub/types.rb', line 9599

class AwsEcsClusterDetails < Struct.new(
  :cluster_arn,
  :active_services_count,
  :capacity_providers,
  :cluster_settings,
  :configuration,
  :default_capacity_provider_strategy,
  :cluster_name,
  :registered_container_instances_count,
  :running_tasks_count,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#default_capacity_provider_strategyArray<Types::AwsEcsClusterDefaultCapacityProviderStrategyDetails>

The default capacity provider strategy for the cluster. The default capacity provider strategy is used when services or tasks are run without a specified launch type or capacity provider strategy.



9599
9600
9601
9602
9603
9604
9605
9606
9607
9608
9609
9610
9611
9612
# File 'lib/aws-sdk-securityhub/types.rb', line 9599

class AwsEcsClusterDetails < Struct.new(
  :cluster_arn,
  :active_services_count,
  :capacity_providers,
  :cluster_settings,
  :configuration,
  :default_capacity_provider_strategy,
  :cluster_name,
  :registered_container_instances_count,
  :running_tasks_count,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#registered_container_instances_countInteger

The number of container instances registered into the cluster. This includes container instances in both ACTIVE and DRAINING status.

Returns:

  • (Integer)


9599
9600
9601
9602
9603
9604
9605
9606
9607
9608
9609
9610
9611
9612
# File 'lib/aws-sdk-securityhub/types.rb', line 9599

class AwsEcsClusterDetails < Struct.new(
  :cluster_arn,
  :active_services_count,
  :capacity_providers,
  :cluster_settings,
  :configuration,
  :default_capacity_provider_strategy,
  :cluster_name,
  :registered_container_instances_count,
  :running_tasks_count,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#running_tasks_countInteger

The number of tasks in the cluster that are in the RUNNING state.

Returns:

  • (Integer)


9599
9600
9601
9602
9603
9604
9605
9606
9607
9608
9609
9610
9611
9612
# File 'lib/aws-sdk-securityhub/types.rb', line 9599

class AwsEcsClusterDetails < Struct.new(
  :cluster_arn,
  :active_services_count,
  :capacity_providers,
  :cluster_settings,
  :configuration,
  :default_capacity_provider_strategy,
  :cluster_name,
  :registered_container_instances_count,
  :running_tasks_count,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the cluster.

Returns:

  • (String)


9599
9600
9601
9602
9603
9604
9605
9606
9607
9608
9609
9610
9611
9612
# File 'lib/aws-sdk-securityhub/types.rb', line 9599

class AwsEcsClusterDetails < Struct.new(
  :cluster_arn,
  :active_services_count,
  :capacity_providers,
  :cluster_settings,
  :configuration,
  :default_capacity_provider_strategy,
  :cluster_name,
  :registered_container_instances_count,
  :running_tasks_count,
  :status)
  SENSITIVE = []
  include Aws::Structure
end