Class: Aws::SecurityHub::Types::AwsEcsServiceCapacityProviderStrategyDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::AwsEcsServiceCapacityProviderStrategyDetails
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Strategy item for the capacity provider strategy that the service uses.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#base ⇒ Integer
The minimum number of tasks to run on the capacity provider.
-
#capacity_provider ⇒ String
The short name of the capacity provider.
-
#weight ⇒ Integer
The relative percentage of the total number of tasks that should use the capacity provider.
Instance Attribute Details
#base ⇒ Integer
The minimum number of tasks to run on the capacity provider. Only
one strategy item can specify a value for Base.
The value must be between 0 and 100000.
9772 9773 9774 9775 9776 9777 9778 |
# File 'lib/aws-sdk-securityhub/types.rb', line 9772 class AwsEcsServiceCapacityProviderStrategyDetails < Struct.new( :base, :capacity_provider, :weight) SENSITIVE = [] include Aws::Structure end |
#capacity_provider ⇒ String
The short name of the capacity provider.
9772 9773 9774 9775 9776 9777 9778 |
# File 'lib/aws-sdk-securityhub/types.rb', line 9772 class AwsEcsServiceCapacityProviderStrategyDetails < Struct.new( :base, :capacity_provider, :weight) SENSITIVE = [] include Aws::Structure end |
#weight ⇒ Integer
The relative percentage of the total number of tasks that should use the capacity provider.
If no weight is specified, the default value is 0. At least one capacity provider must have a weight greater than 0.
The value can be between 0 and 1000.
9772 9773 9774 9775 9776 9777 9778 |
# File 'lib/aws-sdk-securityhub/types.rb', line 9772 class AwsEcsServiceCapacityProviderStrategyDetails < Struct.new( :base, :capacity_provider, :weight) SENSITIVE = [] include Aws::Structure end |