Method: Aws::SecurityHub::Types::AwsEcsServiceCapacityProviderStrategyDetails#base
- Defined in:
- lib/aws-sdk-securityhub/types.rb
#base ⇒ Integer
The minimum number of tasks to run on the capacity provider. Only one strategy item can specify a value for Base.
The value must be between 0 and 100000.
9651 9652 9653 9654 9655 9656 9657 |
# File 'lib/aws-sdk-securityhub/types.rb', line 9651 class AwsEcsServiceCapacityProviderStrategyDetails < Struct.new( :base, :capacity_provider, :weight) SENSITIVE = [] include Aws::Structure end |