Method: Aws::SecurityHub::Types::AwsEcsServiceServiceRegistriesDetails#container_name
- Defined in:
- lib/aws-sdk-securityhub/types.rb
#container_name ⇒ String
The container name value to use for the service discovery service.
If the task definition uses the bridge or host network mode, you must specify ContainerName and ContainerPort.
If the task definition uses the awsvpc network mode and a type SRV DNS record, you must specify either ContainerName and ContainerPort, or Port , but not both.
10106 10107 10108 10109 10110 10111 10112 10113 |
# File 'lib/aws-sdk-securityhub/types.rb', line 10106 class AwsEcsServiceServiceRegistriesDetails < Struct.new( :container_name, :container_port, :port, :registry_arn) SENSITIVE = [] include Aws::Structure end |