Class: Aws::SecurityHub::Types::AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersCapabilitiesDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersCapabilitiesDetails
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
The Linux capabilities for the container that are added to or dropped from the default configuration provided by Docker.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#add ⇒ Array<String>
The Linux capabilities for the container that are added to the default configuration provided by Docker.
-
#drop ⇒ Array<String>
The Linux capabilities for the container that are dropped from the default configuration provided by Docker.
Instance Attribute Details
#add ⇒ Array<String>
The Linux capabilities for the container that are added to the default configuration provided by Docker. Valid values are as follows:
Valid values: ‘“ALL”` \| `“AUDIT_CONTROL”` \|` “AUDIT_WRITE”` \| `“BLOCK_SUSPEND”` \| `“CHOWN”` \| `“DAC_OVERRIDE”` \| `“DAC_READ_SEARCH”` \| `“FOWNER”` \| `“FSETID”` \| `“IPC_LOCK”` \| `“IPC_OWNER”` \| `“KILL”` \| `“LEASE”` \| `“LINUX_IMMUTABLE”` \| `“MAC_ADMIN”` \|` “MAC_OVERRIDE”` \| `“MKNOD”` \| `“NET_ADMIN”` \| `“NET_BIND_SERVICE”` \| `“NET_BROADCAST”` \| `“NET_RAW”` \| `“SETFCAP”` \| `“SETGID”` \| `“SETPCAP”` \| `“SETUID”` \| `“SYS_ADMIN”` \| `“SYS_BOOT”` \| `“SYS_CHROOT”` \| `“SYS_MODULE”` \| `“SYS_NICE”` \| `“SYS_PACCT”` \| `“SYS_PTRACE”` \| `“SYS_RAWIO”` \| `“SYS_RESOURCE”` \| `“SYS_TIME”` \| `“SYS_TTY_CONFIG”` \| `“SYSLOG”` \| `“WAKE_ALARM”`
10553 10554 10555 10556 10557 10558 |
# File 'lib/aws-sdk-securityhub/types.rb', line 10553 class AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersCapabilitiesDetails < Struct.new( :add, :drop) SENSITIVE = [] include Aws::Structure end |
#drop ⇒ Array<String>
The Linux capabilities for the container that are dropped from the default configuration provided by Docker.
Valid values: ‘“ALL”` \| `“AUDIT_CONTROL”` \|` “AUDIT_WRITE”` \| `“BLOCK_SUSPEND”` \| `“CHOWN”` \| `“DAC_OVERRIDE”` \| `“DAC_READ_SEARCH”` \| `“FOWNER”` \| `“FSETID”` \| `“IPC_LOCK”` \| `“IPC_OWNER”` \| `“KILL”` \| `“LEASE”` \| `“LINUX_IMMUTABLE”` \| `“MAC_ADMIN”` \|` “MAC_OVERRIDE”` \| `“MKNOD”` \| `“NET_ADMIN”` \| `“NET_BIND_SERVICE”` \| `“NET_BROADCAST”` \| `“NET_RAW”` \| `“SETFCAP”` \| `“SETGID”` \| `“SETPCAP”` \| `“SETUID”` \| `“SYS_ADMIN”` \| `“SYS_BOOT”` \| `“SYS_CHROOT”` \| `“SYS_MODULE”` \| `“SYS_NICE”` \| `“SYS_PACCT”` \| `“SYS_PTRACE”` \| `“SYS_RAWIO”` \| `“SYS_RESOURCE”` \| `“SYS_TIME”` \| `“SYS_TTY_CONFIG”` \| `“SYSLOG”` \| `“WAKE_ALARM”`
10553 10554 10555 10556 10557 10558 |
# File 'lib/aws-sdk-securityhub/types.rb', line 10553 class AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersCapabilitiesDetails < Struct.new( :add, :drop) SENSITIVE = [] include Aws::Structure end |