Class: Aws::SecurityHub::Types::AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersDetails

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

>Linux-specific modifications that are applied to the container, such as Linux kernel capabilities.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#capabilitiesTypes::AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersCapabilitiesDetails

The Linux capabilities for the container that are added to or dropped from the default configuration provided by Docker.



10718
10719
10720
10721
10722
10723
10724
10725
10726
10727
10728
# File 'lib/aws-sdk-securityhub/types.rb', line 10718

class AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersDetails < Struct.new(
  :capabilities,
  :devices,
  :init_process_enabled,
  :max_swap,
  :shared_memory_size,
  :swappiness,
  :tmpfs)
  SENSITIVE = []
  include Aws::Structure
end

#devicesArray<Types::AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersDevicesDetails>

The host devices to expose to the container.



10718
10719
10720
10721
10722
10723
10724
10725
10726
10727
10728
# File 'lib/aws-sdk-securityhub/types.rb', line 10718

class AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersDetails < Struct.new(
  :capabilities,
  :devices,
  :init_process_enabled,
  :max_swap,
  :shared_memory_size,
  :swappiness,
  :tmpfs)
  SENSITIVE = []
  include Aws::Structure
end

#init_process_enabledBoolean

Whether to run an init process inside the container that forwards signals and reaps processes.

Returns:

  • (Boolean)


10718
10719
10720
10721
10722
10723
10724
10725
10726
10727
10728
# File 'lib/aws-sdk-securityhub/types.rb', line 10718

class AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersDetails < Struct.new(
  :capabilities,
  :devices,
  :init_process_enabled,
  :max_swap,
  :shared_memory_size,
  :swappiness,
  :tmpfs)
  SENSITIVE = []
  include Aws::Structure
end

#max_swapInteger

The total amount of swap memory (in MiB) that a container can use.

Returns:

  • (Integer)


10718
10719
10720
10721
10722
10723
10724
10725
10726
10727
10728
# File 'lib/aws-sdk-securityhub/types.rb', line 10718

class AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersDetails < Struct.new(
  :capabilities,
  :devices,
  :init_process_enabled,
  :max_swap,
  :shared_memory_size,
  :swappiness,
  :tmpfs)
  SENSITIVE = []
  include Aws::Structure
end

#shared_memory_sizeInteger

The value for the size (in MiB) of the /dev/shm volume.

Returns:

  • (Integer)


10718
10719
10720
10721
10722
10723
10724
10725
10726
10727
10728
# File 'lib/aws-sdk-securityhub/types.rb', line 10718

class AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersDetails < Struct.new(
  :capabilities,
  :devices,
  :init_process_enabled,
  :max_swap,
  :shared_memory_size,
  :swappiness,
  :tmpfs)
  SENSITIVE = []
  include Aws::Structure
end

#swappinessInteger

Configures the container's memory swappiness behavior. Determines how aggressively pages are swapped. The higher the value, the more aggressive the swappiness. The default is 60.

Returns:

  • (Integer)


10718
10719
10720
10721
10722
10723
10724
10725
10726
10727
10728
# File 'lib/aws-sdk-securityhub/types.rb', line 10718

class AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersDetails < Struct.new(
  :capabilities,
  :devices,
  :init_process_enabled,
  :max_swap,
  :shared_memory_size,
  :swappiness,
  :tmpfs)
  SENSITIVE = []
  include Aws::Structure
end

#tmpfsArray<Types::AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersTmpfsDetails>

The container path, mount options, and size (in MiB) of the tmpfs mount.



10718
10719
10720
10721
10722
10723
10724
10725
10726
10727
10728
# File 'lib/aws-sdk-securityhub/types.rb', line 10718

class AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersDetails < Struct.new(
  :capabilities,
  :devices,
  :init_process_enabled,
  :max_swap,
  :shared_memory_size,
  :swappiness,
  :tmpfs)
  SENSITIVE = []
  include Aws::Structure
end