Class: Aws::SecurityHub::Types::AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersDetails
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
>Linux-specific modifications that are applied to the container, such as Linux kernel capabilities.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#capabilities ⇒ Types::AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersCapabilitiesDetails
The Linux capabilities for the container that are added to or dropped from the default configuration provided by Docker.
-
#devices ⇒ Array<Types::AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersDevicesDetails>
The host devices to expose to the container.
-
#init_process_enabled ⇒ Boolean
Whether to run an
initprocess inside the container that forwards signals and reaps processes. -
#max_swap ⇒ Integer
The total amount of swap memory (in MiB) that a container can use.
-
#shared_memory_size ⇒ Integer
The value for the size (in MiB) of the /dev/shm volume.
-
#swappiness ⇒ Integer
Configures the container's memory swappiness behavior.
-
#tmpfs ⇒ Array<Types::AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersTmpfsDetails>
The container path, mount options, and size (in MiB) of the tmpfs mount.
Instance Attribute Details
#capabilities ⇒ Types::AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersCapabilitiesDetails
The Linux capabilities for the container that are added to or dropped from the default configuration provided by Docker.
10718 10719 10720 10721 10722 10723 10724 10725 10726 10727 10728 |
# File 'lib/aws-sdk-securityhub/types.rb', line 10718 class AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersDetails < Struct.new( :capabilities, :devices, :init_process_enabled, :max_swap, :shared_memory_size, :swappiness, :tmpfs) SENSITIVE = [] include Aws::Structure end |
#devices ⇒ Array<Types::AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersDevicesDetails>
The host devices to expose to the container.
10718 10719 10720 10721 10722 10723 10724 10725 10726 10727 10728 |
# File 'lib/aws-sdk-securityhub/types.rb', line 10718 class AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersDetails < Struct.new( :capabilities, :devices, :init_process_enabled, :max_swap, :shared_memory_size, :swappiness, :tmpfs) SENSITIVE = [] include Aws::Structure end |
#init_process_enabled ⇒ Boolean
Whether to run an init process inside the container that forwards
signals and reaps processes.
10718 10719 10720 10721 10722 10723 10724 10725 10726 10727 10728 |
# File 'lib/aws-sdk-securityhub/types.rb', line 10718 class AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersDetails < Struct.new( :capabilities, :devices, :init_process_enabled, :max_swap, :shared_memory_size, :swappiness, :tmpfs) SENSITIVE = [] include Aws::Structure end |
#max_swap ⇒ Integer
The total amount of swap memory (in MiB) that a container can use.
10718 10719 10720 10721 10722 10723 10724 10725 10726 10727 10728 |
# File 'lib/aws-sdk-securityhub/types.rb', line 10718 class AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersDetails < Struct.new( :capabilities, :devices, :init_process_enabled, :max_swap, :shared_memory_size, :swappiness, :tmpfs) SENSITIVE = [] include Aws::Structure end |
#shared_memory_size ⇒ Integer
The value for the size (in MiB) of the /dev/shm volume.
10718 10719 10720 10721 10722 10723 10724 10725 10726 10727 10728 |
# File 'lib/aws-sdk-securityhub/types.rb', line 10718 class AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersDetails < Struct.new( :capabilities, :devices, :init_process_enabled, :max_swap, :shared_memory_size, :swappiness, :tmpfs) SENSITIVE = [] include Aws::Structure end |
#swappiness ⇒ Integer
Configures the container's memory swappiness behavior. Determines how aggressively pages are swapped. The higher the value, the more aggressive the swappiness. The default is 60.
10718 10719 10720 10721 10722 10723 10724 10725 10726 10727 10728 |
# File 'lib/aws-sdk-securityhub/types.rb', line 10718 class AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersDetails < Struct.new( :capabilities, :devices, :init_process_enabled, :max_swap, :shared_memory_size, :swappiness, :tmpfs) SENSITIVE = [] include Aws::Structure end |
#tmpfs ⇒ Array<Types::AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersTmpfsDetails>
The container path, mount options, and size (in MiB) of the tmpfs mount.
10718 10719 10720 10721 10722 10723 10724 10725 10726 10727 10728 |
# File 'lib/aws-sdk-securityhub/types.rb', line 10718 class AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersDetails < Struct.new( :capabilities, :devices, :init_process_enabled, :max_swap, :shared_memory_size, :swappiness, :tmpfs) SENSITIVE = [] include Aws::Structure end |