Class: Aws::SecurityHub::Types::AwsEcsTaskDefinitionContainerDefinitionsResourceRequirementsDetails

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

A resource to assign to a container.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#typeString

The type of resource to assign to a container. Valid values are GPU or InferenceAccelerator.

Returns:

  • (String)


10952
10953
10954
10955
10956
10957
# File 'lib/aws-sdk-securityhub/types.rb', line 10952

class AwsEcsTaskDefinitionContainerDefinitionsResourceRequirementsDetails < Struct.new(
  :type,
  :value)
  SENSITIVE = []
  include Aws::Structure
end

#valueString

The value for the specified resource type.

For GPU, the value is the number of physical GPUs the Amazon ECS container agent reserves for the container.

For InferenceAccelerator, the value should match the DeviceName attribute of an entry in InferenceAccelerators.

Returns:

  • (String)


10952
10953
10954
10955
10956
10957
# File 'lib/aws-sdk-securityhub/types.rb', line 10952

class AwsEcsTaskDefinitionContainerDefinitionsResourceRequirementsDetails < Struct.new(
  :type,
  :value)
  SENSITIVE = []
  include Aws::Structure
end