Class: Aws::SecurityHub::Types::AwsEcsTaskDefinitionContainerDefinitionsResourceRequirementsDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::AwsEcsTaskDefinitionContainerDefinitionsResourceRequirementsDetails
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
A resource to assign to a container.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#type ⇒ String
The type of resource to assign to a container.
-
#value ⇒ String
The value for the specified resource type.
Instance Attribute Details
#type ⇒ String
The type of resource to assign to a container. Valid values are
GPU or InferenceAccelerator.
10952 10953 10954 10955 10956 10957 |
# File 'lib/aws-sdk-securityhub/types.rb', line 10952 class AwsEcsTaskDefinitionContainerDefinitionsResourceRequirementsDetails < Struct.new( :type, :value) SENSITIVE = [] include Aws::Structure end |
#value ⇒ String
The value for the specified resource type.
For GPU, the value is the number of physical GPUs the Amazon ECS
container agent reserves for the container.
For InferenceAccelerator, the value should match the DeviceName
attribute of an entry in InferenceAccelerators.
10952 10953 10954 10955 10956 10957 |
# File 'lib/aws-sdk-securityhub/types.rb', line 10952 class AwsEcsTaskDefinitionContainerDefinitionsResourceRequirementsDetails < Struct.new( :type, :value) SENSITIVE = [] include Aws::Structure end |