Class: Aws::SecurityHub::Types::AwsEcsTaskDefinitionContainerDefinitionsSecretsDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::AwsEcsTaskDefinitionContainerDefinitionsSecretsDetails
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
A secret to pass to the container.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#name ⇒ String
The name of the secret.
-
#value_from ⇒ String
The secret to expose to the container.
Instance Attribute Details
#name ⇒ String
The name of the secret.
11002 11003 11004 11005 11006 11007 |
# File 'lib/aws-sdk-securityhub/types.rb', line 11002 class AwsEcsTaskDefinitionContainerDefinitionsSecretsDetails < Struct.new( :name, :value_from) SENSITIVE = [] include Aws::Structure end |
#value_from ⇒ String
The secret to expose to the container. The value is either the full ARN of the Secrets Manager secret or the full ARN of the parameter in the Systems Manager Parameter Store.
11002 11003 11004 11005 11006 11007 |
# File 'lib/aws-sdk-securityhub/types.rb', line 11002 class AwsEcsTaskDefinitionContainerDefinitionsSecretsDetails < Struct.new( :name, :value_from) SENSITIVE = [] include Aws::Structure end |