Class: Aws::SecurityHub::Types::AwsEcsTaskDefinitionContainerDefinitionsSecretsDetails

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

A secret to pass to the container.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#nameString

The name of the secret.

Returns:

  • (String)


10973
10974
10975
10976
10977
10978
# File 'lib/aws-sdk-securityhub/types.rb', line 10973

class AwsEcsTaskDefinitionContainerDefinitionsSecretsDetails < Struct.new(
  :name,
  :value_from)
  SENSITIVE = []
  include Aws::Structure
end

#value_fromString

The secret to expose to the container. The value is either the full ARN of the Secrets Manager secret or the full ARN of the parameter in the Systems Manager Parameter Store.

Returns:

  • (String)


10973
10974
10975
10976
10977
10978
# File 'lib/aws-sdk-securityhub/types.rb', line 10973

class AwsEcsTaskDefinitionContainerDefinitionsSecretsDetails < Struct.new(
  :name,
  :value_from)
  SENSITIVE = []
  include Aws::Structure
end