Class: Aws::SecurityHub::Types::AwsEcsTaskDefinitionVolumesDockerVolumeConfigurationDetails

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

Information about a Docker volume.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#autoprovisionBoolean

Whether to create the Docker volume automatically if it does not already exist.

Returns:

  • (Boolean)


11348
11349
11350
11351
11352
11353
11354
11355
11356
# File 'lib/aws-sdk-securityhub/types.rb', line 11348

class AwsEcsTaskDefinitionVolumesDockerVolumeConfigurationDetails < Struct.new(
  :autoprovision,
  :driver,
  :driver_opts,
  :labels,
  :scope)
  SENSITIVE = []
  include Aws::Structure
end

#driverString

The Docker volume driver to use.

Returns:

  • (String)


11348
11349
11350
11351
11352
11353
11354
11355
11356
# File 'lib/aws-sdk-securityhub/types.rb', line 11348

class AwsEcsTaskDefinitionVolumesDockerVolumeConfigurationDetails < Struct.new(
  :autoprovision,
  :driver,
  :driver_opts,
  :labels,
  :scope)
  SENSITIVE = []
  include Aws::Structure
end

#driver_optsHash<String,String>

A map of Docker driver-specific options that are passed through.

Returns:

  • (Hash<String,String>)


11348
11349
11350
11351
11352
11353
11354
11355
11356
# File 'lib/aws-sdk-securityhub/types.rb', line 11348

class AwsEcsTaskDefinitionVolumesDockerVolumeConfigurationDetails < Struct.new(
  :autoprovision,
  :driver,
  :driver_opts,
  :labels,
  :scope)
  SENSITIVE = []
  include Aws::Structure
end

#labelsHash<String,String>

Custom metadata to add to the Docker volume.

Returns:

  • (Hash<String,String>)


11348
11349
11350
11351
11352
11353
11354
11355
11356
# File 'lib/aws-sdk-securityhub/types.rb', line 11348

class AwsEcsTaskDefinitionVolumesDockerVolumeConfigurationDetails < Struct.new(
  :autoprovision,
  :driver,
  :driver_opts,
  :labels,
  :scope)
  SENSITIVE = []
  include Aws::Structure
end

#scopeString

The scope for the Docker volume that determines its lifecycle. Docker volumes that are scoped to a task are provisioned automatically when the task starts and destroyed when the task stops. Docker volumes that are shared persist after the task stops. Valid values are shared or task.

Returns:

  • (String)


11348
11349
11350
11351
11352
11353
11354
11355
11356
# File 'lib/aws-sdk-securityhub/types.rb', line 11348

class AwsEcsTaskDefinitionVolumesDockerVolumeConfigurationDetails < Struct.new(
  :autoprovision,
  :driver,
  :driver_opts,
  :labels,
  :scope)
  SENSITIVE = []
  include Aws::Structure
end