Class: Aws::SecurityHub::Types::AwsEcsTaskDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::AwsEcsTaskDetails
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Provides details about a task in a cluster.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cluster_arn ⇒ String
The Amazon Resource Name (ARN) of the cluster that hosts the task.
-
#containers ⇒ Array<Types::AwsEcsContainerDetails>
The containers that are associated with the task.
-
#created_at ⇒ String
The Unix timestamp for the time when the task was created.
-
#group ⇒ String
The name of the task group that's associated with the task.
-
#started_at ⇒ String
The Unix timestamp for the time when the task started.
-
#started_by ⇒ String
The tag specified when a task is started.
-
#task_definition_arn ⇒ String
The ARN of the task definition that creates the task.
-
#version ⇒ String
The version counter for the task.
-
#volumes ⇒ Array<Types::AwsEcsTaskVolumeDetails>
Details about the data volume that is used in a task definition.
Instance Attribute Details
#cluster_arn ⇒ String
The Amazon Resource Name (ARN) of the cluster that hosts the task.
11375 11376 11377 11378 11379 11380 11381 11382 11383 11384 11385 11386 11387 |
# File 'lib/aws-sdk-securityhub/types.rb', line 11375 class AwsEcsTaskDetails < Struct.new( :cluster_arn, :task_definition_arn, :version, :created_at, :started_at, :started_by, :group, :volumes, :containers) SENSITIVE = [] include Aws::Structure end |
#containers ⇒ Array<Types::AwsEcsContainerDetails>
The containers that are associated with the task.
11375 11376 11377 11378 11379 11380 11381 11382 11383 11384 11385 11386 11387 |
# File 'lib/aws-sdk-securityhub/types.rb', line 11375 class AwsEcsTaskDetails < Struct.new( :cluster_arn, :task_definition_arn, :version, :created_at, :started_at, :started_by, :group, :volumes, :containers) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ String
The Unix timestamp for the time when the task was created. More
specifically, it's for the time when the task entered the PENDING
state.
11375 11376 11377 11378 11379 11380 11381 11382 11383 11384 11385 11386 11387 |
# File 'lib/aws-sdk-securityhub/types.rb', line 11375 class AwsEcsTaskDetails < Struct.new( :cluster_arn, :task_definition_arn, :version, :created_at, :started_at, :started_by, :group, :volumes, :containers) SENSITIVE = [] include Aws::Structure end |
#group ⇒ String
The name of the task group that's associated with the task.
11375 11376 11377 11378 11379 11380 11381 11382 11383 11384 11385 11386 11387 |
# File 'lib/aws-sdk-securityhub/types.rb', line 11375 class AwsEcsTaskDetails < Struct.new( :cluster_arn, :task_definition_arn, :version, :created_at, :started_at, :started_by, :group, :volumes, :containers) SENSITIVE = [] include Aws::Structure end |
#started_at ⇒ String
The Unix timestamp for the time when the task started. More
specifically, it's for the time when the task transitioned from the
PENDING state to the RUNNING state.
11375 11376 11377 11378 11379 11380 11381 11382 11383 11384 11385 11386 11387 |
# File 'lib/aws-sdk-securityhub/types.rb', line 11375 class AwsEcsTaskDetails < Struct.new( :cluster_arn, :task_definition_arn, :version, :created_at, :started_at, :started_by, :group, :volumes, :containers) SENSITIVE = [] include Aws::Structure end |
#started_by ⇒ String
The tag specified when a task is started. If an Amazon ECS service
started the task, the startedBy parameter contains the deployment
ID of that service.
11375 11376 11377 11378 11379 11380 11381 11382 11383 11384 11385 11386 11387 |
# File 'lib/aws-sdk-securityhub/types.rb', line 11375 class AwsEcsTaskDetails < Struct.new( :cluster_arn, :task_definition_arn, :version, :created_at, :started_at, :started_by, :group, :volumes, :containers) SENSITIVE = [] include Aws::Structure end |
#task_definition_arn ⇒ String
The ARN of the task definition that creates the task.
11375 11376 11377 11378 11379 11380 11381 11382 11383 11384 11385 11386 11387 |
# File 'lib/aws-sdk-securityhub/types.rb', line 11375 class AwsEcsTaskDetails < Struct.new( :cluster_arn, :task_definition_arn, :version, :created_at, :started_at, :started_by, :group, :volumes, :containers) SENSITIVE = [] include Aws::Structure end |
#version ⇒ String
The version counter for the task.
11375 11376 11377 11378 11379 11380 11381 11382 11383 11384 11385 11386 11387 |
# File 'lib/aws-sdk-securityhub/types.rb', line 11375 class AwsEcsTaskDetails < Struct.new( :cluster_arn, :task_definition_arn, :version, :created_at, :started_at, :started_by, :group, :volumes, :containers) SENSITIVE = [] include Aws::Structure end |
#volumes ⇒ Array<Types::AwsEcsTaskVolumeDetails>
Details about the data volume that is used in a task definition.
11375 11376 11377 11378 11379 11380 11381 11382 11383 11384 11385 11386 11387 |
# File 'lib/aws-sdk-securityhub/types.rb', line 11375 class AwsEcsTaskDetails < Struct.new( :cluster_arn, :task_definition_arn, :version, :created_at, :started_at, :started_by, :group, :volumes, :containers) SENSITIVE = [] include Aws::Structure end |