Class: Aws::SecurityHub::Types::AwsEfsAccessPointDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::AwsEfsAccessPointDetails
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Provides information about an Amazon EFS access point.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#access_point_id ⇒ String
The ID of the Amazon EFS access point.
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the Amazon EFS access point.
-
#client_token ⇒ String
The opaque string specified in the request to ensure idempotent creation.
-
#file_system_id ⇒ String
The ID of the Amazon EFS file system that the access point applies to.
-
#posix_user ⇒ Types::AwsEfsAccessPointPosixUserDetails
The full POSIX identity, including the user ID, group ID, and secondary group IDs on the access point, that is used for all file operations by NFS clients using the access point.
-
#root_directory ⇒ Types::AwsEfsAccessPointRootDirectoryDetails
The directory on the Amazon EFS file system that the access point exposes as the root directory to NFS clients using the access point.
Instance Attribute Details
#access_point_id ⇒ String
The ID of the Amazon EFS access point.
11464 11465 11466 11467 11468 11469 11470 11471 11472 11473 |
# File 'lib/aws-sdk-securityhub/types.rb', line 11464 class AwsEfsAccessPointDetails < Struct.new( :access_point_id, :arn, :client_token, :file_system_id, :posix_user, :root_directory) SENSITIVE = [] include Aws::Structure end |
#arn ⇒ String
The Amazon Resource Name (ARN) of the Amazon EFS access point.
11464 11465 11466 11467 11468 11469 11470 11471 11472 11473 |
# File 'lib/aws-sdk-securityhub/types.rb', line 11464 class AwsEfsAccessPointDetails < Struct.new( :access_point_id, :arn, :client_token, :file_system_id, :posix_user, :root_directory) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
The opaque string specified in the request to ensure idempotent creation.
11464 11465 11466 11467 11468 11469 11470 11471 11472 11473 |
# File 'lib/aws-sdk-securityhub/types.rb', line 11464 class AwsEfsAccessPointDetails < Struct.new( :access_point_id, :arn, :client_token, :file_system_id, :posix_user, :root_directory) SENSITIVE = [] include Aws::Structure end |
#file_system_id ⇒ String
The ID of the Amazon EFS file system that the access point applies to.
11464 11465 11466 11467 11468 11469 11470 11471 11472 11473 |
# File 'lib/aws-sdk-securityhub/types.rb', line 11464 class AwsEfsAccessPointDetails < Struct.new( :access_point_id, :arn, :client_token, :file_system_id, :posix_user, :root_directory) SENSITIVE = [] include Aws::Structure end |
#posix_user ⇒ Types::AwsEfsAccessPointPosixUserDetails
The full POSIX identity, including the user ID, group ID, and secondary group IDs on the access point, that is used for all file operations by NFS clients using the access point.
11464 11465 11466 11467 11468 11469 11470 11471 11472 11473 |
# File 'lib/aws-sdk-securityhub/types.rb', line 11464 class AwsEfsAccessPointDetails < Struct.new( :access_point_id, :arn, :client_token, :file_system_id, :posix_user, :root_directory) SENSITIVE = [] include Aws::Structure end |
#root_directory ⇒ Types::AwsEfsAccessPointRootDirectoryDetails
The directory on the Amazon EFS file system that the access point exposes as the root directory to NFS clients using the access point.
11464 11465 11466 11467 11468 11469 11470 11471 11472 11473 |
# File 'lib/aws-sdk-securityhub/types.rb', line 11464 class AwsEfsAccessPointDetails < Struct.new( :access_point_id, :arn, :client_token, :file_system_id, :posix_user, :root_directory) SENSITIVE = [] include Aws::Structure end |