Class: Aws::SecurityHub::Types::AwsEfsAccessPointRootDirectoryDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::AwsEfsAccessPointRootDirectoryDetails
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Provides information about the directory on the Amazon EFS file system that the access point exposes as the root directory to NFS clients using the access point.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#creation_info ⇒ Types::AwsEfsAccessPointRootDirectoryCreationInfoDetails
Specifies the POSIX IDs and permissions to apply to the access point's root directory.
-
#path ⇒ String
Specifies the path on the Amazon EFS file system to expose as the root directory to NFS clients using the access point to access the EFS file system.
Instance Attribute Details
#creation_info ⇒ Types::AwsEfsAccessPointRootDirectoryCreationInfoDetails
Specifies the POSIX IDs and permissions to apply to the access point's root directory.
11649 11650 11651 11652 11653 11654 |
# File 'lib/aws-sdk-securityhub/types.rb', line 11649 class AwsEfsAccessPointRootDirectoryDetails < Struct.new( :creation_info, :path) SENSITIVE = [] include Aws::Structure end |
#path ⇒ String
Specifies the path on the Amazon EFS file system to expose as the
root directory to NFS clients using the access point to access the
EFS file system. A path can have up to four subdirectories. If the
specified path does not exist, you are required to provide
CreationInfo.
11649 11650 11651 11652 11653 11654 |
# File 'lib/aws-sdk-securityhub/types.rb', line 11649 class AwsEfsAccessPointRootDirectoryDetails < Struct.new( :creation_info, :path) SENSITIVE = [] include Aws::Structure end |