Class: Aws::SecurityHub::Types::AwsEksClusterDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::AwsEksClusterDetails
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Provides details about an Amazon EKS cluster.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The ARN of the cluster.
-
#certificate_authority_data ⇒ String
The certificate authority data for the cluster.
-
#cluster_status ⇒ String
The status of the cluster.
-
#endpoint ⇒ String
The endpoint for the Amazon EKS API server.
-
#logging ⇒ Types::AwsEksClusterLoggingDetails
The logging configuration for the cluster.
-
#name ⇒ String
The name of the cluster.
-
#resources_vpc_config ⇒ Types::AwsEksClusterResourcesVpcConfigDetails
The VPC configuration used by the cluster control plane.
-
#role_arn ⇒ String
The ARN of the IAM role that provides permissions for the Amazon EKS control plane to make calls to Amazon Web Services API operations on your behalf.
-
#version ⇒ String
The Amazon EKS server version for the cluster.
Instance Attribute Details
#arn ⇒ String
The ARN of the cluster.
11710 11711 11712 11713 11714 11715 11716 11717 11718 11719 11720 11721 11722 |
# File 'lib/aws-sdk-securityhub/types.rb', line 11710 class AwsEksClusterDetails < Struct.new( :arn, :certificate_authority_data, :cluster_status, :endpoint, :name, :resources_vpc_config, :role_arn, :version, :logging) SENSITIVE = [] include Aws::Structure end |
#certificate_authority_data ⇒ String
The certificate authority data for the cluster.
11710 11711 11712 11713 11714 11715 11716 11717 11718 11719 11720 11721 11722 |
# File 'lib/aws-sdk-securityhub/types.rb', line 11710 class AwsEksClusterDetails < Struct.new( :arn, :certificate_authority_data, :cluster_status, :endpoint, :name, :resources_vpc_config, :role_arn, :version, :logging) SENSITIVE = [] include Aws::Structure end |
#cluster_status ⇒ String
The status of the cluster. Valid values are as follows:
-
ACTIVE -
CREATING -
DELETING -
FAILED -
PENDING -
UPDATING
11710 11711 11712 11713 11714 11715 11716 11717 11718 11719 11720 11721 11722 |
# File 'lib/aws-sdk-securityhub/types.rb', line 11710 class AwsEksClusterDetails < Struct.new( :arn, :certificate_authority_data, :cluster_status, :endpoint, :name, :resources_vpc_config, :role_arn, :version, :logging) SENSITIVE = [] include Aws::Structure end |
#endpoint ⇒ String
The endpoint for the Amazon EKS API server.
11710 11711 11712 11713 11714 11715 11716 11717 11718 11719 11720 11721 11722 |
# File 'lib/aws-sdk-securityhub/types.rb', line 11710 class AwsEksClusterDetails < Struct.new( :arn, :certificate_authority_data, :cluster_status, :endpoint, :name, :resources_vpc_config, :role_arn, :version, :logging) SENSITIVE = [] include Aws::Structure end |
#logging ⇒ Types::AwsEksClusterLoggingDetails
The logging configuration for the cluster.
11710 11711 11712 11713 11714 11715 11716 11717 11718 11719 11720 11721 11722 |
# File 'lib/aws-sdk-securityhub/types.rb', line 11710 class AwsEksClusterDetails < Struct.new( :arn, :certificate_authority_data, :cluster_status, :endpoint, :name, :resources_vpc_config, :role_arn, :version, :logging) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the cluster.
11710 11711 11712 11713 11714 11715 11716 11717 11718 11719 11720 11721 11722 |
# File 'lib/aws-sdk-securityhub/types.rb', line 11710 class AwsEksClusterDetails < Struct.new( :arn, :certificate_authority_data, :cluster_status, :endpoint, :name, :resources_vpc_config, :role_arn, :version, :logging) SENSITIVE = [] include Aws::Structure end |
#resources_vpc_config ⇒ Types::AwsEksClusterResourcesVpcConfigDetails
The VPC configuration used by the cluster control plane.
11710 11711 11712 11713 11714 11715 11716 11717 11718 11719 11720 11721 11722 |
# File 'lib/aws-sdk-securityhub/types.rb', line 11710 class AwsEksClusterDetails < Struct.new( :arn, :certificate_authority_data, :cluster_status, :endpoint, :name, :resources_vpc_config, :role_arn, :version, :logging) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The ARN of the IAM role that provides permissions for the Amazon EKS control plane to make calls to Amazon Web Services API operations on your behalf.
11710 11711 11712 11713 11714 11715 11716 11717 11718 11719 11720 11721 11722 |
# File 'lib/aws-sdk-securityhub/types.rb', line 11710 class AwsEksClusterDetails < Struct.new( :arn, :certificate_authority_data, :cluster_status, :endpoint, :name, :resources_vpc_config, :role_arn, :version, :logging) SENSITIVE = [] include Aws::Structure end |
#version ⇒ String
The Amazon EKS server version for the cluster.
11710 11711 11712 11713 11714 11715 11716 11717 11718 11719 11720 11721 11722 |
# File 'lib/aws-sdk-securityhub/types.rb', line 11710 class AwsEksClusterDetails < Struct.new( :arn, :certificate_authority_data, :cluster_status, :endpoint, :name, :resources_vpc_config, :role_arn, :version, :logging) SENSITIVE = [] include Aws::Structure end |