Class: Aws::SecurityHub::Types::AwsElasticsearchDomainServiceSoftwareOptions
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::AwsElasticsearchDomainServiceSoftwareOptions
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Information about the state of the domain relative to the latest service software.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#automated_update_date ⇒ String
The epoch time when the deployment window closes for required updates.
-
#cancellable ⇒ Boolean
Whether a request to update the domain can be canceled.
-
#current_version ⇒ String
The version of the service software that is currently installed on the domain.
-
#description ⇒ String
A more detailed description of the service software status.
-
#new_version ⇒ String
The most recent version of the service software.
-
#update_available ⇒ Boolean
Whether a service software update is available for the domain.
-
#update_status ⇒ String
The status of the service software update.
Instance Attribute Details
#automated_update_date ⇒ String
The epoch time when the deployment window closes for required updates. After this time, Amazon OpenSearch Service schedules the software upgrade automatically.
12312 12313 12314 12315 12316 12317 12318 12319 12320 12321 12322 |
# File 'lib/aws-sdk-securityhub/types.rb', line 12312 class AwsElasticsearchDomainServiceSoftwareOptions < Struct.new( :automated_update_date, :cancellable, :current_version, :description, :new_version, :update_available, :update_status) SENSITIVE = [] include Aws::Structure end |
#cancellable ⇒ Boolean
Whether a request to update the domain can be canceled.
12312 12313 12314 12315 12316 12317 12318 12319 12320 12321 12322 |
# File 'lib/aws-sdk-securityhub/types.rb', line 12312 class AwsElasticsearchDomainServiceSoftwareOptions < Struct.new( :automated_update_date, :cancellable, :current_version, :description, :new_version, :update_available, :update_status) SENSITIVE = [] include Aws::Structure end |
#current_version ⇒ String
The version of the service software that is currently installed on the domain.
12312 12313 12314 12315 12316 12317 12318 12319 12320 12321 12322 |
# File 'lib/aws-sdk-securityhub/types.rb', line 12312 class AwsElasticsearchDomainServiceSoftwareOptions < Struct.new( :automated_update_date, :cancellable, :current_version, :description, :new_version, :update_available, :update_status) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A more detailed description of the service software status.
12312 12313 12314 12315 12316 12317 12318 12319 12320 12321 12322 |
# File 'lib/aws-sdk-securityhub/types.rb', line 12312 class AwsElasticsearchDomainServiceSoftwareOptions < Struct.new( :automated_update_date, :cancellable, :current_version, :description, :new_version, :update_available, :update_status) SENSITIVE = [] include Aws::Structure end |
#new_version ⇒ String
The most recent version of the service software.
12312 12313 12314 12315 12316 12317 12318 12319 12320 12321 12322 |
# File 'lib/aws-sdk-securityhub/types.rb', line 12312 class AwsElasticsearchDomainServiceSoftwareOptions < Struct.new( :automated_update_date, :cancellable, :current_version, :description, :new_version, :update_available, :update_status) SENSITIVE = [] include Aws::Structure end |
#update_available ⇒ Boolean
Whether a service software update is available for the domain.
12312 12313 12314 12315 12316 12317 12318 12319 12320 12321 12322 |
# File 'lib/aws-sdk-securityhub/types.rb', line 12312 class AwsElasticsearchDomainServiceSoftwareOptions < Struct.new( :automated_update_date, :cancellable, :current_version, :description, :new_version, :update_available, :update_status) SENSITIVE = [] include Aws::Structure end |
#update_status ⇒ String
The status of the service software update. Valid values are as follows:
-
COMPLETED -
ELIGIBLE -
IN_PROGRESS -
NOT_ELIGIBLE -
PENDING_UPDATE
12312 12313 12314 12315 12316 12317 12318 12319 12320 12321 12322 |
# File 'lib/aws-sdk-securityhub/types.rb', line 12312 class AwsElasticsearchDomainServiceSoftwareOptions < Struct.new( :automated_update_date, :cancellable, :current_version, :description, :new_version, :update_available, :update_status) SENSITIVE = [] include Aws::Structure end |