Class: Aws::SecurityHub::Types::AwsElbLbCookieStickinessPolicy
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::AwsElbLbCookieStickinessPolicy
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Contains information about a stickiness policy that was created using
CreateLBCookieStickinessPolicy.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cookie_expiration_period ⇒ Integer
The amount of time, in seconds, after which the cookie is considered stale.
-
#policy_name ⇒ String
The name of the policy.
Instance Attribute Details
#cookie_expiration_period ⇒ Integer
The amount of time, in seconds, after which the cookie is considered stale. If an expiration period is not specified, the stickiness session lasts for the duration of the browser session.
12393 12394 12395 12396 12397 12398 |
# File 'lib/aws-sdk-securityhub/types.rb', line 12393 class AwsElbLbCookieStickinessPolicy < Struct.new( :cookie_expiration_period, :policy_name) SENSITIVE = [] include Aws::Structure end |
#policy_name ⇒ String
The name of the policy. The name must be unique within the set of policies for the load balancer.
12393 12394 12395 12396 12397 12398 |
# File 'lib/aws-sdk-securityhub/types.rb', line 12393 class AwsElbLbCookieStickinessPolicy < Struct.new( :cookie_expiration_period, :policy_name) SENSITIVE = [] include Aws::Structure end |