Class: Aws::SecurityHub::Types::AwsEventSchemasRegistryDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::AwsEventSchemasRegistryDetails
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
A schema defines the structure of events that are sent to Amazon EventBridge. Schema registries are containers for schemas. They collect and organize schemas so that your schemas are in logical groups.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
A description of the registry to be created.
-
#registry_arn ⇒ String
The Amazon Resource Name (ARN) of the registry.
-
#registry_name ⇒ String
The name of the schema registry.
Instance Attribute Details
#description ⇒ String
A description of the registry to be created.
12875 12876 12877 12878 12879 12880 12881 |
# File 'lib/aws-sdk-securityhub/types.rb', line 12875 class AwsEventSchemasRegistryDetails < Struct.new( :description, :registry_arn, :registry_name) SENSITIVE = [] include Aws::Structure end |
#registry_arn ⇒ String
The Amazon Resource Name (ARN) of the registry.
12875 12876 12877 12878 12879 12880 12881 |
# File 'lib/aws-sdk-securityhub/types.rb', line 12875 class AwsEventSchemasRegistryDetails < Struct.new( :description, :registry_arn, :registry_name) SENSITIVE = [] include Aws::Structure end |
#registry_name ⇒ String
The name of the schema registry.
12875 12876 12877 12878 12879 12880 12881 |
# File 'lib/aws-sdk-securityhub/types.rb', line 12875 class AwsEventSchemasRegistryDetails < Struct.new( :description, :registry_arn, :registry_name) SENSITIVE = [] include Aws::Structure end |