Class: Aws::SecurityHub::Types::AwsIamAccessKeyDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::AwsIamAccessKeyDetails
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
IAM access key details related to a finding.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#access_key_id ⇒ String
The identifier of the access key.
-
#account_id ⇒ String
The Amazon Web Services account ID of the account for the key.
-
#created_at ⇒ String
Indicates when the IAM access key was created.
-
#principal_id ⇒ String
The ID of the principal associated with an access key.
-
#principal_name ⇒ String
The name of the principal.
-
#principal_type ⇒ String
The type of principal associated with an access key.
-
#session_context ⇒ Types::AwsIamAccessKeySessionContext
Information about the session that the key was used for.
-
#status ⇒ String
The status of the IAM access key related to a finding.
-
#user_name ⇒ String
The user associated with the IAM access key related to a finding.
Instance Attribute Details
#access_key_id ⇒ String
The identifier of the access key.
13493 13494 13495 13496 13497 13498 13499 13500 13501 13502 13503 13504 13505 |
# File 'lib/aws-sdk-securityhub/types.rb', line 13493 class AwsIamAccessKeyDetails < Struct.new( :user_name, :status, :created_at, :principal_id, :principal_type, :principal_name, :account_id, :access_key_id, :session_context) SENSITIVE = [] include Aws::Structure end |
#account_id ⇒ String
The Amazon Web Services account ID of the account for the key.
13493 13494 13495 13496 13497 13498 13499 13500 13501 13502 13503 13504 13505 |
# File 'lib/aws-sdk-securityhub/types.rb', line 13493 class AwsIamAccessKeyDetails < Struct.new( :user_name, :status, :created_at, :principal_id, :principal_type, :principal_name, :account_id, :access_key_id, :session_context) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ String
Indicates when the IAM access key was created.
For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.
13493 13494 13495 13496 13497 13498 13499 13500 13501 13502 13503 13504 13505 |
# File 'lib/aws-sdk-securityhub/types.rb', line 13493 class AwsIamAccessKeyDetails < Struct.new( :user_name, :status, :created_at, :principal_id, :principal_type, :principal_name, :account_id, :access_key_id, :session_context) SENSITIVE = [] include Aws::Structure end |
#principal_id ⇒ String
The ID of the principal associated with an access key.
13493 13494 13495 13496 13497 13498 13499 13500 13501 13502 13503 13504 13505 |
# File 'lib/aws-sdk-securityhub/types.rb', line 13493 class AwsIamAccessKeyDetails < Struct.new( :user_name, :status, :created_at, :principal_id, :principal_type, :principal_name, :account_id, :access_key_id, :session_context) SENSITIVE = [] include Aws::Structure end |
#principal_name ⇒ String
The name of the principal.
13493 13494 13495 13496 13497 13498 13499 13500 13501 13502 13503 13504 13505 |
# File 'lib/aws-sdk-securityhub/types.rb', line 13493 class AwsIamAccessKeyDetails < Struct.new( :user_name, :status, :created_at, :principal_id, :principal_type, :principal_name, :account_id, :access_key_id, :session_context) SENSITIVE = [] include Aws::Structure end |
#principal_type ⇒ String
The type of principal associated with an access key.
13493 13494 13495 13496 13497 13498 13499 13500 13501 13502 13503 13504 13505 |
# File 'lib/aws-sdk-securityhub/types.rb', line 13493 class AwsIamAccessKeyDetails < Struct.new( :user_name, :status, :created_at, :principal_id, :principal_type, :principal_name, :account_id, :access_key_id, :session_context) SENSITIVE = [] include Aws::Structure end |
#session_context ⇒ Types::AwsIamAccessKeySessionContext
Information about the session that the key was used for.
13493 13494 13495 13496 13497 13498 13499 13500 13501 13502 13503 13504 13505 |
# File 'lib/aws-sdk-securityhub/types.rb', line 13493 class AwsIamAccessKeyDetails < Struct.new( :user_name, :status, :created_at, :principal_id, :principal_type, :principal_name, :account_id, :access_key_id, :session_context) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the IAM access key related to a finding.
13493 13494 13495 13496 13497 13498 13499 13500 13501 13502 13503 13504 13505 |
# File 'lib/aws-sdk-securityhub/types.rb', line 13493 class AwsIamAccessKeyDetails < Struct.new( :user_name, :status, :created_at, :principal_id, :principal_type, :principal_name, :account_id, :access_key_id, :session_context) SENSITIVE = [] include Aws::Structure end |
#user_name ⇒ String
The user associated with the IAM access key related to a finding.
The UserName parameter has been replaced with the PrincipalName
parameter because access keys can also be assigned to principals
that are not IAM users.
13493 13494 13495 13496 13497 13498 13499 13500 13501 13502 13503 13504 13505 |
# File 'lib/aws-sdk-securityhub/types.rb', line 13493 class AwsIamAccessKeyDetails < Struct.new( :user_name, :status, :created_at, :principal_id, :principal_type, :principal_name, :account_id, :access_key_id, :session_context) SENSITIVE = [] include Aws::Structure end |