Class: Aws::SecurityHub::Types::AwsIamAccessKeyDetails

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

IAM access key details related to a finding.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#access_key_idString

The identifier of the access key.



13371
13372
13373
13374
13375
13376
13377
13378
13379
13380
13381
13382
13383
# File 'lib/aws-sdk-securityhub/types.rb', line 13371

class AwsIamAccessKeyDetails < Struct.new(
  :user_name,
  :status,
  :created_at,
  :principal_id,
  :principal_type,
  :principal_name,
  :account_id,
  :access_key_id,
  :session_context)
  SENSITIVE = []
  include Aws::Structure
end

#account_idString

The Amazon Web Services account ID of the account for the key.



13371
13372
13373
13374
13375
13376
13377
13378
13379
13380
13381
13382
13383
# File 'lib/aws-sdk-securityhub/types.rb', line 13371

class AwsIamAccessKeyDetails < Struct.new(
  :user_name,
  :status,
  :created_at,
  :principal_id,
  :principal_type,
  :principal_name,
  :account_id,
  :access_key_id,
  :session_context)
  SENSITIVE = []
  include Aws::Structure
end

#created_atString

Indicates when the IAM access key was created.

For more information about the validation and formatting of timestamp fields in Security Hub, see [Timestamps].

[1]: docs.aws.amazon.com/securityhub/1.0/APIReference/Welcome.html#timestamps



13371
13372
13373
13374
13375
13376
13377
13378
13379
13380
13381
13382
13383
# File 'lib/aws-sdk-securityhub/types.rb', line 13371

class AwsIamAccessKeyDetails < Struct.new(
  :user_name,
  :status,
  :created_at,
  :principal_id,
  :principal_type,
  :principal_name,
  :account_id,
  :access_key_id,
  :session_context)
  SENSITIVE = []
  include Aws::Structure
end

#principal_idString

The ID of the principal associated with an access key.



13371
13372
13373
13374
13375
13376
13377
13378
13379
13380
13381
13382
13383
# File 'lib/aws-sdk-securityhub/types.rb', line 13371

class AwsIamAccessKeyDetails < Struct.new(
  :user_name,
  :status,
  :created_at,
  :principal_id,
  :principal_type,
  :principal_name,
  :account_id,
  :access_key_id,
  :session_context)
  SENSITIVE = []
  include Aws::Structure
end

#principal_nameString

The name of the principal.



13371
13372
13373
13374
13375
13376
13377
13378
13379
13380
13381
13382
13383
# File 'lib/aws-sdk-securityhub/types.rb', line 13371

class AwsIamAccessKeyDetails < Struct.new(
  :user_name,
  :status,
  :created_at,
  :principal_id,
  :principal_type,
  :principal_name,
  :account_id,
  :access_key_id,
  :session_context)
  SENSITIVE = []
  include Aws::Structure
end

#principal_typeString

The type of principal associated with an access key.



13371
13372
13373
13374
13375
13376
13377
13378
13379
13380
13381
13382
13383
# File 'lib/aws-sdk-securityhub/types.rb', line 13371

class AwsIamAccessKeyDetails < Struct.new(
  :user_name,
  :status,
  :created_at,
  :principal_id,
  :principal_type,
  :principal_name,
  :account_id,
  :access_key_id,
  :session_context)
  SENSITIVE = []
  include Aws::Structure
end

#session_contextTypes::AwsIamAccessKeySessionContext

Information about the session that the key was used for.



13371
13372
13373
13374
13375
13376
13377
13378
13379
13380
13381
13382
13383
# File 'lib/aws-sdk-securityhub/types.rb', line 13371

class AwsIamAccessKeyDetails < Struct.new(
  :user_name,
  :status,
  :created_at,
  :principal_id,
  :principal_type,
  :principal_name,
  :account_id,
  :access_key_id,
  :session_context)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the IAM access key related to a finding.



13371
13372
13373
13374
13375
13376
13377
13378
13379
13380
13381
13382
13383
# File 'lib/aws-sdk-securityhub/types.rb', line 13371

class AwsIamAccessKeyDetails < Struct.new(
  :user_name,
  :status,
  :created_at,
  :principal_id,
  :principal_type,
  :principal_name,
  :account_id,
  :access_key_id,
  :session_context)
  SENSITIVE = []
  include Aws::Structure
end

#user_nameString

The user associated with the IAM access key related to a finding.

The UserName parameter has been replaced with the PrincipalName parameter because access keys can also be assigned to principals that are not IAM users.



13371
13372
13373
13374
13375
13376
13377
13378
13379
13380
13381
13382
13383
# File 'lib/aws-sdk-securityhub/types.rb', line 13371

class AwsIamAccessKeyDetails < Struct.new(
  :user_name,
  :status,
  :created_at,
  :principal_id,
  :principal_type,
  :principal_name,
  :account_id,
  :access_key_id,
  :session_context)
  SENSITIVE = []
  include Aws::Structure
end