Class: Aws::SecurityHub::Types::AwsIamGroupDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::AwsIamGroupDetails
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Contains details about an IAM group.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attached_managed_policies ⇒ Array<Types::AwsIamAttachedManagedPolicy>
A list of the managed policies that are attached to the IAM group.
-
#create_date ⇒ String
Indicates when the IAM group was created.
-
#group_id ⇒ String
The identifier of the IAM group.
-
#group_name ⇒ String
The name of the IAM group.
-
#group_policy_list ⇒ Array<Types::AwsIamGroupPolicy>
The list of inline policies that are embedded in the group.
-
#path ⇒ String
The path to the group.
Instance Attribute Details
#attached_managed_policies ⇒ Array<Types::AwsIamAttachedManagedPolicy>
A list of the managed policies that are attached to the IAM group.
13543 13544 13545 13546 13547 13548 13549 13550 13551 13552 |
# File 'lib/aws-sdk-securityhub/types.rb', line 13543 class AwsIamGroupDetails < Struct.new( :attached_managed_policies, :create_date, :group_id, :group_name, :group_policy_list, :path) SENSITIVE = [] include Aws::Structure end |
#create_date ⇒ String
Indicates when the IAM group was created.
For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.
13543 13544 13545 13546 13547 13548 13549 13550 13551 13552 |
# File 'lib/aws-sdk-securityhub/types.rb', line 13543 class AwsIamGroupDetails < Struct.new( :attached_managed_policies, :create_date, :group_id, :group_name, :group_policy_list, :path) SENSITIVE = [] include Aws::Structure end |
#group_id ⇒ String
The identifier of the IAM group.
13543 13544 13545 13546 13547 13548 13549 13550 13551 13552 |
# File 'lib/aws-sdk-securityhub/types.rb', line 13543 class AwsIamGroupDetails < Struct.new( :attached_managed_policies, :create_date, :group_id, :group_name, :group_policy_list, :path) SENSITIVE = [] include Aws::Structure end |
#group_name ⇒ String
The name of the IAM group.
13543 13544 13545 13546 13547 13548 13549 13550 13551 13552 |
# File 'lib/aws-sdk-securityhub/types.rb', line 13543 class AwsIamGroupDetails < Struct.new( :attached_managed_policies, :create_date, :group_id, :group_name, :group_policy_list, :path) SENSITIVE = [] include Aws::Structure end |
#group_policy_list ⇒ Array<Types::AwsIamGroupPolicy>
The list of inline policies that are embedded in the group.
13543 13544 13545 13546 13547 13548 13549 13550 13551 13552 |
# File 'lib/aws-sdk-securityhub/types.rb', line 13543 class AwsIamGroupDetails < Struct.new( :attached_managed_policies, :create_date, :group_id, :group_name, :group_policy_list, :path) SENSITIVE = [] include Aws::Structure end |
#path ⇒ String
The path to the group.
13543 13544 13545 13546 13547 13548 13549 13550 13551 13552 |
# File 'lib/aws-sdk-securityhub/types.rb', line 13543 class AwsIamGroupDetails < Struct.new( :attached_managed_policies, :create_date, :group_id, :group_name, :group_policy_list, :path) SENSITIVE = [] include Aws::Structure end |