Class: Aws::SecurityHub::Types::AwsIamInstanceProfileRole
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::AwsIamInstanceProfileRole
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Information about a role associated with an instance profile.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The ARN of the role.
-
#assume_role_policy_document ⇒ String
The policy that grants an entity permission to assume the role.
-
#create_date ⇒ String
Indicates when the role was created.
-
#path ⇒ String
The path to the role.
-
#role_id ⇒ String
The identifier of the role.
-
#role_name ⇒ String
The name of the role.
Instance Attribute Details
#arn ⇒ String
The ARN of the role.
13779 13780 13781 13782 13783 13784 13785 13786 13787 13788 |
# File 'lib/aws-sdk-securityhub/types.rb', line 13779 class AwsIamInstanceProfileRole < Struct.new( :arn, :assume_role_policy_document, :create_date, :path, :role_id, :role_name) SENSITIVE = [] include Aws::Structure end |
#assume_role_policy_document ⇒ String
The policy that grants an entity permission to assume the role.
13779 13780 13781 13782 13783 13784 13785 13786 13787 13788 |
# File 'lib/aws-sdk-securityhub/types.rb', line 13779 class AwsIamInstanceProfileRole < Struct.new( :arn, :assume_role_policy_document, :create_date, :path, :role_id, :role_name) SENSITIVE = [] include Aws::Structure end |
#create_date ⇒ String
Indicates when the role was created.
For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.
13779 13780 13781 13782 13783 13784 13785 13786 13787 13788 |
# File 'lib/aws-sdk-securityhub/types.rb', line 13779 class AwsIamInstanceProfileRole < Struct.new( :arn, :assume_role_policy_document, :create_date, :path, :role_id, :role_name) SENSITIVE = [] include Aws::Structure end |
#path ⇒ String
The path to the role.
13779 13780 13781 13782 13783 13784 13785 13786 13787 13788 |
# File 'lib/aws-sdk-securityhub/types.rb', line 13779 class AwsIamInstanceProfileRole < Struct.new( :arn, :assume_role_policy_document, :create_date, :path, :role_id, :role_name) SENSITIVE = [] include Aws::Structure end |
#role_id ⇒ String
The identifier of the role.
13779 13780 13781 13782 13783 13784 13785 13786 13787 13788 |
# File 'lib/aws-sdk-securityhub/types.rb', line 13779 class AwsIamInstanceProfileRole < Struct.new( :arn, :assume_role_policy_document, :create_date, :path, :role_id, :role_name) SENSITIVE = [] include Aws::Structure end |
#role_name ⇒ String
The name of the role.
13779 13780 13781 13782 13783 13784 13785 13786 13787 13788 |
# File 'lib/aws-sdk-securityhub/types.rb', line 13779 class AwsIamInstanceProfileRole < Struct.new( :arn, :assume_role_policy_document, :create_date, :path, :role_id, :role_name) SENSITIVE = [] include Aws::Structure end |