Class: Aws::SecurityHub::Types::AwsIamUserDetails

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

Information about an IAM user.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#attached_managed_policiesArray<Types::AwsIamAttachedManagedPolicy>

A list of the managed policies that are attached to the user.



14018
14019
14020
14021
14022
14023
14024
14025
14026
14027
14028
14029
# File 'lib/aws-sdk-securityhub/types.rb', line 14018

class AwsIamUserDetails < Struct.new(
  :attached_managed_policies,
  :create_date,
  :group_list,
  :path,
  :permissions_boundary,
  :user_id,
  :user_name,
  :user_policy_list)
  SENSITIVE = []
  include Aws::Structure
end

#create_dateString

Indicates when the user was created.

For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.

Returns:

  • (String)


14018
14019
14020
14021
14022
14023
14024
14025
14026
14027
14028
14029
# File 'lib/aws-sdk-securityhub/types.rb', line 14018

class AwsIamUserDetails < Struct.new(
  :attached_managed_policies,
  :create_date,
  :group_list,
  :path,
  :permissions_boundary,
  :user_id,
  :user_name,
  :user_policy_list)
  SENSITIVE = []
  include Aws::Structure
end

#group_listArray<String>

A list of IAM groups that the user belongs to.

Returns:

  • (Array<String>)


14018
14019
14020
14021
14022
14023
14024
14025
14026
14027
14028
14029
# File 'lib/aws-sdk-securityhub/types.rb', line 14018

class AwsIamUserDetails < Struct.new(
  :attached_managed_policies,
  :create_date,
  :group_list,
  :path,
  :permissions_boundary,
  :user_id,
  :user_name,
  :user_policy_list)
  SENSITIVE = []
  include Aws::Structure
end

#pathString

The path to the user.

Returns:

  • (String)


14018
14019
14020
14021
14022
14023
14024
14025
14026
14027
14028
14029
# File 'lib/aws-sdk-securityhub/types.rb', line 14018

class AwsIamUserDetails < Struct.new(
  :attached_managed_policies,
  :create_date,
  :group_list,
  :path,
  :permissions_boundary,
  :user_id,
  :user_name,
  :user_policy_list)
  SENSITIVE = []
  include Aws::Structure
end

#permissions_boundaryTypes::AwsIamPermissionsBoundary

The permissions boundary for the user.



14018
14019
14020
14021
14022
14023
14024
14025
14026
14027
14028
14029
# File 'lib/aws-sdk-securityhub/types.rb', line 14018

class AwsIamUserDetails < Struct.new(
  :attached_managed_policies,
  :create_date,
  :group_list,
  :path,
  :permissions_boundary,
  :user_id,
  :user_name,
  :user_policy_list)
  SENSITIVE = []
  include Aws::Structure
end

#user_idString

The unique identifier for the user.

Returns:

  • (String)


14018
14019
14020
14021
14022
14023
14024
14025
14026
14027
14028
14029
# File 'lib/aws-sdk-securityhub/types.rb', line 14018

class AwsIamUserDetails < Struct.new(
  :attached_managed_policies,
  :create_date,
  :group_list,
  :path,
  :permissions_boundary,
  :user_id,
  :user_name,
  :user_policy_list)
  SENSITIVE = []
  include Aws::Structure
end

#user_nameString

The name of the user.

Returns:

  • (String)


14018
14019
14020
14021
14022
14023
14024
14025
14026
14027
14028
14029
# File 'lib/aws-sdk-securityhub/types.rb', line 14018

class AwsIamUserDetails < Struct.new(
  :attached_managed_policies,
  :create_date,
  :group_list,
  :path,
  :permissions_boundary,
  :user_id,
  :user_name,
  :user_policy_list)
  SENSITIVE = []
  include Aws::Structure
end

#user_policy_listArray<Types::AwsIamUserPolicy>

The list of inline policies that are embedded in the user.

Returns:



14018
14019
14020
14021
14022
14023
14024
14025
14026
14027
14028
14029
# File 'lib/aws-sdk-securityhub/types.rb', line 14018

class AwsIamUserDetails < Struct.new(
  :attached_managed_policies,
  :create_date,
  :group_list,
  :path,
  :permissions_boundary,
  :user_id,
  :user_name,
  :user_policy_list)
  SENSITIVE = []
  include Aws::Structure
end