Class: Aws::SecurityHub::Types::AwsKmsKeyDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::AwsKmsKeyDetails
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Contains metadata about an KMS key.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_account_id ⇒ String
The twelve-digit account ID of the Amazon Web Services account that owns the KMS key.
-
#creation_date ⇒ Float
Indicates when the KMS key was created.
-
#description ⇒ String
A description of the KMS key.
-
#key_id ⇒ String
The globally unique identifier for the KMS key.
-
#key_manager ⇒ String
The manager of the KMS key.
-
#key_rotation_status ⇒ Boolean
Whether the key has key rotation enabled.
-
#key_state ⇒ String
The state of the KMS key.
-
#origin ⇒ String
The source of the KMS key material.
Instance Attribute Details
#aws_account_id ⇒ String
The twelve-digit account ID of the Amazon Web Services account that owns the KMS key.
14168 14169 14170 14171 14172 14173 14174 14175 14176 14177 14178 14179 |
# File 'lib/aws-sdk-securityhub/types.rb', line 14168 class AwsKmsKeyDetails < Struct.new( :aws_account_id, :creation_date, :key_id, :key_manager, :key_state, :origin, :description, :key_rotation_status) SENSITIVE = [] include Aws::Structure end |
#creation_date ⇒ Float
Indicates when the KMS key was created.
For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.
14168 14169 14170 14171 14172 14173 14174 14175 14176 14177 14178 14179 |
# File 'lib/aws-sdk-securityhub/types.rb', line 14168 class AwsKmsKeyDetails < Struct.new( :aws_account_id, :creation_date, :key_id, :key_manager, :key_state, :origin, :description, :key_rotation_status) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the KMS key.
14168 14169 14170 14171 14172 14173 14174 14175 14176 14177 14178 14179 |
# File 'lib/aws-sdk-securityhub/types.rb', line 14168 class AwsKmsKeyDetails < Struct.new( :aws_account_id, :creation_date, :key_id, :key_manager, :key_state, :origin, :description, :key_rotation_status) SENSITIVE = [] include Aws::Structure end |
#key_id ⇒ String
The globally unique identifier for the KMS key.
14168 14169 14170 14171 14172 14173 14174 14175 14176 14177 14178 14179 |
# File 'lib/aws-sdk-securityhub/types.rb', line 14168 class AwsKmsKeyDetails < Struct.new( :aws_account_id, :creation_date, :key_id, :key_manager, :key_state, :origin, :description, :key_rotation_status) SENSITIVE = [] include Aws::Structure end |
#key_manager ⇒ String
The manager of the KMS key. KMS keys in your Amazon Web Services account are either customer managed or Amazon Web Services managed.
14168 14169 14170 14171 14172 14173 14174 14175 14176 14177 14178 14179 |
# File 'lib/aws-sdk-securityhub/types.rb', line 14168 class AwsKmsKeyDetails < Struct.new( :aws_account_id, :creation_date, :key_id, :key_manager, :key_state, :origin, :description, :key_rotation_status) SENSITIVE = [] include Aws::Structure end |
#key_rotation_status ⇒ Boolean
Whether the key has key rotation enabled.
14168 14169 14170 14171 14172 14173 14174 14175 14176 14177 14178 14179 |
# File 'lib/aws-sdk-securityhub/types.rb', line 14168 class AwsKmsKeyDetails < Struct.new( :aws_account_id, :creation_date, :key_id, :key_manager, :key_state, :origin, :description, :key_rotation_status) SENSITIVE = [] include Aws::Structure end |
#key_state ⇒ String
The state of the KMS key. Valid values are as follows:
-
Disabled -
Enabled -
PendingDeletion -
PendingImport -
Unavailable
14168 14169 14170 14171 14172 14173 14174 14175 14176 14177 14178 14179 |
# File 'lib/aws-sdk-securityhub/types.rb', line 14168 class AwsKmsKeyDetails < Struct.new( :aws_account_id, :creation_date, :key_id, :key_manager, :key_state, :origin, :description, :key_rotation_status) SENSITIVE = [] include Aws::Structure end |
#origin ⇒ String
The source of the KMS key material.
When this value is AWS_KMS, KMS created the key material.
When this value is EXTERNAL, the key material was imported from
your existing key management infrastructure or the KMS key lacks key
material.
When this value is AWS_CLOUDHSM, the key material was created in
the CloudHSM cluster associated with a custom key store.
14168 14169 14170 14171 14172 14173 14174 14175 14176 14177 14178 14179 |
# File 'lib/aws-sdk-securityhub/types.rb', line 14168 class AwsKmsKeyDetails < Struct.new( :aws_account_id, :creation_date, :key_id, :key_manager, :key_state, :origin, :description, :key_rotation_status) SENSITIVE = [] include Aws::Structure end |