Class: Aws::SecurityHub::Types::AwsKmsKeyDetails

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

Contains metadata about an KMS key.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#aws_account_idString

The twelve-digit account ID of the Amazon Web Services account that owns the KMS key.

Returns:

  • (String)


14067
14068
14069
14070
14071
14072
14073
14074
14075
14076
14077
14078
# File 'lib/aws-sdk-securityhub/types.rb', line 14067

class AwsKmsKeyDetails < Struct.new(
  :aws_account_id,
  :creation_date,
  :key_id,
  :key_manager,
  :key_state,
  :origin,
  :description,
  :key_rotation_status)
  SENSITIVE = []
  include Aws::Structure
end

#creation_dateFloat

Indicates when the KMS key was created.

For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.

Returns:

  • (Float)


14067
14068
14069
14070
14071
14072
14073
14074
14075
14076
14077
14078
# File 'lib/aws-sdk-securityhub/types.rb', line 14067

class AwsKmsKeyDetails < Struct.new(
  :aws_account_id,
  :creation_date,
  :key_id,
  :key_manager,
  :key_state,
  :origin,
  :description,
  :key_rotation_status)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A description of the KMS key.

Returns:

  • (String)


14067
14068
14069
14070
14071
14072
14073
14074
14075
14076
14077
14078
# File 'lib/aws-sdk-securityhub/types.rb', line 14067

class AwsKmsKeyDetails < Struct.new(
  :aws_account_id,
  :creation_date,
  :key_id,
  :key_manager,
  :key_state,
  :origin,
  :description,
  :key_rotation_status)
  SENSITIVE = []
  include Aws::Structure
end

#key_idString

The globally unique identifier for the KMS key.

Returns:

  • (String)


14067
14068
14069
14070
14071
14072
14073
14074
14075
14076
14077
14078
# File 'lib/aws-sdk-securityhub/types.rb', line 14067

class AwsKmsKeyDetails < Struct.new(
  :aws_account_id,
  :creation_date,
  :key_id,
  :key_manager,
  :key_state,
  :origin,
  :description,
  :key_rotation_status)
  SENSITIVE = []
  include Aws::Structure
end

#key_managerString

The manager of the KMS key. KMS keys in your Amazon Web Services account are either customer managed or Amazon Web Services managed.

Returns:

  • (String)


14067
14068
14069
14070
14071
14072
14073
14074
14075
14076
14077
14078
# File 'lib/aws-sdk-securityhub/types.rb', line 14067

class AwsKmsKeyDetails < Struct.new(
  :aws_account_id,
  :creation_date,
  :key_id,
  :key_manager,
  :key_state,
  :origin,
  :description,
  :key_rotation_status)
  SENSITIVE = []
  include Aws::Structure
end

#key_rotation_statusBoolean

Whether the key has key rotation enabled.

Returns:

  • (Boolean)


14067
14068
14069
14070
14071
14072
14073
14074
14075
14076
14077
14078
# File 'lib/aws-sdk-securityhub/types.rb', line 14067

class AwsKmsKeyDetails < Struct.new(
  :aws_account_id,
  :creation_date,
  :key_id,
  :key_manager,
  :key_state,
  :origin,
  :description,
  :key_rotation_status)
  SENSITIVE = []
  include Aws::Structure
end

#key_stateString

The state of the KMS key. Valid values are as follows:

  • Disabled

  • Enabled

  • PendingDeletion

  • PendingImport

  • Unavailable

Returns:

  • (String)


14067
14068
14069
14070
14071
14072
14073
14074
14075
14076
14077
14078
# File 'lib/aws-sdk-securityhub/types.rb', line 14067

class AwsKmsKeyDetails < Struct.new(
  :aws_account_id,
  :creation_date,
  :key_id,
  :key_manager,
  :key_state,
  :origin,
  :description,
  :key_rotation_status)
  SENSITIVE = []
  include Aws::Structure
end

#originString

The source of the KMS key material.

When this value is AWS_KMS, KMS created the key material.

When this value is EXTERNAL, the key material was imported from your existing key management infrastructure or the KMS key lacks key material.

When this value is AWS_CLOUDHSM, the key material was created in the CloudHSM cluster associated with a custom key store.

Returns:

  • (String)


14067
14068
14069
14070
14071
14072
14073
14074
14075
14076
14077
14078
# File 'lib/aws-sdk-securityhub/types.rb', line 14067

class AwsKmsKeyDetails < Struct.new(
  :aws_account_id,
  :creation_date,
  :key_id,
  :key_manager,
  :key_state,
  :origin,
  :description,
  :key_rotation_status)
  SENSITIVE = []
  include Aws::Structure
end