Class: Aws::SecurityHub::Types::AwsLambdaFunctionDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::AwsLambdaFunctionDetails
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Details about an Lambda function's configuration.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#architectures ⇒ Array<String>
The instruction set architecture that the function uses.
-
#code ⇒ Types::AwsLambdaFunctionCode
An
AwsLambdaFunctionCodeobject. -
#code_sha_256 ⇒ String
The SHA256 hash of the function's deployment package.
-
#dead_letter_config ⇒ Types::AwsLambdaFunctionDeadLetterConfig
The function's dead letter queue.
-
#environment ⇒ Types::AwsLambdaFunctionEnvironment
The function's environment variables.
-
#function_name ⇒ String
The name of the function.
-
#handler ⇒ String
The function that Lambda calls to begin executing your function.
-
#kms_key_arn ⇒ String
The KMS key that is used to encrypt the function's environment variables.
-
#last_modified ⇒ String
Indicates when the function was last updated.
-
#layers ⇒ Array<Types::AwsLambdaFunctionLayer>
The function's layers.
-
#master_arn ⇒ String
For Lambda@Edge functions, the ARN of the master function.
-
#memory_size ⇒ Integer
The memory that is allocated to the function.
-
#package_type ⇒ String
The type of deployment package that's used to deploy the function code to Lambda.
-
#revision_id ⇒ String
The latest updated revision of the function or alias.
-
#role ⇒ String
The function's execution role.
-
#runtime ⇒ String
The runtime environment for the Lambda function.
-
#timeout ⇒ Integer
The amount of time that Lambda allows a function to run before stopping it.
-
#tracing_config ⇒ Types::AwsLambdaFunctionTracingConfig
The function's X-Ray tracing configuration.
-
#version ⇒ String
The version of the Lambda function.
-
#vpc_config ⇒ Types::AwsLambdaFunctionVpcConfig
The function's networking configuration.
Instance Attribute Details
#architectures ⇒ Array<String>
The instruction set architecture that the function uses. Valid
values are x86_64 or arm64.
14327 14328 14329 14330 14331 14332 14333 14334 14335 14336 14337 14338 14339 14340 14341 14342 14343 14344 14345 14346 14347 14348 14349 14350 |
# File 'lib/aws-sdk-securityhub/types.rb', line 14327 class AwsLambdaFunctionDetails < Struct.new( :code, :code_sha_256, :dead_letter_config, :environment, :function_name, :handler, :kms_key_arn, :last_modified, :layers, :master_arn, :memory_size, :revision_id, :role, :runtime, :timeout, :tracing_config, :vpc_config, :version, :architectures, :package_type) SENSITIVE = [] include Aws::Structure end |
#code ⇒ Types::AwsLambdaFunctionCode
An AwsLambdaFunctionCode object.
14327 14328 14329 14330 14331 14332 14333 14334 14335 14336 14337 14338 14339 14340 14341 14342 14343 14344 14345 14346 14347 14348 14349 14350 |
# File 'lib/aws-sdk-securityhub/types.rb', line 14327 class AwsLambdaFunctionDetails < Struct.new( :code, :code_sha_256, :dead_letter_config, :environment, :function_name, :handler, :kms_key_arn, :last_modified, :layers, :master_arn, :memory_size, :revision_id, :role, :runtime, :timeout, :tracing_config, :vpc_config, :version, :architectures, :package_type) SENSITIVE = [] include Aws::Structure end |
#code_sha_256 ⇒ String
The SHA256 hash of the function's deployment package.
14327 14328 14329 14330 14331 14332 14333 14334 14335 14336 14337 14338 14339 14340 14341 14342 14343 14344 14345 14346 14347 14348 14349 14350 |
# File 'lib/aws-sdk-securityhub/types.rb', line 14327 class AwsLambdaFunctionDetails < Struct.new( :code, :code_sha_256, :dead_letter_config, :environment, :function_name, :handler, :kms_key_arn, :last_modified, :layers, :master_arn, :memory_size, :revision_id, :role, :runtime, :timeout, :tracing_config, :vpc_config, :version, :architectures, :package_type) SENSITIVE = [] include Aws::Structure end |
#dead_letter_config ⇒ Types::AwsLambdaFunctionDeadLetterConfig
The function's dead letter queue.
14327 14328 14329 14330 14331 14332 14333 14334 14335 14336 14337 14338 14339 14340 14341 14342 14343 14344 14345 14346 14347 14348 14349 14350 |
# File 'lib/aws-sdk-securityhub/types.rb', line 14327 class AwsLambdaFunctionDetails < Struct.new( :code, :code_sha_256, :dead_letter_config, :environment, :function_name, :handler, :kms_key_arn, :last_modified, :layers, :master_arn, :memory_size, :revision_id, :role, :runtime, :timeout, :tracing_config, :vpc_config, :version, :architectures, :package_type) SENSITIVE = [] include Aws::Structure end |
#environment ⇒ Types::AwsLambdaFunctionEnvironment
The function's environment variables.
14327 14328 14329 14330 14331 14332 14333 14334 14335 14336 14337 14338 14339 14340 14341 14342 14343 14344 14345 14346 14347 14348 14349 14350 |
# File 'lib/aws-sdk-securityhub/types.rb', line 14327 class AwsLambdaFunctionDetails < Struct.new( :code, :code_sha_256, :dead_letter_config, :environment, :function_name, :handler, :kms_key_arn, :last_modified, :layers, :master_arn, :memory_size, :revision_id, :role, :runtime, :timeout, :tracing_config, :vpc_config, :version, :architectures, :package_type) SENSITIVE = [] include Aws::Structure end |
#function_name ⇒ String
The name of the function.
14327 14328 14329 14330 14331 14332 14333 14334 14335 14336 14337 14338 14339 14340 14341 14342 14343 14344 14345 14346 14347 14348 14349 14350 |
# File 'lib/aws-sdk-securityhub/types.rb', line 14327 class AwsLambdaFunctionDetails < Struct.new( :code, :code_sha_256, :dead_letter_config, :environment, :function_name, :handler, :kms_key_arn, :last_modified, :layers, :master_arn, :memory_size, :revision_id, :role, :runtime, :timeout, :tracing_config, :vpc_config, :version, :architectures, :package_type) SENSITIVE = [] include Aws::Structure end |
#handler ⇒ String
The function that Lambda calls to begin executing your function.
14327 14328 14329 14330 14331 14332 14333 14334 14335 14336 14337 14338 14339 14340 14341 14342 14343 14344 14345 14346 14347 14348 14349 14350 |
# File 'lib/aws-sdk-securityhub/types.rb', line 14327 class AwsLambdaFunctionDetails < Struct.new( :code, :code_sha_256, :dead_letter_config, :environment, :function_name, :handler, :kms_key_arn, :last_modified, :layers, :master_arn, :memory_size, :revision_id, :role, :runtime, :timeout, :tracing_config, :vpc_config, :version, :architectures, :package_type) SENSITIVE = [] include Aws::Structure end |
#kms_key_arn ⇒ String
The KMS key that is used to encrypt the function's environment variables. This key is only returned if you've configured a customer managed customer managed key.
14327 14328 14329 14330 14331 14332 14333 14334 14335 14336 14337 14338 14339 14340 14341 14342 14343 14344 14345 14346 14347 14348 14349 14350 |
# File 'lib/aws-sdk-securityhub/types.rb', line 14327 class AwsLambdaFunctionDetails < Struct.new( :code, :code_sha_256, :dead_letter_config, :environment, :function_name, :handler, :kms_key_arn, :last_modified, :layers, :master_arn, :memory_size, :revision_id, :role, :runtime, :timeout, :tracing_config, :vpc_config, :version, :architectures, :package_type) SENSITIVE = [] include Aws::Structure end |
#last_modified ⇒ String
Indicates when the function was last updated.
For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.
14327 14328 14329 14330 14331 14332 14333 14334 14335 14336 14337 14338 14339 14340 14341 14342 14343 14344 14345 14346 14347 14348 14349 14350 |
# File 'lib/aws-sdk-securityhub/types.rb', line 14327 class AwsLambdaFunctionDetails < Struct.new( :code, :code_sha_256, :dead_letter_config, :environment, :function_name, :handler, :kms_key_arn, :last_modified, :layers, :master_arn, :memory_size, :revision_id, :role, :runtime, :timeout, :tracing_config, :vpc_config, :version, :architectures, :package_type) SENSITIVE = [] include Aws::Structure end |
#layers ⇒ Array<Types::AwsLambdaFunctionLayer>
The function's layers.
14327 14328 14329 14330 14331 14332 14333 14334 14335 14336 14337 14338 14339 14340 14341 14342 14343 14344 14345 14346 14347 14348 14349 14350 |
# File 'lib/aws-sdk-securityhub/types.rb', line 14327 class AwsLambdaFunctionDetails < Struct.new( :code, :code_sha_256, :dead_letter_config, :environment, :function_name, :handler, :kms_key_arn, :last_modified, :layers, :master_arn, :memory_size, :revision_id, :role, :runtime, :timeout, :tracing_config, :vpc_config, :version, :architectures, :package_type) SENSITIVE = [] include Aws::Structure end |
#master_arn ⇒ String
For Lambda@Edge functions, the ARN of the master function.
14327 14328 14329 14330 14331 14332 14333 14334 14335 14336 14337 14338 14339 14340 14341 14342 14343 14344 14345 14346 14347 14348 14349 14350 |
# File 'lib/aws-sdk-securityhub/types.rb', line 14327 class AwsLambdaFunctionDetails < Struct.new( :code, :code_sha_256, :dead_letter_config, :environment, :function_name, :handler, :kms_key_arn, :last_modified, :layers, :master_arn, :memory_size, :revision_id, :role, :runtime, :timeout, :tracing_config, :vpc_config, :version, :architectures, :package_type) SENSITIVE = [] include Aws::Structure end |
#memory_size ⇒ Integer
The memory that is allocated to the function.
14327 14328 14329 14330 14331 14332 14333 14334 14335 14336 14337 14338 14339 14340 14341 14342 14343 14344 14345 14346 14347 14348 14349 14350 |
# File 'lib/aws-sdk-securityhub/types.rb', line 14327 class AwsLambdaFunctionDetails < Struct.new( :code, :code_sha_256, :dead_letter_config, :environment, :function_name, :handler, :kms_key_arn, :last_modified, :layers, :master_arn, :memory_size, :revision_id, :role, :runtime, :timeout, :tracing_config, :vpc_config, :version, :architectures, :package_type) SENSITIVE = [] include Aws::Structure end |
#package_type ⇒ String
The type of deployment package that's used to deploy the function
code to Lambda. Set to Image for a container image and Zip for a
.zip file archive.
14327 14328 14329 14330 14331 14332 14333 14334 14335 14336 14337 14338 14339 14340 14341 14342 14343 14344 14345 14346 14347 14348 14349 14350 |
# File 'lib/aws-sdk-securityhub/types.rb', line 14327 class AwsLambdaFunctionDetails < Struct.new( :code, :code_sha_256, :dead_letter_config, :environment, :function_name, :handler, :kms_key_arn, :last_modified, :layers, :master_arn, :memory_size, :revision_id, :role, :runtime, :timeout, :tracing_config, :vpc_config, :version, :architectures, :package_type) SENSITIVE = [] include Aws::Structure end |
#revision_id ⇒ String
The latest updated revision of the function or alias.
14327 14328 14329 14330 14331 14332 14333 14334 14335 14336 14337 14338 14339 14340 14341 14342 14343 14344 14345 14346 14347 14348 14349 14350 |
# File 'lib/aws-sdk-securityhub/types.rb', line 14327 class AwsLambdaFunctionDetails < Struct.new( :code, :code_sha_256, :dead_letter_config, :environment, :function_name, :handler, :kms_key_arn, :last_modified, :layers, :master_arn, :memory_size, :revision_id, :role, :runtime, :timeout, :tracing_config, :vpc_config, :version, :architectures, :package_type) SENSITIVE = [] include Aws::Structure end |
#role ⇒ String
The function's execution role.
14327 14328 14329 14330 14331 14332 14333 14334 14335 14336 14337 14338 14339 14340 14341 14342 14343 14344 14345 14346 14347 14348 14349 14350 |
# File 'lib/aws-sdk-securityhub/types.rb', line 14327 class AwsLambdaFunctionDetails < Struct.new( :code, :code_sha_256, :dead_letter_config, :environment, :function_name, :handler, :kms_key_arn, :last_modified, :layers, :master_arn, :memory_size, :revision_id, :role, :runtime, :timeout, :tracing_config, :vpc_config, :version, :architectures, :package_type) SENSITIVE = [] include Aws::Structure end |
#runtime ⇒ String
The runtime environment for the Lambda function.
14327 14328 14329 14330 14331 14332 14333 14334 14335 14336 14337 14338 14339 14340 14341 14342 14343 14344 14345 14346 14347 14348 14349 14350 |
# File 'lib/aws-sdk-securityhub/types.rb', line 14327 class AwsLambdaFunctionDetails < Struct.new( :code, :code_sha_256, :dead_letter_config, :environment, :function_name, :handler, :kms_key_arn, :last_modified, :layers, :master_arn, :memory_size, :revision_id, :role, :runtime, :timeout, :tracing_config, :vpc_config, :version, :architectures, :package_type) SENSITIVE = [] include Aws::Structure end |
#timeout ⇒ Integer
The amount of time that Lambda allows a function to run before stopping it.
14327 14328 14329 14330 14331 14332 14333 14334 14335 14336 14337 14338 14339 14340 14341 14342 14343 14344 14345 14346 14347 14348 14349 14350 |
# File 'lib/aws-sdk-securityhub/types.rb', line 14327 class AwsLambdaFunctionDetails < Struct.new( :code, :code_sha_256, :dead_letter_config, :environment, :function_name, :handler, :kms_key_arn, :last_modified, :layers, :master_arn, :memory_size, :revision_id, :role, :runtime, :timeout, :tracing_config, :vpc_config, :version, :architectures, :package_type) SENSITIVE = [] include Aws::Structure end |
#tracing_config ⇒ Types::AwsLambdaFunctionTracingConfig
The function's X-Ray tracing configuration.
14327 14328 14329 14330 14331 14332 14333 14334 14335 14336 14337 14338 14339 14340 14341 14342 14343 14344 14345 14346 14347 14348 14349 14350 |
# File 'lib/aws-sdk-securityhub/types.rb', line 14327 class AwsLambdaFunctionDetails < Struct.new( :code, :code_sha_256, :dead_letter_config, :environment, :function_name, :handler, :kms_key_arn, :last_modified, :layers, :master_arn, :memory_size, :revision_id, :role, :runtime, :timeout, :tracing_config, :vpc_config, :version, :architectures, :package_type) SENSITIVE = [] include Aws::Structure end |
#version ⇒ String
The version of the Lambda function.
14327 14328 14329 14330 14331 14332 14333 14334 14335 14336 14337 14338 14339 14340 14341 14342 14343 14344 14345 14346 14347 14348 14349 14350 |
# File 'lib/aws-sdk-securityhub/types.rb', line 14327 class AwsLambdaFunctionDetails < Struct.new( :code, :code_sha_256, :dead_letter_config, :environment, :function_name, :handler, :kms_key_arn, :last_modified, :layers, :master_arn, :memory_size, :revision_id, :role, :runtime, :timeout, :tracing_config, :vpc_config, :version, :architectures, :package_type) SENSITIVE = [] include Aws::Structure end |
#vpc_config ⇒ Types::AwsLambdaFunctionVpcConfig
The function's networking configuration.
14327 14328 14329 14330 14331 14332 14333 14334 14335 14336 14337 14338 14339 14340 14341 14342 14343 14344 14345 14346 14347 14348 14349 14350 |
# File 'lib/aws-sdk-securityhub/types.rb', line 14327 class AwsLambdaFunctionDetails < Struct.new( :code, :code_sha_256, :dead_letter_config, :environment, :function_name, :handler, :kms_key_arn, :last_modified, :layers, :master_arn, :memory_size, :revision_id, :role, :runtime, :timeout, :tracing_config, :vpc_config, :version, :architectures, :package_type) SENSITIVE = [] include Aws::Structure end |