Class: Aws::SecurityHub::Types::AwsMskClusterClusterInfoDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::AwsMskClusterClusterInfoDetails
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Provide details about an Amazon Managed Streaming for Apache Kafka (Amazon MSK) cluster.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_authentication ⇒ Types::AwsMskClusterClusterInfoClientAuthenticationDetails
Provides information for different modes of client authentication.
-
#cluster_name ⇒ String
The name of the cluster.
-
#current_version ⇒ String
The current version of the cluster.
-
#encryption_info ⇒ Types::AwsMskClusterClusterInfoEncryptionInfoDetails
Includes encryption-related information, such as the KMS key used for encrypting data at rest and whether you want Amazon MSK to encrypt your data in transit.
-
#enhanced_monitoring ⇒ String
Specifies the level of monitoring for the cluster.
-
#number_of_broker_nodes ⇒ Integer
The number of broker nodes in the cluster.
Instance Attribute Details
#client_authentication ⇒ Types::AwsMskClusterClusterInfoClientAuthenticationDetails
Provides information for different modes of client authentication.
14659 14660 14661 14662 14663 14664 14665 14666 14667 14668 |
# File 'lib/aws-sdk-securityhub/types.rb', line 14659 class AwsMskClusterClusterInfoDetails < Struct.new( :encryption_info, :current_version, :number_of_broker_nodes, :cluster_name, :client_authentication, :enhanced_monitoring) SENSITIVE = [] include Aws::Structure end |
#cluster_name ⇒ String
The name of the cluster.
14659 14660 14661 14662 14663 14664 14665 14666 14667 14668 |
# File 'lib/aws-sdk-securityhub/types.rb', line 14659 class AwsMskClusterClusterInfoDetails < Struct.new( :encryption_info, :current_version, :number_of_broker_nodes, :cluster_name, :client_authentication, :enhanced_monitoring) SENSITIVE = [] include Aws::Structure end |
#current_version ⇒ String
The current version of the cluster.
14659 14660 14661 14662 14663 14664 14665 14666 14667 14668 |
# File 'lib/aws-sdk-securityhub/types.rb', line 14659 class AwsMskClusterClusterInfoDetails < Struct.new( :encryption_info, :current_version, :number_of_broker_nodes, :cluster_name, :client_authentication, :enhanced_monitoring) SENSITIVE = [] include Aws::Structure end |
#encryption_info ⇒ Types::AwsMskClusterClusterInfoEncryptionInfoDetails
Includes encryption-related information, such as the KMS key used for encrypting data at rest and whether you want Amazon MSK to encrypt your data in transit.
14659 14660 14661 14662 14663 14664 14665 14666 14667 14668 |
# File 'lib/aws-sdk-securityhub/types.rb', line 14659 class AwsMskClusterClusterInfoDetails < Struct.new( :encryption_info, :current_version, :number_of_broker_nodes, :cluster_name, :client_authentication, :enhanced_monitoring) SENSITIVE = [] include Aws::Structure end |
#enhanced_monitoring ⇒ String
Specifies the level of monitoring for the cluster.
14659 14660 14661 14662 14663 14664 14665 14666 14667 14668 |
# File 'lib/aws-sdk-securityhub/types.rb', line 14659 class AwsMskClusterClusterInfoDetails < Struct.new( :encryption_info, :current_version, :number_of_broker_nodes, :cluster_name, :client_authentication, :enhanced_monitoring) SENSITIVE = [] include Aws::Structure end |
#number_of_broker_nodes ⇒ Integer
The number of broker nodes in the cluster.
14659 14660 14661 14662 14663 14664 14665 14666 14667 14668 |
# File 'lib/aws-sdk-securityhub/types.rb', line 14659 class AwsMskClusterClusterInfoDetails < Struct.new( :encryption_info, :current_version, :number_of_broker_nodes, :cluster_name, :client_authentication, :enhanced_monitoring) SENSITIVE = [] include Aws::Structure end |