Class: Aws::SecurityHub::Types::AwsMskClusterClusterInfoDetails

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

Provide details about an Amazon Managed Streaming for Apache Kafka (Amazon MSK) cluster.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_authenticationTypes::AwsMskClusterClusterInfoClientAuthenticationDetails

Provides information for different modes of client authentication.



14558
14559
14560
14561
14562
14563
14564
14565
14566
14567
# File 'lib/aws-sdk-securityhub/types.rb', line 14558

class AwsMskClusterClusterInfoDetails < Struct.new(
  :encryption_info,
  :current_version,
  :number_of_broker_nodes,
  :cluster_name,
  :client_authentication,
  :enhanced_monitoring)
  SENSITIVE = []
  include Aws::Structure
end

#cluster_nameString

The name of the cluster.

Returns:

  • (String)


14558
14559
14560
14561
14562
14563
14564
14565
14566
14567
# File 'lib/aws-sdk-securityhub/types.rb', line 14558

class AwsMskClusterClusterInfoDetails < Struct.new(
  :encryption_info,
  :current_version,
  :number_of_broker_nodes,
  :cluster_name,
  :client_authentication,
  :enhanced_monitoring)
  SENSITIVE = []
  include Aws::Structure
end

#current_versionString

The current version of the cluster.

Returns:

  • (String)


14558
14559
14560
14561
14562
14563
14564
14565
14566
14567
# File 'lib/aws-sdk-securityhub/types.rb', line 14558

class AwsMskClusterClusterInfoDetails < Struct.new(
  :encryption_info,
  :current_version,
  :number_of_broker_nodes,
  :cluster_name,
  :client_authentication,
  :enhanced_monitoring)
  SENSITIVE = []
  include Aws::Structure
end

#encryption_infoTypes::AwsMskClusterClusterInfoEncryptionInfoDetails

Includes encryption-related information, such as the KMS key used for encrypting data at rest and whether you want Amazon MSK to encrypt your data in transit.



14558
14559
14560
14561
14562
14563
14564
14565
14566
14567
# File 'lib/aws-sdk-securityhub/types.rb', line 14558

class AwsMskClusterClusterInfoDetails < Struct.new(
  :encryption_info,
  :current_version,
  :number_of_broker_nodes,
  :cluster_name,
  :client_authentication,
  :enhanced_monitoring)
  SENSITIVE = []
  include Aws::Structure
end

#enhanced_monitoringString

Specifies the level of monitoring for the cluster.

Returns:

  • (String)


14558
14559
14560
14561
14562
14563
14564
14565
14566
14567
# File 'lib/aws-sdk-securityhub/types.rb', line 14558

class AwsMskClusterClusterInfoDetails < Struct.new(
  :encryption_info,
  :current_version,
  :number_of_broker_nodes,
  :cluster_name,
  :client_authentication,
  :enhanced_monitoring)
  SENSITIVE = []
  include Aws::Structure
end

#number_of_broker_nodesInteger

The number of broker nodes in the cluster.

Returns:

  • (Integer)


14558
14559
14560
14561
14562
14563
14564
14565
14566
14567
# File 'lib/aws-sdk-securityhub/types.rb', line 14558

class AwsMskClusterClusterInfoDetails < Struct.new(
  :encryption_info,
  :current_version,
  :number_of_broker_nodes,
  :cluster_name,
  :client_authentication,
  :enhanced_monitoring)
  SENSITIVE = []
  include Aws::Structure
end