Class: Aws::SecurityHub::Types::AwsMskClusterClusterInfoEncryptionInfoEncryptionInTransitDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::AwsMskClusterClusterInfoEncryptionInfoEncryptionInTransitDetails
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
The settings for encrypting data in transit.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_broker ⇒ String
Indicates the encryption setting for data in transit between clients and brokers.
-
#in_cluster ⇒ Boolean
When set to
true, it indicates that data communication among the broker nodes of the cluster is encrypted.
Instance Attribute Details
#client_broker ⇒ String
Indicates the encryption setting for data in transit between clients and brokers.
14724 14725 14726 14727 14728 14729 |
# File 'lib/aws-sdk-securityhub/types.rb', line 14724 class AwsMskClusterClusterInfoEncryptionInfoEncryptionInTransitDetails < Struct.new( :in_cluster, :client_broker) SENSITIVE = [] include Aws::Structure end |
#in_cluster ⇒ Boolean
When set to true, it indicates that data communication among the
broker nodes of the cluster is encrypted. When set to false, the
communication happens in plain text. The default value is true.
14724 14725 14726 14727 14728 14729 |
# File 'lib/aws-sdk-securityhub/types.rb', line 14724 class AwsMskClusterClusterInfoEncryptionInfoEncryptionInTransitDetails < Struct.new( :in_cluster, :client_broker) SENSITIVE = [] include Aws::Structure end |