Class: Aws::SecurityHub::Types::AwsNetworkFirewallFirewallDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::AwsNetworkFirewallFirewallDetails
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Details about an Network Firewall firewall.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#delete_protection ⇒ Boolean
Whether the firewall is protected from deletion.
-
#description ⇒ String
A description of the firewall.
-
#firewall_arn ⇒ String
The ARN of the firewall.
-
#firewall_id ⇒ String
The identifier of the firewall.
-
#firewall_name ⇒ String
A descriptive name of the firewall.
-
#firewall_policy_arn ⇒ String
The ARN of the firewall policy.
-
#firewall_policy_change_protection ⇒ Boolean
Whether the firewall is protected from a change to the firewall policy.
-
#subnet_change_protection ⇒ Boolean
Whether the firewall is protected from a change to the subnet associations.
-
#subnet_mappings ⇒ Array<Types::AwsNetworkFirewallFirewallSubnetMappingsDetails>
The public subnets that Network Firewall uses for the firewall.
-
#vpc_id ⇒ String
The identifier of the VPC where the firewall is used.
Instance Attribute Details
#delete_protection ⇒ Boolean
Whether the firewall is protected from deletion. If set to true,
then the firewall cannot be deleted.
14825 14826 14827 14828 14829 14830 14831 14832 14833 14834 14835 14836 14837 14838 |
# File 'lib/aws-sdk-securityhub/types.rb', line 14825 class AwsNetworkFirewallFirewallDetails < Struct.new( :delete_protection, :description, :firewall_arn, :firewall_id, :firewall_name, :firewall_policy_arn, :firewall_policy_change_protection, :subnet_change_protection, :subnet_mappings, :vpc_id) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the firewall.
14825 14826 14827 14828 14829 14830 14831 14832 14833 14834 14835 14836 14837 14838 |
# File 'lib/aws-sdk-securityhub/types.rb', line 14825 class AwsNetworkFirewallFirewallDetails < Struct.new( :delete_protection, :description, :firewall_arn, :firewall_id, :firewall_name, :firewall_policy_arn, :firewall_policy_change_protection, :subnet_change_protection, :subnet_mappings, :vpc_id) SENSITIVE = [] include Aws::Structure end |
#firewall_arn ⇒ String
The ARN of the firewall.
14825 14826 14827 14828 14829 14830 14831 14832 14833 14834 14835 14836 14837 14838 |
# File 'lib/aws-sdk-securityhub/types.rb', line 14825 class AwsNetworkFirewallFirewallDetails < Struct.new( :delete_protection, :description, :firewall_arn, :firewall_id, :firewall_name, :firewall_policy_arn, :firewall_policy_change_protection, :subnet_change_protection, :subnet_mappings, :vpc_id) SENSITIVE = [] include Aws::Structure end |
#firewall_id ⇒ String
The identifier of the firewall.
14825 14826 14827 14828 14829 14830 14831 14832 14833 14834 14835 14836 14837 14838 |
# File 'lib/aws-sdk-securityhub/types.rb', line 14825 class AwsNetworkFirewallFirewallDetails < Struct.new( :delete_protection, :description, :firewall_arn, :firewall_id, :firewall_name, :firewall_policy_arn, :firewall_policy_change_protection, :subnet_change_protection, :subnet_mappings, :vpc_id) SENSITIVE = [] include Aws::Structure end |
#firewall_name ⇒ String
A descriptive name of the firewall.
14825 14826 14827 14828 14829 14830 14831 14832 14833 14834 14835 14836 14837 14838 |
# File 'lib/aws-sdk-securityhub/types.rb', line 14825 class AwsNetworkFirewallFirewallDetails < Struct.new( :delete_protection, :description, :firewall_arn, :firewall_id, :firewall_name, :firewall_policy_arn, :firewall_policy_change_protection, :subnet_change_protection, :subnet_mappings, :vpc_id) SENSITIVE = [] include Aws::Structure end |
#firewall_policy_arn ⇒ String
The ARN of the firewall policy.
14825 14826 14827 14828 14829 14830 14831 14832 14833 14834 14835 14836 14837 14838 |
# File 'lib/aws-sdk-securityhub/types.rb', line 14825 class AwsNetworkFirewallFirewallDetails < Struct.new( :delete_protection, :description, :firewall_arn, :firewall_id, :firewall_name, :firewall_policy_arn, :firewall_policy_change_protection, :subnet_change_protection, :subnet_mappings, :vpc_id) SENSITIVE = [] include Aws::Structure end |
#firewall_policy_change_protection ⇒ Boolean
Whether the firewall is protected from a change to the firewall
policy. If set to true, you cannot associate a different policy
with the firewall.
14825 14826 14827 14828 14829 14830 14831 14832 14833 14834 14835 14836 14837 14838 |
# File 'lib/aws-sdk-securityhub/types.rb', line 14825 class AwsNetworkFirewallFirewallDetails < Struct.new( :delete_protection, :description, :firewall_arn, :firewall_id, :firewall_name, :firewall_policy_arn, :firewall_policy_change_protection, :subnet_change_protection, :subnet_mappings, :vpc_id) SENSITIVE = [] include Aws::Structure end |
#subnet_change_protection ⇒ Boolean
Whether the firewall is protected from a change to the subnet
associations. If set to true, you cannot map different subnets to
the firewall.
14825 14826 14827 14828 14829 14830 14831 14832 14833 14834 14835 14836 14837 14838 |
# File 'lib/aws-sdk-securityhub/types.rb', line 14825 class AwsNetworkFirewallFirewallDetails < Struct.new( :delete_protection, :description, :firewall_arn, :firewall_id, :firewall_name, :firewall_policy_arn, :firewall_policy_change_protection, :subnet_change_protection, :subnet_mappings, :vpc_id) SENSITIVE = [] include Aws::Structure end |
#subnet_mappings ⇒ Array<Types::AwsNetworkFirewallFirewallSubnetMappingsDetails>
The public subnets that Network Firewall uses for the firewall. Each subnet must belong to a different Availability Zone.
14825 14826 14827 14828 14829 14830 14831 14832 14833 14834 14835 14836 14837 14838 |
# File 'lib/aws-sdk-securityhub/types.rb', line 14825 class AwsNetworkFirewallFirewallDetails < Struct.new( :delete_protection, :description, :firewall_arn, :firewall_id, :firewall_name, :firewall_policy_arn, :firewall_policy_change_protection, :subnet_change_protection, :subnet_mappings, :vpc_id) SENSITIVE = [] include Aws::Structure end |
#vpc_id ⇒ String
The identifier of the VPC where the firewall is used.
14825 14826 14827 14828 14829 14830 14831 14832 14833 14834 14835 14836 14837 14838 |
# File 'lib/aws-sdk-securityhub/types.rb', line 14825 class AwsNetworkFirewallFirewallDetails < Struct.new( :delete_protection, :description, :firewall_arn, :firewall_id, :firewall_name, :firewall_policy_arn, :firewall_policy_change_protection, :subnet_change_protection, :subnet_mappings, :vpc_id) SENSITIVE = [] include Aws::Structure end |