Class: Aws::SecurityHub::Types::AwsNetworkFirewallRuleGroupDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::AwsNetworkFirewallRuleGroupDetails
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Details about an Network Firewall rule group. Rule groups are used to inspect and control network traffic. Stateless rule groups apply to individual packets. Stateful rule groups apply to packets in the context of their traffic flow.
Rule groups are referenced in firewall policies.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#capacity ⇒ Integer
The maximum number of operating resources that this rule group can use.
-
#description ⇒ String
A description of the rule group.
-
#rule_group ⇒ Types::RuleGroupDetails
Details about the rule group.
-
#rule_group_arn ⇒ String
The ARN of the rule group.
-
#rule_group_id ⇒ String
The identifier of the rule group.
-
#rule_group_name ⇒ String
The descriptive name of the rule group.
-
#type ⇒ String
The type of rule group.
Instance Attribute Details
#capacity ⇒ Integer
The maximum number of operating resources that this rule group can use.
14797 14798 14799 14800 14801 14802 14803 14804 14805 14806 14807 |
# File 'lib/aws-sdk-securityhub/types.rb', line 14797 class AwsNetworkFirewallRuleGroupDetails < Struct.new( :capacity, :description, :rule_group, :rule_group_arn, :rule_group_id, :rule_group_name, :type) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the rule group.
14797 14798 14799 14800 14801 14802 14803 14804 14805 14806 14807 |
# File 'lib/aws-sdk-securityhub/types.rb', line 14797 class AwsNetworkFirewallRuleGroupDetails < Struct.new( :capacity, :description, :rule_group, :rule_group_arn, :rule_group_id, :rule_group_name, :type) SENSITIVE = [] include Aws::Structure end |
#rule_group ⇒ Types::RuleGroupDetails
Details about the rule group.
14797 14798 14799 14800 14801 14802 14803 14804 14805 14806 14807 |
# File 'lib/aws-sdk-securityhub/types.rb', line 14797 class AwsNetworkFirewallRuleGroupDetails < Struct.new( :capacity, :description, :rule_group, :rule_group_arn, :rule_group_id, :rule_group_name, :type) SENSITIVE = [] include Aws::Structure end |
#rule_group_arn ⇒ String
The ARN of the rule group.
14797 14798 14799 14800 14801 14802 14803 14804 14805 14806 14807 |
# File 'lib/aws-sdk-securityhub/types.rb', line 14797 class AwsNetworkFirewallRuleGroupDetails < Struct.new( :capacity, :description, :rule_group, :rule_group_arn, :rule_group_id, :rule_group_name, :type) SENSITIVE = [] include Aws::Structure end |
#rule_group_id ⇒ String
The identifier of the rule group.
14797 14798 14799 14800 14801 14802 14803 14804 14805 14806 14807 |
# File 'lib/aws-sdk-securityhub/types.rb', line 14797 class AwsNetworkFirewallRuleGroupDetails < Struct.new( :capacity, :description, :rule_group, :rule_group_arn, :rule_group_id, :rule_group_name, :type) SENSITIVE = [] include Aws::Structure end |
#rule_group_name ⇒ String
The descriptive name of the rule group.
14797 14798 14799 14800 14801 14802 14803 14804 14805 14806 14807 |
# File 'lib/aws-sdk-securityhub/types.rb', line 14797 class AwsNetworkFirewallRuleGroupDetails < Struct.new( :capacity, :description, :rule_group, :rule_group_arn, :rule_group_id, :rule_group_name, :type) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of rule group. A rule group can be stateful or stateless.
14797 14798 14799 14800 14801 14802 14803 14804 14805 14806 14807 |
# File 'lib/aws-sdk-securityhub/types.rb', line 14797 class AwsNetworkFirewallRuleGroupDetails < Struct.new( :capacity, :description, :rule_group, :rule_group_arn, :rule_group_id, :rule_group_name, :type) SENSITIVE = [] include Aws::Structure end |