Class: Aws::SecurityHub::Types::AwsRdsDbClusterDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::AwsRdsDbClusterDetails
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Information about an Amazon RDS DB cluster.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#activity_stream_status ⇒ String
The status of the database activity stream.
-
#allocated_storage ⇒ Integer
For all database engines except Aurora, specifies the allocated storage size in gibibytes (GiB).
-
#associated_roles ⇒ Array<Types::AwsRdsDbClusterAssociatedRole>
A list of the IAM roles that are associated with the DB cluster.
-
#auto_minor_version_upgrade ⇒ Boolean
Indicates if minor version upgrades are automatically applied to the cluster.
-
#availability_zones ⇒ Array<String>
A list of Availability Zones (AZs) where instances in the DB cluster can be created.
-
#backup_retention_period ⇒ Integer
The number of days for which automated backups are retained.
-
#cluster_create_time ⇒ String
Indicates when the DB cluster was created, in Universal Coordinated Time (UTC).
-
#copy_tags_to_snapshot ⇒ Boolean
Whether tags are copied from the DB cluster to snapshots of the DB cluster.
-
#cross_account_clone ⇒ Boolean
Whether the DB cluster is a clone of a DB cluster owned by a different Amazon Web Services account.
-
#custom_endpoints ⇒ Array<String>
A list of custom endpoints for the DB cluster.
-
#database_name ⇒ String
The name of the database.
-
#db_cluster_identifier ⇒ String
The DB cluster identifier that the user assigned to the cluster.
-
#db_cluster_members ⇒ Array<Types::AwsRdsDbClusterMember>
The list of instances that make up the DB cluster.
-
#db_cluster_option_group_memberships ⇒ Array<Types::AwsRdsDbClusterOptionGroupMembership>
The list of option group memberships for this DB cluster.
-
#db_cluster_parameter_group ⇒ String
The name of the DB cluster parameter group for the DB cluster.
-
#db_cluster_resource_id ⇒ String
The identifier of the DB cluster.
-
#db_subnet_group ⇒ String
The subnet group that is associated with the DB cluster, including the name, description, and subnets in the subnet group.
-
#deletion_protection ⇒ Boolean
Whether the DB cluster has deletion protection enabled.
-
#domain_memberships ⇒ Array<Types::AwsRdsDbDomainMembership>
The Active Directory domain membership records that are associated with the DB cluster.
-
#enabled_cloud_watch_logs_exports ⇒ Array<String>
A list of log types that this DB cluster is configured to export to CloudWatch Logs.
-
#endpoint ⇒ String
The connection endpoint for the primary instance of the DB cluster.
-
#engine ⇒ String
The name of the database engine to use for this DB cluster.
-
#engine_mode ⇒ String
The database engine mode of the DB cluster.Valid values are as follows:.
-
#engine_version ⇒ String
The version number of the database engine to use.
-
#hosted_zone_id ⇒ String
Specifies the identifier that Amazon Route 53 assigns when you create a hosted zone.
-
#http_endpoint_enabled ⇒ Boolean
Whether the HTTP endpoint for an Aurora Serverless DB cluster is enabled.
-
#iam_database_authentication_enabled ⇒ Boolean
Whether the mapping of IAM accounts to database accounts is enabled.
-
#kms_key_id ⇒ String
The ARN of the KMS master key that is used to encrypt the database instances in the DB cluster.
-
#master_username ⇒ String
The name of the master user for the DB cluster.
-
#multi_az ⇒ Boolean
Whether the DB cluster has instances in multiple Availability Zones.
-
#port ⇒ Integer
The port number on which the DB instances in the DB cluster accept connections.
-
#preferred_backup_window ⇒ String
The range of time each day when automated backups are created, if automated backups are enabled.
-
#preferred_maintenance_window ⇒ String
The weekly time range during which system maintenance can occur, in Universal Coordinated Time (UTC).
-
#read_replica_identifiers ⇒ Array<String>
The identifiers of the read replicas that are associated with this DB cluster.
-
#reader_endpoint ⇒ String
The reader endpoint for the DB cluster.
-
#status ⇒ String
The current status of this DB cluster.
-
#storage_encrypted ⇒ Boolean
Whether the DB cluster is encrypted.
-
#vpc_security_groups ⇒ Array<Types::AwsRdsDbInstanceVpcSecurityGroup>
A list of VPC security groups that the DB cluster belongs to.
Instance Attribute Details
#activity_stream_status ⇒ String
The status of the database activity stream. Valid values are as follows:
-
‘started`
-
‘starting`
-
‘stopped`
-
‘stopping`
15507 15508 15509 15510 15511 15512 15513 15514 15515 15516 15517 15518 15519 15520 15521 15522 15523 15524 15525 15526 15527 15528 15529 15530 15531 15532 15533 15534 15535 15536 15537 15538 15539 15540 15541 15542 15543 15544 15545 15546 15547 15548 |
# File 'lib/aws-sdk-securityhub/types.rb', line 15507 class AwsRdsDbClusterDetails < Struct.new( :allocated_storage, :availability_zones, :backup_retention_period, :database_name, :status, :endpoint, :reader_endpoint, :custom_endpoints, :multi_az, :engine, :engine_version, :port, :master_username, :preferred_backup_window, :preferred_maintenance_window, :read_replica_identifiers, :vpc_security_groups, :hosted_zone_id, :storage_encrypted, :kms_key_id, :db_cluster_resource_id, :associated_roles, :cluster_create_time, :enabled_cloud_watch_logs_exports, :engine_mode, :deletion_protection, :http_endpoint_enabled, :activity_stream_status, :copy_tags_to_snapshot, :cross_account_clone, :domain_memberships, :db_cluster_parameter_group, :db_subnet_group, :db_cluster_option_group_memberships, :db_cluster_identifier, :db_cluster_members, :iam_database_authentication_enabled, :auto_minor_version_upgrade) SENSITIVE = [] include Aws::Structure end |
#allocated_storage ⇒ Integer
For all database engines except Aurora, specifies the allocated storage size in gibibytes (GiB).
15507 15508 15509 15510 15511 15512 15513 15514 15515 15516 15517 15518 15519 15520 15521 15522 15523 15524 15525 15526 15527 15528 15529 15530 15531 15532 15533 15534 15535 15536 15537 15538 15539 15540 15541 15542 15543 15544 15545 15546 15547 15548 |
# File 'lib/aws-sdk-securityhub/types.rb', line 15507 class AwsRdsDbClusterDetails < Struct.new( :allocated_storage, :availability_zones, :backup_retention_period, :database_name, :status, :endpoint, :reader_endpoint, :custom_endpoints, :multi_az, :engine, :engine_version, :port, :master_username, :preferred_backup_window, :preferred_maintenance_window, :read_replica_identifiers, :vpc_security_groups, :hosted_zone_id, :storage_encrypted, :kms_key_id, :db_cluster_resource_id, :associated_roles, :cluster_create_time, :enabled_cloud_watch_logs_exports, :engine_mode, :deletion_protection, :http_endpoint_enabled, :activity_stream_status, :copy_tags_to_snapshot, :cross_account_clone, :domain_memberships, :db_cluster_parameter_group, :db_subnet_group, :db_cluster_option_group_memberships, :db_cluster_identifier, :db_cluster_members, :iam_database_authentication_enabled, :auto_minor_version_upgrade) SENSITIVE = [] include Aws::Structure end |
#associated_roles ⇒ Array<Types::AwsRdsDbClusterAssociatedRole>
A list of the IAM roles that are associated with the DB cluster.
15507 15508 15509 15510 15511 15512 15513 15514 15515 15516 15517 15518 15519 15520 15521 15522 15523 15524 15525 15526 15527 15528 15529 15530 15531 15532 15533 15534 15535 15536 15537 15538 15539 15540 15541 15542 15543 15544 15545 15546 15547 15548 |
# File 'lib/aws-sdk-securityhub/types.rb', line 15507 class AwsRdsDbClusterDetails < Struct.new( :allocated_storage, :availability_zones, :backup_retention_period, :database_name, :status, :endpoint, :reader_endpoint, :custom_endpoints, :multi_az, :engine, :engine_version, :port, :master_username, :preferred_backup_window, :preferred_maintenance_window, :read_replica_identifiers, :vpc_security_groups, :hosted_zone_id, :storage_encrypted, :kms_key_id, :db_cluster_resource_id, :associated_roles, :cluster_create_time, :enabled_cloud_watch_logs_exports, :engine_mode, :deletion_protection, :http_endpoint_enabled, :activity_stream_status, :copy_tags_to_snapshot, :cross_account_clone, :domain_memberships, :db_cluster_parameter_group, :db_subnet_group, :db_cluster_option_group_memberships, :db_cluster_identifier, :db_cluster_members, :iam_database_authentication_enabled, :auto_minor_version_upgrade) SENSITIVE = [] include Aws::Structure end |
#auto_minor_version_upgrade ⇒ Boolean
Indicates if minor version upgrades are automatically applied to the cluster.
15507 15508 15509 15510 15511 15512 15513 15514 15515 15516 15517 15518 15519 15520 15521 15522 15523 15524 15525 15526 15527 15528 15529 15530 15531 15532 15533 15534 15535 15536 15537 15538 15539 15540 15541 15542 15543 15544 15545 15546 15547 15548 |
# File 'lib/aws-sdk-securityhub/types.rb', line 15507 class AwsRdsDbClusterDetails < Struct.new( :allocated_storage, :availability_zones, :backup_retention_period, :database_name, :status, :endpoint, :reader_endpoint, :custom_endpoints, :multi_az, :engine, :engine_version, :port, :master_username, :preferred_backup_window, :preferred_maintenance_window, :read_replica_identifiers, :vpc_security_groups, :hosted_zone_id, :storage_encrypted, :kms_key_id, :db_cluster_resource_id, :associated_roles, :cluster_create_time, :enabled_cloud_watch_logs_exports, :engine_mode, :deletion_protection, :http_endpoint_enabled, :activity_stream_status, :copy_tags_to_snapshot, :cross_account_clone, :domain_memberships, :db_cluster_parameter_group, :db_subnet_group, :db_cluster_option_group_memberships, :db_cluster_identifier, :db_cluster_members, :iam_database_authentication_enabled, :auto_minor_version_upgrade) SENSITIVE = [] include Aws::Structure end |
#availability_zones ⇒ Array<String>
A list of Availability Zones (AZs) where instances in the DB cluster can be created.
15507 15508 15509 15510 15511 15512 15513 15514 15515 15516 15517 15518 15519 15520 15521 15522 15523 15524 15525 15526 15527 15528 15529 15530 15531 15532 15533 15534 15535 15536 15537 15538 15539 15540 15541 15542 15543 15544 15545 15546 15547 15548 |
# File 'lib/aws-sdk-securityhub/types.rb', line 15507 class AwsRdsDbClusterDetails < Struct.new( :allocated_storage, :availability_zones, :backup_retention_period, :database_name, :status, :endpoint, :reader_endpoint, :custom_endpoints, :multi_az, :engine, :engine_version, :port, :master_username, :preferred_backup_window, :preferred_maintenance_window, :read_replica_identifiers, :vpc_security_groups, :hosted_zone_id, :storage_encrypted, :kms_key_id, :db_cluster_resource_id, :associated_roles, :cluster_create_time, :enabled_cloud_watch_logs_exports, :engine_mode, :deletion_protection, :http_endpoint_enabled, :activity_stream_status, :copy_tags_to_snapshot, :cross_account_clone, :domain_memberships, :db_cluster_parameter_group, :db_subnet_group, :db_cluster_option_group_memberships, :db_cluster_identifier, :db_cluster_members, :iam_database_authentication_enabled, :auto_minor_version_upgrade) SENSITIVE = [] include Aws::Structure end |
#backup_retention_period ⇒ Integer
The number of days for which automated backups are retained.
15507 15508 15509 15510 15511 15512 15513 15514 15515 15516 15517 15518 15519 15520 15521 15522 15523 15524 15525 15526 15527 15528 15529 15530 15531 15532 15533 15534 15535 15536 15537 15538 15539 15540 15541 15542 15543 15544 15545 15546 15547 15548 |
# File 'lib/aws-sdk-securityhub/types.rb', line 15507 class AwsRdsDbClusterDetails < Struct.new( :allocated_storage, :availability_zones, :backup_retention_period, :database_name, :status, :endpoint, :reader_endpoint, :custom_endpoints, :multi_az, :engine, :engine_version, :port, :master_username, :preferred_backup_window, :preferred_maintenance_window, :read_replica_identifiers, :vpc_security_groups, :hosted_zone_id, :storage_encrypted, :kms_key_id, :db_cluster_resource_id, :associated_roles, :cluster_create_time, :enabled_cloud_watch_logs_exports, :engine_mode, :deletion_protection, :http_endpoint_enabled, :activity_stream_status, :copy_tags_to_snapshot, :cross_account_clone, :domain_memberships, :db_cluster_parameter_group, :db_subnet_group, :db_cluster_option_group_memberships, :db_cluster_identifier, :db_cluster_members, :iam_database_authentication_enabled, :auto_minor_version_upgrade) SENSITIVE = [] include Aws::Structure end |
#cluster_create_time ⇒ String
Indicates when the DB cluster was created, in Universal Coordinated Time (UTC).
For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see [Timestamps].
[1]: docs.aws.amazon.com/securityhub/1.0/APIReference/Welcome.html#timestamps
15507 15508 15509 15510 15511 15512 15513 15514 15515 15516 15517 15518 15519 15520 15521 15522 15523 15524 15525 15526 15527 15528 15529 15530 15531 15532 15533 15534 15535 15536 15537 15538 15539 15540 15541 15542 15543 15544 15545 15546 15547 15548 |
# File 'lib/aws-sdk-securityhub/types.rb', line 15507 class AwsRdsDbClusterDetails < Struct.new( :allocated_storage, :availability_zones, :backup_retention_period, :database_name, :status, :endpoint, :reader_endpoint, :custom_endpoints, :multi_az, :engine, :engine_version, :port, :master_username, :preferred_backup_window, :preferred_maintenance_window, :read_replica_identifiers, :vpc_security_groups, :hosted_zone_id, :storage_encrypted, :kms_key_id, :db_cluster_resource_id, :associated_roles, :cluster_create_time, :enabled_cloud_watch_logs_exports, :engine_mode, :deletion_protection, :http_endpoint_enabled, :activity_stream_status, :copy_tags_to_snapshot, :cross_account_clone, :domain_memberships, :db_cluster_parameter_group, :db_subnet_group, :db_cluster_option_group_memberships, :db_cluster_identifier, :db_cluster_members, :iam_database_authentication_enabled, :auto_minor_version_upgrade) SENSITIVE = [] include Aws::Structure end |
#copy_tags_to_snapshot ⇒ Boolean
Whether tags are copied from the DB cluster to snapshots of the DB cluster.
15507 15508 15509 15510 15511 15512 15513 15514 15515 15516 15517 15518 15519 15520 15521 15522 15523 15524 15525 15526 15527 15528 15529 15530 15531 15532 15533 15534 15535 15536 15537 15538 15539 15540 15541 15542 15543 15544 15545 15546 15547 15548 |
# File 'lib/aws-sdk-securityhub/types.rb', line 15507 class AwsRdsDbClusterDetails < Struct.new( :allocated_storage, :availability_zones, :backup_retention_period, :database_name, :status, :endpoint, :reader_endpoint, :custom_endpoints, :multi_az, :engine, :engine_version, :port, :master_username, :preferred_backup_window, :preferred_maintenance_window, :read_replica_identifiers, :vpc_security_groups, :hosted_zone_id, :storage_encrypted, :kms_key_id, :db_cluster_resource_id, :associated_roles, :cluster_create_time, :enabled_cloud_watch_logs_exports, :engine_mode, :deletion_protection, :http_endpoint_enabled, :activity_stream_status, :copy_tags_to_snapshot, :cross_account_clone, :domain_memberships, :db_cluster_parameter_group, :db_subnet_group, :db_cluster_option_group_memberships, :db_cluster_identifier, :db_cluster_members, :iam_database_authentication_enabled, :auto_minor_version_upgrade) SENSITIVE = [] include Aws::Structure end |
#cross_account_clone ⇒ Boolean
Whether the DB cluster is a clone of a DB cluster owned by a different Amazon Web Services account.
15507 15508 15509 15510 15511 15512 15513 15514 15515 15516 15517 15518 15519 15520 15521 15522 15523 15524 15525 15526 15527 15528 15529 15530 15531 15532 15533 15534 15535 15536 15537 15538 15539 15540 15541 15542 15543 15544 15545 15546 15547 15548 |
# File 'lib/aws-sdk-securityhub/types.rb', line 15507 class AwsRdsDbClusterDetails < Struct.new( :allocated_storage, :availability_zones, :backup_retention_period, :database_name, :status, :endpoint, :reader_endpoint, :custom_endpoints, :multi_az, :engine, :engine_version, :port, :master_username, :preferred_backup_window, :preferred_maintenance_window, :read_replica_identifiers, :vpc_security_groups, :hosted_zone_id, :storage_encrypted, :kms_key_id, :db_cluster_resource_id, :associated_roles, :cluster_create_time, :enabled_cloud_watch_logs_exports, :engine_mode, :deletion_protection, :http_endpoint_enabled, :activity_stream_status, :copy_tags_to_snapshot, :cross_account_clone, :domain_memberships, :db_cluster_parameter_group, :db_subnet_group, :db_cluster_option_group_memberships, :db_cluster_identifier, :db_cluster_members, :iam_database_authentication_enabled, :auto_minor_version_upgrade) SENSITIVE = [] include Aws::Structure end |
#custom_endpoints ⇒ Array<String>
A list of custom endpoints for the DB cluster.
15507 15508 15509 15510 15511 15512 15513 15514 15515 15516 15517 15518 15519 15520 15521 15522 15523 15524 15525 15526 15527 15528 15529 15530 15531 15532 15533 15534 15535 15536 15537 15538 15539 15540 15541 15542 15543 15544 15545 15546 15547 15548 |
# File 'lib/aws-sdk-securityhub/types.rb', line 15507 class AwsRdsDbClusterDetails < Struct.new( :allocated_storage, :availability_zones, :backup_retention_period, :database_name, :status, :endpoint, :reader_endpoint, :custom_endpoints, :multi_az, :engine, :engine_version, :port, :master_username, :preferred_backup_window, :preferred_maintenance_window, :read_replica_identifiers, :vpc_security_groups, :hosted_zone_id, :storage_encrypted, :kms_key_id, :db_cluster_resource_id, :associated_roles, :cluster_create_time, :enabled_cloud_watch_logs_exports, :engine_mode, :deletion_protection, :http_endpoint_enabled, :activity_stream_status, :copy_tags_to_snapshot, :cross_account_clone, :domain_memberships, :db_cluster_parameter_group, :db_subnet_group, :db_cluster_option_group_memberships, :db_cluster_identifier, :db_cluster_members, :iam_database_authentication_enabled, :auto_minor_version_upgrade) SENSITIVE = [] include Aws::Structure end |
#database_name ⇒ String
The name of the database.
15507 15508 15509 15510 15511 15512 15513 15514 15515 15516 15517 15518 15519 15520 15521 15522 15523 15524 15525 15526 15527 15528 15529 15530 15531 15532 15533 15534 15535 15536 15537 15538 15539 15540 15541 15542 15543 15544 15545 15546 15547 15548 |
# File 'lib/aws-sdk-securityhub/types.rb', line 15507 class AwsRdsDbClusterDetails < Struct.new( :allocated_storage, :availability_zones, :backup_retention_period, :database_name, :status, :endpoint, :reader_endpoint, :custom_endpoints, :multi_az, :engine, :engine_version, :port, :master_username, :preferred_backup_window, :preferred_maintenance_window, :read_replica_identifiers, :vpc_security_groups, :hosted_zone_id, :storage_encrypted, :kms_key_id, :db_cluster_resource_id, :associated_roles, :cluster_create_time, :enabled_cloud_watch_logs_exports, :engine_mode, :deletion_protection, :http_endpoint_enabled, :activity_stream_status, :copy_tags_to_snapshot, :cross_account_clone, :domain_memberships, :db_cluster_parameter_group, :db_subnet_group, :db_cluster_option_group_memberships, :db_cluster_identifier, :db_cluster_members, :iam_database_authentication_enabled, :auto_minor_version_upgrade) SENSITIVE = [] include Aws::Structure end |
#db_cluster_identifier ⇒ String
The DB cluster identifier that the user assigned to the cluster. This identifier is the unique key that identifies a DB cluster.
15507 15508 15509 15510 15511 15512 15513 15514 15515 15516 15517 15518 15519 15520 15521 15522 15523 15524 15525 15526 15527 15528 15529 15530 15531 15532 15533 15534 15535 15536 15537 15538 15539 15540 15541 15542 15543 15544 15545 15546 15547 15548 |
# File 'lib/aws-sdk-securityhub/types.rb', line 15507 class AwsRdsDbClusterDetails < Struct.new( :allocated_storage, :availability_zones, :backup_retention_period, :database_name, :status, :endpoint, :reader_endpoint, :custom_endpoints, :multi_az, :engine, :engine_version, :port, :master_username, :preferred_backup_window, :preferred_maintenance_window, :read_replica_identifiers, :vpc_security_groups, :hosted_zone_id, :storage_encrypted, :kms_key_id, :db_cluster_resource_id, :associated_roles, :cluster_create_time, :enabled_cloud_watch_logs_exports, :engine_mode, :deletion_protection, :http_endpoint_enabled, :activity_stream_status, :copy_tags_to_snapshot, :cross_account_clone, :domain_memberships, :db_cluster_parameter_group, :db_subnet_group, :db_cluster_option_group_memberships, :db_cluster_identifier, :db_cluster_members, :iam_database_authentication_enabled, :auto_minor_version_upgrade) SENSITIVE = [] include Aws::Structure end |
#db_cluster_members ⇒ Array<Types::AwsRdsDbClusterMember>
The list of instances that make up the DB cluster.
15507 15508 15509 15510 15511 15512 15513 15514 15515 15516 15517 15518 15519 15520 15521 15522 15523 15524 15525 15526 15527 15528 15529 15530 15531 15532 15533 15534 15535 15536 15537 15538 15539 15540 15541 15542 15543 15544 15545 15546 15547 15548 |
# File 'lib/aws-sdk-securityhub/types.rb', line 15507 class AwsRdsDbClusterDetails < Struct.new( :allocated_storage, :availability_zones, :backup_retention_period, :database_name, :status, :endpoint, :reader_endpoint, :custom_endpoints, :multi_az, :engine, :engine_version, :port, :master_username, :preferred_backup_window, :preferred_maintenance_window, :read_replica_identifiers, :vpc_security_groups, :hosted_zone_id, :storage_encrypted, :kms_key_id, :db_cluster_resource_id, :associated_roles, :cluster_create_time, :enabled_cloud_watch_logs_exports, :engine_mode, :deletion_protection, :http_endpoint_enabled, :activity_stream_status, :copy_tags_to_snapshot, :cross_account_clone, :domain_memberships, :db_cluster_parameter_group, :db_subnet_group, :db_cluster_option_group_memberships, :db_cluster_identifier, :db_cluster_members, :iam_database_authentication_enabled, :auto_minor_version_upgrade) SENSITIVE = [] include Aws::Structure end |
#db_cluster_option_group_memberships ⇒ Array<Types::AwsRdsDbClusterOptionGroupMembership>
The list of option group memberships for this DB cluster.
15507 15508 15509 15510 15511 15512 15513 15514 15515 15516 15517 15518 15519 15520 15521 15522 15523 15524 15525 15526 15527 15528 15529 15530 15531 15532 15533 15534 15535 15536 15537 15538 15539 15540 15541 15542 15543 15544 15545 15546 15547 15548 |
# File 'lib/aws-sdk-securityhub/types.rb', line 15507 class AwsRdsDbClusterDetails < Struct.new( :allocated_storage, :availability_zones, :backup_retention_period, :database_name, :status, :endpoint, :reader_endpoint, :custom_endpoints, :multi_az, :engine, :engine_version, :port, :master_username, :preferred_backup_window, :preferred_maintenance_window, :read_replica_identifiers, :vpc_security_groups, :hosted_zone_id, :storage_encrypted, :kms_key_id, :db_cluster_resource_id, :associated_roles, :cluster_create_time, :enabled_cloud_watch_logs_exports, :engine_mode, :deletion_protection, :http_endpoint_enabled, :activity_stream_status, :copy_tags_to_snapshot, :cross_account_clone, :domain_memberships, :db_cluster_parameter_group, :db_subnet_group, :db_cluster_option_group_memberships, :db_cluster_identifier, :db_cluster_members, :iam_database_authentication_enabled, :auto_minor_version_upgrade) SENSITIVE = [] include Aws::Structure end |
#db_cluster_parameter_group ⇒ String
The name of the DB cluster parameter group for the DB cluster.
15507 15508 15509 15510 15511 15512 15513 15514 15515 15516 15517 15518 15519 15520 15521 15522 15523 15524 15525 15526 15527 15528 15529 15530 15531 15532 15533 15534 15535 15536 15537 15538 15539 15540 15541 15542 15543 15544 15545 15546 15547 15548 |
# File 'lib/aws-sdk-securityhub/types.rb', line 15507 class AwsRdsDbClusterDetails < Struct.new( :allocated_storage, :availability_zones, :backup_retention_period, :database_name, :status, :endpoint, :reader_endpoint, :custom_endpoints, :multi_az, :engine, :engine_version, :port, :master_username, :preferred_backup_window, :preferred_maintenance_window, :read_replica_identifiers, :vpc_security_groups, :hosted_zone_id, :storage_encrypted, :kms_key_id, :db_cluster_resource_id, :associated_roles, :cluster_create_time, :enabled_cloud_watch_logs_exports, :engine_mode, :deletion_protection, :http_endpoint_enabled, :activity_stream_status, :copy_tags_to_snapshot, :cross_account_clone, :domain_memberships, :db_cluster_parameter_group, :db_subnet_group, :db_cluster_option_group_memberships, :db_cluster_identifier, :db_cluster_members, :iam_database_authentication_enabled, :auto_minor_version_upgrade) SENSITIVE = [] include Aws::Structure end |
#db_cluster_resource_id ⇒ String
The identifier of the DB cluster. The identifier must be unique within each Amazon Web Services Region and is immutable.
15507 15508 15509 15510 15511 15512 15513 15514 15515 15516 15517 15518 15519 15520 15521 15522 15523 15524 15525 15526 15527 15528 15529 15530 15531 15532 15533 15534 15535 15536 15537 15538 15539 15540 15541 15542 15543 15544 15545 15546 15547 15548 |
# File 'lib/aws-sdk-securityhub/types.rb', line 15507 class AwsRdsDbClusterDetails < Struct.new( :allocated_storage, :availability_zones, :backup_retention_period, :database_name, :status, :endpoint, :reader_endpoint, :custom_endpoints, :multi_az, :engine, :engine_version, :port, :master_username, :preferred_backup_window, :preferred_maintenance_window, :read_replica_identifiers, :vpc_security_groups, :hosted_zone_id, :storage_encrypted, :kms_key_id, :db_cluster_resource_id, :associated_roles, :cluster_create_time, :enabled_cloud_watch_logs_exports, :engine_mode, :deletion_protection, :http_endpoint_enabled, :activity_stream_status, :copy_tags_to_snapshot, :cross_account_clone, :domain_memberships, :db_cluster_parameter_group, :db_subnet_group, :db_cluster_option_group_memberships, :db_cluster_identifier, :db_cluster_members, :iam_database_authentication_enabled, :auto_minor_version_upgrade) SENSITIVE = [] include Aws::Structure end |
#db_subnet_group ⇒ String
The subnet group that is associated with the DB cluster, including the name, description, and subnets in the subnet group.
15507 15508 15509 15510 15511 15512 15513 15514 15515 15516 15517 15518 15519 15520 15521 15522 15523 15524 15525 15526 15527 15528 15529 15530 15531 15532 15533 15534 15535 15536 15537 15538 15539 15540 15541 15542 15543 15544 15545 15546 15547 15548 |
# File 'lib/aws-sdk-securityhub/types.rb', line 15507 class AwsRdsDbClusterDetails < Struct.new( :allocated_storage, :availability_zones, :backup_retention_period, :database_name, :status, :endpoint, :reader_endpoint, :custom_endpoints, :multi_az, :engine, :engine_version, :port, :master_username, :preferred_backup_window, :preferred_maintenance_window, :read_replica_identifiers, :vpc_security_groups, :hosted_zone_id, :storage_encrypted, :kms_key_id, :db_cluster_resource_id, :associated_roles, :cluster_create_time, :enabled_cloud_watch_logs_exports, :engine_mode, :deletion_protection, :http_endpoint_enabled, :activity_stream_status, :copy_tags_to_snapshot, :cross_account_clone, :domain_memberships, :db_cluster_parameter_group, :db_subnet_group, :db_cluster_option_group_memberships, :db_cluster_identifier, :db_cluster_members, :iam_database_authentication_enabled, :auto_minor_version_upgrade) SENSITIVE = [] include Aws::Structure end |
#deletion_protection ⇒ Boolean
Whether the DB cluster has deletion protection enabled.
15507 15508 15509 15510 15511 15512 15513 15514 15515 15516 15517 15518 15519 15520 15521 15522 15523 15524 15525 15526 15527 15528 15529 15530 15531 15532 15533 15534 15535 15536 15537 15538 15539 15540 15541 15542 15543 15544 15545 15546 15547 15548 |
# File 'lib/aws-sdk-securityhub/types.rb', line 15507 class AwsRdsDbClusterDetails < Struct.new( :allocated_storage, :availability_zones, :backup_retention_period, :database_name, :status, :endpoint, :reader_endpoint, :custom_endpoints, :multi_az, :engine, :engine_version, :port, :master_username, :preferred_backup_window, :preferred_maintenance_window, :read_replica_identifiers, :vpc_security_groups, :hosted_zone_id, :storage_encrypted, :kms_key_id, :db_cluster_resource_id, :associated_roles, :cluster_create_time, :enabled_cloud_watch_logs_exports, :engine_mode, :deletion_protection, :http_endpoint_enabled, :activity_stream_status, :copy_tags_to_snapshot, :cross_account_clone, :domain_memberships, :db_cluster_parameter_group, :db_subnet_group, :db_cluster_option_group_memberships, :db_cluster_identifier, :db_cluster_members, :iam_database_authentication_enabled, :auto_minor_version_upgrade) SENSITIVE = [] include Aws::Structure end |
#domain_memberships ⇒ Array<Types::AwsRdsDbDomainMembership>
The Active Directory domain membership records that are associated with the DB cluster.
15507 15508 15509 15510 15511 15512 15513 15514 15515 15516 15517 15518 15519 15520 15521 15522 15523 15524 15525 15526 15527 15528 15529 15530 15531 15532 15533 15534 15535 15536 15537 15538 15539 15540 15541 15542 15543 15544 15545 15546 15547 15548 |
# File 'lib/aws-sdk-securityhub/types.rb', line 15507 class AwsRdsDbClusterDetails < Struct.new( :allocated_storage, :availability_zones, :backup_retention_period, :database_name, :status, :endpoint, :reader_endpoint, :custom_endpoints, :multi_az, :engine, :engine_version, :port, :master_username, :preferred_backup_window, :preferred_maintenance_window, :read_replica_identifiers, :vpc_security_groups, :hosted_zone_id, :storage_encrypted, :kms_key_id, :db_cluster_resource_id, :associated_roles, :cluster_create_time, :enabled_cloud_watch_logs_exports, :engine_mode, :deletion_protection, :http_endpoint_enabled, :activity_stream_status, :copy_tags_to_snapshot, :cross_account_clone, :domain_memberships, :db_cluster_parameter_group, :db_subnet_group, :db_cluster_option_group_memberships, :db_cluster_identifier, :db_cluster_members, :iam_database_authentication_enabled, :auto_minor_version_upgrade) SENSITIVE = [] include Aws::Structure end |
#enabled_cloud_watch_logs_exports ⇒ Array<String>
A list of log types that this DB cluster is configured to export to CloudWatch Logs.
15507 15508 15509 15510 15511 15512 15513 15514 15515 15516 15517 15518 15519 15520 15521 15522 15523 15524 15525 15526 15527 15528 15529 15530 15531 15532 15533 15534 15535 15536 15537 15538 15539 15540 15541 15542 15543 15544 15545 15546 15547 15548 |
# File 'lib/aws-sdk-securityhub/types.rb', line 15507 class AwsRdsDbClusterDetails < Struct.new( :allocated_storage, :availability_zones, :backup_retention_period, :database_name, :status, :endpoint, :reader_endpoint, :custom_endpoints, :multi_az, :engine, :engine_version, :port, :master_username, :preferred_backup_window, :preferred_maintenance_window, :read_replica_identifiers, :vpc_security_groups, :hosted_zone_id, :storage_encrypted, :kms_key_id, :db_cluster_resource_id, :associated_roles, :cluster_create_time, :enabled_cloud_watch_logs_exports, :engine_mode, :deletion_protection, :http_endpoint_enabled, :activity_stream_status, :copy_tags_to_snapshot, :cross_account_clone, :domain_memberships, :db_cluster_parameter_group, :db_subnet_group, :db_cluster_option_group_memberships, :db_cluster_identifier, :db_cluster_members, :iam_database_authentication_enabled, :auto_minor_version_upgrade) SENSITIVE = [] include Aws::Structure end |
#endpoint ⇒ String
The connection endpoint for the primary instance of the DB cluster.
15507 15508 15509 15510 15511 15512 15513 15514 15515 15516 15517 15518 15519 15520 15521 15522 15523 15524 15525 15526 15527 15528 15529 15530 15531 15532 15533 15534 15535 15536 15537 15538 15539 15540 15541 15542 15543 15544 15545 15546 15547 15548 |
# File 'lib/aws-sdk-securityhub/types.rb', line 15507 class AwsRdsDbClusterDetails < Struct.new( :allocated_storage, :availability_zones, :backup_retention_period, :database_name, :status, :endpoint, :reader_endpoint, :custom_endpoints, :multi_az, :engine, :engine_version, :port, :master_username, :preferred_backup_window, :preferred_maintenance_window, :read_replica_identifiers, :vpc_security_groups, :hosted_zone_id, :storage_encrypted, :kms_key_id, :db_cluster_resource_id, :associated_roles, :cluster_create_time, :enabled_cloud_watch_logs_exports, :engine_mode, :deletion_protection, :http_endpoint_enabled, :activity_stream_status, :copy_tags_to_snapshot, :cross_account_clone, :domain_memberships, :db_cluster_parameter_group, :db_subnet_group, :db_cluster_option_group_memberships, :db_cluster_identifier, :db_cluster_members, :iam_database_authentication_enabled, :auto_minor_version_upgrade) SENSITIVE = [] include Aws::Structure end |
#engine ⇒ String
The name of the database engine to use for this DB cluster. Valid values are as follows:
-
‘aurora`
-
‘aurora-mysql`
-
‘aurora-postgresql`
15507 15508 15509 15510 15511 15512 15513 15514 15515 15516 15517 15518 15519 15520 15521 15522 15523 15524 15525 15526 15527 15528 15529 15530 15531 15532 15533 15534 15535 15536 15537 15538 15539 15540 15541 15542 15543 15544 15545 15546 15547 15548 |
# File 'lib/aws-sdk-securityhub/types.rb', line 15507 class AwsRdsDbClusterDetails < Struct.new( :allocated_storage, :availability_zones, :backup_retention_period, :database_name, :status, :endpoint, :reader_endpoint, :custom_endpoints, :multi_az, :engine, :engine_version, :port, :master_username, :preferred_backup_window, :preferred_maintenance_window, :read_replica_identifiers, :vpc_security_groups, :hosted_zone_id, :storage_encrypted, :kms_key_id, :db_cluster_resource_id, :associated_roles, :cluster_create_time, :enabled_cloud_watch_logs_exports, :engine_mode, :deletion_protection, :http_endpoint_enabled, :activity_stream_status, :copy_tags_to_snapshot, :cross_account_clone, :domain_memberships, :db_cluster_parameter_group, :db_subnet_group, :db_cluster_option_group_memberships, :db_cluster_identifier, :db_cluster_members, :iam_database_authentication_enabled, :auto_minor_version_upgrade) SENSITIVE = [] include Aws::Structure end |
#engine_mode ⇒ String
The database engine mode of the DB cluster.Valid values are as follows:
-
‘global`
-
‘multimaster`
-
‘parallelquery`
-
‘provisioned`
-
‘serverless`
15507 15508 15509 15510 15511 15512 15513 15514 15515 15516 15517 15518 15519 15520 15521 15522 15523 15524 15525 15526 15527 15528 15529 15530 15531 15532 15533 15534 15535 15536 15537 15538 15539 15540 15541 15542 15543 15544 15545 15546 15547 15548 |
# File 'lib/aws-sdk-securityhub/types.rb', line 15507 class AwsRdsDbClusterDetails < Struct.new( :allocated_storage, :availability_zones, :backup_retention_period, :database_name, :status, :endpoint, :reader_endpoint, :custom_endpoints, :multi_az, :engine, :engine_version, :port, :master_username, :preferred_backup_window, :preferred_maintenance_window, :read_replica_identifiers, :vpc_security_groups, :hosted_zone_id, :storage_encrypted, :kms_key_id, :db_cluster_resource_id, :associated_roles, :cluster_create_time, :enabled_cloud_watch_logs_exports, :engine_mode, :deletion_protection, :http_endpoint_enabled, :activity_stream_status, :copy_tags_to_snapshot, :cross_account_clone, :domain_memberships, :db_cluster_parameter_group, :db_subnet_group, :db_cluster_option_group_memberships, :db_cluster_identifier, :db_cluster_members, :iam_database_authentication_enabled, :auto_minor_version_upgrade) SENSITIVE = [] include Aws::Structure end |
#engine_version ⇒ String
The version number of the database engine to use.
15507 15508 15509 15510 15511 15512 15513 15514 15515 15516 15517 15518 15519 15520 15521 15522 15523 15524 15525 15526 15527 15528 15529 15530 15531 15532 15533 15534 15535 15536 15537 15538 15539 15540 15541 15542 15543 15544 15545 15546 15547 15548 |
# File 'lib/aws-sdk-securityhub/types.rb', line 15507 class AwsRdsDbClusterDetails < Struct.new( :allocated_storage, :availability_zones, :backup_retention_period, :database_name, :status, :endpoint, :reader_endpoint, :custom_endpoints, :multi_az, :engine, :engine_version, :port, :master_username, :preferred_backup_window, :preferred_maintenance_window, :read_replica_identifiers, :vpc_security_groups, :hosted_zone_id, :storage_encrypted, :kms_key_id, :db_cluster_resource_id, :associated_roles, :cluster_create_time, :enabled_cloud_watch_logs_exports, :engine_mode, :deletion_protection, :http_endpoint_enabled, :activity_stream_status, :copy_tags_to_snapshot, :cross_account_clone, :domain_memberships, :db_cluster_parameter_group, :db_subnet_group, :db_cluster_option_group_memberships, :db_cluster_identifier, :db_cluster_members, :iam_database_authentication_enabled, :auto_minor_version_upgrade) SENSITIVE = [] include Aws::Structure end |
#hosted_zone_id ⇒ String
Specifies the identifier that Amazon Route 53 assigns when you create a hosted zone.
15507 15508 15509 15510 15511 15512 15513 15514 15515 15516 15517 15518 15519 15520 15521 15522 15523 15524 15525 15526 15527 15528 15529 15530 15531 15532 15533 15534 15535 15536 15537 15538 15539 15540 15541 15542 15543 15544 15545 15546 15547 15548 |
# File 'lib/aws-sdk-securityhub/types.rb', line 15507 class AwsRdsDbClusterDetails < Struct.new( :allocated_storage, :availability_zones, :backup_retention_period, :database_name, :status, :endpoint, :reader_endpoint, :custom_endpoints, :multi_az, :engine, :engine_version, :port, :master_username, :preferred_backup_window, :preferred_maintenance_window, :read_replica_identifiers, :vpc_security_groups, :hosted_zone_id, :storage_encrypted, :kms_key_id, :db_cluster_resource_id, :associated_roles, :cluster_create_time, :enabled_cloud_watch_logs_exports, :engine_mode, :deletion_protection, :http_endpoint_enabled, :activity_stream_status, :copy_tags_to_snapshot, :cross_account_clone, :domain_memberships, :db_cluster_parameter_group, :db_subnet_group, :db_cluster_option_group_memberships, :db_cluster_identifier, :db_cluster_members, :iam_database_authentication_enabled, :auto_minor_version_upgrade) SENSITIVE = [] include Aws::Structure end |
#http_endpoint_enabled ⇒ Boolean
Whether the HTTP endpoint for an Aurora Serverless DB cluster is enabled.
15507 15508 15509 15510 15511 15512 15513 15514 15515 15516 15517 15518 15519 15520 15521 15522 15523 15524 15525 15526 15527 15528 15529 15530 15531 15532 15533 15534 15535 15536 15537 15538 15539 15540 15541 15542 15543 15544 15545 15546 15547 15548 |
# File 'lib/aws-sdk-securityhub/types.rb', line 15507 class AwsRdsDbClusterDetails < Struct.new( :allocated_storage, :availability_zones, :backup_retention_period, :database_name, :status, :endpoint, :reader_endpoint, :custom_endpoints, :multi_az, :engine, :engine_version, :port, :master_username, :preferred_backup_window, :preferred_maintenance_window, :read_replica_identifiers, :vpc_security_groups, :hosted_zone_id, :storage_encrypted, :kms_key_id, :db_cluster_resource_id, :associated_roles, :cluster_create_time, :enabled_cloud_watch_logs_exports, :engine_mode, :deletion_protection, :http_endpoint_enabled, :activity_stream_status, :copy_tags_to_snapshot, :cross_account_clone, :domain_memberships, :db_cluster_parameter_group, :db_subnet_group, :db_cluster_option_group_memberships, :db_cluster_identifier, :db_cluster_members, :iam_database_authentication_enabled, :auto_minor_version_upgrade) SENSITIVE = [] include Aws::Structure end |
#iam_database_authentication_enabled ⇒ Boolean
Whether the mapping of IAM accounts to database accounts is enabled.
15507 15508 15509 15510 15511 15512 15513 15514 15515 15516 15517 15518 15519 15520 15521 15522 15523 15524 15525 15526 15527 15528 15529 15530 15531 15532 15533 15534 15535 15536 15537 15538 15539 15540 15541 15542 15543 15544 15545 15546 15547 15548 |
# File 'lib/aws-sdk-securityhub/types.rb', line 15507 class AwsRdsDbClusterDetails < Struct.new( :allocated_storage, :availability_zones, :backup_retention_period, :database_name, :status, :endpoint, :reader_endpoint, :custom_endpoints, :multi_az, :engine, :engine_version, :port, :master_username, :preferred_backup_window, :preferred_maintenance_window, :read_replica_identifiers, :vpc_security_groups, :hosted_zone_id, :storage_encrypted, :kms_key_id, :db_cluster_resource_id, :associated_roles, :cluster_create_time, :enabled_cloud_watch_logs_exports, :engine_mode, :deletion_protection, :http_endpoint_enabled, :activity_stream_status, :copy_tags_to_snapshot, :cross_account_clone, :domain_memberships, :db_cluster_parameter_group, :db_subnet_group, :db_cluster_option_group_memberships, :db_cluster_identifier, :db_cluster_members, :iam_database_authentication_enabled, :auto_minor_version_upgrade) SENSITIVE = [] include Aws::Structure end |
#kms_key_id ⇒ String
The ARN of the KMS master key that is used to encrypt the database instances in the DB cluster.
15507 15508 15509 15510 15511 15512 15513 15514 15515 15516 15517 15518 15519 15520 15521 15522 15523 15524 15525 15526 15527 15528 15529 15530 15531 15532 15533 15534 15535 15536 15537 15538 15539 15540 15541 15542 15543 15544 15545 15546 15547 15548 |
# File 'lib/aws-sdk-securityhub/types.rb', line 15507 class AwsRdsDbClusterDetails < Struct.new( :allocated_storage, :availability_zones, :backup_retention_period, :database_name, :status, :endpoint, :reader_endpoint, :custom_endpoints, :multi_az, :engine, :engine_version, :port, :master_username, :preferred_backup_window, :preferred_maintenance_window, :read_replica_identifiers, :vpc_security_groups, :hosted_zone_id, :storage_encrypted, :kms_key_id, :db_cluster_resource_id, :associated_roles, :cluster_create_time, :enabled_cloud_watch_logs_exports, :engine_mode, :deletion_protection, :http_endpoint_enabled, :activity_stream_status, :copy_tags_to_snapshot, :cross_account_clone, :domain_memberships, :db_cluster_parameter_group, :db_subnet_group, :db_cluster_option_group_memberships, :db_cluster_identifier, :db_cluster_members, :iam_database_authentication_enabled, :auto_minor_version_upgrade) SENSITIVE = [] include Aws::Structure end |
#master_username ⇒ String
The name of the master user for the DB cluster.
15507 15508 15509 15510 15511 15512 15513 15514 15515 15516 15517 15518 15519 15520 15521 15522 15523 15524 15525 15526 15527 15528 15529 15530 15531 15532 15533 15534 15535 15536 15537 15538 15539 15540 15541 15542 15543 15544 15545 15546 15547 15548 |
# File 'lib/aws-sdk-securityhub/types.rb', line 15507 class AwsRdsDbClusterDetails < Struct.new( :allocated_storage, :availability_zones, :backup_retention_period, :database_name, :status, :endpoint, :reader_endpoint, :custom_endpoints, :multi_az, :engine, :engine_version, :port, :master_username, :preferred_backup_window, :preferred_maintenance_window, :read_replica_identifiers, :vpc_security_groups, :hosted_zone_id, :storage_encrypted, :kms_key_id, :db_cluster_resource_id, :associated_roles, :cluster_create_time, :enabled_cloud_watch_logs_exports, :engine_mode, :deletion_protection, :http_endpoint_enabled, :activity_stream_status, :copy_tags_to_snapshot, :cross_account_clone, :domain_memberships, :db_cluster_parameter_group, :db_subnet_group, :db_cluster_option_group_memberships, :db_cluster_identifier, :db_cluster_members, :iam_database_authentication_enabled, :auto_minor_version_upgrade) SENSITIVE = [] include Aws::Structure end |
#multi_az ⇒ Boolean
Whether the DB cluster has instances in multiple Availability Zones.
15507 15508 15509 15510 15511 15512 15513 15514 15515 15516 15517 15518 15519 15520 15521 15522 15523 15524 15525 15526 15527 15528 15529 15530 15531 15532 15533 15534 15535 15536 15537 15538 15539 15540 15541 15542 15543 15544 15545 15546 15547 15548 |
# File 'lib/aws-sdk-securityhub/types.rb', line 15507 class AwsRdsDbClusterDetails < Struct.new( :allocated_storage, :availability_zones, :backup_retention_period, :database_name, :status, :endpoint, :reader_endpoint, :custom_endpoints, :multi_az, :engine, :engine_version, :port, :master_username, :preferred_backup_window, :preferred_maintenance_window, :read_replica_identifiers, :vpc_security_groups, :hosted_zone_id, :storage_encrypted, :kms_key_id, :db_cluster_resource_id, :associated_roles, :cluster_create_time, :enabled_cloud_watch_logs_exports, :engine_mode, :deletion_protection, :http_endpoint_enabled, :activity_stream_status, :copy_tags_to_snapshot, :cross_account_clone, :domain_memberships, :db_cluster_parameter_group, :db_subnet_group, :db_cluster_option_group_memberships, :db_cluster_identifier, :db_cluster_members, :iam_database_authentication_enabled, :auto_minor_version_upgrade) SENSITIVE = [] include Aws::Structure end |
#port ⇒ Integer
The port number on which the DB instances in the DB cluster accept connections.
15507 15508 15509 15510 15511 15512 15513 15514 15515 15516 15517 15518 15519 15520 15521 15522 15523 15524 15525 15526 15527 15528 15529 15530 15531 15532 15533 15534 15535 15536 15537 15538 15539 15540 15541 15542 15543 15544 15545 15546 15547 15548 |
# File 'lib/aws-sdk-securityhub/types.rb', line 15507 class AwsRdsDbClusterDetails < Struct.new( :allocated_storage, :availability_zones, :backup_retention_period, :database_name, :status, :endpoint, :reader_endpoint, :custom_endpoints, :multi_az, :engine, :engine_version, :port, :master_username, :preferred_backup_window, :preferred_maintenance_window, :read_replica_identifiers, :vpc_security_groups, :hosted_zone_id, :storage_encrypted, :kms_key_id, :db_cluster_resource_id, :associated_roles, :cluster_create_time, :enabled_cloud_watch_logs_exports, :engine_mode, :deletion_protection, :http_endpoint_enabled, :activity_stream_status, :copy_tags_to_snapshot, :cross_account_clone, :domain_memberships, :db_cluster_parameter_group, :db_subnet_group, :db_cluster_option_group_memberships, :db_cluster_identifier, :db_cluster_members, :iam_database_authentication_enabled, :auto_minor_version_upgrade) SENSITIVE = [] include Aws::Structure end |
#preferred_backup_window ⇒ String
The range of time each day when automated backups are created, if automated backups are enabled.
Uses the format ‘HH:MM-HH:MM`. For example, `04:52-05:22`.
15507 15508 15509 15510 15511 15512 15513 15514 15515 15516 15517 15518 15519 15520 15521 15522 15523 15524 15525 15526 15527 15528 15529 15530 15531 15532 15533 15534 15535 15536 15537 15538 15539 15540 15541 15542 15543 15544 15545 15546 15547 15548 |
# File 'lib/aws-sdk-securityhub/types.rb', line 15507 class AwsRdsDbClusterDetails < Struct.new( :allocated_storage, :availability_zones, :backup_retention_period, :database_name, :status, :endpoint, :reader_endpoint, :custom_endpoints, :multi_az, :engine, :engine_version, :port, :master_username, :preferred_backup_window, :preferred_maintenance_window, :read_replica_identifiers, :vpc_security_groups, :hosted_zone_id, :storage_encrypted, :kms_key_id, :db_cluster_resource_id, :associated_roles, :cluster_create_time, :enabled_cloud_watch_logs_exports, :engine_mode, :deletion_protection, :http_endpoint_enabled, :activity_stream_status, :copy_tags_to_snapshot, :cross_account_clone, :domain_memberships, :db_cluster_parameter_group, :db_subnet_group, :db_cluster_option_group_memberships, :db_cluster_identifier, :db_cluster_members, :iam_database_authentication_enabled, :auto_minor_version_upgrade) SENSITIVE = [] include Aws::Structure end |
#preferred_maintenance_window ⇒ String
The weekly time range during which system maintenance can occur, in Universal Coordinated Time (UTC).
Uses the format ‘<day>:HH:MM-<day>:HH:MM`.
For the day values, use ‘mon`|`tue`|`wed`|`thu`|`fri`|`sat`|`sun`.
For example, ‘sun:09:32-sun:10:02`.
15507 15508 15509 15510 15511 15512 15513 15514 15515 15516 15517 15518 15519 15520 15521 15522 15523 15524 15525 15526 15527 15528 15529 15530 15531 15532 15533 15534 15535 15536 15537 15538 15539 15540 15541 15542 15543 15544 15545 15546 15547 15548 |
# File 'lib/aws-sdk-securityhub/types.rb', line 15507 class AwsRdsDbClusterDetails < Struct.new( :allocated_storage, :availability_zones, :backup_retention_period, :database_name, :status, :endpoint, :reader_endpoint, :custom_endpoints, :multi_az, :engine, :engine_version, :port, :master_username, :preferred_backup_window, :preferred_maintenance_window, :read_replica_identifiers, :vpc_security_groups, :hosted_zone_id, :storage_encrypted, :kms_key_id, :db_cluster_resource_id, :associated_roles, :cluster_create_time, :enabled_cloud_watch_logs_exports, :engine_mode, :deletion_protection, :http_endpoint_enabled, :activity_stream_status, :copy_tags_to_snapshot, :cross_account_clone, :domain_memberships, :db_cluster_parameter_group, :db_subnet_group, :db_cluster_option_group_memberships, :db_cluster_identifier, :db_cluster_members, :iam_database_authentication_enabled, :auto_minor_version_upgrade) SENSITIVE = [] include Aws::Structure end |
#read_replica_identifiers ⇒ Array<String>
The identifiers of the read replicas that are associated with this DB cluster.
15507 15508 15509 15510 15511 15512 15513 15514 15515 15516 15517 15518 15519 15520 15521 15522 15523 15524 15525 15526 15527 15528 15529 15530 15531 15532 15533 15534 15535 15536 15537 15538 15539 15540 15541 15542 15543 15544 15545 15546 15547 15548 |
# File 'lib/aws-sdk-securityhub/types.rb', line 15507 class AwsRdsDbClusterDetails < Struct.new( :allocated_storage, :availability_zones, :backup_retention_period, :database_name, :status, :endpoint, :reader_endpoint, :custom_endpoints, :multi_az, :engine, :engine_version, :port, :master_username, :preferred_backup_window, :preferred_maintenance_window, :read_replica_identifiers, :vpc_security_groups, :hosted_zone_id, :storage_encrypted, :kms_key_id, :db_cluster_resource_id, :associated_roles, :cluster_create_time, :enabled_cloud_watch_logs_exports, :engine_mode, :deletion_protection, :http_endpoint_enabled, :activity_stream_status, :copy_tags_to_snapshot, :cross_account_clone, :domain_memberships, :db_cluster_parameter_group, :db_subnet_group, :db_cluster_option_group_memberships, :db_cluster_identifier, :db_cluster_members, :iam_database_authentication_enabled, :auto_minor_version_upgrade) SENSITIVE = [] include Aws::Structure end |
#reader_endpoint ⇒ String
The reader endpoint for the DB cluster.
15507 15508 15509 15510 15511 15512 15513 15514 15515 15516 15517 15518 15519 15520 15521 15522 15523 15524 15525 15526 15527 15528 15529 15530 15531 15532 15533 15534 15535 15536 15537 15538 15539 15540 15541 15542 15543 15544 15545 15546 15547 15548 |
# File 'lib/aws-sdk-securityhub/types.rb', line 15507 class AwsRdsDbClusterDetails < Struct.new( :allocated_storage, :availability_zones, :backup_retention_period, :database_name, :status, :endpoint, :reader_endpoint, :custom_endpoints, :multi_az, :engine, :engine_version, :port, :master_username, :preferred_backup_window, :preferred_maintenance_window, :read_replica_identifiers, :vpc_security_groups, :hosted_zone_id, :storage_encrypted, :kms_key_id, :db_cluster_resource_id, :associated_roles, :cluster_create_time, :enabled_cloud_watch_logs_exports, :engine_mode, :deletion_protection, :http_endpoint_enabled, :activity_stream_status, :copy_tags_to_snapshot, :cross_account_clone, :domain_memberships, :db_cluster_parameter_group, :db_subnet_group, :db_cluster_option_group_memberships, :db_cluster_identifier, :db_cluster_members, :iam_database_authentication_enabled, :auto_minor_version_upgrade) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of this DB cluster.
15507 15508 15509 15510 15511 15512 15513 15514 15515 15516 15517 15518 15519 15520 15521 15522 15523 15524 15525 15526 15527 15528 15529 15530 15531 15532 15533 15534 15535 15536 15537 15538 15539 15540 15541 15542 15543 15544 15545 15546 15547 15548 |
# File 'lib/aws-sdk-securityhub/types.rb', line 15507 class AwsRdsDbClusterDetails < Struct.new( :allocated_storage, :availability_zones, :backup_retention_period, :database_name, :status, :endpoint, :reader_endpoint, :custom_endpoints, :multi_az, :engine, :engine_version, :port, :master_username, :preferred_backup_window, :preferred_maintenance_window, :read_replica_identifiers, :vpc_security_groups, :hosted_zone_id, :storage_encrypted, :kms_key_id, :db_cluster_resource_id, :associated_roles, :cluster_create_time, :enabled_cloud_watch_logs_exports, :engine_mode, :deletion_protection, :http_endpoint_enabled, :activity_stream_status, :copy_tags_to_snapshot, :cross_account_clone, :domain_memberships, :db_cluster_parameter_group, :db_subnet_group, :db_cluster_option_group_memberships, :db_cluster_identifier, :db_cluster_members, :iam_database_authentication_enabled, :auto_minor_version_upgrade) SENSITIVE = [] include Aws::Structure end |
#storage_encrypted ⇒ Boolean
Whether the DB cluster is encrypted.
15507 15508 15509 15510 15511 15512 15513 15514 15515 15516 15517 15518 15519 15520 15521 15522 15523 15524 15525 15526 15527 15528 15529 15530 15531 15532 15533 15534 15535 15536 15537 15538 15539 15540 15541 15542 15543 15544 15545 15546 15547 15548 |
# File 'lib/aws-sdk-securityhub/types.rb', line 15507 class AwsRdsDbClusterDetails < Struct.new( :allocated_storage, :availability_zones, :backup_retention_period, :database_name, :status, :endpoint, :reader_endpoint, :custom_endpoints, :multi_az, :engine, :engine_version, :port, :master_username, :preferred_backup_window, :preferred_maintenance_window, :read_replica_identifiers, :vpc_security_groups, :hosted_zone_id, :storage_encrypted, :kms_key_id, :db_cluster_resource_id, :associated_roles, :cluster_create_time, :enabled_cloud_watch_logs_exports, :engine_mode, :deletion_protection, :http_endpoint_enabled, :activity_stream_status, :copy_tags_to_snapshot, :cross_account_clone, :domain_memberships, :db_cluster_parameter_group, :db_subnet_group, :db_cluster_option_group_memberships, :db_cluster_identifier, :db_cluster_members, :iam_database_authentication_enabled, :auto_minor_version_upgrade) SENSITIVE = [] include Aws::Structure end |
#vpc_security_groups ⇒ Array<Types::AwsRdsDbInstanceVpcSecurityGroup>
A list of VPC security groups that the DB cluster belongs to.
15507 15508 15509 15510 15511 15512 15513 15514 15515 15516 15517 15518 15519 15520 15521 15522 15523 15524 15525 15526 15527 15528 15529 15530 15531 15532 15533 15534 15535 15536 15537 15538 15539 15540 15541 15542 15543 15544 15545 15546 15547 15548 |
# File 'lib/aws-sdk-securityhub/types.rb', line 15507 class AwsRdsDbClusterDetails < Struct.new( :allocated_storage, :availability_zones, :backup_retention_period, :database_name, :status, :endpoint, :reader_endpoint, :custom_endpoints, :multi_az, :engine, :engine_version, :port, :master_username, :preferred_backup_window, :preferred_maintenance_window, :read_replica_identifiers, :vpc_security_groups, :hosted_zone_id, :storage_encrypted, :kms_key_id, :db_cluster_resource_id, :associated_roles, :cluster_create_time, :enabled_cloud_watch_logs_exports, :engine_mode, :deletion_protection, :http_endpoint_enabled, :activity_stream_status, :copy_tags_to_snapshot, :cross_account_clone, :domain_memberships, :db_cluster_parameter_group, :db_subnet_group, :db_cluster_option_group_memberships, :db_cluster_identifier, :db_cluster_members, :iam_database_authentication_enabled, :auto_minor_version_upgrade) SENSITIVE = [] include Aws::Structure end |