Class: Aws::SecurityHub::Types::AwsRdsDbClusterSnapshotDetails

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

Information about an Amazon RDS DB cluster snapshot.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#allocated_storageInteger

Specifies the allocated storage size in gibibytes (GiB).

Returns:

  • (Integer)


15851
15852
15853
15854
15855
15856
15857
15858
15859
15860
15861
15862
15863
15864
15865
15866
15867
15868
15869
15870
15871
15872
15873
# File 'lib/aws-sdk-securityhub/types.rb', line 15851

class AwsRdsDbClusterSnapshotDetails < Struct.new(
  :availability_zones,
  :snapshot_create_time,
  :engine,
  :allocated_storage,
  :status,
  :port,
  :vpc_id,
  :cluster_create_time,
  :master_username,
  :engine_version,
  :license_model,
  :snapshot_type,
  :percent_progress,
  :storage_encrypted,
  :kms_key_id,
  :db_cluster_identifier,
  :db_cluster_snapshot_identifier,
  :iam_database_authentication_enabled,
  :db_cluster_snapshot_attributes)
  SENSITIVE = []
  include Aws::Structure
end

#availability_zonesArray<String>

A list of Availability Zones where instances in the DB cluster can be created.

Returns:

  • (Array<String>)


15851
15852
15853
15854
15855
15856
15857
15858
15859
15860
15861
15862
15863
15864
15865
15866
15867
15868
15869
15870
15871
15872
15873
# File 'lib/aws-sdk-securityhub/types.rb', line 15851

class AwsRdsDbClusterSnapshotDetails < Struct.new(
  :availability_zones,
  :snapshot_create_time,
  :engine,
  :allocated_storage,
  :status,
  :port,
  :vpc_id,
  :cluster_create_time,
  :master_username,
  :engine_version,
  :license_model,
  :snapshot_type,
  :percent_progress,
  :storage_encrypted,
  :kms_key_id,
  :db_cluster_identifier,
  :db_cluster_snapshot_identifier,
  :iam_database_authentication_enabled,
  :db_cluster_snapshot_attributes)
  SENSITIVE = []
  include Aws::Structure
end

#cluster_create_timeString

Indicates when the DB cluster was created, in Universal Coordinated Time (UTC).

For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.

Returns:

  • (String)


15851
15852
15853
15854
15855
15856
15857
15858
15859
15860
15861
15862
15863
15864
15865
15866
15867
15868
15869
15870
15871
15872
15873
# File 'lib/aws-sdk-securityhub/types.rb', line 15851

class AwsRdsDbClusterSnapshotDetails < Struct.new(
  :availability_zones,
  :snapshot_create_time,
  :engine,
  :allocated_storage,
  :status,
  :port,
  :vpc_id,
  :cluster_create_time,
  :master_username,
  :engine_version,
  :license_model,
  :snapshot_type,
  :percent_progress,
  :storage_encrypted,
  :kms_key_id,
  :db_cluster_identifier,
  :db_cluster_snapshot_identifier,
  :iam_database_authentication_enabled,
  :db_cluster_snapshot_attributes)
  SENSITIVE = []
  include Aws::Structure
end

#db_cluster_identifierString

The DB cluster identifier.

Returns:

  • (String)


15851
15852
15853
15854
15855
15856
15857
15858
15859
15860
15861
15862
15863
15864
15865
15866
15867
15868
15869
15870
15871
15872
15873
# File 'lib/aws-sdk-securityhub/types.rb', line 15851

class AwsRdsDbClusterSnapshotDetails < Struct.new(
  :availability_zones,
  :snapshot_create_time,
  :engine,
  :allocated_storage,
  :status,
  :port,
  :vpc_id,
  :cluster_create_time,
  :master_username,
  :engine_version,
  :license_model,
  :snapshot_type,
  :percent_progress,
  :storage_encrypted,
  :kms_key_id,
  :db_cluster_identifier,
  :db_cluster_snapshot_identifier,
  :iam_database_authentication_enabled,
  :db_cluster_snapshot_attributes)
  SENSITIVE = []
  include Aws::Structure
end

#db_cluster_snapshot_attributesArray<Types::AwsRdsDbClusterSnapshotDbClusterSnapshotAttribute>

Contains the name and values of a manual DB cluster snapshot attribute.



15851
15852
15853
15854
15855
15856
15857
15858
15859
15860
15861
15862
15863
15864
15865
15866
15867
15868
15869
15870
15871
15872
15873
# File 'lib/aws-sdk-securityhub/types.rb', line 15851

class AwsRdsDbClusterSnapshotDetails < Struct.new(
  :availability_zones,
  :snapshot_create_time,
  :engine,
  :allocated_storage,
  :status,
  :port,
  :vpc_id,
  :cluster_create_time,
  :master_username,
  :engine_version,
  :license_model,
  :snapshot_type,
  :percent_progress,
  :storage_encrypted,
  :kms_key_id,
  :db_cluster_identifier,
  :db_cluster_snapshot_identifier,
  :iam_database_authentication_enabled,
  :db_cluster_snapshot_attributes)
  SENSITIVE = []
  include Aws::Structure
end

#db_cluster_snapshot_identifierString

The identifier of the DB cluster snapshot.

Returns:

  • (String)


15851
15852
15853
15854
15855
15856
15857
15858
15859
15860
15861
15862
15863
15864
15865
15866
15867
15868
15869
15870
15871
15872
15873
# File 'lib/aws-sdk-securityhub/types.rb', line 15851

class AwsRdsDbClusterSnapshotDetails < Struct.new(
  :availability_zones,
  :snapshot_create_time,
  :engine,
  :allocated_storage,
  :status,
  :port,
  :vpc_id,
  :cluster_create_time,
  :master_username,
  :engine_version,
  :license_model,
  :snapshot_type,
  :percent_progress,
  :storage_encrypted,
  :kms_key_id,
  :db_cluster_identifier,
  :db_cluster_snapshot_identifier,
  :iam_database_authentication_enabled,
  :db_cluster_snapshot_attributes)
  SENSITIVE = []
  include Aws::Structure
end

#engineString

The name of the database engine that you want to use for this DB instance.

Returns:

  • (String)


15851
15852
15853
15854
15855
15856
15857
15858
15859
15860
15861
15862
15863
15864
15865
15866
15867
15868
15869
15870
15871
15872
15873
# File 'lib/aws-sdk-securityhub/types.rb', line 15851

class AwsRdsDbClusterSnapshotDetails < Struct.new(
  :availability_zones,
  :snapshot_create_time,
  :engine,
  :allocated_storage,
  :status,
  :port,
  :vpc_id,
  :cluster_create_time,
  :master_username,
  :engine_version,
  :license_model,
  :snapshot_type,
  :percent_progress,
  :storage_encrypted,
  :kms_key_id,
  :db_cluster_identifier,
  :db_cluster_snapshot_identifier,
  :iam_database_authentication_enabled,
  :db_cluster_snapshot_attributes)
  SENSITIVE = []
  include Aws::Structure
end

#engine_versionString

The version of the database engine to use.

Returns:

  • (String)


15851
15852
15853
15854
15855
15856
15857
15858
15859
15860
15861
15862
15863
15864
15865
15866
15867
15868
15869
15870
15871
15872
15873
# File 'lib/aws-sdk-securityhub/types.rb', line 15851

class AwsRdsDbClusterSnapshotDetails < Struct.new(
  :availability_zones,
  :snapshot_create_time,
  :engine,
  :allocated_storage,
  :status,
  :port,
  :vpc_id,
  :cluster_create_time,
  :master_username,
  :engine_version,
  :license_model,
  :snapshot_type,
  :percent_progress,
  :storage_encrypted,
  :kms_key_id,
  :db_cluster_identifier,
  :db_cluster_snapshot_identifier,
  :iam_database_authentication_enabled,
  :db_cluster_snapshot_attributes)
  SENSITIVE = []
  include Aws::Structure
end

#iam_database_authentication_enabledBoolean

Whether mapping of IAM accounts to database accounts is enabled.

Returns:

  • (Boolean)


15851
15852
15853
15854
15855
15856
15857
15858
15859
15860
15861
15862
15863
15864
15865
15866
15867
15868
15869
15870
15871
15872
15873
# File 'lib/aws-sdk-securityhub/types.rb', line 15851

class AwsRdsDbClusterSnapshotDetails < Struct.new(
  :availability_zones,
  :snapshot_create_time,
  :engine,
  :allocated_storage,
  :status,
  :port,
  :vpc_id,
  :cluster_create_time,
  :master_username,
  :engine_version,
  :license_model,
  :snapshot_type,
  :percent_progress,
  :storage_encrypted,
  :kms_key_id,
  :db_cluster_identifier,
  :db_cluster_snapshot_identifier,
  :iam_database_authentication_enabled,
  :db_cluster_snapshot_attributes)
  SENSITIVE = []
  include Aws::Structure
end

#kms_key_idString

The ARN of the KMS master key that is used to encrypt the database instances in the DB cluster.

Returns:

  • (String)


15851
15852
15853
15854
15855
15856
15857
15858
15859
15860
15861
15862
15863
15864
15865
15866
15867
15868
15869
15870
15871
15872
15873
# File 'lib/aws-sdk-securityhub/types.rb', line 15851

class AwsRdsDbClusterSnapshotDetails < Struct.new(
  :availability_zones,
  :snapshot_create_time,
  :engine,
  :allocated_storage,
  :status,
  :port,
  :vpc_id,
  :cluster_create_time,
  :master_username,
  :engine_version,
  :license_model,
  :snapshot_type,
  :percent_progress,
  :storage_encrypted,
  :kms_key_id,
  :db_cluster_identifier,
  :db_cluster_snapshot_identifier,
  :iam_database_authentication_enabled,
  :db_cluster_snapshot_attributes)
  SENSITIVE = []
  include Aws::Structure
end

#license_modelString

The license model information for this DB cluster snapshot.

Returns:

  • (String)


15851
15852
15853
15854
15855
15856
15857
15858
15859
15860
15861
15862
15863
15864
15865
15866
15867
15868
15869
15870
15871
15872
15873
# File 'lib/aws-sdk-securityhub/types.rb', line 15851

class AwsRdsDbClusterSnapshotDetails < Struct.new(
  :availability_zones,
  :snapshot_create_time,
  :engine,
  :allocated_storage,
  :status,
  :port,
  :vpc_id,
  :cluster_create_time,
  :master_username,
  :engine_version,
  :license_model,
  :snapshot_type,
  :percent_progress,
  :storage_encrypted,
  :kms_key_id,
  :db_cluster_identifier,
  :db_cluster_snapshot_identifier,
  :iam_database_authentication_enabled,
  :db_cluster_snapshot_attributes)
  SENSITIVE = []
  include Aws::Structure
end

#master_usernameString

The name of the master user for the DB cluster.

Returns:

  • (String)


15851
15852
15853
15854
15855
15856
15857
15858
15859
15860
15861
15862
15863
15864
15865
15866
15867
15868
15869
15870
15871
15872
15873
# File 'lib/aws-sdk-securityhub/types.rb', line 15851

class AwsRdsDbClusterSnapshotDetails < Struct.new(
  :availability_zones,
  :snapshot_create_time,
  :engine,
  :allocated_storage,
  :status,
  :port,
  :vpc_id,
  :cluster_create_time,
  :master_username,
  :engine_version,
  :license_model,
  :snapshot_type,
  :percent_progress,
  :storage_encrypted,
  :kms_key_id,
  :db_cluster_identifier,
  :db_cluster_snapshot_identifier,
  :iam_database_authentication_enabled,
  :db_cluster_snapshot_attributes)
  SENSITIVE = []
  include Aws::Structure
end

#percent_progressInteger

Specifies the percentage of the estimated data that has been transferred.

Returns:

  • (Integer)


15851
15852
15853
15854
15855
15856
15857
15858
15859
15860
15861
15862
15863
15864
15865
15866
15867
15868
15869
15870
15871
15872
15873
# File 'lib/aws-sdk-securityhub/types.rb', line 15851

class AwsRdsDbClusterSnapshotDetails < Struct.new(
  :availability_zones,
  :snapshot_create_time,
  :engine,
  :allocated_storage,
  :status,
  :port,
  :vpc_id,
  :cluster_create_time,
  :master_username,
  :engine_version,
  :license_model,
  :snapshot_type,
  :percent_progress,
  :storage_encrypted,
  :kms_key_id,
  :db_cluster_identifier,
  :db_cluster_snapshot_identifier,
  :iam_database_authentication_enabled,
  :db_cluster_snapshot_attributes)
  SENSITIVE = []
  include Aws::Structure
end

#portInteger

The port number on which the DB instances in the DB cluster accept connections.

Returns:

  • (Integer)


15851
15852
15853
15854
15855
15856
15857
15858
15859
15860
15861
15862
15863
15864
15865
15866
15867
15868
15869
15870
15871
15872
15873
# File 'lib/aws-sdk-securityhub/types.rb', line 15851

class AwsRdsDbClusterSnapshotDetails < Struct.new(
  :availability_zones,
  :snapshot_create_time,
  :engine,
  :allocated_storage,
  :status,
  :port,
  :vpc_id,
  :cluster_create_time,
  :master_username,
  :engine_version,
  :license_model,
  :snapshot_type,
  :percent_progress,
  :storage_encrypted,
  :kms_key_id,
  :db_cluster_identifier,
  :db_cluster_snapshot_identifier,
  :iam_database_authentication_enabled,
  :db_cluster_snapshot_attributes)
  SENSITIVE = []
  include Aws::Structure
end

#snapshot_create_timeString

Indicates when the snapshot was taken.

For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.

Returns:

  • (String)


15851
15852
15853
15854
15855
15856
15857
15858
15859
15860
15861
15862
15863
15864
15865
15866
15867
15868
15869
15870
15871
15872
15873
# File 'lib/aws-sdk-securityhub/types.rb', line 15851

class AwsRdsDbClusterSnapshotDetails < Struct.new(
  :availability_zones,
  :snapshot_create_time,
  :engine,
  :allocated_storage,
  :status,
  :port,
  :vpc_id,
  :cluster_create_time,
  :master_username,
  :engine_version,
  :license_model,
  :snapshot_type,
  :percent_progress,
  :storage_encrypted,
  :kms_key_id,
  :db_cluster_identifier,
  :db_cluster_snapshot_identifier,
  :iam_database_authentication_enabled,
  :db_cluster_snapshot_attributes)
  SENSITIVE = []
  include Aws::Structure
end

#snapshot_typeString

The type of DB cluster snapshot.

Returns:

  • (String)


15851
15852
15853
15854
15855
15856
15857
15858
15859
15860
15861
15862
15863
15864
15865
15866
15867
15868
15869
15870
15871
15872
15873
# File 'lib/aws-sdk-securityhub/types.rb', line 15851

class AwsRdsDbClusterSnapshotDetails < Struct.new(
  :availability_zones,
  :snapshot_create_time,
  :engine,
  :allocated_storage,
  :status,
  :port,
  :vpc_id,
  :cluster_create_time,
  :master_username,
  :engine_version,
  :license_model,
  :snapshot_type,
  :percent_progress,
  :storage_encrypted,
  :kms_key_id,
  :db_cluster_identifier,
  :db_cluster_snapshot_identifier,
  :iam_database_authentication_enabled,
  :db_cluster_snapshot_attributes)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of this DB cluster snapshot.

Returns:

  • (String)


15851
15852
15853
15854
15855
15856
15857
15858
15859
15860
15861
15862
15863
15864
15865
15866
15867
15868
15869
15870
15871
15872
15873
# File 'lib/aws-sdk-securityhub/types.rb', line 15851

class AwsRdsDbClusterSnapshotDetails < Struct.new(
  :availability_zones,
  :snapshot_create_time,
  :engine,
  :allocated_storage,
  :status,
  :port,
  :vpc_id,
  :cluster_create_time,
  :master_username,
  :engine_version,
  :license_model,
  :snapshot_type,
  :percent_progress,
  :storage_encrypted,
  :kms_key_id,
  :db_cluster_identifier,
  :db_cluster_snapshot_identifier,
  :iam_database_authentication_enabled,
  :db_cluster_snapshot_attributes)
  SENSITIVE = []
  include Aws::Structure
end

#storage_encryptedBoolean

Whether the DB cluster is encrypted.

Returns:

  • (Boolean)


15851
15852
15853
15854
15855
15856
15857
15858
15859
15860
15861
15862
15863
15864
15865
15866
15867
15868
15869
15870
15871
15872
15873
# File 'lib/aws-sdk-securityhub/types.rb', line 15851

class AwsRdsDbClusterSnapshotDetails < Struct.new(
  :availability_zones,
  :snapshot_create_time,
  :engine,
  :allocated_storage,
  :status,
  :port,
  :vpc_id,
  :cluster_create_time,
  :master_username,
  :engine_version,
  :license_model,
  :snapshot_type,
  :percent_progress,
  :storage_encrypted,
  :kms_key_id,
  :db_cluster_identifier,
  :db_cluster_snapshot_identifier,
  :iam_database_authentication_enabled,
  :db_cluster_snapshot_attributes)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_idString

The VPC ID that is associated with the DB cluster snapshot.

Returns:

  • (String)


15851
15852
15853
15854
15855
15856
15857
15858
15859
15860
15861
15862
15863
15864
15865
15866
15867
15868
15869
15870
15871
15872
15873
# File 'lib/aws-sdk-securityhub/types.rb', line 15851

class AwsRdsDbClusterSnapshotDetails < Struct.new(
  :availability_zones,
  :snapshot_create_time,
  :engine,
  :allocated_storage,
  :status,
  :port,
  :vpc_id,
  :cluster_create_time,
  :master_username,
  :engine_version,
  :license_model,
  :snapshot_type,
  :percent_progress,
  :storage_encrypted,
  :kms_key_id,
  :db_cluster_identifier,
  :db_cluster_snapshot_identifier,
  :iam_database_authentication_enabled,
  :db_cluster_snapshot_attributes)
  SENSITIVE = []
  include Aws::Structure
end