Class: Aws::SecurityHub::Types::AwsRdsDbPendingModifiedValues
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::AwsRdsDbPendingModifiedValues
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Changes to a DB instance that are currently pending.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#allocated_storage ⇒ Integer
The new value of the allocated storage for the DB instance.
-
#backup_retention_period ⇒ Integer
The new backup retention period for the DB instance.
-
#ca_certificate_identifier ⇒ String
The new CA certificate identifier for the DB instance.
-
#db_instance_class ⇒ String
The new DB instance class for the DB instance.
-
#db_instance_identifier ⇒ String
The new DB instance identifier for the DB instance.
-
#db_subnet_group_name ⇒ String
The name of the new subnet group for the DB instance.
-
#engine_version ⇒ String
The new engine version for the DB instance.
-
#iops ⇒ Integer
The new provisioned IOPS value for the DB instance.
-
#license_model ⇒ String
The new license model value for the DB instance.
-
#master_user_password ⇒ String
The new master user password for the DB instance.
-
#multi_az ⇒ Boolean
Indicates that a single Availability Zone DB instance is changing to a multiple Availability Zone deployment.
-
#pending_cloud_watch_logs_exports ⇒ Types::AwsRdsPendingCloudWatchLogsExports
A list of log types that are being enabled or disabled.
-
#port ⇒ Integer
The new port for the DB instance.
-
#processor_features ⇒ Array<Types::AwsRdsDbProcessorFeature>
Processor features that are being updated.
-
#storage_type ⇒ String
The new storage type for the DB instance.
Instance Attribute Details
#allocated_storage ⇒ Integer
The new value of the allocated storage for the DB instance.
16472 16473 16474 16475 16476 16477 16478 16479 16480 16481 16482 16483 16484 16485 16486 16487 16488 16489 16490 |
# File 'lib/aws-sdk-securityhub/types.rb', line 16472 class AwsRdsDbPendingModifiedValues < Struct.new( :db_instance_class, :allocated_storage, :master_user_password, :port, :backup_retention_period, :multi_az, :engine_version, :license_model, :iops, :db_instance_identifier, :storage_type, :ca_certificate_identifier, :db_subnet_group_name, :pending_cloud_watch_logs_exports, :processor_features) SENSITIVE = [] include Aws::Structure end |
#backup_retention_period ⇒ Integer
The new backup retention period for the DB instance.
16472 16473 16474 16475 16476 16477 16478 16479 16480 16481 16482 16483 16484 16485 16486 16487 16488 16489 16490 |
# File 'lib/aws-sdk-securityhub/types.rb', line 16472 class AwsRdsDbPendingModifiedValues < Struct.new( :db_instance_class, :allocated_storage, :master_user_password, :port, :backup_retention_period, :multi_az, :engine_version, :license_model, :iops, :db_instance_identifier, :storage_type, :ca_certificate_identifier, :db_subnet_group_name, :pending_cloud_watch_logs_exports, :processor_features) SENSITIVE = [] include Aws::Structure end |
#ca_certificate_identifier ⇒ String
The new CA certificate identifier for the DB instance.
16472 16473 16474 16475 16476 16477 16478 16479 16480 16481 16482 16483 16484 16485 16486 16487 16488 16489 16490 |
# File 'lib/aws-sdk-securityhub/types.rb', line 16472 class AwsRdsDbPendingModifiedValues < Struct.new( :db_instance_class, :allocated_storage, :master_user_password, :port, :backup_retention_period, :multi_az, :engine_version, :license_model, :iops, :db_instance_identifier, :storage_type, :ca_certificate_identifier, :db_subnet_group_name, :pending_cloud_watch_logs_exports, :processor_features) SENSITIVE = [] include Aws::Structure end |
#db_instance_class ⇒ String
The new DB instance class for the DB instance.
16472 16473 16474 16475 16476 16477 16478 16479 16480 16481 16482 16483 16484 16485 16486 16487 16488 16489 16490 |
# File 'lib/aws-sdk-securityhub/types.rb', line 16472 class AwsRdsDbPendingModifiedValues < Struct.new( :db_instance_class, :allocated_storage, :master_user_password, :port, :backup_retention_period, :multi_az, :engine_version, :license_model, :iops, :db_instance_identifier, :storage_type, :ca_certificate_identifier, :db_subnet_group_name, :pending_cloud_watch_logs_exports, :processor_features) SENSITIVE = [] include Aws::Structure end |
#db_instance_identifier ⇒ String
The new DB instance identifier for the DB instance.
16472 16473 16474 16475 16476 16477 16478 16479 16480 16481 16482 16483 16484 16485 16486 16487 16488 16489 16490 |
# File 'lib/aws-sdk-securityhub/types.rb', line 16472 class AwsRdsDbPendingModifiedValues < Struct.new( :db_instance_class, :allocated_storage, :master_user_password, :port, :backup_retention_period, :multi_az, :engine_version, :license_model, :iops, :db_instance_identifier, :storage_type, :ca_certificate_identifier, :db_subnet_group_name, :pending_cloud_watch_logs_exports, :processor_features) SENSITIVE = [] include Aws::Structure end |
#db_subnet_group_name ⇒ String
The name of the new subnet group for the DB instance.
16472 16473 16474 16475 16476 16477 16478 16479 16480 16481 16482 16483 16484 16485 16486 16487 16488 16489 16490 |
# File 'lib/aws-sdk-securityhub/types.rb', line 16472 class AwsRdsDbPendingModifiedValues < Struct.new( :db_instance_class, :allocated_storage, :master_user_password, :port, :backup_retention_period, :multi_az, :engine_version, :license_model, :iops, :db_instance_identifier, :storage_type, :ca_certificate_identifier, :db_subnet_group_name, :pending_cloud_watch_logs_exports, :processor_features) SENSITIVE = [] include Aws::Structure end |
#engine_version ⇒ String
The new engine version for the DB instance.
16472 16473 16474 16475 16476 16477 16478 16479 16480 16481 16482 16483 16484 16485 16486 16487 16488 16489 16490 |
# File 'lib/aws-sdk-securityhub/types.rb', line 16472 class AwsRdsDbPendingModifiedValues < Struct.new( :db_instance_class, :allocated_storage, :master_user_password, :port, :backup_retention_period, :multi_az, :engine_version, :license_model, :iops, :db_instance_identifier, :storage_type, :ca_certificate_identifier, :db_subnet_group_name, :pending_cloud_watch_logs_exports, :processor_features) SENSITIVE = [] include Aws::Structure end |
#iops ⇒ Integer
The new provisioned IOPS value for the DB instance.
16472 16473 16474 16475 16476 16477 16478 16479 16480 16481 16482 16483 16484 16485 16486 16487 16488 16489 16490 |
# File 'lib/aws-sdk-securityhub/types.rb', line 16472 class AwsRdsDbPendingModifiedValues < Struct.new( :db_instance_class, :allocated_storage, :master_user_password, :port, :backup_retention_period, :multi_az, :engine_version, :license_model, :iops, :db_instance_identifier, :storage_type, :ca_certificate_identifier, :db_subnet_group_name, :pending_cloud_watch_logs_exports, :processor_features) SENSITIVE = [] include Aws::Structure end |
#license_model ⇒ String
The new license model value for the DB instance.
16472 16473 16474 16475 16476 16477 16478 16479 16480 16481 16482 16483 16484 16485 16486 16487 16488 16489 16490 |
# File 'lib/aws-sdk-securityhub/types.rb', line 16472 class AwsRdsDbPendingModifiedValues < Struct.new( :db_instance_class, :allocated_storage, :master_user_password, :port, :backup_retention_period, :multi_az, :engine_version, :license_model, :iops, :db_instance_identifier, :storage_type, :ca_certificate_identifier, :db_subnet_group_name, :pending_cloud_watch_logs_exports, :processor_features) SENSITIVE = [] include Aws::Structure end |
#master_user_password ⇒ String
The new master user password for the DB instance.
16472 16473 16474 16475 16476 16477 16478 16479 16480 16481 16482 16483 16484 16485 16486 16487 16488 16489 16490 |
# File 'lib/aws-sdk-securityhub/types.rb', line 16472 class AwsRdsDbPendingModifiedValues < Struct.new( :db_instance_class, :allocated_storage, :master_user_password, :port, :backup_retention_period, :multi_az, :engine_version, :license_model, :iops, :db_instance_identifier, :storage_type, :ca_certificate_identifier, :db_subnet_group_name, :pending_cloud_watch_logs_exports, :processor_features) SENSITIVE = [] include Aws::Structure end |
#multi_az ⇒ Boolean
Indicates that a single Availability Zone DB instance is changing to a multiple Availability Zone deployment.
16472 16473 16474 16475 16476 16477 16478 16479 16480 16481 16482 16483 16484 16485 16486 16487 16488 16489 16490 |
# File 'lib/aws-sdk-securityhub/types.rb', line 16472 class AwsRdsDbPendingModifiedValues < Struct.new( :db_instance_class, :allocated_storage, :master_user_password, :port, :backup_retention_period, :multi_az, :engine_version, :license_model, :iops, :db_instance_identifier, :storage_type, :ca_certificate_identifier, :db_subnet_group_name, :pending_cloud_watch_logs_exports, :processor_features) SENSITIVE = [] include Aws::Structure end |
#pending_cloud_watch_logs_exports ⇒ Types::AwsRdsPendingCloudWatchLogsExports
A list of log types that are being enabled or disabled.
16472 16473 16474 16475 16476 16477 16478 16479 16480 16481 16482 16483 16484 16485 16486 16487 16488 16489 16490 |
# File 'lib/aws-sdk-securityhub/types.rb', line 16472 class AwsRdsDbPendingModifiedValues < Struct.new( :db_instance_class, :allocated_storage, :master_user_password, :port, :backup_retention_period, :multi_az, :engine_version, :license_model, :iops, :db_instance_identifier, :storage_type, :ca_certificate_identifier, :db_subnet_group_name, :pending_cloud_watch_logs_exports, :processor_features) SENSITIVE = [] include Aws::Structure end |
#port ⇒ Integer
The new port for the DB instance.
16472 16473 16474 16475 16476 16477 16478 16479 16480 16481 16482 16483 16484 16485 16486 16487 16488 16489 16490 |
# File 'lib/aws-sdk-securityhub/types.rb', line 16472 class AwsRdsDbPendingModifiedValues < Struct.new( :db_instance_class, :allocated_storage, :master_user_password, :port, :backup_retention_period, :multi_az, :engine_version, :license_model, :iops, :db_instance_identifier, :storage_type, :ca_certificate_identifier, :db_subnet_group_name, :pending_cloud_watch_logs_exports, :processor_features) SENSITIVE = [] include Aws::Structure end |
#processor_features ⇒ Array<Types::AwsRdsDbProcessorFeature>
Processor features that are being updated.
16472 16473 16474 16475 16476 16477 16478 16479 16480 16481 16482 16483 16484 16485 16486 16487 16488 16489 16490 |
# File 'lib/aws-sdk-securityhub/types.rb', line 16472 class AwsRdsDbPendingModifiedValues < Struct.new( :db_instance_class, :allocated_storage, :master_user_password, :port, :backup_retention_period, :multi_az, :engine_version, :license_model, :iops, :db_instance_identifier, :storage_type, :ca_certificate_identifier, :db_subnet_group_name, :pending_cloud_watch_logs_exports, :processor_features) SENSITIVE = [] include Aws::Structure end |
#storage_type ⇒ String
The new storage type for the DB instance.
16472 16473 16474 16475 16476 16477 16478 16479 16480 16481 16482 16483 16484 16485 16486 16487 16488 16489 16490 |
# File 'lib/aws-sdk-securityhub/types.rb', line 16472 class AwsRdsDbPendingModifiedValues < Struct.new( :db_instance_class, :allocated_storage, :master_user_password, :port, :backup_retention_period, :multi_az, :engine_version, :license_model, :iops, :db_instance_identifier, :storage_type, :ca_certificate_identifier, :db_subnet_group_name, :pending_cloud_watch_logs_exports, :processor_features) SENSITIVE = [] include Aws::Structure end |