Class: Aws::SecurityHub::Types::AwsRdsEventSubscriptionDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::AwsRdsEventSubscriptionDetails
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Details about an Amazon RDS event notification subscription. The subscription allows Amazon RDS to post events to an SNS topic.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cust_subscription_id ⇒ String
The identifier of the account that is associated with the event notification subscription.
-
#customer_aws_id ⇒ String
The identifier of the event notification subscription.
-
#enabled ⇒ Boolean
Whether the event notification subscription is enabled.
-
#event_categories_list ⇒ Array<String>
The list of event categories for the event notification subscription.
-
#event_subscription_arn ⇒ String
The ARN of the event notification subscription.
-
#sns_topic_arn ⇒ String
The ARN of the SNS topic to post the event notifications to.
-
#source_ids_list ⇒ Array<String>
A list of source identifiers for the event notification subscription.
-
#source_type ⇒ String
The source type for the event notification subscription.
-
#status ⇒ String
The status of the event notification subscription.
-
#subscription_creation_time ⇒ String
The datetime when the event notification subscription was created.
Instance Attribute Details
#cust_subscription_id ⇒ String
The identifier of the account that is associated with the event notification subscription.
16963 16964 16965 16966 16967 16968 16969 16970 16971 16972 16973 16974 16975 16976 |
# File 'lib/aws-sdk-securityhub/types.rb', line 16963 class AwsRdsEventSubscriptionDetails < Struct.new( :cust_subscription_id, :customer_aws_id, :enabled, :event_categories_list, :event_subscription_arn, :sns_topic_arn, :source_ids_list, :source_type, :status, :subscription_creation_time) SENSITIVE = [] include Aws::Structure end |
#customer_aws_id ⇒ String
The identifier of the event notification subscription.
16963 16964 16965 16966 16967 16968 16969 16970 16971 16972 16973 16974 16975 16976 |
# File 'lib/aws-sdk-securityhub/types.rb', line 16963 class AwsRdsEventSubscriptionDetails < Struct.new( :cust_subscription_id, :customer_aws_id, :enabled, :event_categories_list, :event_subscription_arn, :sns_topic_arn, :source_ids_list, :source_type, :status, :subscription_creation_time) SENSITIVE = [] include Aws::Structure end |
#enabled ⇒ Boolean
Whether the event notification subscription is enabled.
16963 16964 16965 16966 16967 16968 16969 16970 16971 16972 16973 16974 16975 16976 |
# File 'lib/aws-sdk-securityhub/types.rb', line 16963 class AwsRdsEventSubscriptionDetails < Struct.new( :cust_subscription_id, :customer_aws_id, :enabled, :event_categories_list, :event_subscription_arn, :sns_topic_arn, :source_ids_list, :source_type, :status, :subscription_creation_time) SENSITIVE = [] include Aws::Structure end |
#event_categories_list ⇒ Array<String>
The list of event categories for the event notification subscription.
16963 16964 16965 16966 16967 16968 16969 16970 16971 16972 16973 16974 16975 16976 |
# File 'lib/aws-sdk-securityhub/types.rb', line 16963 class AwsRdsEventSubscriptionDetails < Struct.new( :cust_subscription_id, :customer_aws_id, :enabled, :event_categories_list, :event_subscription_arn, :sns_topic_arn, :source_ids_list, :source_type, :status, :subscription_creation_time) SENSITIVE = [] include Aws::Structure end |
#event_subscription_arn ⇒ String
The ARN of the event notification subscription.
16963 16964 16965 16966 16967 16968 16969 16970 16971 16972 16973 16974 16975 16976 |
# File 'lib/aws-sdk-securityhub/types.rb', line 16963 class AwsRdsEventSubscriptionDetails < Struct.new( :cust_subscription_id, :customer_aws_id, :enabled, :event_categories_list, :event_subscription_arn, :sns_topic_arn, :source_ids_list, :source_type, :status, :subscription_creation_time) SENSITIVE = [] include Aws::Structure end |
#sns_topic_arn ⇒ String
The ARN of the SNS topic to post the event notifications to.
16963 16964 16965 16966 16967 16968 16969 16970 16971 16972 16973 16974 16975 16976 |
# File 'lib/aws-sdk-securityhub/types.rb', line 16963 class AwsRdsEventSubscriptionDetails < Struct.new( :cust_subscription_id, :customer_aws_id, :enabled, :event_categories_list, :event_subscription_arn, :sns_topic_arn, :source_ids_list, :source_type, :status, :subscription_creation_time) SENSITIVE = [] include Aws::Structure end |
#source_ids_list ⇒ Array<String>
A list of source identifiers for the event notification subscription.
16963 16964 16965 16966 16967 16968 16969 16970 16971 16972 16973 16974 16975 16976 |
# File 'lib/aws-sdk-securityhub/types.rb', line 16963 class AwsRdsEventSubscriptionDetails < Struct.new( :cust_subscription_id, :customer_aws_id, :enabled, :event_categories_list, :event_subscription_arn, :sns_topic_arn, :source_ids_list, :source_type, :status, :subscription_creation_time) SENSITIVE = [] include Aws::Structure end |
#source_type ⇒ String
The source type for the event notification subscription.
16963 16964 16965 16966 16967 16968 16969 16970 16971 16972 16973 16974 16975 16976 |
# File 'lib/aws-sdk-securityhub/types.rb', line 16963 class AwsRdsEventSubscriptionDetails < Struct.new( :cust_subscription_id, :customer_aws_id, :enabled, :event_categories_list, :event_subscription_arn, :sns_topic_arn, :source_ids_list, :source_type, :status, :subscription_creation_time) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the event notification subscription.
Valid values: creating | modifying | deleting | active |
no-permission | topic-not-exist
16963 16964 16965 16966 16967 16968 16969 16970 16971 16972 16973 16974 16975 16976 |
# File 'lib/aws-sdk-securityhub/types.rb', line 16963 class AwsRdsEventSubscriptionDetails < Struct.new( :cust_subscription_id, :customer_aws_id, :enabled, :event_categories_list, :event_subscription_arn, :sns_topic_arn, :source_ids_list, :source_type, :status, :subscription_creation_time) SENSITIVE = [] include Aws::Structure end |
#subscription_creation_time ⇒ String
The datetime when the event notification subscription was created.
For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.
16963 16964 16965 16966 16967 16968 16969 16970 16971 16972 16973 16974 16975 16976 |
# File 'lib/aws-sdk-securityhub/types.rb', line 16963 class AwsRdsEventSubscriptionDetails < Struct.new( :cust_subscription_id, :customer_aws_id, :enabled, :event_categories_list, :event_subscription_arn, :sns_topic_arn, :source_ids_list, :source_type, :status, :subscription_creation_time) SENSITIVE = [] include Aws::Structure end |