Class: Aws::SecurityHub::Types::AwsRedshiftClusterDeferredMaintenanceWindow

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

A time windows during which maintenance was deferred for an Amazon Redshift cluster.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#defer_maintenance_end_timeString

The end of the time window for which maintenance was deferred.

For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.

Returns:

  • (String)


17067
17068
17069
17070
17071
17072
17073
# File 'lib/aws-sdk-securityhub/types.rb', line 17067

class AwsRedshiftClusterDeferredMaintenanceWindow < Struct.new(
  :defer_maintenance_end_time,
  :defer_maintenance_identifier,
  :defer_maintenance_start_time)
  SENSITIVE = []
  include Aws::Structure
end

#defer_maintenance_identifierString

The identifier of the maintenance window.

Returns:

  • (String)


17067
17068
17069
17070
17071
17072
17073
# File 'lib/aws-sdk-securityhub/types.rb', line 17067

class AwsRedshiftClusterDeferredMaintenanceWindow < Struct.new(
  :defer_maintenance_end_time,
  :defer_maintenance_identifier,
  :defer_maintenance_start_time)
  SENSITIVE = []
  include Aws::Structure
end

#defer_maintenance_start_timeString

The start of the time window for which maintenance was deferred.

For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.

Returns:

  • (String)


17067
17068
17069
17070
17071
17072
17073
# File 'lib/aws-sdk-securityhub/types.rb', line 17067

class AwsRedshiftClusterDeferredMaintenanceWindow < Struct.new(
  :defer_maintenance_end_time,
  :defer_maintenance_identifier,
  :defer_maintenance_start_time)
  SENSITIVE = []
  include Aws::Structure
end