Class: Aws::SecurityHub::Types::AwsRedshiftClusterPendingModifiedValues
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::AwsRedshiftClusterPendingModifiedValues
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Changes to the Amazon Redshift cluster that are currently pending.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#automated_snapshot_retention_period ⇒ Integer
The pending or in-progress change to the automated snapshot retention period.
-
#cluster_identifier ⇒ String
The pending or in-progress change to the identifier for the cluster.
-
#cluster_type ⇒ String
The pending or in-progress change to the cluster type.
-
#cluster_version ⇒ String
The pending or in-progress change to the service version.
-
#encryption_type ⇒ String
The encryption type for a cluster.
-
#enhanced_vpc_routing ⇒ Boolean
Indicates whether to create the cluster with enhanced VPC routing enabled.
-
#maintenance_track_name ⇒ String
The name of the maintenance track that the cluster changes to during the next maintenance window.
-
#master_user_password ⇒ String
The pending or in-progress change to the master user password for the cluster.
-
#node_type ⇒ String
The pending or in-progress change to the cluster's node type.
-
#number_of_nodes ⇒ Integer
The pending or in-progress change to the number of nodes in the cluster.
-
#publicly_accessible ⇒ Boolean
The pending or in-progress change to whether the cluster can be connected to from the public network.
Instance Attribute Details
#automated_snapshot_retention_period ⇒ Integer
The pending or in-progress change to the automated snapshot retention period.
17693 17694 17695 17696 17697 17698 17699 17700 17701 17702 17703 17704 17705 17706 17707 |
# File 'lib/aws-sdk-securityhub/types.rb', line 17693 class AwsRedshiftClusterPendingModifiedValues < Struct.new( :automated_snapshot_retention_period, :cluster_identifier, :cluster_type, :cluster_version, :encryption_type, :enhanced_vpc_routing, :maintenance_track_name, :master_user_password, :node_type, :number_of_nodes, :publicly_accessible) SENSITIVE = [] include Aws::Structure end |
#cluster_identifier ⇒ String
The pending or in-progress change to the identifier for the cluster.
17693 17694 17695 17696 17697 17698 17699 17700 17701 17702 17703 17704 17705 17706 17707 |
# File 'lib/aws-sdk-securityhub/types.rb', line 17693 class AwsRedshiftClusterPendingModifiedValues < Struct.new( :automated_snapshot_retention_period, :cluster_identifier, :cluster_type, :cluster_version, :encryption_type, :enhanced_vpc_routing, :maintenance_track_name, :master_user_password, :node_type, :number_of_nodes, :publicly_accessible) SENSITIVE = [] include Aws::Structure end |
#cluster_type ⇒ String
The pending or in-progress change to the cluster type.
17693 17694 17695 17696 17697 17698 17699 17700 17701 17702 17703 17704 17705 17706 17707 |
# File 'lib/aws-sdk-securityhub/types.rb', line 17693 class AwsRedshiftClusterPendingModifiedValues < Struct.new( :automated_snapshot_retention_period, :cluster_identifier, :cluster_type, :cluster_version, :encryption_type, :enhanced_vpc_routing, :maintenance_track_name, :master_user_password, :node_type, :number_of_nodes, :publicly_accessible) SENSITIVE = [] include Aws::Structure end |
#cluster_version ⇒ String
The pending or in-progress change to the service version.
17693 17694 17695 17696 17697 17698 17699 17700 17701 17702 17703 17704 17705 17706 17707 |
# File 'lib/aws-sdk-securityhub/types.rb', line 17693 class AwsRedshiftClusterPendingModifiedValues < Struct.new( :automated_snapshot_retention_period, :cluster_identifier, :cluster_type, :cluster_version, :encryption_type, :enhanced_vpc_routing, :maintenance_track_name, :master_user_password, :node_type, :number_of_nodes, :publicly_accessible) SENSITIVE = [] include Aws::Structure end |
#encryption_type ⇒ String
The encryption type for a cluster.
17693 17694 17695 17696 17697 17698 17699 17700 17701 17702 17703 17704 17705 17706 17707 |
# File 'lib/aws-sdk-securityhub/types.rb', line 17693 class AwsRedshiftClusterPendingModifiedValues < Struct.new( :automated_snapshot_retention_period, :cluster_identifier, :cluster_type, :cluster_version, :encryption_type, :enhanced_vpc_routing, :maintenance_track_name, :master_user_password, :node_type, :number_of_nodes, :publicly_accessible) SENSITIVE = [] include Aws::Structure end |
#enhanced_vpc_routing ⇒ Boolean
Indicates whether to create the cluster with enhanced VPC routing enabled.
17693 17694 17695 17696 17697 17698 17699 17700 17701 17702 17703 17704 17705 17706 17707 |
# File 'lib/aws-sdk-securityhub/types.rb', line 17693 class AwsRedshiftClusterPendingModifiedValues < Struct.new( :automated_snapshot_retention_period, :cluster_identifier, :cluster_type, :cluster_version, :encryption_type, :enhanced_vpc_routing, :maintenance_track_name, :master_user_password, :node_type, :number_of_nodes, :publicly_accessible) SENSITIVE = [] include Aws::Structure end |
#maintenance_track_name ⇒ String
The name of the maintenance track that the cluster changes to during the next maintenance window.
17693 17694 17695 17696 17697 17698 17699 17700 17701 17702 17703 17704 17705 17706 17707 |
# File 'lib/aws-sdk-securityhub/types.rb', line 17693 class AwsRedshiftClusterPendingModifiedValues < Struct.new( :automated_snapshot_retention_period, :cluster_identifier, :cluster_type, :cluster_version, :encryption_type, :enhanced_vpc_routing, :maintenance_track_name, :master_user_password, :node_type, :number_of_nodes, :publicly_accessible) SENSITIVE = [] include Aws::Structure end |
#master_user_password ⇒ String
The pending or in-progress change to the master user password for the cluster.
17693 17694 17695 17696 17697 17698 17699 17700 17701 17702 17703 17704 17705 17706 17707 |
# File 'lib/aws-sdk-securityhub/types.rb', line 17693 class AwsRedshiftClusterPendingModifiedValues < Struct.new( :automated_snapshot_retention_period, :cluster_identifier, :cluster_type, :cluster_version, :encryption_type, :enhanced_vpc_routing, :maintenance_track_name, :master_user_password, :node_type, :number_of_nodes, :publicly_accessible) SENSITIVE = [] include Aws::Structure end |
#node_type ⇒ String
The pending or in-progress change to the cluster's node type.
17693 17694 17695 17696 17697 17698 17699 17700 17701 17702 17703 17704 17705 17706 17707 |
# File 'lib/aws-sdk-securityhub/types.rb', line 17693 class AwsRedshiftClusterPendingModifiedValues < Struct.new( :automated_snapshot_retention_period, :cluster_identifier, :cluster_type, :cluster_version, :encryption_type, :enhanced_vpc_routing, :maintenance_track_name, :master_user_password, :node_type, :number_of_nodes, :publicly_accessible) SENSITIVE = [] include Aws::Structure end |
#number_of_nodes ⇒ Integer
The pending or in-progress change to the number of nodes in the cluster.
17693 17694 17695 17696 17697 17698 17699 17700 17701 17702 17703 17704 17705 17706 17707 |
# File 'lib/aws-sdk-securityhub/types.rb', line 17693 class AwsRedshiftClusterPendingModifiedValues < Struct.new( :automated_snapshot_retention_period, :cluster_identifier, :cluster_type, :cluster_version, :encryption_type, :enhanced_vpc_routing, :maintenance_track_name, :master_user_password, :node_type, :number_of_nodes, :publicly_accessible) SENSITIVE = [] include Aws::Structure end |
#publicly_accessible ⇒ Boolean
The pending or in-progress change to whether the cluster can be connected to from the public network.
17693 17694 17695 17696 17697 17698 17699 17700 17701 17702 17703 17704 17705 17706 17707 |
# File 'lib/aws-sdk-securityhub/types.rb', line 17693 class AwsRedshiftClusterPendingModifiedValues < Struct.new( :automated_snapshot_retention_period, :cluster_identifier, :cluster_type, :cluster_version, :encryption_type, :enhanced_vpc_routing, :maintenance_track_name, :master_user_password, :node_type, :number_of_nodes, :publicly_accessible) SENSITIVE = [] include Aws::Structure end |