Class: Aws::SecurityHub::Types::AwsRoute53HostedZoneDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::AwsRoute53HostedZoneDetails
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Provides details about a specified Amazon RouteĀ 53 hosted zone, including the four name servers assigned to the hosted zone. A hosted zone represents a collection of records that can be managed together, belonging to a single parent domain name.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#hosted_zone ⇒ Types::AwsRoute53HostedZoneObjectDetails
An object that contains information about the specified hosted zone.
-
#name_servers ⇒ Array<String>
An object that contains a list of the authoritative name servers for a hosted zone or for a reusable delegation set.
-
#query_logging_config ⇒ Types::AwsRoute53QueryLoggingConfigDetails
An array that contains one
QueryLoggingConfigelement for each DNS query logging configuration that is associated with the current Amazon Web Services account. -
#vpcs ⇒ Array<Types::AwsRoute53HostedZoneVpcDetails>
An object that contains information about the Amazon Virtual Private Clouds (Amazon VPCs) that are associated with the specified hosted zone.
Instance Attribute Details
#hosted_zone ⇒ Types::AwsRoute53HostedZoneObjectDetails
An object that contains information about the specified hosted zone.
17854 17855 17856 17857 17858 17859 17860 17861 |
# File 'lib/aws-sdk-securityhub/types.rb', line 17854 class AwsRoute53HostedZoneDetails < Struct.new( :hosted_zone, :vpcs, :name_servers, :query_logging_config) SENSITIVE = [] include Aws::Structure end |
#name_servers ⇒ Array<String>
An object that contains a list of the authoritative name servers for a hosted zone or for a reusable delegation set.
17854 17855 17856 17857 17858 17859 17860 17861 |
# File 'lib/aws-sdk-securityhub/types.rb', line 17854 class AwsRoute53HostedZoneDetails < Struct.new( :hosted_zone, :vpcs, :name_servers, :query_logging_config) SENSITIVE = [] include Aws::Structure end |
#query_logging_config ⇒ Types::AwsRoute53QueryLoggingConfigDetails
An array that contains one QueryLoggingConfig element for each DNS
query logging configuration that is associated with the current
Amazon Web Services account.
17854 17855 17856 17857 17858 17859 17860 17861 |
# File 'lib/aws-sdk-securityhub/types.rb', line 17854 class AwsRoute53HostedZoneDetails < Struct.new( :hosted_zone, :vpcs, :name_servers, :query_logging_config) SENSITIVE = [] include Aws::Structure end |
#vpcs ⇒ Array<Types::AwsRoute53HostedZoneVpcDetails>
An object that contains information about the Amazon Virtual Private Clouds (Amazon VPCs) that are associated with the specified hosted zone.
17854 17855 17856 17857 17858 17859 17860 17861 |
# File 'lib/aws-sdk-securityhub/types.rb', line 17854 class AwsRoute53HostedZoneDetails < Struct.new( :hosted_zone, :vpcs, :name_servers, :query_logging_config) SENSITIVE = [] include Aws::Structure end |