Class: Aws::SecurityHub::Types::AwsS3AccessPointDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::AwsS3AccessPointDetails
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Returns configuration information about the specified Amazon S3 access point. S3 access points are named network endpoints that are attached to buckets that you can use to perform S3 object operations.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#access_point_arn ⇒ String
The Amazon Resource Name (ARN) of the access point.
-
#alias ⇒ String
The name or alias of the access point.
-
#bucket ⇒ String
The name of the S3 bucket associated with the specified access point.
-
#bucket_account_id ⇒ String
The Amazon Web Services account ID associated with the S3 bucket associated with this access point.
-
#name ⇒ String
The name of the specified access point.
-
#network_origin ⇒ String
Indicates whether this access point allows access from the public internet.
-
#public_access_block_configuration ⇒ Types::AwsS3AccountPublicAccessBlockDetails
provides information about the Amazon S3 Public Access Block configuration for accounts.
-
#vpc_configuration ⇒ Types::AwsS3AccessPointVpcConfigurationDetails
Contains the virtual private cloud (VPC) configuration for the specified access point.
Instance Attribute Details
#access_point_arn ⇒ String
The Amazon Resource Name (ARN) of the access point.
17848 17849 17850 17851 17852 17853 17854 17855 17856 17857 17858 17859 |
# File 'lib/aws-sdk-securityhub/types.rb', line 17848 class AwsS3AccessPointDetails < Struct.new( :access_point_arn, :alias, :bucket, :bucket_account_id, :name, :network_origin, :public_access_block_configuration, :vpc_configuration) SENSITIVE = [] include Aws::Structure end |
#alias ⇒ String
The name or alias of the access point.
17848 17849 17850 17851 17852 17853 17854 17855 17856 17857 17858 17859 |
# File 'lib/aws-sdk-securityhub/types.rb', line 17848 class AwsS3AccessPointDetails < Struct.new( :access_point_arn, :alias, :bucket, :bucket_account_id, :name, :network_origin, :public_access_block_configuration, :vpc_configuration) SENSITIVE = [] include Aws::Structure end |
#bucket ⇒ String
The name of the S3 bucket associated with the specified access point.
17848 17849 17850 17851 17852 17853 17854 17855 17856 17857 17858 17859 |
# File 'lib/aws-sdk-securityhub/types.rb', line 17848 class AwsS3AccessPointDetails < Struct.new( :access_point_arn, :alias, :bucket, :bucket_account_id, :name, :network_origin, :public_access_block_configuration, :vpc_configuration) SENSITIVE = [] include Aws::Structure end |
#bucket_account_id ⇒ String
The Amazon Web Services account ID associated with the S3 bucket associated with this access point.
17848 17849 17850 17851 17852 17853 17854 17855 17856 17857 17858 17859 |
# File 'lib/aws-sdk-securityhub/types.rb', line 17848 class AwsS3AccessPointDetails < Struct.new( :access_point_arn, :alias, :bucket, :bucket_account_id, :name, :network_origin, :public_access_block_configuration, :vpc_configuration) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the specified access point.
17848 17849 17850 17851 17852 17853 17854 17855 17856 17857 17858 17859 |
# File 'lib/aws-sdk-securityhub/types.rb', line 17848 class AwsS3AccessPointDetails < Struct.new( :access_point_arn, :alias, :bucket, :bucket_account_id, :name, :network_origin, :public_access_block_configuration, :vpc_configuration) SENSITIVE = [] include Aws::Structure end |
#network_origin ⇒ String
Indicates whether this access point allows access from the public internet.
17848 17849 17850 17851 17852 17853 17854 17855 17856 17857 17858 17859 |
# File 'lib/aws-sdk-securityhub/types.rb', line 17848 class AwsS3AccessPointDetails < Struct.new( :access_point_arn, :alias, :bucket, :bucket_account_id, :name, :network_origin, :public_access_block_configuration, :vpc_configuration) SENSITIVE = [] include Aws::Structure end |
#public_access_block_configuration ⇒ Types::AwsS3AccountPublicAccessBlockDetails
provides information about the Amazon S3 Public Access Block configuration for accounts.
17848 17849 17850 17851 17852 17853 17854 17855 17856 17857 17858 17859 |
# File 'lib/aws-sdk-securityhub/types.rb', line 17848 class AwsS3AccessPointDetails < Struct.new( :access_point_arn, :alias, :bucket, :bucket_account_id, :name, :network_origin, :public_access_block_configuration, :vpc_configuration) SENSITIVE = [] include Aws::Structure end |
#vpc_configuration ⇒ Types::AwsS3AccessPointVpcConfigurationDetails
Contains the virtual private cloud (VPC) configuration for the specified access point.
17848 17849 17850 17851 17852 17853 17854 17855 17856 17857 17858 17859 |
# File 'lib/aws-sdk-securityhub/types.rb', line 17848 class AwsS3AccessPointDetails < Struct.new( :access_point_arn, :alias, :bucket, :bucket_account_id, :name, :network_origin, :public_access_block_configuration, :vpc_configuration) SENSITIVE = [] include Aws::Structure end |