Class: Aws::SecurityHub::Types::AwsS3BucketBucketLifecycleConfigurationRulesTransitionsDetails

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

A rule for when objects transition to specific storage classes.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dateString

A date on which to transition objects to the specified storage class. If you provide Date, you cannot provide Days.

For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.

Returns:

  • (String)


18212
18213
18214
18215
18216
18217
18218
# File 'lib/aws-sdk-securityhub/types.rb', line 18212

class AwsS3BucketBucketLifecycleConfigurationRulesTransitionsDetails < Struct.new(
  :date,
  :days,
  :storage_class)
  SENSITIVE = []
  include Aws::Structure
end

#daysInteger

The number of days after which to transition the object to the specified storage class. If you provide Days, you cannot provide Date.

Returns:

  • (Integer)


18212
18213
18214
18215
18216
18217
18218
# File 'lib/aws-sdk-securityhub/types.rb', line 18212

class AwsS3BucketBucketLifecycleConfigurationRulesTransitionsDetails < Struct.new(
  :date,
  :days,
  :storage_class)
  SENSITIVE = []
  include Aws::Structure
end

#storage_classString

The storage class to transition the object to. Valid values are as follows:

  • DEEP_ARCHIVE

  • GLACIER

  • INTELLIGENT_TIERING

  • ONEZONE_IA

  • STANDARD_IA

Returns:

  • (String)


18212
18213
18214
18215
18216
18217
18218
# File 'lib/aws-sdk-securityhub/types.rb', line 18212

class AwsS3BucketBucketLifecycleConfigurationRulesTransitionsDetails < Struct.new(
  :date,
  :days,
  :storage_class)
  SENSITIVE = []
  include Aws::Structure
end