Method: Aws::SecurityHub::Types::AwsSecurityFinding#confidence
- Defined in:
- lib/aws-sdk-securityhub/types.rb
#confidence ⇒ Integer
A finding’s confidence. Confidence is defined as the likelihood that a finding accurately identifies the behavior or issue that it was intended to identify.
Confidence is scored on a 0-100 basis using a ratio scale, where 0 means zero percent confidence and 100 means 100 percent confidence.
19271 19272 19273 19274 19275 19276 19277 19278 19279 19280 19281 19282 19283 19284 19285 19286 19287 19288 19289 19290 19291 19292 19293 19294 19295 19296 19297 19298 19299 19300 19301 19302 19303 19304 19305 19306 19307 19308 19309 19310 19311 19312 19313 19314 19315 19316 19317 19318 19319 |
# File 'lib/aws-sdk-securityhub/types.rb', line 19271 class AwsSecurityFinding < Struct.new( :schema_version, :id, :product_arn, :product_name, :company_name, :region, :generator_id, :aws_account_id, :types, :first_observed_at, :last_observed_at, :created_at, :updated_at, :severity, :confidence, :criticality, :title, :description, :remediation, :source_url, :product_fields, :user_defined_fields, :malware, :network, :network_path, :process, :threats, :threat_intel_indicators, :resources, :compliance, :verification_state, :workflow_state, :workflow, :record_state, :related_findings, :note, :vulnerabilities, :patch_summary, :action, :finding_provider_fields, :sample, :generator_details, :processed_at, :aws_account_name, :detection) SENSITIVE = [] include Aws::Structure end |