Class: Aws::SecurityHub::Types::AwsSnsTopicDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::AwsSnsTopicDetails
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Provides information about an Amazon SNS topic to which notifications can be published.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#application_success_feedback_role_arn ⇒ String
Indicates failed message delivery status for an Amazon SNS topic that is subscribed to a platform application endpoint.
-
#firehose_failure_feedback_role_arn ⇒ String
Indicates failed message delivery status for an Amazon SNS topic that is subscribed to an Amazon Kinesis Data Firehose endpoint.
-
#firehose_success_feedback_role_arn ⇒ String
Indicates successful message delivery status for an Amazon SNS topic that is subscribed to an Amazon Kinesis Data Firehose endpoint.
-
#http_failure_feedback_role_arn ⇒ String
Indicates failed message delivery status for an Amazon SNS topic that is subscribed to an HTTP endpoint.
-
#http_success_feedback_role_arn ⇒ String
Indicates successful message delivery status for an Amazon SNS topic that is subscribed to an HTTP endpoint.
-
#kms_master_key_id ⇒ String
The ID of an Amazon Web Services managed key for Amazon SNS or a customer managed key.
-
#owner ⇒ String
The subscription's owner.
-
#sqs_failure_feedback_role_arn ⇒ String
Indicates failed message delivery status for an Amazon SNS topic that is subscribed to an Amazon SQS endpoint.
-
#sqs_success_feedback_role_arn ⇒ String
Indicates successful message delivery status for an Amazon SNS topic that is subscribed to an Amazon SQS endpoint.
-
#subscription ⇒ Array<Types::AwsSnsTopicSubscription>
Subscription is an embedded property that describes the subscription endpoints of an Amazon SNS topic.
-
#topic_name ⇒ String
The name of the Amazon SNS topic.
Instance Attribute Details
#application_success_feedback_role_arn ⇒ String
Indicates failed message delivery status for an Amazon SNS topic that is subscribed to a platform application endpoint.
20197 20198 20199 20200 20201 20202 20203 20204 20205 20206 20207 20208 20209 20210 20211 |
# File 'lib/aws-sdk-securityhub/types.rb', line 20197 class AwsSnsTopicDetails < Struct.new( :kms_master_key_id, :subscription, :topic_name, :owner, :sqs_success_feedback_role_arn, :sqs_failure_feedback_role_arn, :application_success_feedback_role_arn, :firehose_success_feedback_role_arn, :firehose_failure_feedback_role_arn, :http_success_feedback_role_arn, :http_failure_feedback_role_arn) SENSITIVE = [] include Aws::Structure end |
#firehose_failure_feedback_role_arn ⇒ String
Indicates failed message delivery status for an Amazon SNS topic that is subscribed to an Amazon Kinesis Data Firehose endpoint.
20197 20198 20199 20200 20201 20202 20203 20204 20205 20206 20207 20208 20209 20210 20211 |
# File 'lib/aws-sdk-securityhub/types.rb', line 20197 class AwsSnsTopicDetails < Struct.new( :kms_master_key_id, :subscription, :topic_name, :owner, :sqs_success_feedback_role_arn, :sqs_failure_feedback_role_arn, :application_success_feedback_role_arn, :firehose_success_feedback_role_arn, :firehose_failure_feedback_role_arn, :http_success_feedback_role_arn, :http_failure_feedback_role_arn) SENSITIVE = [] include Aws::Structure end |
#firehose_success_feedback_role_arn ⇒ String
Indicates successful message delivery status for an Amazon SNS topic that is subscribed to an Amazon Kinesis Data Firehose endpoint.
20197 20198 20199 20200 20201 20202 20203 20204 20205 20206 20207 20208 20209 20210 20211 |
# File 'lib/aws-sdk-securityhub/types.rb', line 20197 class AwsSnsTopicDetails < Struct.new( :kms_master_key_id, :subscription, :topic_name, :owner, :sqs_success_feedback_role_arn, :sqs_failure_feedback_role_arn, :application_success_feedback_role_arn, :firehose_success_feedback_role_arn, :firehose_failure_feedback_role_arn, :http_success_feedback_role_arn, :http_failure_feedback_role_arn) SENSITIVE = [] include Aws::Structure end |
#http_failure_feedback_role_arn ⇒ String
Indicates failed message delivery status for an Amazon SNS topic that is subscribed to an HTTP endpoint.
20197 20198 20199 20200 20201 20202 20203 20204 20205 20206 20207 20208 20209 20210 20211 |
# File 'lib/aws-sdk-securityhub/types.rb', line 20197 class AwsSnsTopicDetails < Struct.new( :kms_master_key_id, :subscription, :topic_name, :owner, :sqs_success_feedback_role_arn, :sqs_failure_feedback_role_arn, :application_success_feedback_role_arn, :firehose_success_feedback_role_arn, :firehose_failure_feedback_role_arn, :http_success_feedback_role_arn, :http_failure_feedback_role_arn) SENSITIVE = [] include Aws::Structure end |
#http_success_feedback_role_arn ⇒ String
Indicates successful message delivery status for an Amazon SNS topic that is subscribed to an HTTP endpoint.
20197 20198 20199 20200 20201 20202 20203 20204 20205 20206 20207 20208 20209 20210 20211 |
# File 'lib/aws-sdk-securityhub/types.rb', line 20197 class AwsSnsTopicDetails < Struct.new( :kms_master_key_id, :subscription, :topic_name, :owner, :sqs_success_feedback_role_arn, :sqs_failure_feedback_role_arn, :application_success_feedback_role_arn, :firehose_success_feedback_role_arn, :firehose_failure_feedback_role_arn, :http_success_feedback_role_arn, :http_failure_feedback_role_arn) SENSITIVE = [] include Aws::Structure end |
#kms_master_key_id ⇒ String
The ID of an Amazon Web Services managed key for Amazon SNS or a customer managed key.
20197 20198 20199 20200 20201 20202 20203 20204 20205 20206 20207 20208 20209 20210 20211 |
# File 'lib/aws-sdk-securityhub/types.rb', line 20197 class AwsSnsTopicDetails < Struct.new( :kms_master_key_id, :subscription, :topic_name, :owner, :sqs_success_feedback_role_arn, :sqs_failure_feedback_role_arn, :application_success_feedback_role_arn, :firehose_success_feedback_role_arn, :firehose_failure_feedback_role_arn, :http_success_feedback_role_arn, :http_failure_feedback_role_arn) SENSITIVE = [] include Aws::Structure end |
#owner ⇒ String
The subscription's owner.
20197 20198 20199 20200 20201 20202 20203 20204 20205 20206 20207 20208 20209 20210 20211 |
# File 'lib/aws-sdk-securityhub/types.rb', line 20197 class AwsSnsTopicDetails < Struct.new( :kms_master_key_id, :subscription, :topic_name, :owner, :sqs_success_feedback_role_arn, :sqs_failure_feedback_role_arn, :application_success_feedback_role_arn, :firehose_success_feedback_role_arn, :firehose_failure_feedback_role_arn, :http_success_feedback_role_arn, :http_failure_feedback_role_arn) SENSITIVE = [] include Aws::Structure end |
#sqs_failure_feedback_role_arn ⇒ String
Indicates failed message delivery status for an Amazon SNS topic that is subscribed to an Amazon SQS endpoint.
20197 20198 20199 20200 20201 20202 20203 20204 20205 20206 20207 20208 20209 20210 20211 |
# File 'lib/aws-sdk-securityhub/types.rb', line 20197 class AwsSnsTopicDetails < Struct.new( :kms_master_key_id, :subscription, :topic_name, :owner, :sqs_success_feedback_role_arn, :sqs_failure_feedback_role_arn, :application_success_feedback_role_arn, :firehose_success_feedback_role_arn, :firehose_failure_feedback_role_arn, :http_success_feedback_role_arn, :http_failure_feedback_role_arn) SENSITIVE = [] include Aws::Structure end |
#sqs_success_feedback_role_arn ⇒ String
Indicates successful message delivery status for an Amazon SNS topic that is subscribed to an Amazon SQS endpoint.
20197 20198 20199 20200 20201 20202 20203 20204 20205 20206 20207 20208 20209 20210 20211 |
# File 'lib/aws-sdk-securityhub/types.rb', line 20197 class AwsSnsTopicDetails < Struct.new( :kms_master_key_id, :subscription, :topic_name, :owner, :sqs_success_feedback_role_arn, :sqs_failure_feedback_role_arn, :application_success_feedback_role_arn, :firehose_success_feedback_role_arn, :firehose_failure_feedback_role_arn, :http_success_feedback_role_arn, :http_failure_feedback_role_arn) SENSITIVE = [] include Aws::Structure end |
#subscription ⇒ Array<Types::AwsSnsTopicSubscription>
Subscription is an embedded property that describes the subscription endpoints of an Amazon SNS topic.
20197 20198 20199 20200 20201 20202 20203 20204 20205 20206 20207 20208 20209 20210 20211 |
# File 'lib/aws-sdk-securityhub/types.rb', line 20197 class AwsSnsTopicDetails < Struct.new( :kms_master_key_id, :subscription, :topic_name, :owner, :sqs_success_feedback_role_arn, :sqs_failure_feedback_role_arn, :application_success_feedback_role_arn, :firehose_success_feedback_role_arn, :firehose_failure_feedback_role_arn, :http_success_feedback_role_arn, :http_failure_feedback_role_arn) SENSITIVE = [] include Aws::Structure end |
#topic_name ⇒ String
The name of the Amazon SNS topic.
20197 20198 20199 20200 20201 20202 20203 20204 20205 20206 20207 20208 20209 20210 20211 |
# File 'lib/aws-sdk-securityhub/types.rb', line 20197 class AwsSnsTopicDetails < Struct.new( :kms_master_key_id, :subscription, :topic_name, :owner, :sqs_success_feedback_role_arn, :sqs_failure_feedback_role_arn, :application_success_feedback_role_arn, :firehose_success_feedback_role_arn, :firehose_failure_feedback_role_arn, :http_success_feedback_role_arn, :http_failure_feedback_role_arn) SENSITIVE = [] include Aws::Structure end |