Class: Aws::SecurityHub::Types::AwsWafRateBasedRuleMatchPredicate
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::AwsWafRateBasedRuleMatchPredicate
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
A match predicate. A predicate might look for characteristics such as specific IP addresses, geographic locations, or sizes.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#data_id ⇒ String
The unique identifier for the predicate.
-
#negated ⇒ Boolean
If set to
true, then the rule actions are performed on requests that match the predicate settings. -
#type ⇒ String
The type of predicate.
Instance Attribute Details
#data_id ⇒ String
The unique identifier for the predicate.
20745 20746 20747 20748 20749 20750 20751 |
# File 'lib/aws-sdk-securityhub/types.rb', line 20745 class AwsWafRateBasedRuleMatchPredicate < Struct.new( :data_id, :negated, :type) SENSITIVE = [] include Aws::Structure end |
#negated ⇒ Boolean
If set to true, then the rule actions are performed on requests
that match the predicate settings.
If set to false, then the rule actions are performed on all
requests except those that match the predicate settings.
20745 20746 20747 20748 20749 20750 20751 |
# File 'lib/aws-sdk-securityhub/types.rb', line 20745 class AwsWafRateBasedRuleMatchPredicate < Struct.new( :data_id, :negated, :type) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of predicate. Valid values are as follows:
-
ByteMatch -
GeoMatch -
IPMatch -
RegexMatch -
SizeConstraint -
SqlInjectionMatch -
XssMatch
20745 20746 20747 20748 20749 20750 20751 |
# File 'lib/aws-sdk-securityhub/types.rb', line 20745 class AwsWafRateBasedRuleMatchPredicate < Struct.new( :data_id, :negated, :type) SENSITIVE = [] include Aws::Structure end |