Class: Aws::SecurityHub::Types::AwsWafRateBasedRuleMatchPredicate

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

A match predicate. A predicate might look for characteristics such as specific IP addresses, geographic locations, or sizes.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#data_idString

The unique identifier for the predicate.

Returns:

  • (String)


20644
20645
20646
20647
20648
20649
20650
# File 'lib/aws-sdk-securityhub/types.rb', line 20644

class AwsWafRateBasedRuleMatchPredicate < Struct.new(
  :data_id,
  :negated,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#negatedBoolean

If set to true, then the rule actions are performed on requests that match the predicate settings.

If set to false, then the rule actions are performed on all requests except those that match the predicate settings.

Returns:

  • (Boolean)


20644
20645
20646
20647
20648
20649
20650
# File 'lib/aws-sdk-securityhub/types.rb', line 20644

class AwsWafRateBasedRuleMatchPredicate < Struct.new(
  :data_id,
  :negated,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The type of predicate. Valid values are as follows:

  • ByteMatch

  • GeoMatch

  • IPMatch

  • RegexMatch

  • SizeConstraint

  • SqlInjectionMatch

  • XssMatch

Returns:

  • (String)


20644
20645
20646
20647
20648
20649
20650
# File 'lib/aws-sdk-securityhub/types.rb', line 20644

class AwsWafRateBasedRuleMatchPredicate < Struct.new(
  :data_id,
  :negated,
  :type)
  SENSITIVE = []
  include Aws::Structure
end