Class: Aws::SecurityHub::Types::AwsWafRegionalRateBasedRuleDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::AwsWafRegionalRateBasedRuleDetails
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
contains details about a rate-based rule for Regional resources. A rate-based rule provides settings to indicate when to allow, block, or count a request. Rate-based rules include the number of requests that arrive over a specified period of time.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#match_predicates ⇒ Array<Types::AwsWafRegionalRateBasedRuleMatchPredicate>
The predicates to include in the rate-based rule.
-
#metric_name ⇒ String
The name of the metrics for the rate-based rule.
-
#name ⇒ String
The name of the rate-based rule.
-
#rate_key ⇒ String
The field that WAF uses to determine whether requests are likely arriving from single source and are subject to rate monitoring.
-
#rate_limit ⇒ Integer
The maximum number of requests that have an identical value for the field specified in
RateKeythat are allowed within a five-minute period. -
#rule_id ⇒ String
The unique identifier for the rate-based rule.
Instance Attribute Details
#match_predicates ⇒ Array<Types::AwsWafRegionalRateBasedRuleMatchPredicate>
The predicates to include in the rate-based rule.
20688 20689 20690 20691 20692 20693 20694 20695 20696 20697 |
# File 'lib/aws-sdk-securityhub/types.rb', line 20688 class AwsWafRegionalRateBasedRuleDetails < Struct.new( :metric_name, :name, :rate_key, :rate_limit, :rule_id, :match_predicates) SENSITIVE = [] include Aws::Structure end |
#metric_name ⇒ String
The name of the metrics for the rate-based rule.
20688 20689 20690 20691 20692 20693 20694 20695 20696 20697 |
# File 'lib/aws-sdk-securityhub/types.rb', line 20688 class AwsWafRegionalRateBasedRuleDetails < Struct.new( :metric_name, :name, :rate_key, :rate_limit, :rule_id, :match_predicates) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the rate-based rule.
20688 20689 20690 20691 20692 20693 20694 20695 20696 20697 |
# File 'lib/aws-sdk-securityhub/types.rb', line 20688 class AwsWafRegionalRateBasedRuleDetails < Struct.new( :metric_name, :name, :rate_key, :rate_limit, :rule_id, :match_predicates) SENSITIVE = [] include Aws::Structure end |
#rate_key ⇒ String
The field that WAF uses to determine whether requests are likely arriving from single source and are subject to rate monitoring.
20688 20689 20690 20691 20692 20693 20694 20695 20696 20697 |
# File 'lib/aws-sdk-securityhub/types.rb', line 20688 class AwsWafRegionalRateBasedRuleDetails < Struct.new( :metric_name, :name, :rate_key, :rate_limit, :rule_id, :match_predicates) SENSITIVE = [] include Aws::Structure end |
#rate_limit ⇒ Integer
The maximum number of requests that have an identical value for the
field specified in RateKey that are allowed within a five-minute
period. If the number of requests exceeds RateLimit and the other
predicates specified in the rule are met, WAF triggers the action
for the rule.
20688 20689 20690 20691 20692 20693 20694 20695 20696 20697 |
# File 'lib/aws-sdk-securityhub/types.rb', line 20688 class AwsWafRegionalRateBasedRuleDetails < Struct.new( :metric_name, :name, :rate_key, :rate_limit, :rule_id, :match_predicates) SENSITIVE = [] include Aws::Structure end |
#rule_id ⇒ String
The unique identifier for the rate-based rule.
20688 20689 20690 20691 20692 20693 20694 20695 20696 20697 |
# File 'lib/aws-sdk-securityhub/types.rb', line 20688 class AwsWafRegionalRateBasedRuleDetails < Struct.new( :metric_name, :name, :rate_key, :rate_limit, :rule_id, :match_predicates) SENSITIVE = [] include Aws::Structure end |