Class: Aws::SecurityHub::Types::AwsWafRegionalWebAclDetails

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

Provides information about the web access control list (web ACL). The web ACL contains the rules that identify the requests that you want to allow, block, or count.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#default_actionString

The action to perform if none of the rules contained in the web ACL match.

Returns:

  • (String)


20915
20916
20917
20918
20919
20920
20921
20922
20923
# File 'lib/aws-sdk-securityhub/types.rb', line 20915

class AwsWafRegionalWebAclDetails < Struct.new(
  :default_action,
  :metric_name,
  :name,
  :rules_list,
  :web_acl_id)
  SENSITIVE = []
  include Aws::Structure
end

#metric_nameString

A name for the metrics for this web ACL.

Returns:

  • (String)


20915
20916
20917
20918
20919
20920
20921
20922
20923
# File 'lib/aws-sdk-securityhub/types.rb', line 20915

class AwsWafRegionalWebAclDetails < Struct.new(
  :default_action,
  :metric_name,
  :name,
  :rules_list,
  :web_acl_id)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

A descriptive name for the web ACL.

Returns:

  • (String)


20915
20916
20917
20918
20919
20920
20921
20922
20923
# File 'lib/aws-sdk-securityhub/types.rb', line 20915

class AwsWafRegionalWebAclDetails < Struct.new(
  :default_action,
  :metric_name,
  :name,
  :rules_list,
  :web_acl_id)
  SENSITIVE = []
  include Aws::Structure
end

#rules_listArray<Types::AwsWafRegionalWebAclRulesListDetails>

An array that contains the action for each rule in a web ACL, the priority of the rule, and the ID of the rule.



20915
20916
20917
20918
20919
20920
20921
20922
20923
# File 'lib/aws-sdk-securityhub/types.rb', line 20915

class AwsWafRegionalWebAclDetails < Struct.new(
  :default_action,
  :metric_name,
  :name,
  :rules_list,
  :web_acl_id)
  SENSITIVE = []
  include Aws::Structure
end

#web_acl_idString

The ID of the web ACL.

Returns:

  • (String)


20915
20916
20917
20918
20919
20920
20921
20922
20923
# File 'lib/aws-sdk-securityhub/types.rb', line 20915

class AwsWafRegionalWebAclDetails < Struct.new(
  :default_action,
  :metric_name,
  :name,
  :rules_list,
  :web_acl_id)
  SENSITIVE = []
  include Aws::Structure
end