Class: Aws::SecurityHub::Types::AwsWafRegionalWebAclDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::AwsWafRegionalWebAclDetails
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Provides information about the web access control list (web ACL). The web ACL contains the rules that identify the requests that you want to allow, block, or count.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#default_action ⇒ String
The action to perform if none of the rules contained in the web ACL match.
-
#metric_name ⇒ String
A name for the metrics for this web ACL.
-
#name ⇒ String
A descriptive name for the web ACL.
-
#rules_list ⇒ Array<Types::AwsWafRegionalWebAclRulesListDetails>
An array that contains the action for each rule in a web ACL, the priority of the rule, and the ID of the rule.
-
#web_acl_id ⇒ String
The ID of the web ACL.
Instance Attribute Details
#default_action ⇒ String
The action to perform if none of the rules contained in the web ACL match.
20915 20916 20917 20918 20919 20920 20921 20922 20923 |
# File 'lib/aws-sdk-securityhub/types.rb', line 20915 class AwsWafRegionalWebAclDetails < Struct.new( :default_action, :metric_name, :name, :rules_list, :web_acl_id) SENSITIVE = [] include Aws::Structure end |
#metric_name ⇒ String
A name for the metrics for this web ACL.
20915 20916 20917 20918 20919 20920 20921 20922 20923 |
# File 'lib/aws-sdk-securityhub/types.rb', line 20915 class AwsWafRegionalWebAclDetails < Struct.new( :default_action, :metric_name, :name, :rules_list, :web_acl_id) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
A descriptive name for the web ACL.
20915 20916 20917 20918 20919 20920 20921 20922 20923 |
# File 'lib/aws-sdk-securityhub/types.rb', line 20915 class AwsWafRegionalWebAclDetails < Struct.new( :default_action, :metric_name, :name, :rules_list, :web_acl_id) SENSITIVE = [] include Aws::Structure end |
#rules_list ⇒ Array<Types::AwsWafRegionalWebAclRulesListDetails>
An array that contains the action for each rule in a web ACL, the priority of the rule, and the ID of the rule.
20915 20916 20917 20918 20919 20920 20921 20922 20923 |
# File 'lib/aws-sdk-securityhub/types.rb', line 20915 class AwsWafRegionalWebAclDetails < Struct.new( :default_action, :metric_name, :name, :rules_list, :web_acl_id) SENSITIVE = [] include Aws::Structure end |
#web_acl_id ⇒ String
The ID of the web ACL.
20915 20916 20917 20918 20919 20920 20921 20922 20923 |
# File 'lib/aws-sdk-securityhub/types.rb', line 20915 class AwsWafRegionalWebAclDetails < Struct.new( :default_action, :metric_name, :name, :rules_list, :web_acl_id) SENSITIVE = [] include Aws::Structure end |