Class: Aws::SecurityHub::Types::AwsWafRuleGroupDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::AwsWafRuleGroupDetails
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Provides information about an WAF rule group. A rule group is a collection of rules for inspecting and controlling web requests.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#metric_name ⇒ String
The name of the metrics for this rule group.
-
#name ⇒ String
The name of the rule group.
-
#rule_group_id ⇒ String
The ID of the rule group.
-
#rules ⇒ Array<Types::AwsWafRuleGroupRulesDetails>
Provides information about the rules attached to the rule group.
Instance Attribute Details
#metric_name ⇒ String
The name of the metrics for this rule group.
21151 21152 21153 21154 21155 21156 21157 21158 |
# File 'lib/aws-sdk-securityhub/types.rb', line 21151 class AwsWafRuleGroupDetails < Struct.new( :metric_name, :name, :rule_group_id, :rules) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the rule group.
21151 21152 21153 21154 21155 21156 21157 21158 |
# File 'lib/aws-sdk-securityhub/types.rb', line 21151 class AwsWafRuleGroupDetails < Struct.new( :metric_name, :name, :rule_group_id, :rules) SENSITIVE = [] include Aws::Structure end |
#rule_group_id ⇒ String
The ID of the rule group.
21151 21152 21153 21154 21155 21156 21157 21158 |
# File 'lib/aws-sdk-securityhub/types.rb', line 21151 class AwsWafRuleGroupDetails < Struct.new( :metric_name, :name, :rule_group_id, :rules) SENSITIVE = [] include Aws::Structure end |
#rules ⇒ Array<Types::AwsWafRuleGroupRulesDetails>
Provides information about the rules attached to the rule group. These rules identify the web requests that you want to allow, block, or count.
21151 21152 21153 21154 21155 21156 21157 21158 |
# File 'lib/aws-sdk-securityhub/types.rb', line 21151 class AwsWafRuleGroupDetails < Struct.new( :metric_name, :name, :rule_group_id, :rules) SENSITIVE = [] include Aws::Structure end |