Class: Aws::SecurityHub::Types::AwsWafRuleGroupDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::AwsWafRuleGroupDetails
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Provides information about an WAF rule group. A rule group is a collection of rules for inspecting and controlling web requests.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#metric_name ⇒ String
The name of the metrics for this rule group.
-
#name ⇒ String
The name of the rule group.
-
#rule_group_id ⇒ String
The ID of the rule group.
-
#rules ⇒ Array<Types::AwsWafRuleGroupRulesDetails>
Provides information about the rules attached to the rule group.
Instance Attribute Details
#metric_name ⇒ String
The name of the metrics for this rule group.
21012 21013 21014 21015 21016 21017 21018 21019 |
# File 'lib/aws-sdk-securityhub/types.rb', line 21012 class AwsWafRuleGroupDetails < Struct.new( :metric_name, :name, :rule_group_id, :rules) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the rule group.
21012 21013 21014 21015 21016 21017 21018 21019 |
# File 'lib/aws-sdk-securityhub/types.rb', line 21012 class AwsWafRuleGroupDetails < Struct.new( :metric_name, :name, :rule_group_id, :rules) SENSITIVE = [] include Aws::Structure end |
#rule_group_id ⇒ String
The ID of the rule group.
21012 21013 21014 21015 21016 21017 21018 21019 |
# File 'lib/aws-sdk-securityhub/types.rb', line 21012 class AwsWafRuleGroupDetails < Struct.new( :metric_name, :name, :rule_group_id, :rules) SENSITIVE = [] include Aws::Structure end |
#rules ⇒ Array<Types::AwsWafRuleGroupRulesDetails>
Provides information about the rules attached to the rule group. These rules identify the web requests that you want to allow, block, or count.
21012 21013 21014 21015 21016 21017 21018 21019 |
# File 'lib/aws-sdk-securityhub/types.rb', line 21012 class AwsWafRuleGroupDetails < Struct.new( :metric_name, :name, :rule_group_id, :rules) SENSITIVE = [] include Aws::Structure end |