Class: Aws::SecurityHub::Types::AwsWafv2CustomResponseDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::AwsWafv2CustomResponseDetails
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
A custom response to send to the client. You can define a custom response for rule actions and default web ACL actions that are set to block.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#custom_response_body_key ⇒ String
References the response body that you want WAF to return to the web request client.
-
#response_code ⇒ Integer
The HTTP status code to return to the client.
-
#response_headers ⇒ Array<Types::AwsWafv2CustomHttpHeader>
The HTTP headers to use in the response.
Instance Attribute Details
#custom_response_body_key ⇒ String
References the response body that you want WAF to return to the web request client. You can define a custom response for a rule action or a default web ACL action that is set to block.
21339 21340 21341 21342 21343 21344 21345 |
# File 'lib/aws-sdk-securityhub/types.rb', line 21339 class AwsWafv2CustomResponseDetails < Struct.new( :custom_response_body_key, :response_code, :response_headers) SENSITIVE = [] include Aws::Structure end |
#response_code ⇒ Integer
The HTTP status code to return to the client. For a list of status codes that you can use in your custom responses, see Supported status codes for custom response in the WAF Developer Guide.
21339 21340 21341 21342 21343 21344 21345 |
# File 'lib/aws-sdk-securityhub/types.rb', line 21339 class AwsWafv2CustomResponseDetails < Struct.new( :custom_response_body_key, :response_code, :response_headers) SENSITIVE = [] include Aws::Structure end |
#response_headers ⇒ Array<Types::AwsWafv2CustomHttpHeader>
The HTTP headers to use in the response.
21339 21340 21341 21342 21343 21344 21345 |
# File 'lib/aws-sdk-securityhub/types.rb', line 21339 class AwsWafv2CustomResponseDetails < Struct.new( :custom_response_body_key, :response_code, :response_headers) SENSITIVE = [] include Aws::Structure end |