Class: Aws::SecurityHub::Types::AwsWafv2RulesActionCaptchaDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::AwsWafv2RulesActionCaptchaDetails
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Specifies that WAF should run a CAPTCHA check against the request.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#custom_request_handling ⇒ Types::AwsWafv2CustomRequestHandlingDetails
Defines custom handling for the web request, used when the CAPTCHA inspection determines that the request's token is valid and unexpired.
Instance Attribute Details
#custom_request_handling ⇒ Types::AwsWafv2CustomRequestHandlingDetails
Defines custom handling for the web request, used when the CAPTCHA inspection determines that the request's token is valid and unexpired. For more information, see Customizing web requests and responses in WAF in the WAF Developer Guide..
21549 21550 21551 21552 21553 |
# File 'lib/aws-sdk-securityhub/types.rb', line 21549 class AwsWafv2RulesActionCaptchaDetails < Struct.new( :custom_request_handling) SENSITIVE = [] include Aws::Structure end |