Class: Aws::SecurityHub::Types::AwsWafv2VisibilityConfigDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::AwsWafv2VisibilityConfigDetails
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Defines and enables Amazon CloudWatch metrics and web request sample collection.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cloud_watch_metrics_enabled ⇒ Boolean
A boolean indicating whether the associated resource sends metrics to Amazon CloudWatch.
-
#metric_name ⇒ String
A name of the Amazon CloudWatch metric.
-
#sampled_requests_enabled ⇒ Boolean
A boolean indicating whether WAF should store a sampling of the web requests that match the rules.
Instance Attribute Details
#cloud_watch_metrics_enabled ⇒ Boolean
A boolean indicating whether the associated resource sends metrics to Amazon CloudWatch. For the list of available metrics, see WAF metrics and dimensions in the WAF Developer Guide.
21546 21547 21548 21549 21550 21551 21552 |
# File 'lib/aws-sdk-securityhub/types.rb', line 21546 class AwsWafv2VisibilityConfigDetails < Struct.new( :cloud_watch_metrics_enabled, :metric_name, :sampled_requests_enabled) SENSITIVE = [] include Aws::Structure end |
#metric_name ⇒ String
A name of the Amazon CloudWatch metric.
21546 21547 21548 21549 21550 21551 21552 |
# File 'lib/aws-sdk-securityhub/types.rb', line 21546 class AwsWafv2VisibilityConfigDetails < Struct.new( :cloud_watch_metrics_enabled, :metric_name, :sampled_requests_enabled) SENSITIVE = [] include Aws::Structure end |
#sampled_requests_enabled ⇒ Boolean
A boolean indicating whether WAF should store a sampling of the web requests that match the rules. You can view the sampled requests through the WAF console.
21546 21547 21548 21549 21550 21551 21552 |
# File 'lib/aws-sdk-securityhub/types.rb', line 21546 class AwsWafv2VisibilityConfigDetails < Struct.new( :cloud_watch_metrics_enabled, :metric_name, :sampled_requests_enabled) SENSITIVE = [] include Aws::Structure end |