Class: Aws::SecurityHub::Types::AwsWafv2WebAclDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::AwsWafv2WebAclDetails
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Details about an WAFv2 web Access Control List (ACL).
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the web ACL that you want to associate with the resource.
-
#capacity ⇒ Integer
The web ACL capacity units (WCUs) currently being used by this web ACL.
-
#captcha_config ⇒ Types::AwsWafv2WebAclCaptchaConfigDetails
Specifies how WAF should handle CAPTCHA evaluations for rules that don't have their own
CaptchaConfigsettings. -
#default_action ⇒ Types::AwsWafv2WebAclActionDetails
The action to perform if none of the Rules contained in the web ACL match.
-
#description ⇒ String
A description of the web ACL that helps with identification.
-
#id ⇒ String
A unique identifier for the web ACL.
-
#managedby_firewall_manager ⇒ Boolean
Indicates whether this web ACL is managed by Firewall Manager.
-
#name ⇒ String
The name of the web ACL.
-
#rules ⇒ Array<Types::AwsWafv2RulesDetails>
The Rule statements used to identify the web requests that you want to allow, block, or count.
-
#visibility_config ⇒ Types::AwsWafv2VisibilityConfigDetails
Defines and enables Amazon CloudWatch metrics and web request sample collection.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the web ACL that you want to associate with the resource.
21659 21660 21661 21662 21663 21664 21665 21666 21667 21668 21669 21670 21671 21672 |
# File 'lib/aws-sdk-securityhub/types.rb', line 21659 class AwsWafv2WebAclDetails < Struct.new( :name, :arn, :managedby_firewall_manager, :id, :capacity, :captcha_config, :default_action, :description, :rules, :visibility_config) SENSITIVE = [] include Aws::Structure end |
#capacity ⇒ Integer
The web ACL capacity units (WCUs) currently being used by this web ACL.
21659 21660 21661 21662 21663 21664 21665 21666 21667 21668 21669 21670 21671 21672 |
# File 'lib/aws-sdk-securityhub/types.rb', line 21659 class AwsWafv2WebAclDetails < Struct.new( :name, :arn, :managedby_firewall_manager, :id, :capacity, :captcha_config, :default_action, :description, :rules, :visibility_config) SENSITIVE = [] include Aws::Structure end |
#captcha_config ⇒ Types::AwsWafv2WebAclCaptchaConfigDetails
Specifies how WAF should handle CAPTCHA evaluations for rules that
don't have their own CaptchaConfig settings.
21659 21660 21661 21662 21663 21664 21665 21666 21667 21668 21669 21670 21671 21672 |
# File 'lib/aws-sdk-securityhub/types.rb', line 21659 class AwsWafv2WebAclDetails < Struct.new( :name, :arn, :managedby_firewall_manager, :id, :capacity, :captcha_config, :default_action, :description, :rules, :visibility_config) SENSITIVE = [] include Aws::Structure end |
#default_action ⇒ Types::AwsWafv2WebAclActionDetails
The action to perform if none of the Rules contained in the web ACL match.
21659 21660 21661 21662 21663 21664 21665 21666 21667 21668 21669 21670 21671 21672 |
# File 'lib/aws-sdk-securityhub/types.rb', line 21659 class AwsWafv2WebAclDetails < Struct.new( :name, :arn, :managedby_firewall_manager, :id, :capacity, :captcha_config, :default_action, :description, :rules, :visibility_config) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the web ACL that helps with identification.
21659 21660 21661 21662 21663 21664 21665 21666 21667 21668 21669 21670 21671 21672 |
# File 'lib/aws-sdk-securityhub/types.rb', line 21659 class AwsWafv2WebAclDetails < Struct.new( :name, :arn, :managedby_firewall_manager, :id, :capacity, :captcha_config, :default_action, :description, :rules, :visibility_config) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
A unique identifier for the web ACL.
21659 21660 21661 21662 21663 21664 21665 21666 21667 21668 21669 21670 21671 21672 |
# File 'lib/aws-sdk-securityhub/types.rb', line 21659 class AwsWafv2WebAclDetails < Struct.new( :name, :arn, :managedby_firewall_manager, :id, :capacity, :captcha_config, :default_action, :description, :rules, :visibility_config) SENSITIVE = [] include Aws::Structure end |
#managedby_firewall_manager ⇒ Boolean
Indicates whether this web ACL is managed by Firewall Manager.
21659 21660 21661 21662 21663 21664 21665 21666 21667 21668 21669 21670 21671 21672 |
# File 'lib/aws-sdk-securityhub/types.rb', line 21659 class AwsWafv2WebAclDetails < Struct.new( :name, :arn, :managedby_firewall_manager, :id, :capacity, :captcha_config, :default_action, :description, :rules, :visibility_config) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the web ACL.
21659 21660 21661 21662 21663 21664 21665 21666 21667 21668 21669 21670 21671 21672 |
# File 'lib/aws-sdk-securityhub/types.rb', line 21659 class AwsWafv2WebAclDetails < Struct.new( :name, :arn, :managedby_firewall_manager, :id, :capacity, :captcha_config, :default_action, :description, :rules, :visibility_config) SENSITIVE = [] include Aws::Structure end |
#rules ⇒ Array<Types::AwsWafv2RulesDetails>
The Rule statements used to identify the web requests that you want to allow, block, or count. Each rule includes one top-level statement that WAF uses to identify matching web requests, and parameters that govern how WAF handles them.
21659 21660 21661 21662 21663 21664 21665 21666 21667 21668 21669 21670 21671 21672 |
# File 'lib/aws-sdk-securityhub/types.rb', line 21659 class AwsWafv2WebAclDetails < Struct.new( :name, :arn, :managedby_firewall_manager, :id, :capacity, :captcha_config, :default_action, :description, :rules, :visibility_config) SENSITIVE = [] include Aws::Structure end |
#visibility_config ⇒ Types::AwsWafv2VisibilityConfigDetails
Defines and enables Amazon CloudWatch metrics and web request sample collection.
21659 21660 21661 21662 21663 21664 21665 21666 21667 21668 21669 21670 21671 21672 |
# File 'lib/aws-sdk-securityhub/types.rb', line 21659 class AwsWafv2WebAclDetails < Struct.new( :name, :arn, :managedby_firewall_manager, :id, :capacity, :captcha_config, :default_action, :description, :rules, :visibility_config) SENSITIVE = [] include Aws::Structure end |