Class: Aws::SecurityHub::Types::Cell
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::Cell
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
An occurrence of sensitive data detected in a Microsoft Excel workbook, comma-separated value (CSV) file, or tab-separated value (TSV) file.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cell_reference ⇒ String
For a Microsoft Excel workbook, provides the location of the cell, as an absolute cell reference, that contains the data.
-
#column ⇒ Integer
The column number of the column that contains the data.
-
#column_name ⇒ String
The name of the column that contains the data.
-
#row ⇒ Integer
The row number of the row that contains the data.
Instance Attribute Details
#cell_reference ⇒ String
For a Microsoft Excel workbook, provides the location of the cell, as an absolute cell reference, that contains the data. For example, Sheet2!C5 for cell C5 on Sheet2.
22566 22567 22568 22569 22570 22571 22572 22573 |
# File 'lib/aws-sdk-securityhub/types.rb', line 22566 class Cell < Struct.new( :column, :row, :column_name, :cell_reference) SENSITIVE = [] include Aws::Structure end |
#column ⇒ Integer
The column number of the column that contains the data. For a Microsoft Excel workbook, the column number corresponds to the alphabetical column identifiers. For example, a value of 1 for Column corresponds to the A column in the workbook.
22566 22567 22568 22569 22570 22571 22572 22573 |
# File 'lib/aws-sdk-securityhub/types.rb', line 22566 class Cell < Struct.new( :column, :row, :column_name, :cell_reference) SENSITIVE = [] include Aws::Structure end |