Class: Aws::SecurityHub::Types::Compliance
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::Compliance
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
This object typically provides details about a control finding, such as applicable standards and the status of control checks. While finding providers can add custom content in Compliance object fields, they are typically used to review details of Security Hub CSPM control findings.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#associated_standards ⇒ Array<Types::AssociatedStandard>
Typically provides an array of enabled security standards in which a security control is currently enabled.
-
#related_requirements ⇒ Array<String>
Typically provides the industry or regulatory framework requirements that are related to a control.
-
#security_control_id ⇒ String
Typically provides the unique identifier of a control across standards.
-
#security_control_parameters ⇒ Array<Types::SecurityControlParameter>
Typically an object that includes security control parameter names and values.
-
#status ⇒ String
Typically summarizes the result of a control check.
-
#status_reasons ⇒ Array<Types::StatusReason>
Typically used to provide a list of reasons for the value of
Status.
Instance Attribute Details
#associated_standards ⇒ Array<Types::AssociatedStandard>
Typically provides an array of enabled security standards in which a security control is currently enabled.
22549 22550 22551 22552 22553 22554 22555 22556 22557 22558 |
# File 'lib/aws-sdk-securityhub/types.rb', line 22549 class Compliance < Struct.new( :status, :related_requirements, :status_reasons, :security_control_id, :associated_standards, :security_control_parameters) SENSITIVE = [] include Aws::Structure end |
#related_requirements ⇒ Array<String>
Typically provides the industry or regulatory framework requirements that are related to a control. The check for that control is aligned with these requirements.
Array Members: Maximum number of 32 items.
22549 22550 22551 22552 22553 22554 22555 22556 22557 22558 |
# File 'lib/aws-sdk-securityhub/types.rb', line 22549 class Compliance < Struct.new( :status, :related_requirements, :status_reasons, :security_control_id, :associated_standards, :security_control_parameters) SENSITIVE = [] include Aws::Structure end |
#security_control_id ⇒ String
Typically provides the unique identifier of a control across standards. For Security Hub CSPM controls, this field consists of an Amazon Web Services service and a unique number, such as APIGateway.5.
22549 22550 22551 22552 22553 22554 22555 22556 22557 22558 |
# File 'lib/aws-sdk-securityhub/types.rb', line 22549 class Compliance < Struct.new( :status, :related_requirements, :status_reasons, :security_control_id, :associated_standards, :security_control_parameters) SENSITIVE = [] include Aws::Structure end |
#security_control_parameters ⇒ Array<Types::SecurityControlParameter>
Typically an object that includes security control parameter names and values.
22549 22550 22551 22552 22553 22554 22555 22556 22557 22558 |
# File 'lib/aws-sdk-securityhub/types.rb', line 22549 class Compliance < Struct.new( :status, :related_requirements, :status_reasons, :security_control_id, :associated_standards, :security_control_parameters) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
Typically summarizes the result of a control check.
For Security Hub CSPM controls, valid values for Status are as follows.
-
PASSED- Standards check passed for all evaluated resources. -
WARNING- Some information is missing or this check is not supported for your configuration. -
FAILED- Standards check failed for at least one evaluated resource. -
NOT_AVAILABLE- Check could not be performed due to a service outage, API error, or because the result of the Config evaluation wasNOT_APPLICABLE. If the Config evaluation result wasNOT_APPLICABLEfor a Security Hub CSPM control, Security Hub CSPM automatically archives the finding after 3 days.
-
22549 22550 22551 22552 22553 22554 22555 22556 22557 22558 |
# File 'lib/aws-sdk-securityhub/types.rb', line 22549 class Compliance < Struct.new( :status, :related_requirements, :status_reasons, :security_control_id, :associated_standards, :security_control_parameters) SENSITIVE = [] include Aws::Structure end |
#status_reasons ⇒ Array<Types::StatusReason>
Typically used to provide a list of reasons for the value of Status.
22549 22550 22551 22552 22553 22554 22555 22556 22557 22558 |
# File 'lib/aws-sdk-securityhub/types.rb', line 22549 class Compliance < Struct.new( :status, :related_requirements, :status_reasons, :security_control_id, :associated_standards, :security_control_parameters) SENSITIVE = [] include Aws::Structure end |