Class: Aws::SecurityHub::Types::ContainerDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::ContainerDetails
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Container details related to a finding.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#container_runtime ⇒ String
The runtime of the container.
-
#image_id ⇒ String
The identifier of the container image related to a finding.
-
#image_name ⇒ String
The name of the container image related to a finding.
-
#launched_at ⇒ String
Indicates when the container started.
-
#name ⇒ String
The name of the container related to a finding.
-
#privileged ⇒ Boolean
When this parameter is
true, the container is given elevated privileges on the host container instance (similar to the root user). -
#volume_mounts ⇒ Array<Types::VolumeMount>
Provides information about the mounting of a volume in a container.
Instance Attribute Details
#container_runtime ⇒ String
The runtime of the container.
23086 23087 23088 23089 23090 23091 23092 23093 23094 23095 23096 |
# File 'lib/aws-sdk-securityhub/types.rb', line 23086 class ContainerDetails < Struct.new( :container_runtime, :name, :image_id, :image_name, :launched_at, :volume_mounts, :privileged) SENSITIVE = [] include Aws::Structure end |
#image_id ⇒ String
The identifier of the container image related to a finding.
23086 23087 23088 23089 23090 23091 23092 23093 23094 23095 23096 |
# File 'lib/aws-sdk-securityhub/types.rb', line 23086 class ContainerDetails < Struct.new( :container_runtime, :name, :image_id, :image_name, :launched_at, :volume_mounts, :privileged) SENSITIVE = [] include Aws::Structure end |
#image_name ⇒ String
The name of the container image related to a finding.
23086 23087 23088 23089 23090 23091 23092 23093 23094 23095 23096 |
# File 'lib/aws-sdk-securityhub/types.rb', line 23086 class ContainerDetails < Struct.new( :container_runtime, :name, :image_id, :image_name, :launched_at, :volume_mounts, :privileged) SENSITIVE = [] include Aws::Structure end |
#launched_at ⇒ String
Indicates when the container started.
For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.
23086 23087 23088 23089 23090 23091 23092 23093 23094 23095 23096 |
# File 'lib/aws-sdk-securityhub/types.rb', line 23086 class ContainerDetails < Struct.new( :container_runtime, :name, :image_id, :image_name, :launched_at, :volume_mounts, :privileged) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the container related to a finding.
23086 23087 23088 23089 23090 23091 23092 23093 23094 23095 23096 |
# File 'lib/aws-sdk-securityhub/types.rb', line 23086 class ContainerDetails < Struct.new( :container_runtime, :name, :image_id, :image_name, :launched_at, :volume_mounts, :privileged) SENSITIVE = [] include Aws::Structure end |
#privileged ⇒ Boolean
When this parameter is true, the container is given elevated
privileges on the host container instance (similar to the root
user).
23086 23087 23088 23089 23090 23091 23092 23093 23094 23095 23096 |
# File 'lib/aws-sdk-securityhub/types.rb', line 23086 class ContainerDetails < Struct.new( :container_runtime, :name, :image_id, :image_name, :launched_at, :volume_mounts, :privileged) SENSITIVE = [] include Aws::Structure end |
#volume_mounts ⇒ Array<Types::VolumeMount>
Provides information about the mounting of a volume in a container.
23086 23087 23088 23089 23090 23091 23092 23093 23094 23095 23096 |
# File 'lib/aws-sdk-securityhub/types.rb', line 23086 class ContainerDetails < Struct.new( :container_runtime, :name, :image_id, :image_name, :launched_at, :volume_mounts, :privileged) SENSITIVE = [] include Aws::Structure end |