Class: Aws::SecurityHub::Types::CreateConnectorRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::CreateConnectorRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique identifier used to ensure idempotency of the request.
-
#description ⇒ String
The description of the connector.
-
#name ⇒ String
The name of the connector.
-
#provider ⇒ Types::CspmProviderConfiguration
The configuration for the cloud provider to connect to.
-
#tags ⇒ Hash<String,String>
The tags to add to the connector resource.
Instance Attribute Details
#client_token ⇒ String
A unique identifier used to ensure idempotency of the request.
A suitable default value is auto-generated. You should normally not need to pass this option.
23480 23481 23482 23483 23484 23485 23486 23487 23488 |
# File 'lib/aws-sdk-securityhub/types.rb', line 23480 class CreateConnectorRequest < Struct.new( :name, :description, :provider, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the connector.
23480 23481 23482 23483 23484 23485 23486 23487 23488 |
# File 'lib/aws-sdk-securityhub/types.rb', line 23480 class CreateConnectorRequest < Struct.new( :name, :description, :provider, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the connector. Must be unique within the account.
23480 23481 23482 23483 23484 23485 23486 23487 23488 |
# File 'lib/aws-sdk-securityhub/types.rb', line 23480 class CreateConnectorRequest < Struct.new( :name, :description, :provider, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |
#provider ⇒ Types::CspmProviderConfiguration
The configuration for the cloud provider to connect to. Currently supports Azure.
23480 23481 23482 23483 23484 23485 23486 23487 23488 |
# File 'lib/aws-sdk-securityhub/types.rb', line 23480 class CreateConnectorRequest < Struct.new( :name, :description, :provider, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags to add to the connector resource.
23480 23481 23482 23483 23484 23485 23486 23487 23488 |
# File 'lib/aws-sdk-securityhub/types.rb', line 23480 class CreateConnectorRequest < Struct.new( :name, :description, :provider, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |