Class: Aws::SecurityHub::Types::CreateMembersRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::CreateMembersRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#account_details ⇒ Array<Types::AccountDetails>
The list of accounts to associate with the Security Hub CSPM administrator account.
Instance Attribute Details
#account_details ⇒ Array<Types::AccountDetails>
The list of accounts to associate with the Security Hub CSPM administrator account. For each account, the list includes the account ID and optionally the email address.
23512 23513 23514 23515 23516 |
# File 'lib/aws-sdk-securityhub/types.rb', line 23512 class CreateMembersRequest < Struct.new( :account_details) SENSITIVE = [] include Aws::Structure end |