Class: Aws::SecurityHub::Types::CspmHealthCheck
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::CspmHealthCheck
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Information about the operational status and health of a CSPM connector.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#connector_status ⇒ String
The connectivity status of the connector.
-
#issues ⇒ Array<Types::HealthIssue>
A list of health issues associated with the connector.
-
#last_checked_at ⇒ Time
The ISO 8601 UTC timestamp indicating when the health status was last checked.
-
#message ⇒ String
A message describing the reason for the current connector status.
Instance Attribute Details
#connector_status ⇒ String
The connectivity status of the connector.
23887 23888 23889 23890 23891 23892 23893 23894 |
# File 'lib/aws-sdk-securityhub/types.rb', line 23887 class CspmHealthCheck < Struct.new( :connector_status, :message, :last_checked_at, :issues) SENSITIVE = [] include Aws::Structure end |
#issues ⇒ Array<Types::HealthIssue>
A list of health issues associated with the connector.
23887 23888 23889 23890 23891 23892 23893 23894 |
# File 'lib/aws-sdk-securityhub/types.rb', line 23887 class CspmHealthCheck < Struct.new( :connector_status, :message, :last_checked_at, :issues) SENSITIVE = [] include Aws::Structure end |
#last_checked_at ⇒ Time
The ISO 8601 UTC timestamp indicating when the health status was last checked.
23887 23888 23889 23890 23891 23892 23893 23894 |
# File 'lib/aws-sdk-securityhub/types.rb', line 23887 class CspmHealthCheck < Struct.new( :connector_status, :message, :last_checked_at, :issues) SENSITIVE = [] include Aws::Structure end |
#message ⇒ String
A message describing the reason for the current connector status.
23887 23888 23889 23890 23891 23892 23893 23894 |
# File 'lib/aws-sdk-securityhub/types.rb', line 23887 class CspmHealthCheck < Struct.new( :connector_status, :message, :last_checked_at, :issues) SENSITIVE = [] include Aws::Structure end |