Class: Aws::SecurityHub::Types::CspmProviderDetail
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::CspmProviderDetail
- Includes:
- Aws::Structure, Aws::Structure::Union
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Note:
CspmProviderDetail is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of CspmProviderDetail corresponding to the set member.
The detailed cloud provider configuration for a connector. This is a union type that currently supports Azure.
Defined Under Namespace
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#azure ⇒ Types::AzureDetail
The Azure provider detail.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#azure ⇒ Types::AzureDetail
The Azure provider detail.
23929 23930 23931 23932 23933 23934 23935 23936 23937 23938 |
# File 'lib/aws-sdk-securityhub/types.rb', line 23929 class CspmProviderDetail < Struct.new( :azure, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Azure < CspmProviderDetail; end class Unknown < CspmProviderDetail; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
23929 23930 23931 |
# File 'lib/aws-sdk-securityhub/types.rb', line 23929 def unknown @unknown end |