Class: Aws::SecurityHub::Types::DateRange

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

A date range for the date filter.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#comparisonString

The condition to apply to a date range filter. If you specify ‘WITHIN`, Security Hub filters for dates within the specified date range. If you specify `OLDER_THAN`, Security Hub filters for dates before the specified date range. If you don’t specify a value, the default is ‘WITHIN`.

Returns:

  • (String)


23768
23769
23770
23771
23772
23773
23774
# File 'lib/aws-sdk-securityhub/types.rb', line 23768

class DateRange < Struct.new(
  :value,
  :unit,
  :comparison)
  SENSITIVE = []
  include Aws::Structure
end

#unitString

A date range unit for the date filter.

Returns:

  • (String)


23768
23769
23770
23771
23772
23773
23774
# File 'lib/aws-sdk-securityhub/types.rb', line 23768

class DateRange < Struct.new(
  :value,
  :unit,
  :comparison)
  SENSITIVE = []
  include Aws::Structure
end

#valueInteger

A date range value for the date filter.

Returns:

  • (Integer)


23768
23769
23770
23771
23772
23773
23774
# File 'lib/aws-sdk-securityhub/types.rb', line 23768

class DateRange < Struct.new(
  :value,
  :unit,
  :comparison)
  SENSITIVE = []
  include Aws::Structure
end