Class: Aws::SecurityHub::Types::DeleteInvitationsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::DeleteInvitationsResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#unprocessed_accounts ⇒ Array<Types::Result>
The list of Amazon Web Services accounts for which the invitations were not deleted.
Instance Attribute Details
#unprocessed_accounts ⇒ Array<Types::Result>
The list of Amazon Web Services accounts for which the invitations were not deleted. For each account, the list includes the account ID and the email address.
23955 23956 23957 23958 23959 |
# File 'lib/aws-sdk-securityhub/types.rb', line 23955 class DeleteInvitationsResponse < Struct.new( :unprocessed_accounts) SENSITIVE = [] include Aws::Structure end |