Class: Aws::SecurityHub::Types::DescribeActionTargetsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::DescribeActionTargetsRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#action_target_arns ⇒ Array<String>
A list of custom action target ARNs for the custom action targets to retrieve.
-
#max_results ⇒ Integer
The maximum number of results to return.
-
#next_token ⇒ String
The token that is required for pagination.
Instance Attribute Details
#action_target_arns ⇒ Array<String>
A list of custom action target ARNs for the custom action targets to retrieve.
24421 24422 24423 24424 24425 24426 24427 |
# File 'lib/aws-sdk-securityhub/types.rb', line 24421 class DescribeActionTargetsRequest < Struct.new( :action_target_arns, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return.
24421 24422 24423 24424 24425 24426 24427 |
# File 'lib/aws-sdk-securityhub/types.rb', line 24421 class DescribeActionTargetsRequest < Struct.new( :action_target_arns, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token that is required for pagination. On your first call to the
DescribeActionTargets operation, set the value of this parameter
to NULL.
For subsequent calls to the operation, to continue listing data, set the value of this parameter to the value returned from the previous response.
24421 24422 24423 24424 24425 24426 24427 |
# File 'lib/aws-sdk-securityhub/types.rb', line 24421 class DescribeActionTargetsRequest < Struct.new( :action_target_arns, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |