Class: Aws::SecurityHub::Types::DescribeSecurityHubV2Response
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::DescribeSecurityHubV2Response
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#features ⇒ Hash<String,Types::FeatureDetail>
A map of opt-in features and their current status and metadata for the account in the current Region.
-
#hub_v2_arn ⇒ String
The ARN of the service resource.
-
#subscribed_at ⇒ String
The date and time when the service was enabled in the account.
Instance Attribute Details
#features ⇒ Hash<String,Types::FeatureDetail>
A map of opt-in features and their current status and metadata for the account in the current Region.
24684 24685 24686 24687 24688 24689 24690 |
# File 'lib/aws-sdk-securityhub/types.rb', line 24684 class DescribeSecurityHubV2Response < Struct.new( :hub_v2_arn, :subscribed_at, :features) SENSITIVE = [] include Aws::Structure end |
#hub_v2_arn ⇒ String
The ARN of the service resource.
24684 24685 24686 24687 24688 24689 24690 |
# File 'lib/aws-sdk-securityhub/types.rb', line 24684 class DescribeSecurityHubV2Response < Struct.new( :hub_v2_arn, :subscribed_at, :features) SENSITIVE = [] include Aws::Structure end |
#subscribed_at ⇒ String
The date and time when the service was enabled in the account.
24684 24685 24686 24687 24688 24689 24690 |
# File 'lib/aws-sdk-securityhub/types.rb', line 24684 class DescribeSecurityHubV2Response < Struct.new( :hub_v2_arn, :subscribed_at, :features) SENSITIVE = [] include Aws::Structure end |