Class: Aws::SecurityHub::Types::DescribeStandardsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::DescribeStandardsRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
The maximum number of standards to return.
-
#next_token ⇒ String
The token that is required for pagination.
-
#providers ⇒ Array<String>
A list of cloud providers to filter the standards by.
Instance Attribute Details
#max_results ⇒ Integer
The maximum number of standards to return.
24862 24863 24864 24865 24866 24867 24868 |
# File 'lib/aws-sdk-securityhub/types.rb', line 24862 class DescribeStandardsRequest < Struct.new( :next_token, :max_results, :providers) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token that is required for pagination. On your first call to the
DescribeStandards operation, set the value of this parameter to
NULL.
For subsequent calls to the operation, to continue listing data, set the value of this parameter to the value returned from the previous response.
24862 24863 24864 24865 24866 24867 24868 |
# File 'lib/aws-sdk-securityhub/types.rb', line 24862 class DescribeStandardsRequest < Struct.new( :next_token, :max_results, :providers) SENSITIVE = [] include Aws::Structure end |
#providers ⇒ Array<String>
A list of cloud providers to filter the standards by. For example,
specify Azure to return only standards that evaluate Azure
resources.
24862 24863 24864 24865 24866 24867 24868 |
# File 'lib/aws-sdk-securityhub/types.rb', line 24862 class DescribeStandardsRequest < Struct.new( :next_token, :max_results, :providers) SENSITIVE = [] include Aws::Structure end |