Class: Aws::SecurityHub::Types::EnableOrganizationAdminAccountResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::EnableOrganizationAdminAccountResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#admin_account_id ⇒ String
The Amazon Web Services account identifier of the account to designate as the Security Hub CSPM administrator account.
-
#feature ⇒ String
The feature where the delegated administrator is enabled.
Instance Attribute Details
#admin_account_id ⇒ String
The Amazon Web Services account identifier of the account to designate as the Security Hub CSPM administrator account.
25034 25035 25036 25037 25038 25039 |
# File 'lib/aws-sdk-securityhub/types.rb', line 25034 class EnableOrganizationAdminAccountResponse < Struct.new( :admin_account_id, :feature) SENSITIVE = [] include Aws::Structure end |
#feature ⇒ String
The feature where the delegated administrator is enabled. The default is Security Hub CSPM CSPM if no delegated administrator is specified in the request.
25034 25035 25036 25037 25038 25039 |
# File 'lib/aws-sdk-securityhub/types.rb', line 25034 class EnableOrganizationAdminAccountResponse < Struct.new( :admin_account_id, :feature) SENSITIVE = [] include Aws::Structure end |