Class: Aws::SecurityHub::Types::FindingHistoryUpdate
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::FindingHistoryUpdate
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
An array of objects that provides details about a change to a finding, including the Amazon Web Services Security Finding Format (ASFF) field that changed, the value of the field before the change, and the value of the field after the change.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#new_value ⇒ String
The value of the ASFF field after the finding change event.
-
#old_value ⇒ String
The value of the ASFF field before the finding change event.
-
#updated_field ⇒ String
The ASFF field that changed during the finding change event.
Instance Attribute Details
#new_value ⇒ String
The value of the ASFF field after the finding change event. To preserve storage and readability, Security Hub CSPM omits this value if [ ‘FindingHistoryRecord` ][1] exceeds database limits.
[1]: docs.aws.amazon.com/securityhub/1.0/APIReference/API_FindingHistoryRecord.html
24883 24884 24885 24886 24887 24888 24889 |
# File 'lib/aws-sdk-securityhub/types.rb', line 24883 class FindingHistoryUpdate < Struct.new( :updated_field, :old_value, :new_value) SENSITIVE = [] include Aws::Structure end |
#old_value ⇒ String
The value of the ASFF field before the finding change event.
24883 24884 24885 24886 24887 24888 24889 |
# File 'lib/aws-sdk-securityhub/types.rb', line 24883 class FindingHistoryUpdate < Struct.new( :updated_field, :old_value, :new_value) SENSITIVE = [] include Aws::Structure end |
#updated_field ⇒ String
The ASFF field that changed during the finding change event.
24883 24884 24885 24886 24887 24888 24889 |
# File 'lib/aws-sdk-securityhub/types.rb', line 24883 class FindingHistoryUpdate < Struct.new( :updated_field, :old_value, :new_value) SENSITIVE = [] include Aws::Structure end |