Class: Aws::SecurityHub::Types::FindingProviderSeverity
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::FindingProviderSeverity
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
The severity assigned to a finding by the finding provider. This object may include one or more of the following attributes:
-
Label -
Normalized -
Original -
Product
If a [ BatchImportFindings ][1] request for a new finding only provides Label or only provides Normalized, Security Hub CSPM automatically populates the value of the other field.
The Normalized and Product attributes are included in the FindingProviderSeverity structure to preserve the historical information associated with the finding, even if the top-level Severity object is later modified using the [ BatchUpdateFindings ][2] operation.
If the top-level Finding.Severity object is present, but Finding.FindingProviderFields isn’t present, Security Hub CSPM creates the FindingProviderFields.Severity object and copies the entire Finding.Severity object into it. This ensures that the original, provider-supplied details are retained within the FindingProviderFields.Severity object, even if the top-level Severity object is overwritten.
[1]: docs.aws.amazon.com/securityhub/1.0/APIReference/API_BatchImportFindings.html [2]: docs.aws.amazon.com/securityhub/1.0/APIReference/API_BatchUpdateFindings.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#label ⇒ String
The severity label assigned to the finding by the finding provider.
-
#original ⇒ String
The finding provider’s original value for the severity.
Instance Attribute Details
#label ⇒ String
The severity label assigned to the finding by the finding provider.
25003 25004 25005 25006 25007 25008 |
# File 'lib/aws-sdk-securityhub/types.rb', line 25003 class FindingProviderSeverity < Struct.new( :label, :original) SENSITIVE = [] include Aws::Structure end |
#original ⇒ String
The finding provider’s original value for the severity.
Length Constraints: Minimum length of 1. Maximum length of 64.
25003 25004 25005 25006 25007 25008 |
# File 'lib/aws-sdk-securityhub/types.rb', line 25003 class FindingProviderSeverity < Struct.new( :label, :original) SENSITIVE = [] include Aws::Structure end |