Class: Aws::SecurityHub::Types::FindingScopes
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::FindingScopes
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Defines the data boundary for a findings query. Scopes determine which organizational units or organizations to retrieve data from.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_organizations ⇒ Array<Types::AwsOrganizationScope>
A list of Organizations scopes to include in the query results.
Instance Attribute Details
#aws_organizations ⇒ Array<Types::AwsOrganizationScope>
A list of Organizations scopes to include in the query results. Each entry in the list specifies an organization or organizational unit to include for the delegated administrator's account. If the list specifies multiple entries, the entries are combined using OR logic.
25550 25551 25552 25553 25554 |
# File 'lib/aws-sdk-securityhub/types.rb', line 25550 class FindingScopes < Struct.new( :aws_organizations) SENSITIVE = [] include Aws::Structure end |