Class: Aws::SecurityHub::Types::FreeTrialStatus
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::FreeTrialStatus
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
The free trial period for a Security Hub feature, and whether the trial is currently active.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#expires_at ⇒ Time
The date and time at which the free trial period ends.
-
#feature_type ⇒ String
The feature that the free trial period applies to.
-
#started_at ⇒ Time
The date and time at which the free trial period began.
-
#status ⇒ String
Whether the free trial period is currently active.
Instance Attribute Details
#expires_at ⇒ Time
The date and time at which the free trial period ends.
25932 25933 25934 25935 25936 25937 25938 25939 |
# File 'lib/aws-sdk-securityhub/types.rb', line 25932 class FreeTrialStatus < Struct.new( :feature_type, :status, :started_at, :expires_at) SENSITIVE = [] include Aws::Structure end |
#feature_type ⇒ String
The feature that the free trial period applies to. Valid values:
-
SECURITY_HUB_V2specifies Security Hub. -
SECURITY_HUB_V2_MULTI_CLOUD_AZUREspecifies Security Hub coverage for Microsoft Azure resources.
25932 25933 25934 25935 25936 25937 25938 25939 |
# File 'lib/aws-sdk-securityhub/types.rb', line 25932 class FreeTrialStatus < Struct.new( :feature_type, :status, :started_at, :expires_at) SENSITIVE = [] include Aws::Structure end |
#started_at ⇒ Time
The date and time at which the free trial period began.
25932 25933 25934 25935 25936 25937 25938 25939 |
# File 'lib/aws-sdk-securityhub/types.rb', line 25932 class FreeTrialStatus < Struct.new( :feature_type, :status, :started_at, :expires_at) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
Whether the free trial period is currently active. Valid values:
-
ACTIVEspecifies that the free trial period is ongoing. -
INACTIVEspecifies that the free trial period has ended, or that it never started.
To determine whether a trial has expired, compare ExpiresAt to the
current time.
25932 25933 25934 25935 25936 25937 25938 25939 |
# File 'lib/aws-sdk-securityhub/types.rb', line 25932 class FreeTrialStatus < Struct.new( :feature_type, :status, :started_at, :expires_at) SENSITIVE = [] include Aws::Structure end |