Class: Aws::SecurityHub::Types::GeneratorDetails

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

Provides metadata for the Amazon CodeGuru detector associated with a finding. This field pertains to findings that relate to Lambda functions. Amazon Inspector identifies policy violations and vulnerabilities in Lambda function code based on internal detectors developed in collaboration with Amazon CodeGuru. Security Hub CSPM receives those findings.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

The description of the detector used to identify the code vulnerability.

Returns:

  • (String)


25912
25913
25914
25915
25916
25917
25918
# File 'lib/aws-sdk-securityhub/types.rb', line 25912

class GeneratorDetails < Struct.new(
  :name,
  :description,
  :labels)
  SENSITIVE = []
  include Aws::Structure
end

#labelsArray<String>

An array of tags used to identify the detector associated with the finding.

Array Members: Minimum number of 0 items. Maximum number of 10 items.

Returns:

  • (Array<String>)


25912
25913
25914
25915
25916
25917
25918
# File 'lib/aws-sdk-securityhub/types.rb', line 25912

class GeneratorDetails < Struct.new(
  :name,
  :description,
  :labels)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the detector used to identify the code vulnerability.

Returns:

  • (String)


25912
25913
25914
25915
25916
25917
25918
# File 'lib/aws-sdk-securityhub/types.rb', line 25912

class GeneratorDetails < Struct.new(
  :name,
  :description,
  :labels)
  SENSITIVE = []
  include Aws::Structure
end