Class: Aws::SecurityHub::Types::GetEnabledStandardsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::GetEnabledStandardsRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
The maximum number of results to return in the response.
-
#next_token ⇒ String
The token that is required for pagination.
-
#providers ⇒ Array<String>
A list of cloud providers to filter the enabled standards by.
-
#standards_subscription_arns ⇒ Array<String>
The list of the standards subscription ARNs for the standards to retrieve.
Instance Attribute Details
#max_results ⇒ Integer
The maximum number of results to return in the response.
26367 26368 26369 26370 26371 26372 26373 26374 |
# File 'lib/aws-sdk-securityhub/types.rb', line 26367 class GetEnabledStandardsRequest < Struct.new( :standards_subscription_arns, :next_token, :max_results, :providers) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token that is required for pagination. On your first call to the
GetEnabledStandards operation, set the value of this parameter to
NULL.
For subsequent calls to the operation, to continue listing data, set the value of this parameter to the value returned from the previous response.
26367 26368 26369 26370 26371 26372 26373 26374 |
# File 'lib/aws-sdk-securityhub/types.rb', line 26367 class GetEnabledStandardsRequest < Struct.new( :standards_subscription_arns, :next_token, :max_results, :providers) SENSITIVE = [] include Aws::Structure end |
#providers ⇒ Array<String>
A list of cloud providers to filter the enabled standards by. For
example, specify Azure to return only enabled standards that
evaluate Azure resources.
26367 26368 26369 26370 26371 26372 26373 26374 |
# File 'lib/aws-sdk-securityhub/types.rb', line 26367 class GetEnabledStandardsRequest < Struct.new( :standards_subscription_arns, :next_token, :max_results, :providers) SENSITIVE = [] include Aws::Structure end |
#standards_subscription_arns ⇒ Array<String>
The list of the standards subscription ARNs for the standards to retrieve.
26367 26368 26369 26370 26371 26372 26373 26374 |
# File 'lib/aws-sdk-securityhub/types.rb', line 26367 class GetEnabledStandardsRequest < Struct.new( :standards_subscription_arns, :next_token, :max_results, :providers) SENSITIVE = [] include Aws::Structure end |