Class: Aws::SecurityHub::Types::GetFindingHistoryResponse

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_tokenString

A token for pagination purposes. Provide this token in the subsequent request to GetFindingsHistory to get up to an additional 100 results of history for the same finding that you specified in your initial request.

Returns:

  • (String)


26601
26602
26603
26604
26605
26606
# File 'lib/aws-sdk-securityhub/types.rb', line 26601

class GetFindingHistoryResponse < Struct.new(
  :records,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#recordsArray<Types::FindingHistoryRecord>

A list of events that altered the specified finding during the specified time period.

Returns:



26601
26602
26603
26604
26605
26606
# File 'lib/aws-sdk-securityhub/types.rb', line 26601

class GetFindingHistoryResponse < Struct.new(
  :records,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end