Class: Aws::SecurityHub::Types::GetFindingStatisticsV2Request
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::GetFindingStatisticsV2Request
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#group_by_rules ⇒ Array<Types::GroupByRule>
Specifies how security findings should be aggregated and organized in the statistical analysis.
-
#max_statistic_results ⇒ Integer
The maximum number of results to be returned.
-
#scopes ⇒ Types::FindingScopes
Limits the results to findings from specific organizational units or from the delegated administrator’s organization.
-
#sort_order ⇒ String
Orders the aggregation count in descending or ascending order.
Instance Attribute Details
#group_by_rules ⇒ Array<Types::GroupByRule>
Specifies how security findings should be aggregated and organized in the statistical analysis. It can accept up to 5 ‘groupBy` fields in a single call.
25826 25827 25828 25829 25830 25831 25832 25833 |
# File 'lib/aws-sdk-securityhub/types.rb', line 25826 class GetFindingStatisticsV2Request < Struct.new( :group_by_rules, :scopes, :sort_order, :max_statistic_results) SENSITIVE = [] include Aws::Structure end |
#max_statistic_results ⇒ Integer
The maximum number of results to be returned.
25826 25827 25828 25829 25830 25831 25832 25833 |
# File 'lib/aws-sdk-securityhub/types.rb', line 25826 class GetFindingStatisticsV2Request < Struct.new( :group_by_rules, :scopes, :sort_order, :max_statistic_results) SENSITIVE = [] include Aws::Structure end |
#scopes ⇒ Types::FindingScopes
Limits the results to findings from specific organizational units or from the delegated administrator’s organization. Only the delegated administrator account can use this parameter. Other accounts receive an ‘AccessDeniedException`.
This parameter is optional. If you omit it, the delegated administrator sees statistics from all accounts across the entire organization. Other accounts see only statistics for their own findings.
You can specify up to 10 entries in ‘Scopes.AwsOrganizations`. If multiple entries are specified, the entries are combined using OR logic.
25826 25827 25828 25829 25830 25831 25832 25833 |
# File 'lib/aws-sdk-securityhub/types.rb', line 25826 class GetFindingStatisticsV2Request < Struct.new( :group_by_rules, :scopes, :sort_order, :max_statistic_results) SENSITIVE = [] include Aws::Structure end |
#sort_order ⇒ String
Orders the aggregation count in descending or ascending order. Descending order is the default.
25826 25827 25828 25829 25830 25831 25832 25833 |
# File 'lib/aws-sdk-securityhub/types.rb', line 25826 class GetFindingStatisticsV2Request < Struct.new( :group_by_rules, :scopes, :sort_order, :max_statistic_results) SENSITIVE = [] include Aws::Structure end |