Class: Aws::SecurityHub::Types::GetFindingsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::GetFindingsRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#filters ⇒ Types::AwsSecurityFindingFilters
The finding attributes used to define a condition to filter the returned findings.
-
#max_results ⇒ Integer
The maximum number of findings to return.
-
#next_token ⇒ String
The token that is required for pagination.
-
#sort_criteria ⇒ Array<Types::SortCriterion>
The finding attributes used to sort the list of returned findings.
Instance Attribute Details
#filters ⇒ Types::AwsSecurityFindingFilters
The finding attributes used to define a condition to filter the returned findings.
You can filter by up to 10 finding attributes. For each attribute, you can provide up to 20 filter values.
Note that in the available filter fields, ‘WorkflowState` is deprecated. To search for a finding based on its workflow status, use `WorkflowStatus`.
25905 25906 25907 25908 25909 25910 25911 25912 |
# File 'lib/aws-sdk-securityhub/types.rb', line 25905 class GetFindingsRequest < Struct.new( :filters, :sort_criteria, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of findings to return.
25905 25906 25907 25908 25909 25910 25911 25912 |
# File 'lib/aws-sdk-securityhub/types.rb', line 25905 class GetFindingsRequest < Struct.new( :filters, :sort_criteria, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token that is required for pagination. On your first call to the ‘GetFindings` operation, set the value of this parameter to `NULL`.
For subsequent calls to the operation, to continue listing data, set the value of this parameter to the value returned from the previous response.
25905 25906 25907 25908 25909 25910 25911 25912 |
# File 'lib/aws-sdk-securityhub/types.rb', line 25905 class GetFindingsRequest < Struct.new( :filters, :sort_criteria, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#sort_criteria ⇒ Array<Types::SortCriterion>
The finding attributes used to sort the list of returned findings.
25905 25906 25907 25908 25909 25910 25911 25912 |
# File 'lib/aws-sdk-securityhub/types.rb', line 25905 class GetFindingsRequest < Struct.new( :filters, :sort_criteria, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |