Class: Aws::SecurityHub::Types::GetFindingsV2Request

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#filtersTypes::OcsfFindingFilters

The finding attributes used to define a condition to filter the returned OCSF findings. You can filter up to 10 composite filters. For each filter type inside of a composite filter, you can provide up to 20 filters.



26004
26005
26006
26007
26008
26009
26010
26011
26012
# File 'lib/aws-sdk-securityhub/types.rb', line 26004

class GetFindingsV2Request < Struct.new(
  :filters,
  :scopes,
  :sort_criteria,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return.

Returns:

  • (Integer)


26004
26005
26006
26007
26008
26009
26010
26011
26012
# File 'lib/aws-sdk-securityhub/types.rb', line 26004

class GetFindingsV2Request < Struct.new(
  :filters,
  :scopes,
  :sort_criteria,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token required for pagination. On your first call, set the value of this parameter to ‘NULL`. For subsequent calls, to continue listing data, set the value of this parameter to the value returned in the previous response.

Returns:

  • (String)


26004
26005
26006
26007
26008
26009
26010
26011
26012
# File 'lib/aws-sdk-securityhub/types.rb', line 26004

class GetFindingsV2Request < Struct.new(
  :filters,
  :scopes,
  :sort_criteria,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#scopesTypes::FindingScopes

Limits the results to findings from specific organizational units or from the delegated administrator’s organization. Only the delegated administrator account can use this parameter. Other accounts receive an ‘AccessDeniedException`.

This parameter is optional. If you omit it, the delegated administrator sees findings from all accounts across the entire organization. Other accounts see only their own findings.

You can specify up to 10 entries in ‘Scopes.AwsOrganizations`. If multiple entries are specified, the entries are combined using OR logic.



26004
26005
26006
26007
26008
26009
26010
26011
26012
# File 'lib/aws-sdk-securityhub/types.rb', line 26004

class GetFindingsV2Request < Struct.new(
  :filters,
  :scopes,
  :sort_criteria,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#sort_criteriaArray<Types::SortCriterion>

The finding attributes used to sort the list of returned findings.

Returns:



26004
26005
26006
26007
26008
26009
26010
26011
26012
# File 'lib/aws-sdk-securityhub/types.rb', line 26004

class GetFindingsV2Request < Struct.new(
  :filters,
  :scopes,
  :sort_criteria,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end