Class: Aws::SecurityHub::Types::GetMembersResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::GetMembersResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#members ⇒ Array<Types::Member>
The list of details about the Security Hub CSPM member accounts.
-
#unprocessed_accounts ⇒ Array<Types::Result>
The list of Amazon Web Services accounts that could not be processed.
Instance Attribute Details
#members ⇒ Array<Types::Member>
The list of details about the Security Hub CSPM member accounts.
26909 26910 26911 26912 26913 26914 |
# File 'lib/aws-sdk-securityhub/types.rb', line 26909 class GetMembersResponse < Struct.new( :members, :unprocessed_accounts) SENSITIVE = [] include Aws::Structure end |
#unprocessed_accounts ⇒ Array<Types::Result>
The list of Amazon Web Services accounts that could not be processed. For each account, the list includes the account ID and the email address.
26909 26910 26911 26912 26913 26914 |
# File 'lib/aws-sdk-securityhub/types.rb', line 26909 class GetMembersResponse < Struct.new( :members, :unprocessed_accounts) SENSITIVE = [] include Aws::Structure end |