Class: Aws::SecurityHub::Types::GetMembersResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::GetMembersResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#members ⇒ Array<Types::Member>
The list of details about the Security Hub CSPM member accounts.
-
#unprocessed_accounts ⇒ Array<Types::Result>
The list of Amazon Web Services accounts that could not be processed.
Instance Attribute Details
#members ⇒ Array<Types::Member>
The list of details about the Security Hub CSPM member accounts.
26192 26193 26194 26195 26196 26197 |
# File 'lib/aws-sdk-securityhub/types.rb', line 26192 class GetMembersResponse < Struct.new( :members, :unprocessed_accounts) SENSITIVE = [] include Aws::Structure end |
#unprocessed_accounts ⇒ Array<Types::Result>
The list of Amazon Web Services accounts that could not be processed. For each account, the list includes the account ID and the email address.
26192 26193 26194 26195 26196 26197 |
# File 'lib/aws-sdk-securityhub/types.rb', line 26192 class GetMembersResponse < Struct.new( :members, :unprocessed_accounts) SENSITIVE = [] include Aws::Structure end |