Class: Aws::SecurityHub::Types::GetMembersResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::GetMembersResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#members ⇒ Array<Types::Member>
The list of details about the Security Hub CSPM member accounts.
-
#unprocessed_accounts ⇒ Array<Types::Result>
The list of Amazon Web Services accounts that could not be processed.
Instance Attribute Details
#members ⇒ Array<Types::Member>
The list of details about the Security Hub CSPM member accounts.
26074 26075 26076 26077 26078 26079 |
# File 'lib/aws-sdk-securityhub/types.rb', line 26074 class GetMembersResponse < Struct.new( :members, :unprocessed_accounts) SENSITIVE = [] include Aws::Structure end |
#unprocessed_accounts ⇒ Array<Types::Result>
The list of Amazon Web Services accounts that could not be processed. For each account, the list includes the account ID and the email address.
26074 26075 26076 26077 26078 26079 |
# File 'lib/aws-sdk-securityhub/types.rb', line 26074 class GetMembersResponse < Struct.new( :members, :unprocessed_accounts) SENSITIVE = [] include Aws::Structure end |