Class: Aws::SecurityHub::Types::GetRecommendedPolicyV2Response
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::GetRecommendedPolicyV2Response
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#error ⇒ Types::RecommendationError
Detailed information for a ‘FAILED` retrieval status.
-
#next_token ⇒ String
The pagination token to use to request the next page of results.
-
#recommendation_steps ⇒ Array<Types::RecommendationStep>
The recommended steps to take to resolve the finding.
-
#recommendation_type ⇒ String
The type of recommendation for the finding.
-
#resource_arn ⇒ String
The ARN of the resource of the finding.
-
#status ⇒ String
The current status of the recommended policy retrieval.
Instance Attribute Details
#error ⇒ Types::RecommendationError
Detailed information for a ‘FAILED` retrieval status.
26252 26253 26254 26255 26256 26257 26258 26259 26260 26261 |
# File 'lib/aws-sdk-securityhub/types.rb', line 26252 class GetRecommendedPolicyV2Response < Struct.new( :next_token, :recommendation_type, :recommendation_steps, :error, :status, :resource_arn) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The pagination token to use to request the next page of results.
26252 26253 26254 26255 26256 26257 26258 26259 26260 26261 |
# File 'lib/aws-sdk-securityhub/types.rb', line 26252 class GetRecommendedPolicyV2Response < Struct.new( :next_token, :recommendation_type, :recommendation_steps, :error, :status, :resource_arn) SENSITIVE = [] include Aws::Structure end |
#recommendation_steps ⇒ Array<Types::RecommendationStep>
The recommended steps to take to resolve the finding.
26252 26253 26254 26255 26256 26257 26258 26259 26260 26261 |
# File 'lib/aws-sdk-securityhub/types.rb', line 26252 class GetRecommendedPolicyV2Response < Struct.new( :next_token, :recommendation_type, :recommendation_steps, :error, :status, :resource_arn) SENSITIVE = [] include Aws::Structure end |
#recommendation_type ⇒ String
The type of recommendation for the finding.
26252 26253 26254 26255 26256 26257 26258 26259 26260 26261 |
# File 'lib/aws-sdk-securityhub/types.rb', line 26252 class GetRecommendedPolicyV2Response < Struct.new( :next_token, :recommendation_type, :recommendation_steps, :error, :status, :resource_arn) SENSITIVE = [] include Aws::Structure end |
#resource_arn ⇒ String
The ARN of the resource of the finding.
26252 26253 26254 26255 26256 26257 26258 26259 26260 26261 |
# File 'lib/aws-sdk-securityhub/types.rb', line 26252 class GetRecommendedPolicyV2Response < Struct.new( :next_token, :recommendation_type, :recommendation_steps, :error, :status, :resource_arn) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the recommended policy retrieval.
26252 26253 26254 26255 26256 26257 26258 26259 26260 26261 |
# File 'lib/aws-sdk-securityhub/types.rb', line 26252 class GetRecommendedPolicyV2Response < Struct.new( :next_token, :recommendation_type, :recommendation_steps, :error, :status, :resource_arn) SENSITIVE = [] include Aws::Structure end |