Class: Aws::SecurityHub::Types::GetResourcesStatisticsV2Request
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::GetResourcesStatisticsV2Request
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#group_by_rules ⇒ Array<Types::ResourceGroupByRule>
How resource statistics should be aggregated and organized in the response.
-
#max_statistic_results ⇒ Integer
The maximum number of results to be returned.
-
#scopes ⇒ Types::ResourceScopes
Limits the results to resources from specific organizational units or from the delegated administrator’s organization.
-
#sort_order ⇒ String
Sorts aggregated statistics.
Instance Attribute Details
#group_by_rules ⇒ Array<Types::ResourceGroupByRule>
How resource statistics should be aggregated and organized in the response.
26204 26205 26206 26207 26208 26209 26210 26211 |
# File 'lib/aws-sdk-securityhub/types.rb', line 26204 class GetResourcesStatisticsV2Request < Struct.new( :group_by_rules, :scopes, :sort_order, :max_statistic_results) SENSITIVE = [] include Aws::Structure end |
#max_statistic_results ⇒ Integer
The maximum number of results to be returned.
26204 26205 26206 26207 26208 26209 26210 26211 |
# File 'lib/aws-sdk-securityhub/types.rb', line 26204 class GetResourcesStatisticsV2Request < Struct.new( :group_by_rules, :scopes, :sort_order, :max_statistic_results) SENSITIVE = [] include Aws::Structure end |
#scopes ⇒ Types::ResourceScopes
Limits the results to resources from specific organizational units or from the delegated administrator’s organization. Only the delegated administrator account can use this parameter. Other accounts receive an ‘AccessDeniedException`.
This parameter is optional. If you omit it, the delegated administrator sees statistics from all accounts across the entire organization. Other accounts see only statistics for their own resources.
You can specify up to 10 entries in ‘Scopes.AwsOrganizations`. If multiple entries are specified, the entries are combined using OR logic.
26204 26205 26206 26207 26208 26209 26210 26211 |
# File 'lib/aws-sdk-securityhub/types.rb', line 26204 class GetResourcesStatisticsV2Request < Struct.new( :group_by_rules, :scopes, :sort_order, :max_statistic_results) SENSITIVE = [] include Aws::Structure end |
#sort_order ⇒ String
Sorts aggregated statistics.
26204 26205 26206 26207 26208 26209 26210 26211 |
# File 'lib/aws-sdk-securityhub/types.rb', line 26204 class GetResourcesStatisticsV2Request < Struct.new( :group_by_rules, :scopes, :sort_order, :max_statistic_results) SENSITIVE = [] include Aws::Structure end |