Class: Aws::SecurityHub::Types::GetResourcesV2Request
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::GetResourcesV2Request
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#filters ⇒ Types::ResourcesFilters
Filters resources based on a set of criteria.
-
#max_results ⇒ Integer
The maximum number of results to return.
-
#next_token ⇒ String
The token required for pagination.
-
#scopes ⇒ Types::ResourceScopes
Limits the results to resources from specific organizational units or from the delegated administrator's organization.
-
#sort_criteria ⇒ Array<Types::SortCriterion>
The resource attributes used to sort the list of returned resources.
Instance Attribute Details
#filters ⇒ Types::ResourcesFilters
Filters resources based on a set of criteria.
27202 27203 27204 27205 27206 27207 27208 27209 27210 |
# File 'lib/aws-sdk-securityhub/types.rb', line 27202 class GetResourcesV2Request < Struct.new( :filters, :scopes, :sort_criteria, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return.
27202 27203 27204 27205 27206 27207 27208 27209 27210 |
# File 'lib/aws-sdk-securityhub/types.rb', line 27202 class GetResourcesV2Request < Struct.new( :filters, :scopes, :sort_criteria, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token required for pagination. On your first call, set the value
of this parameter to NULL. For subsequent calls, to continue
listing data, set the value of this parameter to the value returned
in the previous response.
27202 27203 27204 27205 27206 27207 27208 27209 27210 |
# File 'lib/aws-sdk-securityhub/types.rb', line 27202 class GetResourcesV2Request < Struct.new( :filters, :scopes, :sort_criteria, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#scopes ⇒ Types::ResourceScopes
Limits the results to resources from specific organizational units
or from the delegated administrator's organization. Only the
delegated administrator account can use this parameter. Other
accounts receive an AccessDeniedException.
This parameter is optional. If you omit it, the delegated administrator sees resources from all accounts across the entire organization. Other accounts see only their own resources.
You can specify up to 10 entries in Scopes.AwsOrganizations. If
multiple entries are specified, the entries are combined using OR
logic.
27202 27203 27204 27205 27206 27207 27208 27209 27210 |
# File 'lib/aws-sdk-securityhub/types.rb', line 27202 class GetResourcesV2Request < Struct.new( :filters, :scopes, :sort_criteria, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#sort_criteria ⇒ Array<Types::SortCriterion>
The resource attributes used to sort the list of returned resources.
27202 27203 27204 27205 27206 27207 27208 27209 27210 |
# File 'lib/aws-sdk-securityhub/types.rb', line 27202 class GetResourcesV2Request < Struct.new( :filters, :scopes, :sort_criteria, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |