Class: Aws::SecurityHub::Types::GetResourcesV2Request

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#filtersTypes::ResourcesFilters

Filters resources based on a set of criteria.



27130
27131
27132
27133
27134
27135
27136
27137
27138
# File 'lib/aws-sdk-securityhub/types.rb', line 27130

class GetResourcesV2Request < Struct.new(
  :filters,
  :scopes,
  :sort_criteria,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return.

Returns:

  • (Integer)


27130
27131
27132
27133
27134
27135
27136
27137
27138
# File 'lib/aws-sdk-securityhub/types.rb', line 27130

class GetResourcesV2Request < Struct.new(
  :filters,
  :scopes,
  :sort_criteria,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token required for pagination. On your first call, set the value of this parameter to NULL. For subsequent calls, to continue listing data, set the value of this parameter to the value returned in the previous response.

Returns:

  • (String)


27130
27131
27132
27133
27134
27135
27136
27137
27138
# File 'lib/aws-sdk-securityhub/types.rb', line 27130

class GetResourcesV2Request < Struct.new(
  :filters,
  :scopes,
  :sort_criteria,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#scopesTypes::ResourceScopes

Limits the results to resources from specific organizational units or from the delegated administrator's organization. Only the delegated administrator account can use this parameter. Other accounts receive an AccessDeniedException.

This parameter is optional. If you omit it, the delegated administrator sees resources from all accounts across the entire organization. Other accounts see only their own resources.

You can specify up to 10 entries in Scopes.AwsOrganizations. If multiple entries are specified, the entries are combined using OR logic.



27130
27131
27132
27133
27134
27135
27136
27137
27138
# File 'lib/aws-sdk-securityhub/types.rb', line 27130

class GetResourcesV2Request < Struct.new(
  :filters,
  :scopes,
  :sort_criteria,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#sort_criteriaArray<Types::SortCriterion>

The resource attributes used to sort the list of returned resources.

Returns:



27130
27131
27132
27133
27134
27135
27136
27137
27138
# File 'lib/aws-sdk-securityhub/types.rb', line 27130

class GetResourcesV2Request < Struct.new(
  :filters,
  :scopes,
  :sort_criteria,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end