Class: Aws::SecurityHub::Types::GetResourcesV2Request

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#filtersTypes::ResourcesFilters

Filters resources based on a set of criteria.



26323
26324
26325
26326
26327
26328
26329
26330
26331
# File 'lib/aws-sdk-securityhub/types.rb', line 26323

class GetResourcesV2Request < Struct.new(
  :filters,
  :scopes,
  :sort_criteria,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return.

Returns:

  • (Integer)


26323
26324
26325
26326
26327
26328
26329
26330
26331
# File 'lib/aws-sdk-securityhub/types.rb', line 26323

class GetResourcesV2Request < Struct.new(
  :filters,
  :scopes,
  :sort_criteria,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token required for pagination. On your first call, set the value of this parameter to ‘NULL`. For subsequent calls, to continue listing data, set the value of this parameter to the value returned in the previous response.

Returns:

  • (String)


26323
26324
26325
26326
26327
26328
26329
26330
26331
# File 'lib/aws-sdk-securityhub/types.rb', line 26323

class GetResourcesV2Request < Struct.new(
  :filters,
  :scopes,
  :sort_criteria,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#scopesTypes::ResourceScopes

Limits the results to resources from specific organizational units or from the delegated administrator’s organization. Only the delegated administrator account can use this parameter. Other accounts receive an ‘AccessDeniedException`.

This parameter is optional. If you omit it, the delegated administrator sees resources from all accounts across the entire organization. Other accounts see only their own resources.

You can specify up to 10 entries in ‘Scopes.AwsOrganizations`. If multiple entries are specified, the entries are combined using OR logic.



26323
26324
26325
26326
26327
26328
26329
26330
26331
# File 'lib/aws-sdk-securityhub/types.rb', line 26323

class GetResourcesV2Request < Struct.new(
  :filters,
  :scopes,
  :sort_criteria,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#sort_criteriaArray<Types::SortCriterion>

The resource attributes used to sort the list of returned resources.

Returns:



26323
26324
26325
26326
26327
26328
26329
26330
26331
# File 'lib/aws-sdk-securityhub/types.rb', line 26323

class GetResourcesV2Request < Struct.new(
  :filters,
  :scopes,
  :sort_criteria,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end