Class: Aws::SecurityHub::Types::GetResourcesV2Request
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::GetResourcesV2Request
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#filters ⇒ Types::ResourcesFilters
Filters resources based on a set of criteria.
-
#max_results ⇒ Integer
The maximum number of results to return.
-
#next_token ⇒ String
The token required for pagination.
-
#sort_criteria ⇒ Array<Types::SortCriterion>
The finding attributes used to sort the list of returned findings.
Instance Attribute Details
#filters ⇒ Types::ResourcesFilters
Filters resources based on a set of criteria.
26199 26200 26201 26202 26203 26204 26205 26206 |
# File 'lib/aws-sdk-securityhub/types.rb', line 26199 class GetResourcesV2Request < Struct.new( :filters, :sort_criteria, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return.
26199 26200 26201 26202 26203 26204 26205 26206 |
# File 'lib/aws-sdk-securityhub/types.rb', line 26199 class GetResourcesV2Request < Struct.new( :filters, :sort_criteria, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token required for pagination. On your first call, set the value of this parameter to NULL. For subsequent calls, to continue listing data, set the value of this parameter to the value returned in the previous response.
26199 26200 26201 26202 26203 26204 26205 26206 |
# File 'lib/aws-sdk-securityhub/types.rb', line 26199 class GetResourcesV2Request < Struct.new( :filters, :sort_criteria, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#sort_criteria ⇒ Array<Types::SortCriterion>
The finding attributes used to sort the list of returned findings.
26199 26200 26201 26202 26203 26204 26205 26206 |
# File 'lib/aws-sdk-securityhub/types.rb', line 26199 class GetResourcesV2Request < Struct.new( :filters, :sort_criteria, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |