Class: Aws::SecurityHub::Types::HealthCheck
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::HealthCheck
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Information about the operational status and health of a connectorV2.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#connector_status ⇒ String
The status of the connectorV2.
-
#issues ⇒ Array<Types::HealthIssue>
A list of health issues associated with the connector, including error codes and messages.
-
#last_checked_at ⇒ Time
ISO 8601 UTC timestamp for the time check the health status of the connectorV2.
-
#message ⇒ String
The message for the reason of connectorStatus change.
Instance Attribute Details
#connector_status ⇒ String
The status of the connectorV2.
27168 27169 27170 27171 27172 27173 27174 27175 |
# File 'lib/aws-sdk-securityhub/types.rb', line 27168 class HealthCheck < Struct.new( :connector_status, :message, :last_checked_at, :issues) SENSITIVE = [] include Aws::Structure end |
#issues ⇒ Array<Types::HealthIssue>
A list of health issues associated with the connector, including error codes and messages.
27168 27169 27170 27171 27172 27173 27174 27175 |
# File 'lib/aws-sdk-securityhub/types.rb', line 27168 class HealthCheck < Struct.new( :connector_status, :message, :last_checked_at, :issues) SENSITIVE = [] include Aws::Structure end |
#last_checked_at ⇒ Time
ISO 8601 UTC timestamp for the time check the health status of the connectorV2.
27168 27169 27170 27171 27172 27173 27174 27175 |
# File 'lib/aws-sdk-securityhub/types.rb', line 27168 class HealthCheck < Struct.new( :connector_status, :message, :last_checked_at, :issues) SENSITIVE = [] include Aws::Structure end |
#message ⇒ String
The message for the reason of connectorStatus change.
27168 27169 27170 27171 27172 27173 27174 27175 |
# File 'lib/aws-sdk-securityhub/types.rb', line 27168 class HealthCheck < Struct.new( :connector_status, :message, :last_checked_at, :issues) SENSITIVE = [] include Aws::Structure end |