Class: Aws::SecurityHub::Types::HealthCheck
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::HealthCheck
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Information about the operational status and health of a connectorV2.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#connector_status ⇒ String
The status of the connectorV2.
-
#last_checked_at ⇒ Time
ISO 8601 UTC timestamp for the time check the health status of the connectorV2.
-
#message ⇒ String
The message for the reason of connectorStatus change.
Instance Attribute Details
#connector_status ⇒ String
The status of the connectorV2.
26547 26548 26549 26550 26551 26552 26553 |
# File 'lib/aws-sdk-securityhub/types.rb', line 26547 class HealthCheck < Struct.new( :connector_status, :message, :last_checked_at) SENSITIVE = [] include Aws::Structure end |
#last_checked_at ⇒ Time
ISO 8601 UTC timestamp for the time check the health status of the connectorV2.
26547 26548 26549 26550 26551 26552 26553 |
# File 'lib/aws-sdk-securityhub/types.rb', line 26547 class HealthCheck < Struct.new( :connector_status, :message, :last_checked_at) SENSITIVE = [] include Aws::Structure end |
#message ⇒ String
The message for the reason of connectorStatus change.
26547 26548 26549 26550 26551 26552 26553 |
# File 'lib/aws-sdk-securityhub/types.rb', line 26547 class HealthCheck < Struct.new( :connector_status, :message, :last_checked_at) SENSITIVE = [] include Aws::Structure end |