Class: Aws::SecurityHub::Types::HealthIssue
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::HealthIssue
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Represents a specific health issue detected for a connector.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#code ⇒ String
The error code that identifies the type of health issue.
-
#message ⇒ String
A human-readable message that describes the health issue.
Instance Attribute Details
#code ⇒ String
The error code that identifies the type of health issue.
27189 27190 27191 27192 27193 27194 |
# File 'lib/aws-sdk-securityhub/types.rb', line 27189 class HealthIssue < Struct.new( :code, :message) SENSITIVE = [] include Aws::Structure end |
#message ⇒ String
A human-readable message that describes the health issue.
27189 27190 27191 27192 27193 27194 |
# File 'lib/aws-sdk-securityhub/types.rb', line 27189 class HealthIssue < Struct.new( :code, :message) SENSITIVE = [] include Aws::Structure end |