Class: Aws::SecurityHub::Types::Indicator
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::Indicator
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Contains information about the indicators observed in an Amazon GuardDuty Extended Threat Detection attack sequence. Indicators include a set of signals, which can be API activities or findings that GuardDuty uses to detect an attack sequence finding. GuardDuty generates an attack sequence finding when multiple signals align to a potentially suspicious activity. To receive GuardDuty attack sequence findings in Security Hub CSPM, you must have GuardDuty and GuardDuty S3 Protection enabled. For more information, see GuardDuty Extended Threat Detection in the Amazon GuardDuty User Guide.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#key ⇒ String
The name of the indicator that’s present in the attack sequence finding.
-
#title ⇒ String
The title describing the indicator.
-
#type ⇒ String
The type of indicator.
-
#values ⇒ Array<String>
Values associated with each indicator key.
Instance Attribute Details
#key ⇒ String
The name of the indicator that’s present in the attack sequence finding.
27280 27281 27282 27283 27284 27285 27286 27287 |
# File 'lib/aws-sdk-securityhub/types.rb', line 27280 class Indicator < Struct.new( :key, :values, :title, :type) SENSITIVE = [] include Aws::Structure end |
#title ⇒ String
The title describing the indicator.
27280 27281 27282 27283 27284 27285 27286 27287 |
# File 'lib/aws-sdk-securityhub/types.rb', line 27280 class Indicator < Struct.new( :key, :values, :title, :type) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of indicator.
27280 27281 27282 27283 27284 27285 27286 27287 |
# File 'lib/aws-sdk-securityhub/types.rb', line 27280 class Indicator < Struct.new( :key, :values, :title, :type) SENSITIVE = [] include Aws::Structure end |
#values ⇒ Array<String>
Values associated with each indicator key. For example, if the
indicator key is SUSPICIOUS_NETWORK, then the value will be the
name of the network. If the indicator key is ATTACK_TACTIC, then
the value will be one of the MITRE tactics.
27280 27281 27282 27283 27284 27285 27286 27287 |
# File 'lib/aws-sdk-securityhub/types.rb', line 27280 class Indicator < Struct.new( :key, :values, :title, :type) SENSITIVE = [] include Aws::Structure end |