Class: Aws::SecurityHub::Types::Insight
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::Insight
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Contains information about a Security Hub CSPM insight.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#filters ⇒ Types::AwsSecurityFindingFilters
One or more attributes used to filter the findings included in the insight.
-
#group_by_attribute ⇒ String
The grouping attribute for the insight's findings.
-
#insight_arn ⇒ String
The ARN of a Security Hub CSPM insight.
-
#name ⇒ String
The name of a Security Hub CSPM insight.
Instance Attribute Details
#filters ⇒ Types::AwsSecurityFindingFilters
One or more attributes used to filter the findings included in the insight. You can filter by up to ten finding attributes. For each attribute, you can provide up to 20 filter values. The insight only includes findings that match the criteria defined in the filters.
27489 27490 27491 27492 27493 27494 27495 27496 |
# File 'lib/aws-sdk-securityhub/types.rb', line 27489 class Insight < Struct.new( :insight_arn, :name, :filters, :group_by_attribute) SENSITIVE = [] include Aws::Structure end |
#group_by_attribute ⇒ String
The grouping attribute for the insight's findings. Indicates how to group the matching findings, and identifies the type of item that the insight applies to. For example, if an insight is grouped by resource identifier, then the insight produces a list of resource identifiers.
27489 27490 27491 27492 27493 27494 27495 27496 |
# File 'lib/aws-sdk-securityhub/types.rb', line 27489 class Insight < Struct.new( :insight_arn, :name, :filters, :group_by_attribute) SENSITIVE = [] include Aws::Structure end |