Class: Aws::SecurityHub::Types::Insight

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

Contains information about a Security Hub CSPM insight.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#filtersTypes::AwsSecurityFindingFilters

One or more attributes used to filter the findings included in the insight. You can filter by up to ten finding attributes. For each attribute, you can provide up to 20 filter values. The insight only includes findings that match the criteria defined in the filters.



27417
27418
27419
27420
27421
27422
27423
27424
# File 'lib/aws-sdk-securityhub/types.rb', line 27417

class Insight < Struct.new(
  :insight_arn,
  :name,
  :filters,
  :group_by_attribute)
  SENSITIVE = []
  include Aws::Structure
end

#group_by_attributeString

The grouping attribute for the insight's findings. Indicates how to group the matching findings, and identifies the type of item that the insight applies to. For example, if an insight is grouped by resource identifier, then the insight produces a list of resource identifiers.

Returns:

  • (String)


27417
27418
27419
27420
27421
27422
27423
27424
# File 'lib/aws-sdk-securityhub/types.rb', line 27417

class Insight < Struct.new(
  :insight_arn,
  :name,
  :filters,
  :group_by_attribute)
  SENSITIVE = []
  include Aws::Structure
end

#insight_arnString

The ARN of a Security Hub CSPM insight.

Returns:

  • (String)


27417
27418
27419
27420
27421
27422
27423
27424
# File 'lib/aws-sdk-securityhub/types.rb', line 27417

class Insight < Struct.new(
  :insight_arn,
  :name,
  :filters,
  :group_by_attribute)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of a Security Hub CSPM insight.

Returns:

  • (String)


27417
27418
27419
27420
27421
27422
27423
27424
# File 'lib/aws-sdk-securityhub/types.rb', line 27417

class Insight < Struct.new(
  :insight_arn,
  :name,
  :filters,
  :group_by_attribute)
  SENSITIVE = []
  include Aws::Structure
end