Class: Aws::SecurityHub::Types::LimitExceededException
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::LimitExceededException
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
The request was rejected because it attempted to create resources beyond the current Amazon Web Services account or throttling limits. The error code describes the limit exceeded.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
Instance Attribute Details
#code ⇒ String
27000 27001 27002 27003 27004 27005 |
# File 'lib/aws-sdk-securityhub/types.rb', line 27000 class LimitExceededException < Struct.new( :message, :code) SENSITIVE = [] include Aws::Structure end |
#message ⇒ String
27000 27001 27002 27003 27004 27005 |
# File 'lib/aws-sdk-securityhub/types.rb', line 27000 class LimitExceededException < Struct.new( :message, :code) SENSITIVE = [] include Aws::Structure end |