Class: Aws::SecurityHub::Types::ListConfigurationPoliciesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::ListConfigurationPoliciesRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
The maximum number of results that’s returned by
ListConfigurationPoliciesin each page of the response. -
#next_token ⇒ String
The NextToken value that’s returned from a previous paginated
ListConfigurationPoliciesrequest whereMaxResultswas used but the results exceeded the value of that parameter.
Instance Attribute Details
#max_results ⇒ Integer
The maximum number of results that’s returned by ListConfigurationPolicies in each page of the response. When this parameter is used, ListConfigurationPolicies returns the specified number of results in a single page and a NextToken response element. You can see the remaining results of the initial request by sending another ListConfigurationPolicies request with the returned NextToken value. A valid range for MaxResults is between 1 and 100.
27020 27021 27022 27023 27024 27025 |
# File 'lib/aws-sdk-securityhub/types.rb', line 27020 class ListConfigurationPoliciesRequest < Struct.new( :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The NextToken value that’s returned from a previous paginated ListConfigurationPolicies request where MaxResults was used but the results exceeded the value of that parameter. Pagination continues from the MaxResults was used but the results exceeded the value of that parameter. Pagination continues from the end of the previous response that returned the NextToken value. This value is null when there are no more results to return.
27020 27021 27022 27023 27024 27025 |
# File 'lib/aws-sdk-securityhub/types.rb', line 27020 class ListConfigurationPoliciesRequest < Struct.new( :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |