Class: Aws::SecurityHub::Types::ListConfigurationPolicyAssociationsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::ListConfigurationPolicyAssociationsRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#filters ⇒ Types::AssociationFilters
Options for filtering the
ListConfigurationPolicyAssociationsresponse. -
#max_results ⇒ Integer
The maximum number of results that's returned by
ListConfigurationPoliciesin each page of the response. -
#next_token ⇒ String
The
NextTokenvalue that's returned from a previous paginatedListConfigurationPolicyAssociationsrequest whereMaxResultswas used but the results exceeded the value of that parameter.
Instance Attribute Details
#filters ⇒ Types::AssociationFilters
Options for filtering the ListConfigurationPolicyAssociations
response. You can filter by the Amazon Resource Name (ARN) or
universally unique identifier (UUID) of a configuration,
AssociationType, or AssociationStatus.
27202 27203 27204 27205 27206 27207 27208 |
# File 'lib/aws-sdk-securityhub/types.rb', line 27202 class ListConfigurationPolicyAssociationsRequest < Struct.new( :next_token, :max_results, :filters) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results that's returned by
ListConfigurationPolicies in each page of the response. When this
parameter is used, ListConfigurationPolicyAssociations returns the
specified number of results in a single page and a NextToken
response element. You can see the remaining results of the initial
request by sending another ListConfigurationPolicyAssociations
request with the returned NextToken value. A valid range for
MaxResults is between 1 and 100.
27202 27203 27204 27205 27206 27207 27208 |
# File 'lib/aws-sdk-securityhub/types.rb', line 27202 class ListConfigurationPolicyAssociationsRequest < Struct.new( :next_token, :max_results, :filters) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The NextToken value that's returned from a previous paginated
ListConfigurationPolicyAssociations request where MaxResults was
used but the results exceeded the value of that parameter.
Pagination continues from the end of the previous response that
returned the NextToken value. This value is null when there are
no more results to return.
27202 27203 27204 27205 27206 27207 27208 |
# File 'lib/aws-sdk-securityhub/types.rb', line 27202 class ListConfigurationPolicyAssociationsRequest < Struct.new( :next_token, :max_results, :filters) SENSITIVE = [] include Aws::Structure end |