Class: Aws::SecurityHub::Types::ListConfigurationPolicyAssociationsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::ListConfigurationPolicyAssociationsResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#configuration_policy_association_summaries ⇒ Array<Types::ConfigurationPolicyAssociationSummary>
An object that contains the details of each configuration policy association that’s returned in a
ListConfigurationPolicyAssociationsrequest. -
#next_token ⇒ String
The
NextTokenvalue to include in the nextListConfigurationPolicyAssociationsrequest.
Instance Attribute Details
#configuration_policy_association_summaries ⇒ Array<Types::ConfigurationPolicyAssociationSummary>
An object that contains the details of each configuration policy association that’s returned in a ListConfigurationPolicyAssociations request.
27101 27102 27103 27104 27105 27106 |
# File 'lib/aws-sdk-securityhub/types.rb', line 27101 class ListConfigurationPolicyAssociationsResponse < Struct.new( :configuration_policy_association_summaries, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The NextToken value to include in the next ListConfigurationPolicyAssociations request. When the results of a ListConfigurationPolicyAssociations request exceed MaxResults, this value can be used to retrieve the next page of results. This value is null when there are no more results to return.
27101 27102 27103 27104 27105 27106 |
# File 'lib/aws-sdk-securityhub/types.rb', line 27101 class ListConfigurationPolicyAssociationsResponse < Struct.new( :configuration_policy_association_summaries, :next_token) SENSITIVE = [] include Aws::Structure end |