Class: Aws::SecurityHub::Types::ListFreeTrialStatusesV2Request
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::ListFreeTrialStatusesV2Request
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#account_ids ⇒ Array<String>
The Amazon Web Services account identifiers to list free trial status for.
-
#max_results ⇒ Integer
The maximum number of results to return.
-
#next_token ⇒ String
The pagination token to request the next page of results.
-
#statuses ⇒ Array<String>
The free trial statuses to filter the results by.
Instance Attribute Details
#account_ids ⇒ Array<String>
The Amazon Web Services account identifiers to list free trial status for. You can specify accounts other than your own only if you are a delegated Security Hub administrator.
28344 28345 28346 28347 28348 28349 28350 28351 |
# File 'lib/aws-sdk-securityhub/types.rb', line 28344 class ListFreeTrialStatusesV2Request < Struct.new( :account_ids, :statuses, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return. If you don't specify a value, Security Hub returns up to 100 results.
28344 28345 28346 28347 28348 28349 28350 28351 |
# File 'lib/aws-sdk-securityhub/types.rb', line 28344 class ListFreeTrialStatusesV2Request < Struct.new( :account_ids, :statuses, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The pagination token to request the next page of results.
28344 28345 28346 28347 28348 28349 28350 28351 |
# File 'lib/aws-sdk-securityhub/types.rb', line 28344 class ListFreeTrialStatusesV2Request < Struct.new( :account_ids, :statuses, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#statuses ⇒ Array<String>
The free trial statuses to filter the results by. Valid values:
-
ACTIVEreturns only features with an ongoing free trial period. -
INACTIVEreturns only features whose free trial period has ended, or that never started.
28344 28345 28346 28347 28348 28349 28350 28351 |
# File 'lib/aws-sdk-securityhub/types.rb', line 28344 class ListFreeTrialStatusesV2Request < Struct.new( :account_ids, :statuses, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |