Class: Aws::SecurityHub::Types::ListInvitationsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::ListInvitationsRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
The maximum number of items to return in the response.
-
#next_token ⇒ String
The token that is required for pagination.
Instance Attribute Details
#max_results ⇒ Integer
The maximum number of items to return in the response.
27250 27251 27252 27253 27254 27255 |
# File 'lib/aws-sdk-securityhub/types.rb', line 27250 class ListInvitationsRequest < Struct.new( :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token that is required for pagination. On your first call to the ListInvitations operation, set the value of this parameter to NULL.
For subsequent calls to the operation, to continue listing data, set the value of this parameter to the value returned from the previous response.
27250 27251 27252 27253 27254 27255 |
# File 'lib/aws-sdk-securityhub/types.rb', line 27250 class ListInvitationsRequest < Struct.new( :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |