Class: Aws::SecurityHub::Types::ListMembersRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::ListMembersRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
The maximum number of items to return in the response.
-
#next_token ⇒ String
The token that is required for pagination.
-
#only_associated ⇒ Boolean
Specifies which member accounts to include in the response based on their relationship status with the administrator account.
Instance Attribute Details
#max_results ⇒ Integer
The maximum number of items to return in the response.
27302 27303 27304 27305 27306 27307 27308 |
# File 'lib/aws-sdk-securityhub/types.rb', line 27302 class ListMembersRequest < Struct.new( :only_associated, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token that is required for pagination. On your first call to the ListMembers operation, set the value of this parameter to NULL.
For subsequent calls to the operation, to continue listing data, set the value of this parameter to the value returned from the previous response.
27302 27303 27304 27305 27306 27307 27308 |
# File 'lib/aws-sdk-securityhub/types.rb', line 27302 class ListMembersRequest < Struct.new( :only_associated, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#only_associated ⇒ Boolean
Specifies which member accounts to include in the response based on their relationship status with the administrator account. The default value is TRUE.
If OnlyAssociated is set to TRUE, the response includes member accounts whose relationship status with the administrator account is set to ENABLED.
If OnlyAssociated is set to FALSE, the response includes all existing member accounts.
27302 27303 27304 27305 27306 27307 27308 |
# File 'lib/aws-sdk-securityhub/types.rb', line 27302 class ListMembersRequest < Struct.new( :only_associated, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |