Class: Aws::SecurityHub::Types::ListOrganizationAdminAccountsRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#featureString

The feature where the delegated administrator account is listed. Defaults to Security Hub CSPM if not specified.

Returns:

  • (String)


27346
27347
27348
27349
27350
27351
27352
# File 'lib/aws-sdk-securityhub/types.rb', line 27346

class ListOrganizationAdminAccountsRequest < Struct.new(
  :max_results,
  :next_token,
  :feature)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of items to return in the response.

Returns:

  • (Integer)


27346
27347
27348
27349
27350
27351
27352
# File 'lib/aws-sdk-securityhub/types.rb', line 27346

class ListOrganizationAdminAccountsRequest < Struct.new(
  :max_results,
  :next_token,
  :feature)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token that is required for pagination. On your first call to the ListOrganizationAdminAccounts operation, set the value of this parameter to NULL. For subsequent calls to the operation, to continue listing data, set the value of this parameter to the value returned from the previous response.

Returns:

  • (String)


27346
27347
27348
27349
27350
27351
27352
# File 'lib/aws-sdk-securityhub/types.rb', line 27346

class ListOrganizationAdminAccountsRequest < Struct.new(
  :max_results,
  :next_token,
  :feature)
  SENSITIVE = []
  include Aws::Structure
end