Class: Aws::SecurityHub::Types::ListSecurityControlDefinitionsRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#max_resultsInteger

An optional parameter that limits the total results of the API response to the specified number. If this parameter isn’t provided in the request, the results include the first 25 security controls that apply to the specified standard. The results also include a NextToken parameter that you can use in a subsequent API call to get the next 25 controls. This repeats until all controls for the standard are returned.

Returns:

  • (Integer)


25521
25522
25523
25524
25525
25526
25527
# File 'lib/aws-sdk-securityhub/types.rb', line 25521

class ListSecurityControlDefinitionsRequest < Struct.new(
  :standards_arn,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

Optional pagination parameter.

Returns:

  • (String)


25521
25522
25523
25524
25525
25526
25527
# File 'lib/aws-sdk-securityhub/types.rb', line 25521

class ListSecurityControlDefinitionsRequest < Struct.new(
  :standards_arn,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#standards_arnString

The Amazon Resource Name (ARN) of the standard that you want to view controls for.

Returns:

  • (String)


25521
25522
25523
25524
25525
25526
25527
# File 'lib/aws-sdk-securityhub/types.rb', line 25521

class ListSecurityControlDefinitionsRequest < Struct.new(
  :standards_arn,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end