Class: Aws::SecurityHub::Types::ListSecurityControlDefinitionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::ListSecurityControlDefinitionsRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
An optional parameter that limits the total results of the API response to the specified number.
-
#next_token ⇒ String
Optional pagination parameter.
-
#providers ⇒ Array<String>
A list of cloud providers to filter the security control definitions by.
-
#standards_arn ⇒ String
The Amazon Resource Name (ARN) of the standard that you want to view controls for.
Instance Attribute Details
#max_results ⇒ Integer
An optional parameter that limits the total results of the API
response to the specified number. If this parameter isn't provided
in the request, the results include the first 25 security controls
that apply to the specified standard. The results also include a
NextToken parameter that you can use in a subsequent API call to
get the next 25 controls. This repeats until all controls for the
standard are returned.
28541 28542 28543 28544 28545 28546 28547 28548 |
# File 'lib/aws-sdk-securityhub/types.rb', line 28541 class ListSecurityControlDefinitionsRequest < Struct.new( :standards_arn, :next_token, :max_results, :providers) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
Optional pagination parameter.
28541 28542 28543 28544 28545 28546 28547 28548 |
# File 'lib/aws-sdk-securityhub/types.rb', line 28541 class ListSecurityControlDefinitionsRequest < Struct.new( :standards_arn, :next_token, :max_results, :providers) SENSITIVE = [] include Aws::Structure end |
#providers ⇒ Array<String>
A list of cloud providers to filter the security control definitions
by. For example, specify Azure to return only controls that
evaluate Azure resources.
28541 28542 28543 28544 28545 28546 28547 28548 |
# File 'lib/aws-sdk-securityhub/types.rb', line 28541 class ListSecurityControlDefinitionsRequest < Struct.new( :standards_arn, :next_token, :max_results, :providers) SENSITIVE = [] include Aws::Structure end |
#standards_arn ⇒ String
The Amazon Resource Name (ARN) of the standard that you want to view controls for.
28541 28542 28543 28544 28545 28546 28547 28548 |
# File 'lib/aws-sdk-securityhub/types.rb', line 28541 class ListSecurityControlDefinitionsRequest < Struct.new( :standards_arn, :next_token, :max_results, :providers) SENSITIVE = [] include Aws::Structure end |