Class: Aws::SecurityHub::Types::ListStandardsControlAssociationsRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#max_resultsInteger

An optional parameter that limits the total results of the API response to the specified number. If this parameter isn’t provided in the request, the results include the first 25 standard and control associations. The results also include a NextToken parameter that you can use in a subsequent API call to get the next 25 associations. This repeats until all associations for the specified control are returned. The number of results is limited by the number of supported Security Hub CSPM standards that you’ve enabled in the calling account.

Returns:

  • (Integer)


27448
27449
27450
27451
27452
27453
27454
# File 'lib/aws-sdk-securityhub/types.rb', line 27448

class ListStandardsControlAssociationsRequest < Struct.new(
  :security_control_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

Optional pagination parameter.

Returns:

  • (String)


27448
27449
27450
27451
27452
27453
27454
# File 'lib/aws-sdk-securityhub/types.rb', line 27448

class ListStandardsControlAssociationsRequest < Struct.new(
  :security_control_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#security_control_idString

The identifier of the control (identified with SecurityControlId, SecurityControlArn, or a mix of both parameters) that you want to determine the enablement status of in each enabled standard.

Returns:

  • (String)


27448
27449
27450
27451
27452
27453
27454
# File 'lib/aws-sdk-securityhub/types.rb', line 27448

class ListStandardsControlAssociationsRequest < Struct.new(
  :security_control_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end