Class: Aws::SecurityHub::Types::LoadBalancerState
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::LoadBalancerState
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Information about the state of the load balancer.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#code ⇒ String
The state code.
-
#reason ⇒ String
A description of the state.
Instance Attribute Details
#code ⇒ String
The state code. The initial state of the load balancer is provisioning.
After the load balancer is fully set up and ready to route traffic, its state is active.
If the load balancer could not be set up, its state is failed.
28435 28436 28437 28438 28439 28440 |
# File 'lib/aws-sdk-securityhub/types.rb', line 28435 class LoadBalancerState < Struct.new( :code, :reason) SENSITIVE = [] include Aws::Structure end |
#reason ⇒ String
A description of the state.
28435 28436 28437 28438 28439 28440 |
# File 'lib/aws-sdk-securityhub/types.rb', line 28435 class LoadBalancerState < Struct.new( :code, :reason) SENSITIVE = [] include Aws::Structure end |