Class: Aws::SecurityHub::Types::NetworkAutonomousSystem

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

Contains information about the Autonomous System (AS) of the network endpoints involved in an Amazon GuardDuty Extended Threat Detection attack sequence. GuardDuty generates an attack sequence finding when multiple events align to a potentially suspicious activity. To receive GuardDuty attack sequence findings in Security Hub CSPM, you must have GuardDuty enabled. For more information, see [GuardDuty Extended Threat Detection ][1] in the *Amazon GuardDuty User Guide*.

[1]: docs.aws.amazon.com/guardduty/latest/ug/guardduty-extended-threat-detection.html

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#nameString

The name associated with the AS.

Returns:

  • (String)


28042
28043
28044
28045
28046
28047
# File 'lib/aws-sdk-securityhub/types.rb', line 28042

class NetworkAutonomousSystem < Struct.new(
  :name,
  :number)
  SENSITIVE = []
  include Aws::Structure
end

#numberInteger

The unique number that identifies the AS.

Returns:

  • (Integer)


28042
28043
28044
28045
28046
28047
# File 'lib/aws-sdk-securityhub/types.rb', line 28042

class NetworkAutonomousSystem < Struct.new(
  :name,
  :number)
  SENSITIVE = []
  include Aws::Structure
end