Class: Aws::SecurityHub::Types::NetworkConnection
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::NetworkConnection
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Contains information about the network connection involved in an Amazon GuardDuty Extended Threat Detection attack sequence. GuardDuty generates an attack sequence finding when multiple events align to a potentially suspicious activity. To receive GuardDuty attack sequence findings in Security Hub CSPM, you must have GuardDuty enabled. For more information, see GuardDuty Extended Threat Detection in the Amazon GuardDuty User Guide.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#direction ⇒ String
The direction in which the network traffic is flowing.
Instance Attribute Details
#direction ⇒ String
The direction in which the network traffic is flowing.
28770 28771 28772 28773 28774 |
# File 'lib/aws-sdk-securityhub/types.rb', line 28770 class NetworkConnection < Struct.new( :direction) SENSITIVE = [] include Aws::Structure end |