Class: Aws::SecurityHub::Types::NetworkGeoLocation
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::NetworkGeoLocation
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Contains information about the location of a network endpoint involved in an Amazon GuardDuty Extended Threat Detection attack sequence. GuardDuty generates an attack sequence finding when multiple events align to a potentially suspicious activity. To receive GuardDuty attack sequence findings in Security Hub CSPM, you must have GuardDuty enabled. For more information, see GuardDuty Extended Threat Detection in the Amazon GuardDuty User Guide.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#city ⇒ String
The name of the city.
-
#country ⇒ String
The name of the country.
-
#lat ⇒ Float
The latitude information of the endpoint location.
-
#lon ⇒ Float
The longitude information of the endpoint location.
Instance Attribute Details
#city ⇒ String
The name of the city.
29134 29135 29136 29137 29138 29139 29140 29141 |
# File 'lib/aws-sdk-securityhub/types.rb', line 29134 class NetworkGeoLocation < Struct.new( :city, :country, :lat, :lon) SENSITIVE = [] include Aws::Structure end |
#country ⇒ String
The name of the country.
29134 29135 29136 29137 29138 29139 29140 29141 |
# File 'lib/aws-sdk-securityhub/types.rb', line 29134 class NetworkGeoLocation < Struct.new( :city, :country, :lat, :lon) SENSITIVE = [] include Aws::Structure end |
#lat ⇒ Float
The latitude information of the endpoint location.
29134 29135 29136 29137 29138 29139 29140 29141 |
# File 'lib/aws-sdk-securityhub/types.rb', line 29134 class NetworkGeoLocation < Struct.new( :city, :country, :lat, :lon) SENSITIVE = [] include Aws::Structure end |
#lon ⇒ Float
The longitude information of the endpoint location.
29134 29135 29136 29137 29138 29139 29140 29141 |
# File 'lib/aws-sdk-securityhub/types.rb', line 29134 class NetworkGeoLocation < Struct.new( :city, :country, :lat, :lon) SENSITIVE = [] include Aws::Structure end |