Class: Aws::SecurityHub::Types::Note

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

A user-defined note added to a finding.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#textString

The text of a note.

Length Constraints: Minimum of 1. Maximum of 512.

Returns:

  • (String)


29125
29126
29127
29128
29129
29130
29131
# File 'lib/aws-sdk-securityhub/types.rb', line 29125

class Note < Struct.new(
  :text,
  :updated_by,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#updated_atString

A timestamp that indicates when the note was updated.

For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.

Returns:

  • (String)


29125
29126
29127
29128
29129
29130
29131
# File 'lib/aws-sdk-securityhub/types.rb', line 29125

class Note < Struct.new(
  :text,
  :updated_by,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#updated_byString

The principal that created a note.

Returns:

  • (String)


29125
29126
29127
29128
29129
29130
29131
# File 'lib/aws-sdk-securityhub/types.rb', line 29125

class Note < Struct.new(
  :text,
  :updated_by,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end