Class: Aws::SecurityHub::Types::Note
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::Note
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
A user-defined note added to a finding.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#text ⇒ String
The text of a note.
-
#updated_at ⇒ String
A timestamp that indicates when the note was updated.
-
#updated_by ⇒ String
The principal that created a note.
Instance Attribute Details
#text ⇒ String
The text of a note.
Length Constraints: Minimum of 1. Maximum of 512.
29024 29025 29026 29027 29028 29029 29030 |
# File 'lib/aws-sdk-securityhub/types.rb', line 29024 class Note < Struct.new( :text, :updated_by, :updated_at) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ String
A timestamp that indicates when the note was updated.
For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.
29024 29025 29026 29027 29028 29029 29030 |
# File 'lib/aws-sdk-securityhub/types.rb', line 29024 class Note < Struct.new( :text, :updated_by, :updated_at) SENSITIVE = [] include Aws::Structure end |