Class: Aws::SecurityHub::Types::ParameterValue

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure, Aws::Structure::Union
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

Note:

ParameterValue is a union - when making an API calls you must set exactly one of the members.

Note:

ParameterValue is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of ParameterValue corresponding to the set member.

An object that includes the data type of a security control parameter and its current value.

Defined Under Namespace

Classes: Boolean, Double, Enum, EnumList, Integer, IntegerList, String, StringList, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#booleanBoolean

A control parameter that is a boolean.

Returns:



29602
29603
29604
29605
29606
29607
29608
29609
29610
29611
29612
29613
29614
29615
29616
29617
29618
29619
29620
29621
29622
29623
29624
29625
# File 'lib/aws-sdk-securityhub/types.rb', line 29602

class ParameterValue < Struct.new(
  :integer,
  :integer_list,
  :double,
  :string,
  :string_list,
  :boolean,
  :enum,
  :enum_list,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Integer < ParameterValue; end
  class IntegerList < ParameterValue; end
  class Double < ParameterValue; end
  class String < ParameterValue; end
  class StringList < ParameterValue; end
  class Boolean < ParameterValue; end
  class Enum < ParameterValue; end
  class EnumList < ParameterValue; end
  class Unknown < ParameterValue; end
end

#doubleFloat

A control parameter that is a double.

Returns:

  • (Float)


29602
29603
29604
29605
29606
29607
29608
29609
29610
29611
29612
29613
29614
29615
29616
29617
29618
29619
29620
29621
29622
29623
29624
29625
# File 'lib/aws-sdk-securityhub/types.rb', line 29602

class ParameterValue < Struct.new(
  :integer,
  :integer_list,
  :double,
  :string,
  :string_list,
  :boolean,
  :enum,
  :enum_list,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Integer < ParameterValue; end
  class IntegerList < ParameterValue; end
  class Double < ParameterValue; end
  class String < ParameterValue; end
  class StringList < ParameterValue; end
  class Boolean < ParameterValue; end
  class Enum < ParameterValue; end
  class EnumList < ParameterValue; end
  class Unknown < ParameterValue; end
end

#enumString

A control parameter that is an enum.

Returns:



29602
29603
29604
29605
29606
29607
29608
29609
29610
29611
29612
29613
29614
29615
29616
29617
29618
29619
29620
29621
29622
29623
29624
29625
# File 'lib/aws-sdk-securityhub/types.rb', line 29602

class ParameterValue < Struct.new(
  :integer,
  :integer_list,
  :double,
  :string,
  :string_list,
  :boolean,
  :enum,
  :enum_list,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Integer < ParameterValue; end
  class IntegerList < ParameterValue; end
  class Double < ParameterValue; end
  class String < ParameterValue; end
  class StringList < ParameterValue; end
  class Boolean < ParameterValue; end
  class Enum < ParameterValue; end
  class EnumList < ParameterValue; end
  class Unknown < ParameterValue; end
end

#enum_listArray<String>

A control parameter that is a list of enums.

Returns:



29602
29603
29604
29605
29606
29607
29608
29609
29610
29611
29612
29613
29614
29615
29616
29617
29618
29619
29620
29621
29622
29623
29624
29625
# File 'lib/aws-sdk-securityhub/types.rb', line 29602

class ParameterValue < Struct.new(
  :integer,
  :integer_list,
  :double,
  :string,
  :string_list,
  :boolean,
  :enum,
  :enum_list,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Integer < ParameterValue; end
  class IntegerList < ParameterValue; end
  class Double < ParameterValue; end
  class String < ParameterValue; end
  class StringList < ParameterValue; end
  class Boolean < ParameterValue; end
  class Enum < ParameterValue; end
  class EnumList < ParameterValue; end
  class Unknown < ParameterValue; end
end

#integerInteger

A control parameter that is an integer.

Returns:



29602
29603
29604
29605
29606
29607
29608
29609
29610
29611
29612
29613
29614
29615
29616
29617
29618
29619
29620
29621
29622
29623
29624
29625
# File 'lib/aws-sdk-securityhub/types.rb', line 29602

class ParameterValue < Struct.new(
  :integer,
  :integer_list,
  :double,
  :string,
  :string_list,
  :boolean,
  :enum,
  :enum_list,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Integer < ParameterValue; end
  class IntegerList < ParameterValue; end
  class Double < ParameterValue; end
  class String < ParameterValue; end
  class StringList < ParameterValue; end
  class Boolean < ParameterValue; end
  class Enum < ParameterValue; end
  class EnumList < ParameterValue; end
  class Unknown < ParameterValue; end
end

#integer_listArray<Integer>

A control parameter that is a list of integers.

Returns:



29602
29603
29604
29605
29606
29607
29608
29609
29610
29611
29612
29613
29614
29615
29616
29617
29618
29619
29620
29621
29622
29623
29624
29625
# File 'lib/aws-sdk-securityhub/types.rb', line 29602

class ParameterValue < Struct.new(
  :integer,
  :integer_list,
  :double,
  :string,
  :string_list,
  :boolean,
  :enum,
  :enum_list,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Integer < ParameterValue; end
  class IntegerList < ParameterValue; end
  class Double < ParameterValue; end
  class String < ParameterValue; end
  class StringList < ParameterValue; end
  class Boolean < ParameterValue; end
  class Enum < ParameterValue; end
  class EnumList < ParameterValue; end
  class Unknown < ParameterValue; end
end

#stringString

A control parameter that is a string.

Returns:



29602
29603
29604
29605
29606
29607
29608
29609
29610
29611
29612
29613
29614
29615
29616
29617
29618
29619
29620
29621
29622
29623
29624
29625
# File 'lib/aws-sdk-securityhub/types.rb', line 29602

class ParameterValue < Struct.new(
  :integer,
  :integer_list,
  :double,
  :string,
  :string_list,
  :boolean,
  :enum,
  :enum_list,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Integer < ParameterValue; end
  class IntegerList < ParameterValue; end
  class Double < ParameterValue; end
  class String < ParameterValue; end
  class StringList < ParameterValue; end
  class Boolean < ParameterValue; end
  class Enum < ParameterValue; end
  class EnumList < ParameterValue; end
  class Unknown < ParameterValue; end
end

#string_listArray<String>

A control parameter that is a list of strings.

Returns:



29602
29603
29604
29605
29606
29607
29608
29609
29610
29611
29612
29613
29614
29615
29616
29617
29618
29619
29620
29621
29622
29623
29624
29625
# File 'lib/aws-sdk-securityhub/types.rb', line 29602

class ParameterValue < Struct.new(
  :integer,
  :integer_list,
  :double,
  :string,
  :string_list,
  :boolean,
  :enum,
  :enum_list,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Integer < ParameterValue; end
  class IntegerList < ParameterValue; end
  class Double < ParameterValue; end
  class String < ParameterValue; end
  class StringList < ParameterValue; end
  class Boolean < ParameterValue; end
  class Enum < ParameterValue; end
  class EnumList < ParameterValue; end
  class Unknown < ParameterValue; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



29602
29603
29604
# File 'lib/aws-sdk-securityhub/types.rb', line 29602

def unknown
  @unknown
end