Class: Aws::SecurityHub::Types::Policy

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure, Aws::Structure::Union
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

Note:

Policy is a union - when making an API calls you must set exactly one of the members.

Note:

Policy is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of Policy corresponding to the set member.

An object that defines how Security Hub CSPM is configured. It includes whether Security Hub CSPM is enabled or disabled, a list of enabled security standards, a list of enabled or disabled security controls, and a list of custom parameter values for specified controls. If you provide a list of security controls that are enabled in the configuration policy, Security Hub CSPM disables all other controls (including newly released controls). If you provide a list of security controls that are disabled in the configuration policy, Security Hub CSPM enables all other controls (including newly released controls).

Direct Known Subclasses

SecurityHub, Unknown

Defined Under Namespace

Classes: SecurityHub, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#security_hubTypes::SecurityHubPolicy

The Amazon Web Services service that the configuration policy applies to.

Returns:



28700
28701
28702
28703
28704
28705
28706
28707
28708
28709
# File 'lib/aws-sdk-securityhub/types.rb', line 28700

class Policy < Struct.new(
  :security_hub,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class SecurityHub < Policy; end
  class Unknown < Policy; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • the current value of unknown



28700
28701
28702
# File 'lib/aws-sdk-securityhub/types.rb', line 28700

def unknown
  @unknown
end