Class: Aws::SecurityHub::Types::PortProbeDetail
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::PortProbeDetail
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
A port scan that was part of the port probe. For each scan, PortProbeDetails provides information about the local IP address and port that were scanned, and the remote IP address that the scan originated from.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#local_ip_details ⇒ Types::ActionLocalIpDetails
Provides information about the IP address where the scanned port is located.
-
#local_port_details ⇒ Types::ActionLocalPortDetails
Provides information about the port that was scanned.
-
#remote_ip_details ⇒ Types::ActionRemoteIpDetails
Provides information about the remote IP address that performed the scan.
Instance Attribute Details
#local_ip_details ⇒ Types::ActionLocalIpDetails
Provides information about the IP address where the scanned port is located.
29807 29808 29809 29810 29811 29812 29813 |
# File 'lib/aws-sdk-securityhub/types.rb', line 29807 class PortProbeDetail < Struct.new( :local_port_details, :local_ip_details, :remote_ip_details) SENSITIVE = [] include Aws::Structure end |
#local_port_details ⇒ Types::ActionLocalPortDetails
Provides information about the port that was scanned.
29807 29808 29809 29810 29811 29812 29813 |
# File 'lib/aws-sdk-securityhub/types.rb', line 29807 class PortProbeDetail < Struct.new( :local_port_details, :local_ip_details, :remote_ip_details) SENSITIVE = [] include Aws::Structure end |
#remote_ip_details ⇒ Types::ActionRemoteIpDetails
Provides information about the remote IP address that performed the scan.
29807 29808 29809 29810 29811 29812 29813 |
# File 'lib/aws-sdk-securityhub/types.rb', line 29807 class PortProbeDetail < Struct.new( :local_port_details, :local_ip_details, :remote_ip_details) SENSITIVE = [] include Aws::Structure end |