Class: Aws::SecurityHub::Types::PortProbeDetail

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

A port scan that was part of the port probe. For each scan, PortProbeDetails provides information about the local IP address and port that were scanned, and the remote IP address that the scan originated from.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#local_ip_detailsTypes::ActionLocalIpDetails

Provides information about the IP address where the scanned port is located.



29706
29707
29708
29709
29710
29711
29712
# File 'lib/aws-sdk-securityhub/types.rb', line 29706

class PortProbeDetail < Struct.new(
  :local_port_details,
  :local_ip_details,
  :remote_ip_details)
  SENSITIVE = []
  include Aws::Structure
end

#local_port_detailsTypes::ActionLocalPortDetails

Provides information about the port that was scanned.



29706
29707
29708
29709
29710
29711
29712
# File 'lib/aws-sdk-securityhub/types.rb', line 29706

class PortProbeDetail < Struct.new(
  :local_port_details,
  :local_ip_details,
  :remote_ip_details)
  SENSITIVE = []
  include Aws::Structure
end

#remote_ip_detailsTypes::ActionRemoteIpDetails

Provides information about the remote IP address that performed the scan.



29706
29707
29708
29709
29710
29711
29712
# File 'lib/aws-sdk-securityhub/types.rb', line 29706

class PortProbeDetail < Struct.new(
  :local_port_details,
  :local_ip_details,
  :remote_ip_details)
  SENSITIVE = []
  include Aws::Structure
end