Class: Aws::SecurityHub::Types::ProviderConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure, Aws::Structure::Union
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

Note:

ProviderConfiguration is a union - when making an API calls you must set exactly one of the members.

The initial configuration settings required to establish an integration between Security Hub and third-party provider.

Direct Known Subclasses

JiraCloud, ServiceNow, Unknown

Defined Under Namespace

Classes: JiraCloud, ServiceNow, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#jira_cloudTypes::JiraCloudProviderConfiguration

The configuration settings required to establish an integration with Jira Cloud.



29260
29261
29262
29263
29264
29265
29266
29267
29268
29269
29270
29271
# File 'lib/aws-sdk-securityhub/types.rb', line 29260

class ProviderConfiguration < Struct.new(
  :jira_cloud,
  :service_now,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class JiraCloud < ProviderConfiguration; end
  class ServiceNow < ProviderConfiguration; end
  class Unknown < ProviderConfiguration; end
end

#service_nowTypes::ServiceNowProviderConfiguration

The configuration settings required to establish an integration with ServiceNow ITSM.



29260
29261
29262
29263
29264
29265
29266
29267
29268
29269
29270
29271
# File 'lib/aws-sdk-securityhub/types.rb', line 29260

class ProviderConfiguration < Struct.new(
  :jira_cloud,
  :service_now,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class JiraCloud < ProviderConfiguration; end
  class ServiceNow < ProviderConfiguration; end
  class Unknown < ProviderConfiguration; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



29260
29261
29262
# File 'lib/aws-sdk-securityhub/types.rb', line 29260

def unknown
  @unknown
end