Class: Aws::SecurityHub::Types::ProviderDetail

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure, Aws::Structure::Union
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

Note:

ProviderDetail is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of ProviderDetail corresponding to the set member.

The third-party provider detail for a service configuration.

Defined Under Namespace

Classes: Azure, JiraCloud, ServiceNow, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#azureTypes::AzureDetail

Details about a Microsoft Azure CSPM integration.

Returns:



30102
30103
30104
30105
30106
30107
30108
30109
30110
30111
30112
30113
30114
30115
# File 'lib/aws-sdk-securityhub/types.rb', line 30102

class ProviderDetail < Struct.new(
  :jira_cloud,
  :service_now,
  :azure,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class JiraCloud < ProviderDetail; end
  class ServiceNow < ProviderDetail; end
  class Azure < ProviderDetail; end
  class Unknown < ProviderDetail; end
end

#jira_cloudTypes::JiraCloudDetail

Details about a Jira Cloud integration.



30102
30103
30104
30105
30106
30107
30108
30109
30110
30111
30112
30113
30114
30115
# File 'lib/aws-sdk-securityhub/types.rb', line 30102

class ProviderDetail < Struct.new(
  :jira_cloud,
  :service_now,
  :azure,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class JiraCloud < ProviderDetail; end
  class ServiceNow < ProviderDetail; end
  class Azure < ProviderDetail; end
  class Unknown < ProviderDetail; end
end

#service_nowTypes::ServiceNowDetail

Details about a ServiceNow ITSM integration.



30102
30103
30104
30105
30106
30107
30108
30109
30110
30111
30112
30113
30114
30115
# File 'lib/aws-sdk-securityhub/types.rb', line 30102

class ProviderDetail < Struct.new(
  :jira_cloud,
  :service_now,
  :azure,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class JiraCloud < ProviderDetail; end
  class ServiceNow < ProviderDetail; end
  class Azure < ProviderDetail; end
  class Unknown < ProviderDetail; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



30102
30103
30104
# File 'lib/aws-sdk-securityhub/types.rb', line 30102

def unknown
  @unknown
end