Class: Aws::SecurityHub::Types::ProviderDetail

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure, Aws::Structure::Union
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

Note:

ProviderDetail is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of ProviderDetail corresponding to the set member.

The third-party provider detail for a service configuration.

Defined Under Namespace

Classes: Azure, JiraCloud, ServiceNow, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#azureTypes::AzureDetail

Details about a Microsoft Azure CSPM integration.

Returns:



30001
30002
30003
30004
30005
30006
30007
30008
30009
30010
30011
30012
30013
30014
# File 'lib/aws-sdk-securityhub/types.rb', line 30001

class ProviderDetail < Struct.new(
  :jira_cloud,
  :service_now,
  :azure,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class JiraCloud < ProviderDetail; end
  class ServiceNow < ProviderDetail; end
  class Azure < ProviderDetail; end
  class Unknown < ProviderDetail; end
end

#jira_cloudTypes::JiraCloudDetail

Details about a Jira Cloud integration.



30001
30002
30003
30004
30005
30006
30007
30008
30009
30010
30011
30012
30013
30014
# File 'lib/aws-sdk-securityhub/types.rb', line 30001

class ProviderDetail < Struct.new(
  :jira_cloud,
  :service_now,
  :azure,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class JiraCloud < ProviderDetail; end
  class ServiceNow < ProviderDetail; end
  class Azure < ProviderDetail; end
  class Unknown < ProviderDetail; end
end

#service_nowTypes::ServiceNowDetail

Details about a ServiceNow ITSM integration.



30001
30002
30003
30004
30005
30006
30007
30008
30009
30010
30011
30012
30013
30014
# File 'lib/aws-sdk-securityhub/types.rb', line 30001

class ProviderDetail < Struct.new(
  :jira_cloud,
  :service_now,
  :azure,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class JiraCloud < ProviderDetail; end
  class ServiceNow < ProviderDetail; end
  class Azure < ProviderDetail; end
  class Unknown < ProviderDetail; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



30001
30002
30003
# File 'lib/aws-sdk-securityhub/types.rb', line 30001

def unknown
  @unknown
end