Class: Aws::SecurityHub::Types::ProviderDetail
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::ProviderDetail
- Includes:
- Aws::Structure, Aws::Structure::Union
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Note:
ProviderDetail is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of ProviderDetail corresponding to the set member.
The third-party provider detail for a service configuration.
Direct Known Subclasses
Defined Under Namespace
Classes: JiraCloud, ServiceNow, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#jira_cloud ⇒ Types::JiraCloudDetail
Details about a Jira Cloud integration.
-
#service_now ⇒ Types::ServiceNowDetail
Details about a ServiceNow ITSM integration.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#jira_cloud ⇒ Types::JiraCloudDetail
Details about a Jira Cloud integration.
29287 29288 29289 29290 29291 29292 29293 29294 29295 29296 29297 29298 |
# File 'lib/aws-sdk-securityhub/types.rb', line 29287 class ProviderDetail < Struct.new( :jira_cloud, :service_now, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class JiraCloud < ProviderDetail; end class ServiceNow < ProviderDetail; end class Unknown < ProviderDetail; end end |
#service_now ⇒ Types::ServiceNowDetail
Details about a ServiceNow ITSM integration.
29287 29288 29289 29290 29291 29292 29293 29294 29295 29296 29297 29298 |
# File 'lib/aws-sdk-securityhub/types.rb', line 29287 class ProviderDetail < Struct.new( :jira_cloud, :service_now, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class JiraCloud < ProviderDetail; end class ServiceNow < ProviderDetail; end class Unknown < ProviderDetail; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
29287 29288 29289 |
# File 'lib/aws-sdk-securityhub/types.rb', line 29287 def unknown @unknown end |