Class: Aws::SecurityHub::Types::ProviderUpdateConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure, Aws::Structure::Union
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

Note:

ProviderUpdateConfiguration is a union - when making an API calls you must set exactly one of the members.

The parameters required to update the configuration of an integration provider.

Defined Under Namespace

Classes: Azure, JiraCloud, ServiceNow, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#azureTypes::AzureUpdateConfiguration

The parameters required to update the configuration for a Microsoft Azure CSPM integration.



30163
30164
30165
30166
30167
30168
30169
30170
30171
30172
30173
30174
30175
30176
# File 'lib/aws-sdk-securityhub/types.rb', line 30163

class ProviderUpdateConfiguration < Struct.new(
  :jira_cloud,
  :service_now,
  :azure,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class JiraCloud < ProviderUpdateConfiguration; end
  class ServiceNow < ProviderUpdateConfiguration; end
  class Azure < ProviderUpdateConfiguration; end
  class Unknown < ProviderUpdateConfiguration; end
end

#jira_cloudTypes::JiraCloudUpdateConfiguration

The parameters required to update the configuration for a Jira Cloud integration.



30163
30164
30165
30166
30167
30168
30169
30170
30171
30172
30173
30174
30175
30176
# File 'lib/aws-sdk-securityhub/types.rb', line 30163

class ProviderUpdateConfiguration < Struct.new(
  :jira_cloud,
  :service_now,
  :azure,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class JiraCloud < ProviderUpdateConfiguration; end
  class ServiceNow < ProviderUpdateConfiguration; end
  class Azure < ProviderUpdateConfiguration; end
  class Unknown < ProviderUpdateConfiguration; end
end

#service_nowTypes::ServiceNowUpdateConfiguration

The parameters required to update the configuration for a ServiceNow integration.



30163
30164
30165
30166
30167
30168
30169
30170
30171
30172
30173
30174
30175
30176
# File 'lib/aws-sdk-securityhub/types.rb', line 30163

class ProviderUpdateConfiguration < Struct.new(
  :jira_cloud,
  :service_now,
  :azure,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class JiraCloud < ProviderUpdateConfiguration; end
  class ServiceNow < ProviderUpdateConfiguration; end
  class Azure < ProviderUpdateConfiguration; end
  class Unknown < ProviderUpdateConfiguration; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



30163
30164
30165
# File 'lib/aws-sdk-securityhub/types.rb', line 30163

def unknown
  @unknown
end