Class: Aws::SecurityHub::Types::ProviderUpdateConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::ProviderUpdateConfiguration
- Includes:
- Aws::Structure, Aws::Structure::Union
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
ProviderUpdateConfiguration is a union - when making an API calls you must set exactly one of the members.
The parameters required to update the configuration of an integration provider.
Defined Under Namespace
Classes: Azure, JiraCloud, ServiceNow, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#azure ⇒ Types::AzureUpdateConfiguration
The parameters required to update the configuration for a Microsoft Azure CSPM integration.
-
#jira_cloud ⇒ Types::JiraCloudUpdateConfiguration
The parameters required to update the configuration for a Jira Cloud integration.
-
#service_now ⇒ Types::ServiceNowUpdateConfiguration
The parameters required to update the configuration for a ServiceNow integration.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#azure ⇒ Types::AzureUpdateConfiguration
The parameters required to update the configuration for a Microsoft Azure CSPM integration.
30163 30164 30165 30166 30167 30168 30169 30170 30171 30172 30173 30174 30175 30176 |
# File 'lib/aws-sdk-securityhub/types.rb', line 30163 class ProviderUpdateConfiguration < Struct.new( :jira_cloud, :service_now, :azure, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class JiraCloud < ProviderUpdateConfiguration; end class ServiceNow < ProviderUpdateConfiguration; end class Azure < ProviderUpdateConfiguration; end class Unknown < ProviderUpdateConfiguration; end end |
#jira_cloud ⇒ Types::JiraCloudUpdateConfiguration
The parameters required to update the configuration for a Jira Cloud integration.
30163 30164 30165 30166 30167 30168 30169 30170 30171 30172 30173 30174 30175 30176 |
# File 'lib/aws-sdk-securityhub/types.rb', line 30163 class ProviderUpdateConfiguration < Struct.new( :jira_cloud, :service_now, :azure, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class JiraCloud < ProviderUpdateConfiguration; end class ServiceNow < ProviderUpdateConfiguration; end class Azure < ProviderUpdateConfiguration; end class Unknown < ProviderUpdateConfiguration; end end |
#service_now ⇒ Types::ServiceNowUpdateConfiguration
The parameters required to update the configuration for a ServiceNow integration.
30163 30164 30165 30166 30167 30168 30169 30170 30171 30172 30173 30174 30175 30176 |
# File 'lib/aws-sdk-securityhub/types.rb', line 30163 class ProviderUpdateConfiguration < Struct.new( :jira_cloud, :service_now, :azure, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class JiraCloud < ProviderUpdateConfiguration; end class ServiceNow < ProviderUpdateConfiguration; end class Azure < ProviderUpdateConfiguration; end class Unknown < ProviderUpdateConfiguration; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
30163 30164 30165 |
# File 'lib/aws-sdk-securityhub/types.rb', line 30163 def unknown @unknown end |