Class: Aws::SecurityHub::Types::ProviderUpdateConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::ProviderUpdateConfiguration
- Includes:
- Aws::Structure, Aws::Structure::Union
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
ProviderUpdateConfiguration is a union - when making an API calls you must set exactly one of the members.
The parameters required to update the configuration of an integration provider.
Defined Under Namespace
Classes: Azure, JiraCloud, ServiceNow, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#azure ⇒ Types::AzureUpdateConfiguration
The parameters required to update the configuration for a Microsoft Azure CSPM integration.
-
#jira_cloud ⇒ Types::JiraCloudUpdateConfiguration
The parameters required to update the configuration for a Jira Cloud integration.
-
#service_now ⇒ Types::ServiceNowUpdateConfiguration
The parameters required to update the configuration for a ServiceNow integration.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#azure ⇒ Types::AzureUpdateConfiguration
The parameters required to update the configuration for a Microsoft Azure CSPM integration.
30062 30063 30064 30065 30066 30067 30068 30069 30070 30071 30072 30073 30074 30075 |
# File 'lib/aws-sdk-securityhub/types.rb', line 30062 class ProviderUpdateConfiguration < Struct.new( :jira_cloud, :service_now, :azure, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class JiraCloud < ProviderUpdateConfiguration; end class ServiceNow < ProviderUpdateConfiguration; end class Azure < ProviderUpdateConfiguration; end class Unknown < ProviderUpdateConfiguration; end end |
#jira_cloud ⇒ Types::JiraCloudUpdateConfiguration
The parameters required to update the configuration for a Jira Cloud integration.
30062 30063 30064 30065 30066 30067 30068 30069 30070 30071 30072 30073 30074 30075 |
# File 'lib/aws-sdk-securityhub/types.rb', line 30062 class ProviderUpdateConfiguration < Struct.new( :jira_cloud, :service_now, :azure, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class JiraCloud < ProviderUpdateConfiguration; end class ServiceNow < ProviderUpdateConfiguration; end class Azure < ProviderUpdateConfiguration; end class Unknown < ProviderUpdateConfiguration; end end |
#service_now ⇒ Types::ServiceNowUpdateConfiguration
The parameters required to update the configuration for a ServiceNow integration.
30062 30063 30064 30065 30066 30067 30068 30069 30070 30071 30072 30073 30074 30075 |
# File 'lib/aws-sdk-securityhub/types.rb', line 30062 class ProviderUpdateConfiguration < Struct.new( :jira_cloud, :service_now, :azure, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class JiraCloud < ProviderUpdateConfiguration; end class ServiceNow < ProviderUpdateConfiguration; end class Azure < ProviderUpdateConfiguration; end class Unknown < ProviderUpdateConfiguration; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
30062 30063 30064 |
# File 'lib/aws-sdk-securityhub/types.rb', line 30062 def unknown @unknown end |