Class: Aws::SecurityHub::Types::ProviderUpdateConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure, Aws::Structure::Union
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

Note:

ProviderUpdateConfiguration is a union - when making an API calls you must set exactly one of the members.

The parameters required to update the configuration of an integration provider.

Direct Known Subclasses

JiraCloud, ServiceNow, Unknown

Defined Under Namespace

Classes: JiraCloud, ServiceNow, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#jira_cloudTypes::JiraCloudUpdateConfiguration

The parameters required to update the configuration for a Jira Cloud integration.



29336
29337
29338
29339
29340
29341
29342
29343
29344
29345
29346
29347
# File 'lib/aws-sdk-securityhub/types.rb', line 29336

class ProviderUpdateConfiguration < Struct.new(
  :jira_cloud,
  :service_now,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class JiraCloud < ProviderUpdateConfiguration; end
  class ServiceNow < ProviderUpdateConfiguration; end
  class Unknown < ProviderUpdateConfiguration; end
end

#service_nowTypes::ServiceNowUpdateConfiguration

The parameters required to update the configuration for a ServiceNow integration.



29336
29337
29338
29339
29340
29341
29342
29343
29344
29345
29346
29347
# File 'lib/aws-sdk-securityhub/types.rb', line 29336

class ProviderUpdateConfiguration < Struct.new(
  :jira_cloud,
  :service_now,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class JiraCloud < ProviderUpdateConfiguration; end
  class ServiceNow < ProviderUpdateConfiguration; end
  class Unknown < ProviderUpdateConfiguration; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



29336
29337
29338
# File 'lib/aws-sdk-securityhub/types.rb', line 29336

def unknown
  @unknown
end