Class: Aws::SecurityHub::Types::RecommendationError
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::RecommendationError
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Contains information about the reason that the retrieval of a recommended policy for a finding failed.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#code ⇒ String
The error code for a failed retrieval of a recommended policy for a finding.
-
#message ⇒ String
The error message for a failed retrieval of a recommended policy for a finding.
Instance Attribute Details
#code ⇒ String
The error code for a failed retrieval of a recommended policy for a finding.
29417 29418 29419 29420 29421 29422 |
# File 'lib/aws-sdk-securityhub/types.rb', line 29417 class RecommendationError < Struct.new( :code, :message) SENSITIVE = [] include Aws::Structure end |
#message ⇒ String
The error message for a failed retrieval of a recommended policy for a finding.
29417 29418 29419 29420 29421 29422 |
# File 'lib/aws-sdk-securityhub/types.rb', line 29417 class RecommendationError < Struct.new( :code, :message) SENSITIVE = [] include Aws::Structure end |