Class: Aws::SecurityHub::Types::ResourceOwnerAccount
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::ResourceOwnerAccount
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Information about the account that owns a resource, for example, an Azure Subscription or Amazon Web Services Account.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#id ⇒ String
The unique identifier of the account that owns the resource, for example, Azure Subscription Id or Amazon Web Services Account Id.
Instance Attribute Details
#id ⇒ String
The unique identifier of the account that owns the resource, for example, Azure Subscription Id or Amazon Web Services Account Id.
31086 31087 31088 31089 31090 |
# File 'lib/aws-sdk-securityhub/types.rb', line 31086 class ResourceOwnerAccount < Struct.new( :id) SENSITIVE = [] include Aws::Structure end |