Class: Aws::SecurityHub::Types::ResourceOwnerOrg
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::ResourceOwnerOrg
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Information about the organization that owns a resource, for example, an Azure Tenant.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#id ⇒ String
The unique identifier of the organization that owns the resource, for example, Azure Tenant Id.
Instance Attribute Details
#id ⇒ String
The unique identifier of the organization that owns the resource, for example, Azure Tenant Id.
31102 31103 31104 31105 31106 |
# File 'lib/aws-sdk-securityhub/types.rb', line 31102 class ResourceOwnerOrg < Struct.new( :id) SENSITIVE = [] include Aws::Structure end |