Class: Aws::SecurityHub::Types::ResourceResult

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

Provides comprehensive details about an Amazon Web Services resource and its associated security findings.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#account_idString

The Amazon Web Services account that recorded the resource data in Security Hub.

Returns:

  • (String)


31336
31337
31338
31339
31340
31341
31342
31343
31344
31345
31346
31347
31348
31349
31350
31351
31352
31353
31354
31355
31356
31357
31358
31359
31360
# File 'lib/aws-sdk-securityhub/types.rb', line 31336

class ResourceResult < Struct.new(
  :resource_guid,
  :resource_id,
  :account_id,
  :account_name,
  :region,
  :resource_provider,
  :resource_owner_account_id,
  :resource_owner_org_id,
  :resource_cloud_partition,
  :resource_region,
  :resource_category,
  :resource_type,
  :resource_name,
  :resource_creation_time_dt,
  :resource_detail_capture_time_dt,
  :findings_summary,
  :resource_tags,
  :resource_config,
  :resource_sub_category,
  :discovery_type,
  :resource_info)
  SENSITIVE = []
  include Aws::Structure
end

#account_nameString

The name of the Amazon Web Services account that's associated with the resource.

Returns:

  • (String)


31336
31337
31338
31339
31340
31341
31342
31343
31344
31345
31346
31347
31348
31349
31350
31351
31352
31353
31354
31355
31356
31357
31358
31359
31360
# File 'lib/aws-sdk-securityhub/types.rb', line 31336

class ResourceResult < Struct.new(
  :resource_guid,
  :resource_id,
  :account_id,
  :account_name,
  :region,
  :resource_provider,
  :resource_owner_account_id,
  :resource_owner_org_id,
  :resource_cloud_partition,
  :resource_region,
  :resource_category,
  :resource_type,
  :resource_name,
  :resource_creation_time_dt,
  :resource_detail_capture_time_dt,
  :findings_summary,
  :resource_tags,
  :resource_config,
  :resource_sub_category,
  :discovery_type,
  :resource_info)
  SENSITIVE = []
  include Aws::Structure
end

#discovery_typeString

Specifies how the resource was discovered. If the value is Managed, the resource is natively provided by a cloud service provider. If the value is SelfHosted, the resource is hosted on customer-managed infrastructure, such as a compute instance or container image.

Returns:

  • (String)


31336
31337
31338
31339
31340
31341
31342
31343
31344
31345
31346
31347
31348
31349
31350
31351
31352
31353
31354
31355
31356
31357
31358
31359
31360
# File 'lib/aws-sdk-securityhub/types.rb', line 31336

class ResourceResult < Struct.new(
  :resource_guid,
  :resource_id,
  :account_id,
  :account_name,
  :region,
  :resource_provider,
  :resource_owner_account_id,
  :resource_owner_org_id,
  :resource_cloud_partition,
  :resource_region,
  :resource_category,
  :resource_type,
  :resource_name,
  :resource_creation_time_dt,
  :resource_detail_capture_time_dt,
  :findings_summary,
  :resource_tags,
  :resource_config,
  :resource_sub_category,
  :discovery_type,
  :resource_info)
  SENSITIVE = []
  include Aws::Structure
end

#findings_summaryArray<Types::ResourceFindingsSummary>

An aggregated view of security findings associated with a resource.

Returns:



31336
31337
31338
31339
31340
31341
31342
31343
31344
31345
31346
31347
31348
31349
31350
31351
31352
31353
31354
31355
31356
31357
31358
31359
31360
# File 'lib/aws-sdk-securityhub/types.rb', line 31336

class ResourceResult < Struct.new(
  :resource_guid,
  :resource_id,
  :account_id,
  :account_name,
  :region,
  :resource_provider,
  :resource_owner_account_id,
  :resource_owner_org_id,
  :resource_cloud_partition,
  :resource_region,
  :resource_category,
  :resource_type,
  :resource_name,
  :resource_creation_time_dt,
  :resource_detail_capture_time_dt,
  :findings_summary,
  :resource_tags,
  :resource_config,
  :resource_sub_category,
  :discovery_type,
  :resource_info)
  SENSITIVE = []
  include Aws::Structure
end

#regionString

The Amazon Web Services Region that recorded the resource data in Security Hub.

Returns:

  • (String)


31336
31337
31338
31339
31340
31341
31342
31343
31344
31345
31346
31347
31348
31349
31350
31351
31352
31353
31354
31355
31356
31357
31358
31359
31360
# File 'lib/aws-sdk-securityhub/types.rb', line 31336

class ResourceResult < Struct.new(
  :resource_guid,
  :resource_id,
  :account_id,
  :account_name,
  :region,
  :resource_provider,
  :resource_owner_account_id,
  :resource_owner_org_id,
  :resource_cloud_partition,
  :resource_region,
  :resource_category,
  :resource_type,
  :resource_name,
  :resource_creation_time_dt,
  :resource_detail_capture_time_dt,
  :findings_summary,
  :resource_tags,
  :resource_config,
  :resource_sub_category,
  :discovery_type,
  :resource_info)
  SENSITIVE = []
  include Aws::Structure
end

#resource_categoryString

The grouping where the resource belongs.

Returns:

  • (String)


31336
31337
31338
31339
31340
31341
31342
31343
31344
31345
31346
31347
31348
31349
31350
31351
31352
31353
31354
31355
31356
31357
31358
31359
31360
# File 'lib/aws-sdk-securityhub/types.rb', line 31336

class ResourceResult < Struct.new(
  :resource_guid,
  :resource_id,
  :account_id,
  :account_name,
  :region,
  :resource_provider,
  :resource_owner_account_id,
  :resource_owner_org_id,
  :resource_cloud_partition,
  :resource_region,
  :resource_category,
  :resource_type,
  :resource_name,
  :resource_creation_time_dt,
  :resource_detail_capture_time_dt,
  :findings_summary,
  :resource_tags,
  :resource_config,
  :resource_sub_category,
  :discovery_type,
  :resource_info)
  SENSITIVE = []
  include Aws::Structure
end

#resource_cloud_partitionString

The cloud partition where the resource exists. For Amazon Web Services, valid values include aws, aws-cn, and aws-us-gov. This field isn't returned for cloud providers that don't use partitions.

Returns:

  • (String)


31336
31337
31338
31339
31340
31341
31342
31343
31344
31345
31346
31347
31348
31349
31350
31351
31352
31353
31354
31355
31356
31357
31358
31359
31360
# File 'lib/aws-sdk-securityhub/types.rb', line 31336

class ResourceResult < Struct.new(
  :resource_guid,
  :resource_id,
  :account_id,
  :account_name,
  :region,
  :resource_provider,
  :resource_owner_account_id,
  :resource_owner_org_id,
  :resource_cloud_partition,
  :resource_region,
  :resource_category,
  :resource_type,
  :resource_name,
  :resource_creation_time_dt,
  :resource_detail_capture_time_dt,
  :findings_summary,
  :resource_tags,
  :resource_config,
  :resource_sub_category,
  :discovery_type,
  :resource_info)
  SENSITIVE = []
  include Aws::Structure
end

#resource_configHash, ...

The configuration details of a resource.

Returns:

  • (Hash, Array, String, Numeric, Boolean)


31336
31337
31338
31339
31340
31341
31342
31343
31344
31345
31346
31347
31348
31349
31350
31351
31352
31353
31354
31355
31356
31357
31358
31359
31360
# File 'lib/aws-sdk-securityhub/types.rb', line 31336

class ResourceResult < Struct.new(
  :resource_guid,
  :resource_id,
  :account_id,
  :account_name,
  :region,
  :resource_provider,
  :resource_owner_account_id,
  :resource_owner_org_id,
  :resource_cloud_partition,
  :resource_region,
  :resource_category,
  :resource_type,
  :resource_name,
  :resource_creation_time_dt,
  :resource_detail_capture_time_dt,
  :findings_summary,
  :resource_tags,
  :resource_config,
  :resource_sub_category,
  :discovery_type,
  :resource_info)
  SENSITIVE = []
  include Aws::Structure
end

#resource_creation_time_dtString

The time when the resource was created.

Returns:

  • (String)


31336
31337
31338
31339
31340
31341
31342
31343
31344
31345
31346
31347
31348
31349
31350
31351
31352
31353
31354
31355
31356
31357
31358
31359
31360
# File 'lib/aws-sdk-securityhub/types.rb', line 31336

class ResourceResult < Struct.new(
  :resource_guid,
  :resource_id,
  :account_id,
  :account_name,
  :region,
  :resource_provider,
  :resource_owner_account_id,
  :resource_owner_org_id,
  :resource_cloud_partition,
  :resource_region,
  :resource_category,
  :resource_type,
  :resource_name,
  :resource_creation_time_dt,
  :resource_detail_capture_time_dt,
  :findings_summary,
  :resource_tags,
  :resource_config,
  :resource_sub_category,
  :discovery_type,
  :resource_info)
  SENSITIVE = []
  include Aws::Structure
end

#resource_detail_capture_time_dtString

The timestamp when information about the resource was captured.

Returns:

  • (String)


31336
31337
31338
31339
31340
31341
31342
31343
31344
31345
31346
31347
31348
31349
31350
31351
31352
31353
31354
31355
31356
31357
31358
31359
31360
# File 'lib/aws-sdk-securityhub/types.rb', line 31336

class ResourceResult < Struct.new(
  :resource_guid,
  :resource_id,
  :account_id,
  :account_name,
  :region,
  :resource_provider,
  :resource_owner_account_id,
  :resource_owner_org_id,
  :resource_cloud_partition,
  :resource_region,
  :resource_category,
  :resource_type,
  :resource_name,
  :resource_creation_time_dt,
  :resource_detail_capture_time_dt,
  :findings_summary,
  :resource_tags,
  :resource_config,
  :resource_sub_category,
  :discovery_type,
  :resource_info)
  SENSITIVE = []
  include Aws::Structure
end

#resource_guidString

The global identifier used to identify a resource.

Returns:

  • (String)


31336
31337
31338
31339
31340
31341
31342
31343
31344
31345
31346
31347
31348
31349
31350
31351
31352
31353
31354
31355
31356
31357
31358
31359
31360
# File 'lib/aws-sdk-securityhub/types.rb', line 31336

class ResourceResult < Struct.new(
  :resource_guid,
  :resource_id,
  :account_id,
  :account_name,
  :region,
  :resource_provider,
  :resource_owner_account_id,
  :resource_owner_org_id,
  :resource_cloud_partition,
  :resource_region,
  :resource_category,
  :resource_type,
  :resource_name,
  :resource_creation_time_dt,
  :resource_detail_capture_time_dt,
  :findings_summary,
  :resource_tags,
  :resource_config,
  :resource_sub_category,
  :discovery_type,
  :resource_info)
  SENSITIVE = []
  include Aws::Structure
end

#resource_idString

The unique identifier for a resource.

Returns:

  • (String)


31336
31337
31338
31339
31340
31341
31342
31343
31344
31345
31346
31347
31348
31349
31350
31351
31352
31353
31354
31355
31356
31357
31358
31359
31360
# File 'lib/aws-sdk-securityhub/types.rb', line 31336

class ResourceResult < Struct.new(
  :resource_guid,
  :resource_id,
  :account_id,
  :account_name,
  :region,
  :resource_provider,
  :resource_owner_account_id,
  :resource_owner_org_id,
  :resource_cloud_partition,
  :resource_region,
  :resource_category,
  :resource_type,
  :resource_name,
  :resource_creation_time_dt,
  :resource_detail_capture_time_dt,
  :findings_summary,
  :resource_tags,
  :resource_config,
  :resource_sub_category,
  :discovery_type,
  :resource_info)
  SENSITIVE = []
  include Aws::Structure
end

#resource_infoTypes::ResourceInfo

Additional resource-type-specific details. For self-hosted AI resources and their host resources, contains an AIDetails structure.

Returns:



31336
31337
31338
31339
31340
31341
31342
31343
31344
31345
31346
31347
31348
31349
31350
31351
31352
31353
31354
31355
31356
31357
31358
31359
31360
# File 'lib/aws-sdk-securityhub/types.rb', line 31336

class ResourceResult < Struct.new(
  :resource_guid,
  :resource_id,
  :account_id,
  :account_name,
  :region,
  :resource_provider,
  :resource_owner_account_id,
  :resource_owner_org_id,
  :resource_cloud_partition,
  :resource_region,
  :resource_category,
  :resource_type,
  :resource_name,
  :resource_creation_time_dt,
  :resource_detail_capture_time_dt,
  :findings_summary,
  :resource_tags,
  :resource_config,
  :resource_sub_category,
  :discovery_type,
  :resource_info)
  SENSITIVE = []
  include Aws::Structure
end

#resource_nameString

The name of the resource.

Returns:

  • (String)


31336
31337
31338
31339
31340
31341
31342
31343
31344
31345
31346
31347
31348
31349
31350
31351
31352
31353
31354
31355
31356
31357
31358
31359
31360
# File 'lib/aws-sdk-securityhub/types.rb', line 31336

class ResourceResult < Struct.new(
  :resource_guid,
  :resource_id,
  :account_id,
  :account_name,
  :region,
  :resource_provider,
  :resource_owner_account_id,
  :resource_owner_org_id,
  :resource_cloud_partition,
  :resource_region,
  :resource_category,
  :resource_type,
  :resource_name,
  :resource_creation_time_dt,
  :resource_detail_capture_time_dt,
  :findings_summary,
  :resource_tags,
  :resource_config,
  :resource_sub_category,
  :discovery_type,
  :resource_info)
  SENSITIVE = []
  include Aws::Structure
end

#resource_owner_account_idString

The identifier of the cloud account that owns the resource. For Amazon Web Services resources, this is the Amazon Web Services account ID. For Azure resources, this is the Azure subscription ID.

Returns:

  • (String)


31336
31337
31338
31339
31340
31341
31342
31343
31344
31345
31346
31347
31348
31349
31350
31351
31352
31353
31354
31355
31356
31357
31358
31359
31360
# File 'lib/aws-sdk-securityhub/types.rb', line 31336

class ResourceResult < Struct.new(
  :resource_guid,
  :resource_id,
  :account_id,
  :account_name,
  :region,
  :resource_provider,
  :resource_owner_account_id,
  :resource_owner_org_id,
  :resource_cloud_partition,
  :resource_region,
  :resource_category,
  :resource_type,
  :resource_name,
  :resource_creation_time_dt,
  :resource_detail_capture_time_dt,
  :findings_summary,
  :resource_tags,
  :resource_config,
  :resource_sub_category,
  :discovery_type,
  :resource_info)
  SENSITIVE = []
  include Aws::Structure
end

#resource_owner_org_idString

The identifier of the cloud organization that owns the resource. For Amazon Web Services resources, this is the Organizations ID. For Azure resources, this is the Azure tenant ID.

Returns:

  • (String)


31336
31337
31338
31339
31340
31341
31342
31343
31344
31345
31346
31347
31348
31349
31350
31351
31352
31353
31354
31355
31356
31357
31358
31359
31360
# File 'lib/aws-sdk-securityhub/types.rb', line 31336

class ResourceResult < Struct.new(
  :resource_guid,
  :resource_id,
  :account_id,
  :account_name,
  :region,
  :resource_provider,
  :resource_owner_account_id,
  :resource_owner_org_id,
  :resource_cloud_partition,
  :resource_region,
  :resource_category,
  :resource_type,
  :resource_name,
  :resource_creation_time_dt,
  :resource_detail_capture_time_dt,
  :findings_summary,
  :resource_tags,
  :resource_config,
  :resource_sub_category,
  :discovery_type,
  :resource_info)
  SENSITIVE = []
  include Aws::Structure
end

#resource_providerString

The cloud provider where the resource exists. Valid values are AWS and Azure. This field is always included.

Returns:

  • (String)


31336
31337
31338
31339
31340
31341
31342
31343
31344
31345
31346
31347
31348
31349
31350
31351
31352
31353
31354
31355
31356
31357
31358
31359
31360
# File 'lib/aws-sdk-securityhub/types.rb', line 31336

class ResourceResult < Struct.new(
  :resource_guid,
  :resource_id,
  :account_id,
  :account_name,
  :region,
  :resource_provider,
  :resource_owner_account_id,
  :resource_owner_org_id,
  :resource_cloud_partition,
  :resource_region,
  :resource_category,
  :resource_type,
  :resource_name,
  :resource_creation_time_dt,
  :resource_detail_capture_time_dt,
  :findings_summary,
  :resource_tags,
  :resource_config,
  :resource_sub_category,
  :discovery_type,
  :resource_info)
  SENSITIVE = []
  include Aws::Structure
end

#resource_regionString

The native cloud region where the resource is located. For Amazon Web Services, this is an Amazon Web Services Region (for example, us-east-1). For Azure resources, this is the Azure region (for example, westus2). This field is always included.

Returns:

  • (String)


31336
31337
31338
31339
31340
31341
31342
31343
31344
31345
31346
31347
31348
31349
31350
31351
31352
31353
31354
31355
31356
31357
31358
31359
31360
# File 'lib/aws-sdk-securityhub/types.rb', line 31336

class ResourceResult < Struct.new(
  :resource_guid,
  :resource_id,
  :account_id,
  :account_name,
  :region,
  :resource_provider,
  :resource_owner_account_id,
  :resource_owner_org_id,
  :resource_cloud_partition,
  :resource_region,
  :resource_category,
  :resource_type,
  :resource_name,
  :resource_creation_time_dt,
  :resource_detail_capture_time_dt,
  :findings_summary,
  :resource_tags,
  :resource_config,
  :resource_sub_category,
  :discovery_type,
  :resource_info)
  SENSITIVE = []
  include Aws::Structure
end

#resource_sub_categoryString

The AI/ML sub-grouping of the resource. Present only when ResourceCategory is AI/ML.

Returns:

  • (String)


31336
31337
31338
31339
31340
31341
31342
31343
31344
31345
31346
31347
31348
31349
31350
31351
31352
31353
31354
31355
31356
31357
31358
31359
31360
# File 'lib/aws-sdk-securityhub/types.rb', line 31336

class ResourceResult < Struct.new(
  :resource_guid,
  :resource_id,
  :account_id,
  :account_name,
  :region,
  :resource_provider,
  :resource_owner_account_id,
  :resource_owner_org_id,
  :resource_cloud_partition,
  :resource_region,
  :resource_category,
  :resource_type,
  :resource_name,
  :resource_creation_time_dt,
  :resource_detail_capture_time_dt,
  :findings_summary,
  :resource_tags,
  :resource_config,
  :resource_sub_category,
  :discovery_type,
  :resource_info)
  SENSITIVE = []
  include Aws::Structure
end

#resource_tagsArray<Types::ResourceTag>

The key-value pairs associated with a resource.

Returns:



31336
31337
31338
31339
31340
31341
31342
31343
31344
31345
31346
31347
31348
31349
31350
31351
31352
31353
31354
31355
31356
31357
31358
31359
31360
# File 'lib/aws-sdk-securityhub/types.rb', line 31336

class ResourceResult < Struct.new(
  :resource_guid,
  :resource_id,
  :account_id,
  :account_name,
  :region,
  :resource_provider,
  :resource_owner_account_id,
  :resource_owner_org_id,
  :resource_cloud_partition,
  :resource_region,
  :resource_category,
  :resource_type,
  :resource_name,
  :resource_creation_time_dt,
  :resource_detail_capture_time_dt,
  :findings_summary,
  :resource_tags,
  :resource_config,
  :resource_sub_category,
  :discovery_type,
  :resource_info)
  SENSITIVE = []
  include Aws::Structure
end

#resource_typeString

The type of resource.

Returns:

  • (String)


31336
31337
31338
31339
31340
31341
31342
31343
31344
31345
31346
31347
31348
31349
31350
31351
31352
31353
31354
31355
31356
31357
31358
31359
31360
# File 'lib/aws-sdk-securityhub/types.rb', line 31336

class ResourceResult < Struct.new(
  :resource_guid,
  :resource_id,
  :account_id,
  :account_name,
  :region,
  :resource_provider,
  :resource_owner_account_id,
  :resource_owner_org_id,
  :resource_cloud_partition,
  :resource_region,
  :resource_category,
  :resource_type,
  :resource_name,
  :resource_creation_time_dt,
  :resource_detail_capture_time_dt,
  :findings_summary,
  :resource_tags,
  :resource_config,
  :resource_sub_category,
  :discovery_type,
  :resource_info)
  SENSITIVE = []
  include Aws::Structure
end