Class: Aws::SecurityHub::Types::ResourceResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::ResourceResult
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Provides comprehensive details about an Amazon Web Services resource and its associated security findings.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#account_id ⇒ String
The Amazon Web Services account that recorded the resource data in Security Hub.
-
#account_name ⇒ String
The name of the Amazon Web Services account that's associated with the resource.
-
#discovery_type ⇒ String
Specifies how the resource was discovered.
-
#findings_summary ⇒ Array<Types::ResourceFindingsSummary>
An aggregated view of security findings associated with a resource.
-
#region ⇒ String
The Amazon Web Services Region that recorded the resource data in Security Hub.
-
#resource_category ⇒ String
The grouping where the resource belongs.
-
#resource_cloud_partition ⇒ String
The cloud partition where the resource exists.
-
#resource_config ⇒ Hash, ...
The configuration details of a resource.
-
#resource_creation_time_dt ⇒ String
The time when the resource was created.
-
#resource_detail_capture_time_dt ⇒ String
The timestamp when information about the resource was captured.
-
#resource_guid ⇒ String
The global identifier used to identify a resource.
-
#resource_id ⇒ String
The unique identifier for a resource.
-
#resource_info ⇒ Types::ResourceInfo
Additional resource-type-specific details.
-
#resource_name ⇒ String
The name of the resource.
-
#resource_owner_account_id ⇒ String
The identifier of the cloud account that owns the resource.
-
#resource_owner_org_id ⇒ String
The identifier of the cloud organization that owns the resource.
-
#resource_provider ⇒ String
The cloud provider where the resource exists.
-
#resource_region ⇒ String
The native cloud region where the resource is located.
-
#resource_sub_category ⇒ String
The AI/ML sub-grouping of the resource.
-
#resource_tags ⇒ Array<Types::ResourceTag>
The key-value pairs associated with a resource.
-
#resource_type ⇒ String
The type of resource.
Instance Attribute Details
#account_id ⇒ String
The Amazon Web Services account that recorded the resource data in Security Hub.
31336 31337 31338 31339 31340 31341 31342 31343 31344 31345 31346 31347 31348 31349 31350 31351 31352 31353 31354 31355 31356 31357 31358 31359 31360 |
# File 'lib/aws-sdk-securityhub/types.rb', line 31336 class ResourceResult < Struct.new( :resource_guid, :resource_id, :account_id, :account_name, :region, :resource_provider, :resource_owner_account_id, :resource_owner_org_id, :resource_cloud_partition, :resource_region, :resource_category, :resource_type, :resource_name, :resource_creation_time_dt, :resource_detail_capture_time_dt, :findings_summary, :resource_tags, :resource_config, :resource_sub_category, :discovery_type, :resource_info) SENSITIVE = [] include Aws::Structure end |
#account_name ⇒ String
The name of the Amazon Web Services account that's associated with the resource.
31336 31337 31338 31339 31340 31341 31342 31343 31344 31345 31346 31347 31348 31349 31350 31351 31352 31353 31354 31355 31356 31357 31358 31359 31360 |
# File 'lib/aws-sdk-securityhub/types.rb', line 31336 class ResourceResult < Struct.new( :resource_guid, :resource_id, :account_id, :account_name, :region, :resource_provider, :resource_owner_account_id, :resource_owner_org_id, :resource_cloud_partition, :resource_region, :resource_category, :resource_type, :resource_name, :resource_creation_time_dt, :resource_detail_capture_time_dt, :findings_summary, :resource_tags, :resource_config, :resource_sub_category, :discovery_type, :resource_info) SENSITIVE = [] include Aws::Structure end |
#discovery_type ⇒ String
Specifies how the resource was discovered. If the value is
Managed, the resource is natively provided by a cloud service
provider. If the value is SelfHosted, the resource is hosted on
customer-managed infrastructure, such as a compute instance or
container image.
31336 31337 31338 31339 31340 31341 31342 31343 31344 31345 31346 31347 31348 31349 31350 31351 31352 31353 31354 31355 31356 31357 31358 31359 31360 |
# File 'lib/aws-sdk-securityhub/types.rb', line 31336 class ResourceResult < Struct.new( :resource_guid, :resource_id, :account_id, :account_name, :region, :resource_provider, :resource_owner_account_id, :resource_owner_org_id, :resource_cloud_partition, :resource_region, :resource_category, :resource_type, :resource_name, :resource_creation_time_dt, :resource_detail_capture_time_dt, :findings_summary, :resource_tags, :resource_config, :resource_sub_category, :discovery_type, :resource_info) SENSITIVE = [] include Aws::Structure end |
#findings_summary ⇒ Array<Types::ResourceFindingsSummary>
An aggregated view of security findings associated with a resource.
31336 31337 31338 31339 31340 31341 31342 31343 31344 31345 31346 31347 31348 31349 31350 31351 31352 31353 31354 31355 31356 31357 31358 31359 31360 |
# File 'lib/aws-sdk-securityhub/types.rb', line 31336 class ResourceResult < Struct.new( :resource_guid, :resource_id, :account_id, :account_name, :region, :resource_provider, :resource_owner_account_id, :resource_owner_org_id, :resource_cloud_partition, :resource_region, :resource_category, :resource_type, :resource_name, :resource_creation_time_dt, :resource_detail_capture_time_dt, :findings_summary, :resource_tags, :resource_config, :resource_sub_category, :discovery_type, :resource_info) SENSITIVE = [] include Aws::Structure end |
#region ⇒ String
The Amazon Web Services Region that recorded the resource data in Security Hub.
31336 31337 31338 31339 31340 31341 31342 31343 31344 31345 31346 31347 31348 31349 31350 31351 31352 31353 31354 31355 31356 31357 31358 31359 31360 |
# File 'lib/aws-sdk-securityhub/types.rb', line 31336 class ResourceResult < Struct.new( :resource_guid, :resource_id, :account_id, :account_name, :region, :resource_provider, :resource_owner_account_id, :resource_owner_org_id, :resource_cloud_partition, :resource_region, :resource_category, :resource_type, :resource_name, :resource_creation_time_dt, :resource_detail_capture_time_dt, :findings_summary, :resource_tags, :resource_config, :resource_sub_category, :discovery_type, :resource_info) SENSITIVE = [] include Aws::Structure end |
#resource_category ⇒ String
The grouping where the resource belongs.
31336 31337 31338 31339 31340 31341 31342 31343 31344 31345 31346 31347 31348 31349 31350 31351 31352 31353 31354 31355 31356 31357 31358 31359 31360 |
# File 'lib/aws-sdk-securityhub/types.rb', line 31336 class ResourceResult < Struct.new( :resource_guid, :resource_id, :account_id, :account_name, :region, :resource_provider, :resource_owner_account_id, :resource_owner_org_id, :resource_cloud_partition, :resource_region, :resource_category, :resource_type, :resource_name, :resource_creation_time_dt, :resource_detail_capture_time_dt, :findings_summary, :resource_tags, :resource_config, :resource_sub_category, :discovery_type, :resource_info) SENSITIVE = [] include Aws::Structure end |
#resource_cloud_partition ⇒ String
The cloud partition where the resource exists. For Amazon Web
Services, valid values include aws, aws-cn, and aws-us-gov.
This field isn't returned for cloud providers that don't use
partitions.
31336 31337 31338 31339 31340 31341 31342 31343 31344 31345 31346 31347 31348 31349 31350 31351 31352 31353 31354 31355 31356 31357 31358 31359 31360 |
# File 'lib/aws-sdk-securityhub/types.rb', line 31336 class ResourceResult < Struct.new( :resource_guid, :resource_id, :account_id, :account_name, :region, :resource_provider, :resource_owner_account_id, :resource_owner_org_id, :resource_cloud_partition, :resource_region, :resource_category, :resource_type, :resource_name, :resource_creation_time_dt, :resource_detail_capture_time_dt, :findings_summary, :resource_tags, :resource_config, :resource_sub_category, :discovery_type, :resource_info) SENSITIVE = [] include Aws::Structure end |
#resource_config ⇒ Hash, ...
The configuration details of a resource.
31336 31337 31338 31339 31340 31341 31342 31343 31344 31345 31346 31347 31348 31349 31350 31351 31352 31353 31354 31355 31356 31357 31358 31359 31360 |
# File 'lib/aws-sdk-securityhub/types.rb', line 31336 class ResourceResult < Struct.new( :resource_guid, :resource_id, :account_id, :account_name, :region, :resource_provider, :resource_owner_account_id, :resource_owner_org_id, :resource_cloud_partition, :resource_region, :resource_category, :resource_type, :resource_name, :resource_creation_time_dt, :resource_detail_capture_time_dt, :findings_summary, :resource_tags, :resource_config, :resource_sub_category, :discovery_type, :resource_info) SENSITIVE = [] include Aws::Structure end |
#resource_creation_time_dt ⇒ String
The time when the resource was created.
31336 31337 31338 31339 31340 31341 31342 31343 31344 31345 31346 31347 31348 31349 31350 31351 31352 31353 31354 31355 31356 31357 31358 31359 31360 |
# File 'lib/aws-sdk-securityhub/types.rb', line 31336 class ResourceResult < Struct.new( :resource_guid, :resource_id, :account_id, :account_name, :region, :resource_provider, :resource_owner_account_id, :resource_owner_org_id, :resource_cloud_partition, :resource_region, :resource_category, :resource_type, :resource_name, :resource_creation_time_dt, :resource_detail_capture_time_dt, :findings_summary, :resource_tags, :resource_config, :resource_sub_category, :discovery_type, :resource_info) SENSITIVE = [] include Aws::Structure end |
#resource_detail_capture_time_dt ⇒ String
The timestamp when information about the resource was captured.
31336 31337 31338 31339 31340 31341 31342 31343 31344 31345 31346 31347 31348 31349 31350 31351 31352 31353 31354 31355 31356 31357 31358 31359 31360 |
# File 'lib/aws-sdk-securityhub/types.rb', line 31336 class ResourceResult < Struct.new( :resource_guid, :resource_id, :account_id, :account_name, :region, :resource_provider, :resource_owner_account_id, :resource_owner_org_id, :resource_cloud_partition, :resource_region, :resource_category, :resource_type, :resource_name, :resource_creation_time_dt, :resource_detail_capture_time_dt, :findings_summary, :resource_tags, :resource_config, :resource_sub_category, :discovery_type, :resource_info) SENSITIVE = [] include Aws::Structure end |
#resource_guid ⇒ String
The global identifier used to identify a resource.
31336 31337 31338 31339 31340 31341 31342 31343 31344 31345 31346 31347 31348 31349 31350 31351 31352 31353 31354 31355 31356 31357 31358 31359 31360 |
# File 'lib/aws-sdk-securityhub/types.rb', line 31336 class ResourceResult < Struct.new( :resource_guid, :resource_id, :account_id, :account_name, :region, :resource_provider, :resource_owner_account_id, :resource_owner_org_id, :resource_cloud_partition, :resource_region, :resource_category, :resource_type, :resource_name, :resource_creation_time_dt, :resource_detail_capture_time_dt, :findings_summary, :resource_tags, :resource_config, :resource_sub_category, :discovery_type, :resource_info) SENSITIVE = [] include Aws::Structure end |
#resource_id ⇒ String
The unique identifier for a resource.
31336 31337 31338 31339 31340 31341 31342 31343 31344 31345 31346 31347 31348 31349 31350 31351 31352 31353 31354 31355 31356 31357 31358 31359 31360 |
# File 'lib/aws-sdk-securityhub/types.rb', line 31336 class ResourceResult < Struct.new( :resource_guid, :resource_id, :account_id, :account_name, :region, :resource_provider, :resource_owner_account_id, :resource_owner_org_id, :resource_cloud_partition, :resource_region, :resource_category, :resource_type, :resource_name, :resource_creation_time_dt, :resource_detail_capture_time_dt, :findings_summary, :resource_tags, :resource_config, :resource_sub_category, :discovery_type, :resource_info) SENSITIVE = [] include Aws::Structure end |
#resource_info ⇒ Types::ResourceInfo
Additional resource-type-specific details. For self-hosted AI
resources and their host resources, contains an AIDetails
structure.
31336 31337 31338 31339 31340 31341 31342 31343 31344 31345 31346 31347 31348 31349 31350 31351 31352 31353 31354 31355 31356 31357 31358 31359 31360 |
# File 'lib/aws-sdk-securityhub/types.rb', line 31336 class ResourceResult < Struct.new( :resource_guid, :resource_id, :account_id, :account_name, :region, :resource_provider, :resource_owner_account_id, :resource_owner_org_id, :resource_cloud_partition, :resource_region, :resource_category, :resource_type, :resource_name, :resource_creation_time_dt, :resource_detail_capture_time_dt, :findings_summary, :resource_tags, :resource_config, :resource_sub_category, :discovery_type, :resource_info) SENSITIVE = [] include Aws::Structure end |
#resource_name ⇒ String
The name of the resource.
31336 31337 31338 31339 31340 31341 31342 31343 31344 31345 31346 31347 31348 31349 31350 31351 31352 31353 31354 31355 31356 31357 31358 31359 31360 |
# File 'lib/aws-sdk-securityhub/types.rb', line 31336 class ResourceResult < Struct.new( :resource_guid, :resource_id, :account_id, :account_name, :region, :resource_provider, :resource_owner_account_id, :resource_owner_org_id, :resource_cloud_partition, :resource_region, :resource_category, :resource_type, :resource_name, :resource_creation_time_dt, :resource_detail_capture_time_dt, :findings_summary, :resource_tags, :resource_config, :resource_sub_category, :discovery_type, :resource_info) SENSITIVE = [] include Aws::Structure end |
#resource_owner_account_id ⇒ String
The identifier of the cloud account that owns the resource. For Amazon Web Services resources, this is the Amazon Web Services account ID. For Azure resources, this is the Azure subscription ID.
31336 31337 31338 31339 31340 31341 31342 31343 31344 31345 31346 31347 31348 31349 31350 31351 31352 31353 31354 31355 31356 31357 31358 31359 31360 |
# File 'lib/aws-sdk-securityhub/types.rb', line 31336 class ResourceResult < Struct.new( :resource_guid, :resource_id, :account_id, :account_name, :region, :resource_provider, :resource_owner_account_id, :resource_owner_org_id, :resource_cloud_partition, :resource_region, :resource_category, :resource_type, :resource_name, :resource_creation_time_dt, :resource_detail_capture_time_dt, :findings_summary, :resource_tags, :resource_config, :resource_sub_category, :discovery_type, :resource_info) SENSITIVE = [] include Aws::Structure end |
#resource_owner_org_id ⇒ String
The identifier of the cloud organization that owns the resource. For Amazon Web Services resources, this is the Organizations ID. For Azure resources, this is the Azure tenant ID.
31336 31337 31338 31339 31340 31341 31342 31343 31344 31345 31346 31347 31348 31349 31350 31351 31352 31353 31354 31355 31356 31357 31358 31359 31360 |
# File 'lib/aws-sdk-securityhub/types.rb', line 31336 class ResourceResult < Struct.new( :resource_guid, :resource_id, :account_id, :account_name, :region, :resource_provider, :resource_owner_account_id, :resource_owner_org_id, :resource_cloud_partition, :resource_region, :resource_category, :resource_type, :resource_name, :resource_creation_time_dt, :resource_detail_capture_time_dt, :findings_summary, :resource_tags, :resource_config, :resource_sub_category, :discovery_type, :resource_info) SENSITIVE = [] include Aws::Structure end |
#resource_provider ⇒ String
The cloud provider where the resource exists. Valid values are AWS
and Azure. This field is always included.
31336 31337 31338 31339 31340 31341 31342 31343 31344 31345 31346 31347 31348 31349 31350 31351 31352 31353 31354 31355 31356 31357 31358 31359 31360 |
# File 'lib/aws-sdk-securityhub/types.rb', line 31336 class ResourceResult < Struct.new( :resource_guid, :resource_id, :account_id, :account_name, :region, :resource_provider, :resource_owner_account_id, :resource_owner_org_id, :resource_cloud_partition, :resource_region, :resource_category, :resource_type, :resource_name, :resource_creation_time_dt, :resource_detail_capture_time_dt, :findings_summary, :resource_tags, :resource_config, :resource_sub_category, :discovery_type, :resource_info) SENSITIVE = [] include Aws::Structure end |
#resource_region ⇒ String
The native cloud region where the resource is located. For Amazon
Web Services, this is an Amazon Web Services Region (for example,
us-east-1). For Azure resources, this is the Azure region (for
example, westus2). This field is always included.
31336 31337 31338 31339 31340 31341 31342 31343 31344 31345 31346 31347 31348 31349 31350 31351 31352 31353 31354 31355 31356 31357 31358 31359 31360 |
# File 'lib/aws-sdk-securityhub/types.rb', line 31336 class ResourceResult < Struct.new( :resource_guid, :resource_id, :account_id, :account_name, :region, :resource_provider, :resource_owner_account_id, :resource_owner_org_id, :resource_cloud_partition, :resource_region, :resource_category, :resource_type, :resource_name, :resource_creation_time_dt, :resource_detail_capture_time_dt, :findings_summary, :resource_tags, :resource_config, :resource_sub_category, :discovery_type, :resource_info) SENSITIVE = [] include Aws::Structure end |
#resource_sub_category ⇒ String
The AI/ML sub-grouping of the resource. Present only when
ResourceCategory is AI/ML.
31336 31337 31338 31339 31340 31341 31342 31343 31344 31345 31346 31347 31348 31349 31350 31351 31352 31353 31354 31355 31356 31357 31358 31359 31360 |
# File 'lib/aws-sdk-securityhub/types.rb', line 31336 class ResourceResult < Struct.new( :resource_guid, :resource_id, :account_id, :account_name, :region, :resource_provider, :resource_owner_account_id, :resource_owner_org_id, :resource_cloud_partition, :resource_region, :resource_category, :resource_type, :resource_name, :resource_creation_time_dt, :resource_detail_capture_time_dt, :findings_summary, :resource_tags, :resource_config, :resource_sub_category, :discovery_type, :resource_info) SENSITIVE = [] include Aws::Structure end |
#resource_tags ⇒ Array<Types::ResourceTag>
The key-value pairs associated with a resource.
31336 31337 31338 31339 31340 31341 31342 31343 31344 31345 31346 31347 31348 31349 31350 31351 31352 31353 31354 31355 31356 31357 31358 31359 31360 |
# File 'lib/aws-sdk-securityhub/types.rb', line 31336 class ResourceResult < Struct.new( :resource_guid, :resource_id, :account_id, :account_name, :region, :resource_provider, :resource_owner_account_id, :resource_owner_org_id, :resource_cloud_partition, :resource_region, :resource_category, :resource_type, :resource_name, :resource_creation_time_dt, :resource_detail_capture_time_dt, :findings_summary, :resource_tags, :resource_config, :resource_sub_category, :discovery_type, :resource_info) SENSITIVE = [] include Aws::Structure end |
#resource_type ⇒ String
The type of resource.
31336 31337 31338 31339 31340 31341 31342 31343 31344 31345 31346 31347 31348 31349 31350 31351 31352 31353 31354 31355 31356 31357 31358 31359 31360 |
# File 'lib/aws-sdk-securityhub/types.rb', line 31336 class ResourceResult < Struct.new( :resource_guid, :resource_id, :account_id, :account_name, :region, :resource_provider, :resource_owner_account_id, :resource_owner_org_id, :resource_cloud_partition, :resource_region, :resource_category, :resource_type, :resource_name, :resource_creation_time_dt, :resource_detail_capture_time_dt, :findings_summary, :resource_tags, :resource_config, :resource_sub_category, :discovery_type, :resource_info) SENSITIVE = [] include Aws::Structure end |