Class: Aws::SecurityHub::Types::ResourceScopes
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::ResourceScopes
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Defines the data boundary for a resources query. Scopes determine which organizational units or organizations to retrieve data from.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_organizations ⇒ Array<Types::AwsOrganizationScope>
A list of Organizations scopes to include in the query results.
Instance Attribute Details
#aws_organizations ⇒ Array<Types::AwsOrganizationScope>
A list of Organizations scopes to include in the query results. Each entry in the list specifies an organization or organizational unit to include for the delegated administrator’s account. If the list specifies multiple entries, the entries are combined using OR logic.
30391 30392 30393 30394 30395 |
# File 'lib/aws-sdk-securityhub/types.rb', line 30391 class ResourceScopes < Struct.new( :aws_organizations) SENSITIVE = [] include Aws::Structure end |