Class: Aws::SecurityHub::Types::ResourceSeverityBreakdown

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

A comprehensive distribution of security findings by severity level for Amazon Web Services resources.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#criticalInteger

The number of findings with a severity level of critical.

Returns:

  • (Integer)


30300
30301
30302
30303
30304
30305
30306
30307
30308
30309
30310
30311
# File 'lib/aws-sdk-securityhub/types.rb', line 30300

class ResourceSeverityBreakdown < Struct.new(
  :other,
  :fatal,
  :critical,
  :high,
  :medium,
  :low,
  :informational,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
end

#fatalInteger

The number of findings with a severity level of fatal.

Returns:

  • (Integer)


30300
30301
30302
30303
30304
30305
30306
30307
30308
30309
30310
30311
# File 'lib/aws-sdk-securityhub/types.rb', line 30300

class ResourceSeverityBreakdown < Struct.new(
  :other,
  :fatal,
  :critical,
  :high,
  :medium,
  :low,
  :informational,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
end

#highInteger

The number of findings with a severity level of high.

Returns:

  • (Integer)


30300
30301
30302
30303
30304
30305
30306
30307
30308
30309
30310
30311
# File 'lib/aws-sdk-securityhub/types.rb', line 30300

class ResourceSeverityBreakdown < Struct.new(
  :other,
  :fatal,
  :critical,
  :high,
  :medium,
  :low,
  :informational,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
end

#informationalInteger

The number of findings that provide security-related information.

Returns:

  • (Integer)


30300
30301
30302
30303
30304
30305
30306
30307
30308
30309
30310
30311
# File 'lib/aws-sdk-securityhub/types.rb', line 30300

class ResourceSeverityBreakdown < Struct.new(
  :other,
  :fatal,
  :critical,
  :high,
  :medium,
  :low,
  :informational,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
end

#lowInteger

The number of findings with a severity level of low.

Returns:

  • (Integer)


30300
30301
30302
30303
30304
30305
30306
30307
30308
30309
30310
30311
# File 'lib/aws-sdk-securityhub/types.rb', line 30300

class ResourceSeverityBreakdown < Struct.new(
  :other,
  :fatal,
  :critical,
  :high,
  :medium,
  :low,
  :informational,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
end

#mediumInteger

The number of findings with a severity level of medium.

Returns:

  • (Integer)


30300
30301
30302
30303
30304
30305
30306
30307
30308
30309
30310
30311
# File 'lib/aws-sdk-securityhub/types.rb', line 30300

class ResourceSeverityBreakdown < Struct.new(
  :other,
  :fatal,
  :critical,
  :high,
  :medium,
  :low,
  :informational,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
end

#otherInteger

The number of findings not in any of the severity categories.

Returns:

  • (Integer)


30300
30301
30302
30303
30304
30305
30306
30307
30308
30309
30310
30311
# File 'lib/aws-sdk-securityhub/types.rb', line 30300

class ResourceSeverityBreakdown < Struct.new(
  :other,
  :fatal,
  :critical,
  :high,
  :medium,
  :low,
  :informational,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
end

#unknownInteger

The number of findings with a severity level cannot be determined.

Returns:

  • (Integer)


30300
30301
30302
30303
30304
30305
30306
30307
30308
30309
30310
30311
# File 'lib/aws-sdk-securityhub/types.rb', line 30300

class ResourceSeverityBreakdown < Struct.new(
  :other,
  :fatal,
  :critical,
  :high,
  :medium,
  :low,
  :informational,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
end