Class: Aws::SecurityHub::Types::ResourcesMapFilter
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::ResourcesMapFilter
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Enables filtering of Amazon Web Services resources based on key-value map attributes.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#field_name ⇒ String
The name of the field.
-
#filter ⇒ Types::MapFilter
A map filter for filtering Security Hub CSPM findings.
Instance Attribute Details
#field_name ⇒ String
The name of the field.
30270 30271 30272 30273 30274 30275 |
# File 'lib/aws-sdk-securityhub/types.rb', line 30270 class ResourcesMapFilter < Struct.new( :field_name, :filter) SENSITIVE = [] include Aws::Structure end |
#filter ⇒ Types::MapFilter
A map filter for filtering Security Hub CSPM findings. Each map filter provides the field to check for, the value to check for, and the comparison operator.
30270 30271 30272 30273 30274 30275 |
# File 'lib/aws-sdk-securityhub/types.rb', line 30270 class ResourcesMapFilter < Struct.new( :field_name, :filter) SENSITIVE = [] include Aws::Structure end |