Class: Aws::SecurityHub::Types::ResourcesTrendsValues
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::ResourcesTrendsValues
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Contains the aggregated resource count values for a specific point in the resources trend timeline.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#resources_count ⇒ Types::ResourcesCount
The resource count statistics for this data point in the trend timeline.
Instance Attribute Details
#resources_count ⇒ Types::ResourcesCount
The resource count statistics for this data point in the trend timeline.
31599 31600 31601 31602 31603 |
# File 'lib/aws-sdk-securityhub/types.rb', line 31599 class ResourcesTrendsValues < Struct.new( :resources_count) SENSITIVE = [] include Aws::Structure end |