Class: Aws::SecurityHub::Types::RouteSetDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::RouteSetDetails
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Provides details about the routes in the route table.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#carrier_gateway_id ⇒ String
The ID of the carrier gateway.
-
#core_network_arn ⇒ String
The Amazon Resource Name (ARN) of the core network.
-
#destination_cidr_block ⇒ String
The IPv4 CIDR block used for the destination match.
-
#destination_ipv_6_cidr_block ⇒ String
The IPv6 CIDR block used for the destination match.
-
#destination_prefix_list_id ⇒ String
The prefix of the destination Amazon Web Services service.
-
#egress_only_internet_gateway_id ⇒ String
The ID of the egress-only internet gateway.
-
#gateway_id ⇒ String
The ID of a gateway attached to your VPC.
-
#instance_id ⇒ String
The ID of a NAT instance in your VPC.
-
#instance_owner_id ⇒ String
The ID of the Amazon Web Services account that owns the instance.
-
#local_gateway_id ⇒ String
The ID of the local gateway.
-
#nat_gateway_id ⇒ String
The ID of a NAT gateway.
-
#network_interface_id ⇒ String
The ID of the network interface.
-
#origin ⇒ String
Describes how the route was created.
-
#state ⇒ String
The state of the route.
-
#transit_gateway_id ⇒ String
The ID of a transit gateway.
-
#vpc_peering_connection_id ⇒ String
The ID of a VPC peering connection.
Instance Attribute Details
#carrier_gateway_id ⇒ String
The ID of the carrier gateway.
31958 31959 31960 31961 31962 31963 31964 31965 31966 31967 31968 31969 31970 31971 31972 31973 31974 31975 31976 31977 |
# File 'lib/aws-sdk-securityhub/types.rb', line 31958 class RouteSetDetails < Struct.new( :carrier_gateway_id, :core_network_arn, :destination_cidr_block, :destination_ipv_6_cidr_block, :destination_prefix_list_id, :egress_only_internet_gateway_id, :gateway_id, :instance_id, :instance_owner_id, :local_gateway_id, :nat_gateway_id, :network_interface_id, :origin, :state, :transit_gateway_id, :vpc_peering_connection_id) SENSITIVE = [] include Aws::Structure end |
#core_network_arn ⇒ String
The Amazon Resource Name (ARN) of the core network.
31958 31959 31960 31961 31962 31963 31964 31965 31966 31967 31968 31969 31970 31971 31972 31973 31974 31975 31976 31977 |
# File 'lib/aws-sdk-securityhub/types.rb', line 31958 class RouteSetDetails < Struct.new( :carrier_gateway_id, :core_network_arn, :destination_cidr_block, :destination_ipv_6_cidr_block, :destination_prefix_list_id, :egress_only_internet_gateway_id, :gateway_id, :instance_id, :instance_owner_id, :local_gateway_id, :nat_gateway_id, :network_interface_id, :origin, :state, :transit_gateway_id, :vpc_peering_connection_id) SENSITIVE = [] include Aws::Structure end |
#destination_cidr_block ⇒ String
The IPv4 CIDR block used for the destination match.
31958 31959 31960 31961 31962 31963 31964 31965 31966 31967 31968 31969 31970 31971 31972 31973 31974 31975 31976 31977 |
# File 'lib/aws-sdk-securityhub/types.rb', line 31958 class RouteSetDetails < Struct.new( :carrier_gateway_id, :core_network_arn, :destination_cidr_block, :destination_ipv_6_cidr_block, :destination_prefix_list_id, :egress_only_internet_gateway_id, :gateway_id, :instance_id, :instance_owner_id, :local_gateway_id, :nat_gateway_id, :network_interface_id, :origin, :state, :transit_gateway_id, :vpc_peering_connection_id) SENSITIVE = [] include Aws::Structure end |
#destination_ipv_6_cidr_block ⇒ String
The IPv6 CIDR block used for the destination match.
31958 31959 31960 31961 31962 31963 31964 31965 31966 31967 31968 31969 31970 31971 31972 31973 31974 31975 31976 31977 |
# File 'lib/aws-sdk-securityhub/types.rb', line 31958 class RouteSetDetails < Struct.new( :carrier_gateway_id, :core_network_arn, :destination_cidr_block, :destination_ipv_6_cidr_block, :destination_prefix_list_id, :egress_only_internet_gateway_id, :gateway_id, :instance_id, :instance_owner_id, :local_gateway_id, :nat_gateway_id, :network_interface_id, :origin, :state, :transit_gateway_id, :vpc_peering_connection_id) SENSITIVE = [] include Aws::Structure end |
#destination_prefix_list_id ⇒ String
The prefix of the destination Amazon Web Services service.
31958 31959 31960 31961 31962 31963 31964 31965 31966 31967 31968 31969 31970 31971 31972 31973 31974 31975 31976 31977 |
# File 'lib/aws-sdk-securityhub/types.rb', line 31958 class RouteSetDetails < Struct.new( :carrier_gateway_id, :core_network_arn, :destination_cidr_block, :destination_ipv_6_cidr_block, :destination_prefix_list_id, :egress_only_internet_gateway_id, :gateway_id, :instance_id, :instance_owner_id, :local_gateway_id, :nat_gateway_id, :network_interface_id, :origin, :state, :transit_gateway_id, :vpc_peering_connection_id) SENSITIVE = [] include Aws::Structure end |
#egress_only_internet_gateway_id ⇒ String
The ID of the egress-only internet gateway.
31958 31959 31960 31961 31962 31963 31964 31965 31966 31967 31968 31969 31970 31971 31972 31973 31974 31975 31976 31977 |
# File 'lib/aws-sdk-securityhub/types.rb', line 31958 class RouteSetDetails < Struct.new( :carrier_gateway_id, :core_network_arn, :destination_cidr_block, :destination_ipv_6_cidr_block, :destination_prefix_list_id, :egress_only_internet_gateway_id, :gateway_id, :instance_id, :instance_owner_id, :local_gateway_id, :nat_gateway_id, :network_interface_id, :origin, :state, :transit_gateway_id, :vpc_peering_connection_id) SENSITIVE = [] include Aws::Structure end |
#gateway_id ⇒ String
The ID of a gateway attached to your VPC.
31958 31959 31960 31961 31962 31963 31964 31965 31966 31967 31968 31969 31970 31971 31972 31973 31974 31975 31976 31977 |
# File 'lib/aws-sdk-securityhub/types.rb', line 31958 class RouteSetDetails < Struct.new( :carrier_gateway_id, :core_network_arn, :destination_cidr_block, :destination_ipv_6_cidr_block, :destination_prefix_list_id, :egress_only_internet_gateway_id, :gateway_id, :instance_id, :instance_owner_id, :local_gateway_id, :nat_gateway_id, :network_interface_id, :origin, :state, :transit_gateway_id, :vpc_peering_connection_id) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The ID of a NAT instance in your VPC.
31958 31959 31960 31961 31962 31963 31964 31965 31966 31967 31968 31969 31970 31971 31972 31973 31974 31975 31976 31977 |
# File 'lib/aws-sdk-securityhub/types.rb', line 31958 class RouteSetDetails < Struct.new( :carrier_gateway_id, :core_network_arn, :destination_cidr_block, :destination_ipv_6_cidr_block, :destination_prefix_list_id, :egress_only_internet_gateway_id, :gateway_id, :instance_id, :instance_owner_id, :local_gateway_id, :nat_gateway_id, :network_interface_id, :origin, :state, :transit_gateway_id, :vpc_peering_connection_id) SENSITIVE = [] include Aws::Structure end |
#instance_owner_id ⇒ String
The ID of the Amazon Web Services account that owns the instance.
31958 31959 31960 31961 31962 31963 31964 31965 31966 31967 31968 31969 31970 31971 31972 31973 31974 31975 31976 31977 |
# File 'lib/aws-sdk-securityhub/types.rb', line 31958 class RouteSetDetails < Struct.new( :carrier_gateway_id, :core_network_arn, :destination_cidr_block, :destination_ipv_6_cidr_block, :destination_prefix_list_id, :egress_only_internet_gateway_id, :gateway_id, :instance_id, :instance_owner_id, :local_gateway_id, :nat_gateway_id, :network_interface_id, :origin, :state, :transit_gateway_id, :vpc_peering_connection_id) SENSITIVE = [] include Aws::Structure end |
#local_gateway_id ⇒ String
The ID of the local gateway.
31958 31959 31960 31961 31962 31963 31964 31965 31966 31967 31968 31969 31970 31971 31972 31973 31974 31975 31976 31977 |
# File 'lib/aws-sdk-securityhub/types.rb', line 31958 class RouteSetDetails < Struct.new( :carrier_gateway_id, :core_network_arn, :destination_cidr_block, :destination_ipv_6_cidr_block, :destination_prefix_list_id, :egress_only_internet_gateway_id, :gateway_id, :instance_id, :instance_owner_id, :local_gateway_id, :nat_gateway_id, :network_interface_id, :origin, :state, :transit_gateway_id, :vpc_peering_connection_id) SENSITIVE = [] include Aws::Structure end |
#nat_gateway_id ⇒ String
The ID of a NAT gateway.
31958 31959 31960 31961 31962 31963 31964 31965 31966 31967 31968 31969 31970 31971 31972 31973 31974 31975 31976 31977 |
# File 'lib/aws-sdk-securityhub/types.rb', line 31958 class RouteSetDetails < Struct.new( :carrier_gateway_id, :core_network_arn, :destination_cidr_block, :destination_ipv_6_cidr_block, :destination_prefix_list_id, :egress_only_internet_gateway_id, :gateway_id, :instance_id, :instance_owner_id, :local_gateway_id, :nat_gateway_id, :network_interface_id, :origin, :state, :transit_gateway_id, :vpc_peering_connection_id) SENSITIVE = [] include Aws::Structure end |
#network_interface_id ⇒ String
The ID of the network interface.
31958 31959 31960 31961 31962 31963 31964 31965 31966 31967 31968 31969 31970 31971 31972 31973 31974 31975 31976 31977 |
# File 'lib/aws-sdk-securityhub/types.rb', line 31958 class RouteSetDetails < Struct.new( :carrier_gateway_id, :core_network_arn, :destination_cidr_block, :destination_ipv_6_cidr_block, :destination_prefix_list_id, :egress_only_internet_gateway_id, :gateway_id, :instance_id, :instance_owner_id, :local_gateway_id, :nat_gateway_id, :network_interface_id, :origin, :state, :transit_gateway_id, :vpc_peering_connection_id) SENSITIVE = [] include Aws::Structure end |
#origin ⇒ String
Describes how the route was created.
31958 31959 31960 31961 31962 31963 31964 31965 31966 31967 31968 31969 31970 31971 31972 31973 31974 31975 31976 31977 |
# File 'lib/aws-sdk-securityhub/types.rb', line 31958 class RouteSetDetails < Struct.new( :carrier_gateway_id, :core_network_arn, :destination_cidr_block, :destination_ipv_6_cidr_block, :destination_prefix_list_id, :egress_only_internet_gateway_id, :gateway_id, :instance_id, :instance_owner_id, :local_gateway_id, :nat_gateway_id, :network_interface_id, :origin, :state, :transit_gateway_id, :vpc_peering_connection_id) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The state of the route.
31958 31959 31960 31961 31962 31963 31964 31965 31966 31967 31968 31969 31970 31971 31972 31973 31974 31975 31976 31977 |
# File 'lib/aws-sdk-securityhub/types.rb', line 31958 class RouteSetDetails < Struct.new( :carrier_gateway_id, :core_network_arn, :destination_cidr_block, :destination_ipv_6_cidr_block, :destination_prefix_list_id, :egress_only_internet_gateway_id, :gateway_id, :instance_id, :instance_owner_id, :local_gateway_id, :nat_gateway_id, :network_interface_id, :origin, :state, :transit_gateway_id, :vpc_peering_connection_id) SENSITIVE = [] include Aws::Structure end |
#transit_gateway_id ⇒ String
The ID of a transit gateway.
31958 31959 31960 31961 31962 31963 31964 31965 31966 31967 31968 31969 31970 31971 31972 31973 31974 31975 31976 31977 |
# File 'lib/aws-sdk-securityhub/types.rb', line 31958 class RouteSetDetails < Struct.new( :carrier_gateway_id, :core_network_arn, :destination_cidr_block, :destination_ipv_6_cidr_block, :destination_prefix_list_id, :egress_only_internet_gateway_id, :gateway_id, :instance_id, :instance_owner_id, :local_gateway_id, :nat_gateway_id, :network_interface_id, :origin, :state, :transit_gateway_id, :vpc_peering_connection_id) SENSITIVE = [] include Aws::Structure end |
#vpc_peering_connection_id ⇒ String
The ID of a VPC peering connection.
31958 31959 31960 31961 31962 31963 31964 31965 31966 31967 31968 31969 31970 31971 31972 31973 31974 31975 31976 31977 |
# File 'lib/aws-sdk-securityhub/types.rb', line 31958 class RouteSetDetails < Struct.new( :carrier_gateway_id, :core_network_arn, :destination_cidr_block, :destination_ipv_6_cidr_block, :destination_prefix_list_id, :egress_only_internet_gateway_id, :gateway_id, :instance_id, :instance_owner_id, :local_gateway_id, :nat_gateway_id, :network_interface_id, :origin, :state, :transit_gateway_id, :vpc_peering_connection_id) SENSITIVE = [] include Aws::Structure end |