Class: Aws::SecurityHub::Types::RuleGroupSourceStatelessRuleMatchAttributesTcpFlags

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

A set of TCP flags and masks to inspect for.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#flagsArray<String>

Defines the flags from the Masks setting that must be set in order for the packet to match. Flags that are listed must be set. Flags that are not listed must not be set.

Returns:

  • (Array<String>)


32061
32062
32063
32064
32065
32066
# File 'lib/aws-sdk-securityhub/types.rb', line 32061

class RuleGroupSourceStatelessRuleMatchAttributesTcpFlags < Struct.new(
  :flags,
  :masks)
  SENSITIVE = []
  include Aws::Structure
end

#masksArray<String>

The set of flags to consider in the inspection. If not specified, then all flags are inspected.

Returns:

  • (Array<String>)


32061
32062
32063
32064
32065
32066
# File 'lib/aws-sdk-securityhub/types.rb', line 32061

class RuleGroupSourceStatelessRuleMatchAttributesTcpFlags < Struct.new(
  :flags,
  :masks)
  SENSITIVE = []
  include Aws::Structure
end