Class: Aws::SecurityHub::Types::SecurityControlsConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::SecurityControlsConfiguration
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
An object that defines which security controls are enabled in an Security Hub CSPM configuration policy. The enablement status of a control is aligned across all of the enabled standards in an account.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#disabled_security_control_identifiers ⇒ Array<String>
A list of security controls that are disabled in the configuration policy.
-
#enabled_security_control_identifiers ⇒ Array<String>
A list of security controls that are enabled in the configuration policy.
-
#security_control_custom_parameters ⇒ Array<Types::SecurityControlCustomParameter>
A list of security controls and control parameter values that are included in a configuration policy.
Instance Attribute Details
#disabled_security_control_identifiers ⇒ Array<String>
A list of security controls that are disabled in the configuration policy. Security Hub CSPM enables all other controls (including newly released controls) other than the listed controls.
32659 32660 32661 32662 32663 32664 32665 |
# File 'lib/aws-sdk-securityhub/types.rb', line 32659 class SecurityControlsConfiguration < Struct.new( :enabled_security_control_identifiers, :disabled_security_control_identifiers, :security_control_custom_parameters) SENSITIVE = [] include Aws::Structure end |
#enabled_security_control_identifiers ⇒ Array<String>
A list of security controls that are enabled in the configuration policy. Security Hub CSPM disables all other controls (including newly released controls) other than the listed controls.
32659 32660 32661 32662 32663 32664 32665 |
# File 'lib/aws-sdk-securityhub/types.rb', line 32659 class SecurityControlsConfiguration < Struct.new( :enabled_security_control_identifiers, :disabled_security_control_identifiers, :security_control_custom_parameters) SENSITIVE = [] include Aws::Structure end |
#security_control_custom_parameters ⇒ Array<Types::SecurityControlCustomParameter>
A list of security controls and control parameter values that are included in a configuration policy.
32659 32660 32661 32662 32663 32664 32665 |
# File 'lib/aws-sdk-securityhub/types.rb', line 32659 class SecurityControlsConfiguration < Struct.new( :enabled_security_control_identifiers, :disabled_security_control_identifiers, :security_control_custom_parameters) SENSITIVE = [] include Aws::Structure end |