Class: Aws::SecurityHub::Types::SensitiveDataResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::SensitiveDataResult
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Contains a detected instance of sensitive data that are based on built-in identifiers.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#category ⇒ String
The category of sensitive data that was detected.
-
#detections ⇒ Array<Types::SensitiveDataDetections>
The list of detected instances of sensitive data.
-
#total_count ⇒ Integer
The total number of occurrences of sensitive data.
Instance Attribute Details
#category ⇒ String
The category of sensitive data that was detected. For example, the category can indicate that the sensitive data involved credentials, financial information, or personal information.
32748 32749 32750 32751 32752 32753 32754 |
# File 'lib/aws-sdk-securityhub/types.rb', line 32748 class SensitiveDataResult < Struct.new( :category, :detections, :total_count) SENSITIVE = [] include Aws::Structure end |
#detections ⇒ Array<Types::SensitiveDataDetections>
The list of detected instances of sensitive data.
32748 32749 32750 32751 32752 32753 32754 |
# File 'lib/aws-sdk-securityhub/types.rb', line 32748 class SensitiveDataResult < Struct.new( :category, :detections, :total_count) SENSITIVE = [] include Aws::Structure end |
#total_count ⇒ Integer
The total number of occurrences of sensitive data.
32748 32749 32750 32751 32752 32753 32754 |
# File 'lib/aws-sdk-securityhub/types.rb', line 32748 class SensitiveDataResult < Struct.new( :category, :detections, :total_count) SENSITIVE = [] include Aws::Structure end |