Class: Aws::SecurityHub::Types::Sequence

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

Contains information about an Amazon GuardDuty Extended Threat Detection attack sequence finding. GuardDuty generates an attack sequence finding when multiple events align to a potentially suspicious activity. To receive GuardDuty attack sequence findings in Security Hub CSPM, you must have GuardDuty enabled. For more information, see GuardDuty Extended Threat Detection in the Amazon GuardDuty User Guide.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#actorsArray<Types::Actor>

Provides information about the actors involved in the attack sequence.

Returns:



32675
32676
32677
32678
32679
32680
32681
32682
32683
# File 'lib/aws-sdk-securityhub/types.rb', line 32675

class Sequence < Struct.new(
  :uid,
  :actors,
  :endpoints,
  :signals,
  :sequence_indicators)
  SENSITIVE = []
  include Aws::Structure
end

#endpointsArray<Types::NetworkEndpoint>

Contains information about the network endpoints that were used in the attack sequence.

Returns:



32675
32676
32677
32678
32679
32680
32681
32682
32683
# File 'lib/aws-sdk-securityhub/types.rb', line 32675

class Sequence < Struct.new(
  :uid,
  :actors,
  :endpoints,
  :signals,
  :sequence_indicators)
  SENSITIVE = []
  include Aws::Structure
end

#sequence_indicatorsArray<Types::Indicator>

Contains information about the indicators observed in the attack sequence. The values for SignalIndicators are a subset of the values for SequenceIndicators, but the values for these fields don't always match 1:1.

Returns:



32675
32676
32677
32678
32679
32680
32681
32682
32683
# File 'lib/aws-sdk-securityhub/types.rb', line 32675

class Sequence < Struct.new(
  :uid,
  :actors,
  :endpoints,
  :signals,
  :sequence_indicators)
  SENSITIVE = []
  include Aws::Structure
end

#signalsArray<Types::Signal>

Contains information about the signals involved in the attack sequence.

Returns:



32675
32676
32677
32678
32679
32680
32681
32682
32683
# File 'lib/aws-sdk-securityhub/types.rb', line 32675

class Sequence < Struct.new(
  :uid,
  :actors,
  :endpoints,
  :signals,
  :sequence_indicators)
  SENSITIVE = []
  include Aws::Structure
end

#uidString

Unique identifier of the attack sequence.

Returns:

  • (String)


32675
32676
32677
32678
32679
32680
32681
32682
32683
# File 'lib/aws-sdk-securityhub/types.rb', line 32675

class Sequence < Struct.new(
  :uid,
  :actors,
  :endpoints,
  :signals,
  :sequence_indicators)
  SENSITIVE = []
  include Aws::Structure
end