Class: Aws::SecurityHub::Types::SeverityTrendsCount
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::SeverityTrendsCount
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Contains counts of findings grouped by severity level for trend analysis.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#critical ⇒ Integer
The count of findings with Critical severity level at this point in the trend timeline.
-
#fatal ⇒ Integer
The count of findings with Fatal severity level at this point in the trend timeline.
-
#high ⇒ Integer
The count of findings with High severity level at this point in the trend timeline.
-
#informational ⇒ Integer
The count of findings with Informational severity level at this point in the trend timeline.
-
#low ⇒ Integer
The count of findings with Low severity level at this point in the trend timeline.
-
#medium ⇒ Integer
The count of findings with Medium severity level at this point in the trend timeline.
-
#other ⇒ Integer
The count of findings with severity levels not fitting into the standard categories at this point in the trend timeline.
-
#unknown ⇒ Integer
The count of findings with Unknown severity level at this point in the trend timeline.
Instance Attribute Details
#critical ⇒ Integer
The count of findings with Critical severity level at this point in the trend timeline.
32756 32757 32758 32759 32760 32761 32762 32763 32764 32765 32766 32767 |
# File 'lib/aws-sdk-securityhub/types.rb', line 32756 class SeverityTrendsCount < Struct.new( :unknown, :informational, :low, :medium, :high, :critical, :fatal, :other) SENSITIVE = [] include Aws::Structure end |
#fatal ⇒ Integer
The count of findings with Fatal severity level at this point in the trend timeline.
32756 32757 32758 32759 32760 32761 32762 32763 32764 32765 32766 32767 |
# File 'lib/aws-sdk-securityhub/types.rb', line 32756 class SeverityTrendsCount < Struct.new( :unknown, :informational, :low, :medium, :high, :critical, :fatal, :other) SENSITIVE = [] include Aws::Structure end |
#high ⇒ Integer
The count of findings with High severity level at this point in the trend timeline.
32756 32757 32758 32759 32760 32761 32762 32763 32764 32765 32766 32767 |
# File 'lib/aws-sdk-securityhub/types.rb', line 32756 class SeverityTrendsCount < Struct.new( :unknown, :informational, :low, :medium, :high, :critical, :fatal, :other) SENSITIVE = [] include Aws::Structure end |
#informational ⇒ Integer
The count of findings with Informational severity level at this point in the trend timeline.
32756 32757 32758 32759 32760 32761 32762 32763 32764 32765 32766 32767 |
# File 'lib/aws-sdk-securityhub/types.rb', line 32756 class SeverityTrendsCount < Struct.new( :unknown, :informational, :low, :medium, :high, :critical, :fatal, :other) SENSITIVE = [] include Aws::Structure end |
#low ⇒ Integer
The count of findings with Low severity level at this point in the trend timeline.
32756 32757 32758 32759 32760 32761 32762 32763 32764 32765 32766 32767 |
# File 'lib/aws-sdk-securityhub/types.rb', line 32756 class SeverityTrendsCount < Struct.new( :unknown, :informational, :low, :medium, :high, :critical, :fatal, :other) SENSITIVE = [] include Aws::Structure end |
#medium ⇒ Integer
The count of findings with Medium severity level at this point in the trend timeline.
32756 32757 32758 32759 32760 32761 32762 32763 32764 32765 32766 32767 |
# File 'lib/aws-sdk-securityhub/types.rb', line 32756 class SeverityTrendsCount < Struct.new( :unknown, :informational, :low, :medium, :high, :critical, :fatal, :other) SENSITIVE = [] include Aws::Structure end |
#other ⇒ Integer
The count of findings with severity levels not fitting into the standard categories at this point in the trend timeline.
32756 32757 32758 32759 32760 32761 32762 32763 32764 32765 32766 32767 |
# File 'lib/aws-sdk-securityhub/types.rb', line 32756 class SeverityTrendsCount < Struct.new( :unknown, :informational, :low, :medium, :high, :critical, :fatal, :other) SENSITIVE = [] include Aws::Structure end |
#unknown ⇒ Integer
The count of findings with Unknown severity level at this point in the trend timeline.
32756 32757 32758 32759 32760 32761 32762 32763 32764 32765 32766 32767 |
# File 'lib/aws-sdk-securityhub/types.rb', line 32756 class SeverityTrendsCount < Struct.new( :unknown, :informational, :low, :medium, :high, :critical, :fatal, :other) SENSITIVE = [] include Aws::Structure end |