Class: Aws::SecurityHub::Types::Standard
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::Standard
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Provides information about a specific security standard.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
A description of the standard.
-
#enabled_by_default ⇒ Boolean
Whether the standard is enabled by default.
-
#name ⇒ String
The name of the standard.
-
#provider ⇒ String
The cloud provider whose resources the standard evaluates.
-
#standards_arn ⇒ String
The ARN of the standard.
-
#standards_managed_by ⇒ Types::StandardsManagedBy
Provides details about the management of a standard.
Instance Attribute Details
#description ⇒ String
A description of the standard.
33342 33343 33344 33345 33346 33347 33348 33349 33350 33351 |
# File 'lib/aws-sdk-securityhub/types.rb', line 33342 class Standard < Struct.new( :standards_arn, :name, :description, :enabled_by_default, :provider, :standards_managed_by) SENSITIVE = [] include Aws::Structure end |
#enabled_by_default ⇒ Boolean
Whether the standard is enabled by default. When Security Hub CSPM is enabled from the console, if a standard is enabled by default, the check box for that standard is selected by default.
When Security Hub CSPM is enabled using the EnableSecurityHub API
operation, the standard is enabled by default unless
EnableDefaultStandards is set to false.
33342 33343 33344 33345 33346 33347 33348 33349 33350 33351 |
# File 'lib/aws-sdk-securityhub/types.rb', line 33342 class Standard < Struct.new( :standards_arn, :name, :description, :enabled_by_default, :provider, :standards_managed_by) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the standard.
33342 33343 33344 33345 33346 33347 33348 33349 33350 33351 |
# File 'lib/aws-sdk-securityhub/types.rb', line 33342 class Standard < Struct.new( :standards_arn, :name, :description, :enabled_by_default, :provider, :standards_managed_by) SENSITIVE = [] include Aws::Structure end |
#provider ⇒ String
The cloud provider whose resources the standard evaluates. For
example, AWS or Azure.
33342 33343 33344 33345 33346 33347 33348 33349 33350 33351 |
# File 'lib/aws-sdk-securityhub/types.rb', line 33342 class Standard < Struct.new( :standards_arn, :name, :description, :enabled_by_default, :provider, :standards_managed_by) SENSITIVE = [] include Aws::Structure end |
#standards_arn ⇒ String
The ARN of the standard.
33342 33343 33344 33345 33346 33347 33348 33349 33350 33351 |
# File 'lib/aws-sdk-securityhub/types.rb', line 33342 class Standard < Struct.new( :standards_arn, :name, :description, :enabled_by_default, :provider, :standards_managed_by) SENSITIVE = [] include Aws::Structure end |
#standards_managed_by ⇒ Types::StandardsManagedBy
Provides details about the management of a standard.
33342 33343 33344 33345 33346 33347 33348 33349 33350 33351 |
# File 'lib/aws-sdk-securityhub/types.rb', line 33342 class Standard < Struct.new( :standards_arn, :name, :description, :enabled_by_default, :provider, :standards_managed_by) SENSITIVE = [] include Aws::Structure end |