Class: Aws::SecurityHub::Types::Standard

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

Provides information about a specific security standard.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

A description of the standard.

Returns:

  • (String)


33217
33218
33219
33220
33221
33222
33223
33224
33225
33226
# File 'lib/aws-sdk-securityhub/types.rb', line 33217

class Standard < Struct.new(
  :standards_arn,
  :name,
  :description,
  :enabled_by_default,
  :provider,
  :standards_managed_by)
  SENSITIVE = []
  include Aws::Structure
end

#enabled_by_defaultBoolean

Whether the standard is enabled by default. When Security Hub CSPM is enabled from the console, if a standard is enabled by default, the check box for that standard is selected by default.

When Security Hub CSPM is enabled using the EnableSecurityHub API operation, the standard is enabled by default unless EnableDefaultStandards is set to false.

Returns:

  • (Boolean)


33217
33218
33219
33220
33221
33222
33223
33224
33225
33226
# File 'lib/aws-sdk-securityhub/types.rb', line 33217

class Standard < Struct.new(
  :standards_arn,
  :name,
  :description,
  :enabled_by_default,
  :provider,
  :standards_managed_by)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the standard.

Returns:

  • (String)


33217
33218
33219
33220
33221
33222
33223
33224
33225
33226
# File 'lib/aws-sdk-securityhub/types.rb', line 33217

class Standard < Struct.new(
  :standards_arn,
  :name,
  :description,
  :enabled_by_default,
  :provider,
  :standards_managed_by)
  SENSITIVE = []
  include Aws::Structure
end

#providerString

The cloud provider whose resources the standard evaluates. For example, AWS or Azure.

Returns:

  • (String)


33217
33218
33219
33220
33221
33222
33223
33224
33225
33226
# File 'lib/aws-sdk-securityhub/types.rb', line 33217

class Standard < Struct.new(
  :standards_arn,
  :name,
  :description,
  :enabled_by_default,
  :provider,
  :standards_managed_by)
  SENSITIVE = []
  include Aws::Structure
end

#standards_arnString

The ARN of the standard.

Returns:

  • (String)


33217
33218
33219
33220
33221
33222
33223
33224
33225
33226
# File 'lib/aws-sdk-securityhub/types.rb', line 33217

class Standard < Struct.new(
  :standards_arn,
  :name,
  :description,
  :enabled_by_default,
  :provider,
  :standards_managed_by)
  SENSITIVE = []
  include Aws::Structure
end

#standards_managed_byTypes::StandardsManagedBy

Provides details about the management of a standard.



33217
33218
33219
33220
33221
33222
33223
33224
33225
33226
# File 'lib/aws-sdk-securityhub/types.rb', line 33217

class Standard < Struct.new(
  :standards_arn,
  :name,
  :description,
  :enabled_by_default,
  :provider,
  :standards_managed_by)
  SENSITIVE = []
  include Aws::Structure
end