Class: Aws::SecurityHub::Types::Standard

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

Provides information about a specific security standard.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

A description of the standard.

Returns:



31878
31879
31880
31881
31882
31883
31884
31885
31886
# File 'lib/aws-sdk-securityhub/types.rb', line 31878

class Standard < Struct.new(
  :standards_arn,
  :name,
  :description,
  :enabled_by_default,
  :standards_managed_by)
  SENSITIVE = []
  include Aws::Structure
end

#enabled_by_defaultBoolean

Whether the standard is enabled by default. When Security Hub CSPM is enabled from the console, if a standard is enabled by default, the check box for that standard is selected by default.

When Security Hub CSPM is enabled using the EnableSecurityHub API operation, the standard is enabled by default unless EnableDefaultStandards is set to false.

Returns:



31878
31879
31880
31881
31882
31883
31884
31885
31886
# File 'lib/aws-sdk-securityhub/types.rb', line 31878

class Standard < Struct.new(
  :standards_arn,
  :name,
  :description,
  :enabled_by_default,
  :standards_managed_by)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the standard.

Returns:



31878
31879
31880
31881
31882
31883
31884
31885
31886
# File 'lib/aws-sdk-securityhub/types.rb', line 31878

class Standard < Struct.new(
  :standards_arn,
  :name,
  :description,
  :enabled_by_default,
  :standards_managed_by)
  SENSITIVE = []
  include Aws::Structure
end

#standards_arnString

The ARN of the standard.

Returns:



31878
31879
31880
31881
31882
31883
31884
31885
31886
# File 'lib/aws-sdk-securityhub/types.rb', line 31878

class Standard < Struct.new(
  :standards_arn,
  :name,
  :description,
  :enabled_by_default,
  :standards_managed_by)
  SENSITIVE = []
  include Aws::Structure
end

#standards_managed_byTypes::StandardsManagedBy

Provides details about the management of a standard.

Returns:



31878
31879
31880
31881
31882
31883
31884
31885
31886
# File 'lib/aws-sdk-securityhub/types.rb', line 31878

class Standard < Struct.new(
  :standards_arn,
  :name,
  :description,
  :enabled_by_default,
  :standards_managed_by)
  SENSITIVE = []
  include Aws::Structure
end