Class: Aws::SecurityHub::Types::StandardsControl

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityhub/types.rb

Overview

Details for an individual security standard control.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#control_idString

The identifier of the security standard control.

Returns:

  • (String)


33283
33284
33285
33286
33287
33288
33289
33290
33291
33292
33293
33294
33295
33296
# File 'lib/aws-sdk-securityhub/types.rb', line 33283

class StandardsControl < Struct.new(
  :standards_control_arn,
  :control_status,
  :disabled_reason,
  :control_status_updated_at,
  :control_id,
  :title,
  :description,
  :remediation_url,
  :severity_rating,
  :related_requirements)
  SENSITIVE = []
  include Aws::Structure
end

#control_statusString

The current status of the security standard control. Indicates whether the control is enabled or disabled. Security Hub CSPM does not check against disabled controls.

Returns:

  • (String)


33283
33284
33285
33286
33287
33288
33289
33290
33291
33292
33293
33294
33295
33296
# File 'lib/aws-sdk-securityhub/types.rb', line 33283

class StandardsControl < Struct.new(
  :standards_control_arn,
  :control_status,
  :disabled_reason,
  :control_status_updated_at,
  :control_id,
  :title,
  :description,
  :remediation_url,
  :severity_rating,
  :related_requirements)
  SENSITIVE = []
  include Aws::Structure
end

#control_status_updated_atTime

The date and time that the status of the security standard control was most recently updated.

Returns:

  • (Time)


33283
33284
33285
33286
33287
33288
33289
33290
33291
33292
33293
33294
33295
33296
# File 'lib/aws-sdk-securityhub/types.rb', line 33283

class StandardsControl < Struct.new(
  :standards_control_arn,
  :control_status,
  :disabled_reason,
  :control_status_updated_at,
  :control_id,
  :title,
  :description,
  :remediation_url,
  :severity_rating,
  :related_requirements)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The longer description of the security standard control. Provides information about what the control is checking for.

Returns:

  • (String)


33283
33284
33285
33286
33287
33288
33289
33290
33291
33292
33293
33294
33295
33296
# File 'lib/aws-sdk-securityhub/types.rb', line 33283

class StandardsControl < Struct.new(
  :standards_control_arn,
  :control_status,
  :disabled_reason,
  :control_status_updated_at,
  :control_id,
  :title,
  :description,
  :remediation_url,
  :severity_rating,
  :related_requirements)
  SENSITIVE = []
  include Aws::Structure
end

#disabled_reasonString

The reason provided for the most recent change in status for the control.

Returns:

  • (String)


33283
33284
33285
33286
33287
33288
33289
33290
33291
33292
33293
33294
33295
33296
# File 'lib/aws-sdk-securityhub/types.rb', line 33283

class StandardsControl < Struct.new(
  :standards_control_arn,
  :control_status,
  :disabled_reason,
  :control_status_updated_at,
  :control_id,
  :title,
  :description,
  :remediation_url,
  :severity_rating,
  :related_requirements)
  SENSITIVE = []
  include Aws::Structure
end

The list of requirements that are related to this control.

Returns:

  • (Array<String>)


33283
33284
33285
33286
33287
33288
33289
33290
33291
33292
33293
33294
33295
33296
# File 'lib/aws-sdk-securityhub/types.rb', line 33283

class StandardsControl < Struct.new(
  :standards_control_arn,
  :control_status,
  :disabled_reason,
  :control_status_updated_at,
  :control_id,
  :title,
  :description,
  :remediation_url,
  :severity_rating,
  :related_requirements)
  SENSITIVE = []
  include Aws::Structure
end

#remediation_urlString

A link to remediation information for the control in the Security Hub CSPM user documentation.

Returns:

  • (String)


33283
33284
33285
33286
33287
33288
33289
33290
33291
33292
33293
33294
33295
33296
# File 'lib/aws-sdk-securityhub/types.rb', line 33283

class StandardsControl < Struct.new(
  :standards_control_arn,
  :control_status,
  :disabled_reason,
  :control_status_updated_at,
  :control_id,
  :title,
  :description,
  :remediation_url,
  :severity_rating,
  :related_requirements)
  SENSITIVE = []
  include Aws::Structure
end

#severity_ratingString

The severity of findings generated from this security standard control.

The finding severity is based on an assessment of how easy it would be to compromise Amazon Web Services resources if the issue is detected.

Returns:

  • (String)


33283
33284
33285
33286
33287
33288
33289
33290
33291
33292
33293
33294
33295
33296
# File 'lib/aws-sdk-securityhub/types.rb', line 33283

class StandardsControl < Struct.new(
  :standards_control_arn,
  :control_status,
  :disabled_reason,
  :control_status_updated_at,
  :control_id,
  :title,
  :description,
  :remediation_url,
  :severity_rating,
  :related_requirements)
  SENSITIVE = []
  include Aws::Structure
end

#standards_control_arnString

The ARN of the security standard control.

Returns:

  • (String)


33283
33284
33285
33286
33287
33288
33289
33290
33291
33292
33293
33294
33295
33296
# File 'lib/aws-sdk-securityhub/types.rb', line 33283

class StandardsControl < Struct.new(
  :standards_control_arn,
  :control_status,
  :disabled_reason,
  :control_status_updated_at,
  :control_id,
  :title,
  :description,
  :remediation_url,
  :severity_rating,
  :related_requirements)
  SENSITIVE = []
  include Aws::Structure
end

#titleString

The title of the security standard control.

Returns:

  • (String)


33283
33284
33285
33286
33287
33288
33289
33290
33291
33292
33293
33294
33295
33296
# File 'lib/aws-sdk-securityhub/types.rb', line 33283

class StandardsControl < Struct.new(
  :standards_control_arn,
  :control_status,
  :disabled_reason,
  :control_status_updated_at,
  :control_id,
  :title,
  :description,
  :remediation_url,
  :severity_rating,
  :related_requirements)
  SENSITIVE = []
  include Aws::Structure
end