Class: Aws::SecurityHub::Types::StandardsStatusReason
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::StandardsStatusReason
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
The reason for the current status of your subscription to the standard.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#status_reason_code ⇒ String
The reason code that represents the reason for the current status of a standard subscription.
Instance Attribute Details
#status_reason_code ⇒ String
The reason code that represents the reason for the current status of a standard subscription.
32195 32196 32197 32198 32199 |
# File 'lib/aws-sdk-securityhub/types.rb', line 32195 class StandardsStatusReason < Struct.new( :status_reason_code) SENSITIVE = [] include Aws::Structure end |