Class: Aws::SecurityHub::Types::StandardsSubscription
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::StandardsSubscription
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
A resource that represents your subscription to a supported standard.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#standards_arn ⇒ String
The ARN of the standard.
-
#standards_controls_updatable ⇒ String
Specifies whether you can retrieve information about and configure individual controls that apply to the standard.
-
#standards_input ⇒ Hash<String,String>
A key-value pair of input for the standard.
-
#standards_status ⇒ String
The status of your subscription to the standard.
-
#standards_status_reason ⇒ Types::StandardsStatusReason
The reason for the current status.
-
#standards_subscription_arn ⇒ String
The ARN of the resource that represents your subscription to the standard.
Instance Attribute Details
#standards_arn ⇒ String
The ARN of the standard.
32254 32255 32256 32257 32258 32259 32260 32261 32262 32263 |
# File 'lib/aws-sdk-securityhub/types.rb', line 32254 class StandardsSubscription < Struct.new( :standards_subscription_arn, :standards_arn, :standards_input, :standards_status, :standards_controls_updatable, :standards_status_reason) SENSITIVE = [] include Aws::Structure end |
#standards_controls_updatable ⇒ String
Specifies whether you can retrieve information about and configure individual controls that apply to the standard. Possible values are:
-
READY_FOR_UPDATES- Controls in the standard can be retrieved and configured. -
NOT_READY_FOR_UPDATES- Controls in the standard cannot be retrieved or configured.
32254 32255 32256 32257 32258 32259 32260 32261 32262 32263 |
# File 'lib/aws-sdk-securityhub/types.rb', line 32254 class StandardsSubscription < Struct.new( :standards_subscription_arn, :standards_arn, :standards_input, :standards_status, :standards_controls_updatable, :standards_status_reason) SENSITIVE = [] include Aws::Structure end |
#standards_input ⇒ Hash<String,String>
A key-value pair of input for the standard.
32254 32255 32256 32257 32258 32259 32260 32261 32262 32263 |
# File 'lib/aws-sdk-securityhub/types.rb', line 32254 class StandardsSubscription < Struct.new( :standards_subscription_arn, :standards_arn, :standards_input, :standards_status, :standards_controls_updatable, :standards_status_reason) SENSITIVE = [] include Aws::Structure end |
#standards_status ⇒ String
The status of your subscription to the standard. Possible values are:
-
PENDING- The standard is in the process of being enabled. Or the standard is already enabled and Security Hub CSPM is adding new controls to the standard. -
READY- The standard is enabled. -
INCOMPLETE- The standard could not be enabled completely. One or more errors (StandardsStatusReason) occurred when Security Hub CSPM attempted to enable the standard. -
DELETING- The standard is in the process of being disabled. -
FAILED- The standard could not be disabled. One or more errors (StandardsStatusReason) occurred when Security Hub CSPM attempted to disable the standard.
32254 32255 32256 32257 32258 32259 32260 32261 32262 32263 |
# File 'lib/aws-sdk-securityhub/types.rb', line 32254 class StandardsSubscription < Struct.new( :standards_subscription_arn, :standards_arn, :standards_input, :standards_status, :standards_controls_updatable, :standards_status_reason) SENSITIVE = [] include Aws::Structure end |
#standards_status_reason ⇒ Types::StandardsStatusReason
The reason for the current status.
32254 32255 32256 32257 32258 32259 32260 32261 32262 32263 |
# File 'lib/aws-sdk-securityhub/types.rb', line 32254 class StandardsSubscription < Struct.new( :standards_subscription_arn, :standards_arn, :standards_input, :standards_status, :standards_controls_updatable, :standards_status_reason) SENSITIVE = [] include Aws::Structure end |
#standards_subscription_arn ⇒ String
The ARN of the resource that represents your subscription to the standard.
32254 32255 32256 32257 32258 32259 32260 32261 32262 32263 |
# File 'lib/aws-sdk-securityhub/types.rb', line 32254 class StandardsSubscription < Struct.new( :standards_subscription_arn, :standards_arn, :standards_input, :standards_status, :standards_controls_updatable, :standards_status_reason) SENSITIVE = [] include Aws::Structure end |