Class: Aws::SecurityHub::Types::StatusReason
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::StatusReason
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Provides additional context for the value of Compliance.Status.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
The corresponding description for the status reason code.
-
#reason_code ⇒ String
A code that represents a reason for the control status.
Instance Attribute Details
#description ⇒ String
The corresponding description for the status reason code.
33647 33648 33649 33650 33651 33652 |
# File 'lib/aws-sdk-securityhub/types.rb', line 33647 class StatusReason < Struct.new( :reason_code, :description) SENSITIVE = [] include Aws::Structure end |
#reason_code ⇒ String
A code that represents a reason for the control status. For the list of status reason codes and their meanings, see Compliance details for control findings in the Security Hub CSPM User Guide.
33647 33648 33649 33650 33651 33652 |
# File 'lib/aws-sdk-securityhub/types.rb', line 33647 class StatusReason < Struct.new( :reason_code, :description) SENSITIVE = [] include Aws::Structure end |