Class: Aws::SecurityHub::Types::ThreatIntelIndicator
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::ThreatIntelIndicator
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Details about the threat intelligence related to a finding.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#category ⇒ String
The category of a threat intelligence indicator.
-
#last_observed_at ⇒ String
Indicates when the most recent instance of a threat intelligence indicator was observed.
-
#source ⇒ String
The source of the threat intelligence indicator.
-
#source_url ⇒ String
The URL to the page or site where you can get more information about the threat intelligence indicator.
-
#type ⇒ String
The type of threat intelligence indicator.
-
#value ⇒ String
The value of a threat intelligence indicator.
Instance Attribute Details
#category ⇒ String
The category of a threat intelligence indicator.
33962 33963 33964 33965 33966 33967 33968 33969 33970 33971 |
# File 'lib/aws-sdk-securityhub/types.rb', line 33962 class ThreatIntelIndicator < Struct.new( :type, :value, :category, :last_observed_at, :source, :source_url) SENSITIVE = [] include Aws::Structure end |
#last_observed_at ⇒ String
Indicates when the most recent instance of a threat intelligence indicator was observed.
For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.
33962 33963 33964 33965 33966 33967 33968 33969 33970 33971 |
# File 'lib/aws-sdk-securityhub/types.rb', line 33962 class ThreatIntelIndicator < Struct.new( :type, :value, :category, :last_observed_at, :source, :source_url) SENSITIVE = [] include Aws::Structure end |
#source ⇒ String
The source of the threat intelligence indicator.
Length Constraints: Minimum of 1 length. Maximum of 64 length.
33962 33963 33964 33965 33966 33967 33968 33969 33970 33971 |
# File 'lib/aws-sdk-securityhub/types.rb', line 33962 class ThreatIntelIndicator < Struct.new( :type, :value, :category, :last_observed_at, :source, :source_url) SENSITIVE = [] include Aws::Structure end |
#source_url ⇒ String
The URL to the page or site where you can get more information about the threat intelligence indicator.
33962 33963 33964 33965 33966 33967 33968 33969 33970 33971 |
# File 'lib/aws-sdk-securityhub/types.rb', line 33962 class ThreatIntelIndicator < Struct.new( :type, :value, :category, :last_observed_at, :source, :source_url) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of threat intelligence indicator.
33962 33963 33964 33965 33966 33967 33968 33969 33970 33971 |
# File 'lib/aws-sdk-securityhub/types.rb', line 33962 class ThreatIntelIndicator < Struct.new( :type, :value, :category, :last_observed_at, :source, :source_url) SENSITIVE = [] include Aws::Structure end |
#value ⇒ String
The value of a threat intelligence indicator.
Length Constraints: Minimum of 1 length. Maximum of 512 length.
33962 33963 33964 33965 33966 33967 33968 33969 33970 33971 |
# File 'lib/aws-sdk-securityhub/types.rb', line 33962 class ThreatIntelIndicator < Struct.new( :type, :value, :category, :last_observed_at, :source, :source_url) SENSITIVE = [] include Aws::Structure end |