Class: Aws::SecurityHub::Types::UpdateAutomationRulesRequestItem
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::UpdateAutomationRulesRequestItem
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Specifies the parameters to update in an existing automation rule.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#actions ⇒ Array<Types::AutomationRulesAction>
One or more actions to update finding fields if a finding matches the conditions specified in ‘Criteria`.
-
#criteria ⇒ Types::AutomationRulesFindingFilters
A set of ASFF finding field attributes and corresponding expected values that Security Hub CSPM uses to filter findings.
-
#description ⇒ String
A description of the rule.
-
#is_terminal ⇒ Boolean
Specifies whether a rule is the last to be applied with respect to a finding that matches the rule criteria.
-
#rule_arn ⇒ String
The Amazon Resource Name (ARN) for the rule.
-
#rule_name ⇒ String
The name of the rule.
-
#rule_order ⇒ Integer
An integer ranging from 1 to 1000 that represents the order in which the rule action is applied to findings.
-
#rule_status ⇒ String
Whether the rule is active after it is created.
Instance Attribute Details
#actions ⇒ Array<Types::AutomationRulesAction>
One or more actions to update finding fields if a finding matches the conditions specified in ‘Criteria`.
33545 33546 33547 33548 33549 33550 33551 33552 33553 33554 33555 33556 |
# File 'lib/aws-sdk-securityhub/types.rb', line 33545 class UpdateAutomationRulesRequestItem < Struct.new( :rule_arn, :rule_status, :rule_order, :description, :rule_name, :is_terminal, :criteria, :actions) SENSITIVE = [] include Aws::Structure end |
#criteria ⇒ Types::AutomationRulesFindingFilters
A set of ASFF finding field attributes and corresponding expected values that Security Hub CSPM uses to filter findings. If a rule is enabled and a finding matches the conditions specified in this parameter, Security Hub CSPM applies the rule action to the finding.
33545 33546 33547 33548 33549 33550 33551 33552 33553 33554 33555 33556 |
# File 'lib/aws-sdk-securityhub/types.rb', line 33545 class UpdateAutomationRulesRequestItem < Struct.new( :rule_arn, :rule_status, :rule_order, :description, :rule_name, :is_terminal, :criteria, :actions) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the rule.
33545 33546 33547 33548 33549 33550 33551 33552 33553 33554 33555 33556 |
# File 'lib/aws-sdk-securityhub/types.rb', line 33545 class UpdateAutomationRulesRequestItem < Struct.new( :rule_arn, :rule_status, :rule_order, :description, :rule_name, :is_terminal, :criteria, :actions) SENSITIVE = [] include Aws::Structure end |
#is_terminal ⇒ Boolean
Specifies whether a rule is the last to be applied with respect to a finding that matches the rule criteria. This is useful when a finding matches the criteria for multiple rules, and each rule has different actions. If a rule is terminal, Security Hub CSPM applies the rule action to a finding that matches the rule criteria and doesn’t evaluate other rules for the finding. By default, a rule isn’t terminal.
33545 33546 33547 33548 33549 33550 33551 33552 33553 33554 33555 33556 |
# File 'lib/aws-sdk-securityhub/types.rb', line 33545 class UpdateAutomationRulesRequestItem < Struct.new( :rule_arn, :rule_status, :rule_order, :description, :rule_name, :is_terminal, :criteria, :actions) SENSITIVE = [] include Aws::Structure end |
#rule_arn ⇒ String
The Amazon Resource Name (ARN) for the rule.
33545 33546 33547 33548 33549 33550 33551 33552 33553 33554 33555 33556 |
# File 'lib/aws-sdk-securityhub/types.rb', line 33545 class UpdateAutomationRulesRequestItem < Struct.new( :rule_arn, :rule_status, :rule_order, :description, :rule_name, :is_terminal, :criteria, :actions) SENSITIVE = [] include Aws::Structure end |
#rule_name ⇒ String
The name of the rule.
33545 33546 33547 33548 33549 33550 33551 33552 33553 33554 33555 33556 |
# File 'lib/aws-sdk-securityhub/types.rb', line 33545 class UpdateAutomationRulesRequestItem < Struct.new( :rule_arn, :rule_status, :rule_order, :description, :rule_name, :is_terminal, :criteria, :actions) SENSITIVE = [] include Aws::Structure end |
#rule_order ⇒ Integer
An integer ranging from 1 to 1000 that represents the order in which the rule action is applied to findings. Security Hub CSPM applies rules with lower values for this parameter first.
33545 33546 33547 33548 33549 33550 33551 33552 33553 33554 33555 33556 |
# File 'lib/aws-sdk-securityhub/types.rb', line 33545 class UpdateAutomationRulesRequestItem < Struct.new( :rule_arn, :rule_status, :rule_order, :description, :rule_name, :is_terminal, :criteria, :actions) SENSITIVE = [] include Aws::Structure end |
#rule_status ⇒ String
Whether the rule is active after it is created. If this parameter is equal to ‘ENABLED`, Security Hub CSPM starts applying the rule to findings and finding updates after the rule is created. To change the value of this parameter after creating a rule, use [ `BatchUpdateAutomationRules` ][1].
[1]: docs.aws.amazon.com/securityhub/1.0/APIReference/API_BatchUpdateAutomationRules.html
33545 33546 33547 33548 33549 33550 33551 33552 33553 33554 33555 33556 |
# File 'lib/aws-sdk-securityhub/types.rb', line 33545 class UpdateAutomationRulesRequestItem < Struct.new( :rule_arn, :rule_status, :rule_order, :description, :rule_name, :is_terminal, :criteria, :actions) SENSITIVE = [] include Aws::Structure end |