Class: Aws::SecurityHub::Types::UpdateConfigurationPolicyResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::UpdateConfigurationPolicyResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The ARN of the configuration policy.
-
#configuration_policy ⇒ Types::Policy
An object that defines how Security Hub CSPM is configured.
-
#created_at ⇒ Time
The date and time, in UTC and ISO 8601 format, that the configuration policy was created.
-
#description ⇒ String
The description of the configuration policy.
-
#id ⇒ String
The UUID of the configuration policy.
-
#name ⇒ String
The name of the configuration policy.
-
#updated_at ⇒ Time
The date and time, in UTC and ISO 8601 format, that the configuration policy was last updated.
Instance Attribute Details
#arn ⇒ String
The ARN of the configuration policy.
34680 34681 34682 34683 34684 34685 34686 34687 34688 34689 34690 |
# File 'lib/aws-sdk-securityhub/types.rb', line 34680 class UpdateConfigurationPolicyResponse < Struct.new( :arn, :id, :name, :description, :updated_at, :created_at, :configuration_policy) SENSITIVE = [] include Aws::Structure end |
#configuration_policy ⇒ Types::Policy
An object that defines how Security Hub CSPM is configured. It includes whether Security Hub CSPM is enabled or disabled, a list of enabled security standards, a list of enabled or disabled security controls, and a list of custom parameter values for specified controls. If the request included a list of security controls that are enabled in the configuration policy, Security Hub CSPM disables all other controls (including newly released controls). If the request included a list of security controls that are disabled in the configuration policy, Security Hub CSPM enables all other controls (including newly released controls).
34680 34681 34682 34683 34684 34685 34686 34687 34688 34689 34690 |
# File 'lib/aws-sdk-securityhub/types.rb', line 34680 class UpdateConfigurationPolicyResponse < Struct.new( :arn, :id, :name, :description, :updated_at, :created_at, :configuration_policy) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The date and time, in UTC and ISO 8601 format, that the configuration policy was created.
34680 34681 34682 34683 34684 34685 34686 34687 34688 34689 34690 |
# File 'lib/aws-sdk-securityhub/types.rb', line 34680 class UpdateConfigurationPolicyResponse < Struct.new( :arn, :id, :name, :description, :updated_at, :created_at, :configuration_policy) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the configuration policy.
34680 34681 34682 34683 34684 34685 34686 34687 34688 34689 34690 |
# File 'lib/aws-sdk-securityhub/types.rb', line 34680 class UpdateConfigurationPolicyResponse < Struct.new( :arn, :id, :name, :description, :updated_at, :created_at, :configuration_policy) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The UUID of the configuration policy.
34680 34681 34682 34683 34684 34685 34686 34687 34688 34689 34690 |
# File 'lib/aws-sdk-securityhub/types.rb', line 34680 class UpdateConfigurationPolicyResponse < Struct.new( :arn, :id, :name, :description, :updated_at, :created_at, :configuration_policy) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the configuration policy.
34680 34681 34682 34683 34684 34685 34686 34687 34688 34689 34690 |
# File 'lib/aws-sdk-securityhub/types.rb', line 34680 class UpdateConfigurationPolicyResponse < Struct.new( :arn, :id, :name, :description, :updated_at, :created_at, :configuration_policy) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The date and time, in UTC and ISO 8601 format, that the configuration policy was last updated.
34680 34681 34682 34683 34684 34685 34686 34687 34688 34689 34690 |
# File 'lib/aws-sdk-securityhub/types.rb', line 34680 class UpdateConfigurationPolicyResponse < Struct.new( :arn, :id, :name, :description, :updated_at, :created_at, :configuration_policy) SENSITIVE = [] include Aws::Structure end |