Class: Aws::SecurityHub::Types::UpdateConnectorResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::UpdateConnectorResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#connector_status ⇒ String
The connectivity status of the connector after the update.
-
#enablement_status ⇒ String
The enablement status of the connector after the update.
Instance Attribute Details
#connector_status ⇒ String
The connectivity status of the connector after the update.
34584 34585 34586 34587 34588 34589 |
# File 'lib/aws-sdk-securityhub/types.rb', line 34584 class UpdateConnectorResponse < Struct.new( :connector_status, :enablement_status) SENSITIVE = [] include Aws::Structure end |
#enablement_status ⇒ String
The enablement status of the connector after the update.
34584 34585 34586 34587 34588 34589 |
# File 'lib/aws-sdk-securityhub/types.rb', line 34584 class UpdateConnectorResponse < Struct.new( :connector_status, :enablement_status) SENSITIVE = [] include Aws::Structure end |