Class: Aws::SecurityHub::Types::UpdateFindingAggregatorRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::UpdateFindingAggregatorRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#finding_aggregator_arn ⇒ String
The ARN of the finding aggregator.
-
#region_linking_mode ⇒ String
Indicates whether to aggregate findings from all of the available Regions in the current partition.
-
#regions ⇒ Array<String>
If ‘RegionLinkingMode` is `ALL_REGIONS_EXCEPT_SPECIFIED`, then this is a space-separated list of Regions that don’t replicate and send findings to the home Region.
Instance Attribute Details
#finding_aggregator_arn ⇒ String
The ARN of the finding aggregator. To obtain the ARN, use ‘ListFindingAggregators`.
33382 33383 33384 33385 33386 33387 33388 |
# File 'lib/aws-sdk-securityhub/types.rb', line 33382 class UpdateFindingAggregatorRequest < Struct.new( :finding_aggregator_arn, :region_linking_mode, :regions) SENSITIVE = [] include Aws::Structure end |
#region_linking_mode ⇒ String
Indicates whether to aggregate findings from all of the available Regions in the current partition. Also determines whether to automatically aggregate findings from new Regions as Security Hub CSPM supports them and you opt into them.
The selected option also determines how to use the Regions provided in the Regions list.
The options are as follows:
-
‘ALL_REGIONS` - Aggregates findings from all of the Regions where Security Hub CSPM is enabled. When you choose this option, Security Hub CSPM also automatically aggregates findings from new Regions as Security Hub CSPM supports them and you opt into them.
-
‘ALL_REGIONS_EXCEPT_SPECIFIED` - Aggregates findings from all of the Regions where Security Hub CSPM is enabled, except for the Regions listed in the `Regions` parameter. When you choose this option, Security Hub CSPM also automatically aggregates findings from new Regions as Security Hub CSPM supports them and you opt into them.
-
‘SPECIFIED_REGIONS` - Aggregates findings only from the Regions listed in the `Regions` parameter. Security Hub CSPM does not automatically aggregate findings from new Regions.
-
‘NO_REGIONS` - Aggregates no data because no Regions are selected as linked Regions.
33382 33383 33384 33385 33386 33387 33388 |
# File 'lib/aws-sdk-securityhub/types.rb', line 33382 class UpdateFindingAggregatorRequest < Struct.new( :finding_aggregator_arn, :region_linking_mode, :regions) SENSITIVE = [] include Aws::Structure end |
#regions ⇒ Array<String>
If ‘RegionLinkingMode` is `ALL_REGIONS_EXCEPT_SPECIFIED`, then this is a space-separated list of Regions that don’t replicate and send findings to the home Region.
If ‘RegionLinkingMode` is `SPECIFIED_REGIONS`, then this is a space-separated list of Regions that do replicate and send findings to the home Region.
An ‘InvalidInputException` error results if you populate this field while `RegionLinkingMode` is `NO_REGIONS`.
33382 33383 33384 33385 33386 33387 33388 |
# File 'lib/aws-sdk-securityhub/types.rb', line 33382 class UpdateFindingAggregatorRequest < Struct.new( :finding_aggregator_arn, :region_linking_mode, :regions) SENSITIVE = [] include Aws::Structure end |