Class: Aws::SecurityHub::Types::UserAccount
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::UserAccount
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Provides Amazon Web Services account information of the user involved in an Amazon GuardDuty Extended Threat Detection attack sequence. GuardDuty generates an attack sequence finding when multiple events align to a potentially suspicious activity. To receive GuardDuty attack sequence findings in Security Hub CSPM, you must have GuardDuty enabled. For more information, see GuardDuty Extended Threat Detection in the Amazon GuardDuty User Guide.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#name ⇒ String
The name of the user account involved in the attack sequence.
-
#uid ⇒ String
The unique identifier of the user account involved in the attack sequence.
Instance Attribute Details
#name ⇒ String
The name of the user account involved in the attack sequence.
34962 34963 34964 34965 34966 34967 |
# File 'lib/aws-sdk-securityhub/types.rb', line 34962 class UserAccount < Struct.new( :uid, :name) SENSITIVE = [] include Aws::Structure end |
#uid ⇒ String
The unique identifier of the user account involved in the attack sequence.
34962 34963 34964 34965 34966 34967 |
# File 'lib/aws-sdk-securityhub/types.rb', line 34962 class UserAccount < Struct.new( :uid, :name) SENSITIVE = [] include Aws::Structure end |