Class: Aws::SecurityHub::Types::VulnerabilityVendor
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::VulnerabilityVendor
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
A vendor that generates a vulnerability report.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#name ⇒ String
The name of the vendor.
-
#url ⇒ String
The URL of the vulnerability advisory.
-
#vendor_created_at ⇒ String
Indicates when the vulnerability advisory was created.
-
#vendor_severity ⇒ String
The severity that the vendor assigned to the vulnerability.
-
#vendor_updated_at ⇒ String
Indicates when the vulnerability advisory was last updated.
Instance Attribute Details
#name ⇒ String
The name of the vendor.
35350 35351 35352 35353 35354 35355 35356 35357 35358 |
# File 'lib/aws-sdk-securityhub/types.rb', line 35350 class VulnerabilityVendor < Struct.new( :name, :url, :vendor_severity, :vendor_created_at, :vendor_updated_at) SENSITIVE = [] include Aws::Structure end |
#url ⇒ String
The URL of the vulnerability advisory.
35350 35351 35352 35353 35354 35355 35356 35357 35358 |
# File 'lib/aws-sdk-securityhub/types.rb', line 35350 class VulnerabilityVendor < Struct.new( :name, :url, :vendor_severity, :vendor_created_at, :vendor_updated_at) SENSITIVE = [] include Aws::Structure end |
#vendor_created_at ⇒ String
Indicates when the vulnerability advisory was created.
For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.
35350 35351 35352 35353 35354 35355 35356 35357 35358 |
# File 'lib/aws-sdk-securityhub/types.rb', line 35350 class VulnerabilityVendor < Struct.new( :name, :url, :vendor_severity, :vendor_created_at, :vendor_updated_at) SENSITIVE = [] include Aws::Structure end |
#vendor_severity ⇒ String
The severity that the vendor assigned to the vulnerability.
35350 35351 35352 35353 35354 35355 35356 35357 35358 |
# File 'lib/aws-sdk-securityhub/types.rb', line 35350 class VulnerabilityVendor < Struct.new( :name, :url, :vendor_severity, :vendor_created_at, :vendor_updated_at) SENSITIVE = [] include Aws::Structure end |
#vendor_updated_at ⇒ String
Indicates when the vulnerability advisory was last updated.
For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps.
35350 35351 35352 35353 35354 35355 35356 35357 35358 |
# File 'lib/aws-sdk-securityhub/types.rb', line 35350 class VulnerabilityVendor < Struct.new( :name, :url, :vendor_severity, :vendor_created_at, :vendor_updated_at) SENSITIVE = [] include Aws::Structure end |