Class: Aws::SecurityHub::Types::WorkflowUpdate
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityHub::Types::WorkflowUpdate
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityhub/types.rb
Overview
Used to update information about the investigation into the finding.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#status ⇒ String
The status of the investigation into the finding.
Instance Attribute Details
#status ⇒ String
The status of the investigation into the finding. The workflow
status is specific to an individual finding. It does not affect the
generation of new findings. For example, setting the workflow status
to SUPPRESSED or RESOLVED does not prevent a new finding for the
same issue.
The allowed values are the following.
-
NEW- The initial state of a finding, before it is reviewed.Security Hub CSPM also resets
WorkFlowStatusfromNOTIFIEDorRESOLVEDtoNEWin the following cases: -
The record state changes from
ARCHIVEDtoACTIVE. -
The compliance status changes from
PASSEDto eitherWARNING,FAILED, orNOT_AVAILABLE. -
NOTIFIED- Indicates that you notified the resource owner about the security issue. Used when the initial reviewer is not the resource owner, and needs intervention from the resource owner. -
RESOLVED- The finding was reviewed and remediated and is now considered resolved. -
SUPPRESSED- Indicates that you reviewed the finding and don't believe that any action is needed. The finding is no longer updated.
35352 35353 35354 35355 35356 |
# File 'lib/aws-sdk-securityhub/types.rb', line 35352 class WorkflowUpdate < Struct.new( :status) SENSITIVE = [] include Aws::Structure end |